@@ -24,16 +24,13 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
      */
     protected $_db;
     
-    /**
-     * @var Tinebase_Backend_Sql
-     */
-    protected $_rolesBackend;
-    
     protected $_classCache = array(
         'getRoleMemberships' => array(),
         'hasRight'           => array(),
     );
 
+    protected $_allowDeleteDefaulRoles = false;
+
     protected static $injectRoleMembers;
 
     /**
@@ -59,13 +56,14 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
      */
     protected function __construct()
     {
-        $this->_applicationName = 'Tinebase';
-        $this->_modelName = 'Tinebase_Model_Role';
+        $this->_applicationName = Tinebase_Config::APP_NAME;
+        $this->_modelName = Tinebase_Model_Role::class;
         $this->_backend = new Tinebase_Backend_Sql(array(
-            'modelName' => 'Tinebase_Model_Role',
-            'tableName' => 'roles',
+            Tinebase_Backend_Sql::MODEL_NAME    => Tinebase_Model_Role::class,
+            Tinebase_Backend_Sql::TABLE_NAME    => 'roles',
+            Tinebase_Backend_Sql::MODLOG_ACTIVE => true,
         ), $this->_getDb());
-        //$this->_purgeRecords = TRUE;
+        $this->_purgeRecords = false;
         //$this->_resolveCustomFields = FALSE;
         $this->_updateMultipleValidateEachRecord = TRUE;
         $this->_doContainerACLChecks = FALSE;
@@ -119,12 +117,8 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
         }
         
         if (empty($roleMemberships)) {
-            Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__ . ' ' . $_accountId . ' has no role/group memberships.');
-            if (is_object(Tinebase_Core::getUser()) && Tinebase_Core::getUser()->getId() === $_accountId) {
-                // @todo throw exception in this case?
-                Tinebase_Session::destroyAndRemoveCookie();
-            }
-            
+            $message = 'User ' .  $_accountId . ' has no role/group memberships';
+            Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__ . ' ' . $message);
             return false;
         }
         
@@ -154,7 +148,14 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
         
         $applicationId = $application->getId();
         
-        return isset($rights[$applicationId]) && (isset($rights[$applicationId][$_right]) || isset($rights[$applicationId][Tinebase_Acl_Rights::ADMIN]));
+        $result = isset($rights[$applicationId]) && (isset($rights[$applicationId][$_right]) || isset($rights[$applicationId][Tinebase_Acl_Rights::ADMIN]));
+        if (!$result) {
+            $appCtrl = Tinebase_Core::getApplicationInstance($application->name, '', true);
+            if (method_exists($appCtrl, 'hasImplicitRight')) {
+                $result = $appCtrl->hasImplicitRight($_accountId, $_right);
+            }
+        }
+        return $result;
     }
     
     /**
@@ -258,7 +259,7 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
     public function getRoleById($_roleId)
     {
         /** @var Tinebase_Model_Role $role */
-        $role = $this->_getRolesBackend()->get((string)$_roleId);
+        $role = $this->_backend->get((string)$_roleId);
         return $role;
     }
     
@@ -272,7 +273,7 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
     public function getRoleByName($_roleName)
     {
         /** @var Tinebase_Model_Role $role */
-        $role = $this->_getRolesBackend()->getByProperty($_roleName, 'name');
+        $role = $this->_backend->getByProperty($_roleName, 'name');
         return $role;
     }
 
@@ -287,7 +288,7 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
      */
     public function getMultiple($_ids, $_ignoreACL = false, Tinebase_Record_Expander $_expander = null, $_getDeleted = false)
     {
-        return $this->_getRolesBackend()->getMultiple($_ids, $_ignoreACL, $_expander, $_getDeleted);
+        return $this->_backend->getMultiple($_ids, $_ignoreACL, $_expander, $_getDeleted);
     }
     
     /**
@@ -319,7 +320,44 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
         
         return $role;
     }
-    
+
+    /**
+     * @param Tinebase_Model_Role $updatedRecord
+     * @param Tinebase_Model_Role $record
+     * @param Tinebase_Model_Role $currentRecord
+     */
+    protected function _inspectAfterUpdate($updatedRecord, $record, $currentRecord)
+    {
+        parent::_inspectAfterUpdate($updatedRecord, $record, $currentRecord); // TODO: Change the autogenerated stub
+
+        if ($updatedRecord->name !== $currentRecord->name) {
+            if (Tinebase_Config::getInstance()->{Tinebase_Config::DEFAULT_ADMIN_ROLE_NAME} === $currentRecord->name) {
+                Tinebase_Config::getInstance()->{Tinebase_Config::DEFAULT_ADMIN_ROLE_NAME} = $updatedRecord->name;
+            } elseif (Tinebase_Config::getInstance()->{Tinebase_Config::DEFAULT_USER_ROLE_NAME} === $currentRecord->name) {
+                Tinebase_Config::getInstance()->{Tinebase_Config::DEFAULT_USER_ROLE_NAME} = $updatedRecord->name;
+            }
+        }
+    }
+
+    protected function _inspectDelete(array $_ids)
+    {
+        $_ids = parent::_inspectDelete($_ids);
+
+        if (!$this->_allowDeleteDefaulRoles) {
+            foreach ($this->_backend->getMultiple($_ids) as $role) {
+                if (Tinebase_Config::getInstance()->{Tinebase_Config::DEFAULT_ADMIN_ROLE_NAME} === $role->name) {
+                    Tinebase_Core::getLogger()->err(__METHOD__ . '::' . __LINE__ . ' default admin role can\'t be deleted');
+                    unset($_ids[array_search($role->getId(), $_ids)]);
+                } elseif (Tinebase_Config::getInstance()->{Tinebase_Config::DEFAULT_USER_ROLE_NAME} === $role->name) {
+                    Tinebase_Core::getLogger()->err(__METHOD__ . '::' . __LINE__ . ' default user role can\'t be deleted');
+                    unset($_ids[array_search($role->getId(), $_ids)]);
+                }
+            }
+        }
+
+        return $_ids;
+    }
+
     /**
      * Deletes roles identified by their identifiers
      * 
@@ -347,7 +385,9 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
      */
     public function deleteAllRoles()
     {
-        $roleIds = $this->_getRolesBackend()
+        $this->_allowDeleteDefaulRoles = true;
+
+        $roleIds = $this->_backend
             ->getAll()
             ->getArrayOfIds();
         
@@ -482,6 +522,7 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
         $select = $this->_getDb()->select()
             ->distinct()
             ->from(array('role_accounts' => SQL_TABLE_PREFIX . 'role_accounts'), array('role_id'))
+            ->join(['r' => $this->_backend->getTablePrefix() . $this->_backend->getTableName()], 'role_accounts.role_id = r.id AND r.is_deleted = 0', [])
             ->where($this->_getDb()->quoteInto($this->_getDb()->quoteIdentifier('account_id') . ' = ?', $accountId) . ' AND ' 
                 . $this->_getDb()->quoteInto($this->_getDb()->quoteIdentifier('account_type') . ' = ?', $type));
         
@@ -635,7 +676,7 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
     {
         $seq = intval($_oldRole->seq);
         $_oldRole->seq = $seq + 1;
-        $this->_getRolesBackend()->update($_oldRole);
+        $this->_backend->update($_oldRole);
 
         $newRole = $this->get($_oldRole->getId());
         $this->_writeModLog($newRole, $_oldRole);
@@ -949,23 +990,6 @@ class Tinebase_Acl_Roles extends Tinebase_Controller_Record_Abstract
         
         return $this->_db;
     }
-    
-    /**
-     * create backend for roles table
-     * 
-     * @return Tinebase_Backend_Sql
-     */
-    protected function _getRolesBackend()
-    {
-        if (!$this->_rolesBackend) {
-            $this->_rolesBackend = new Tinebase_Backend_Sql(array(
-                'modelName' => 'Tinebase_Model_Role', 
-                'tableName' => 'roles',
-            ), $this->_getDb());
-        }
-        
-        return $this->_rolesBackend;
-    }
 
     /**
      * get by id
