@@ -6,7 +6,7 @@
  * @subpackage  ActionQueue
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Cornelius Weiss <c.weiss@metaways.de>
- * @copyright   Copyright (c) 2012-2018 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2012-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  */
 
 use Zend_RedisProxy as Redis;
@@ -88,8 +88,6 @@ class Tinebase_ActionQueue_Backend_Redis implements Tinebase_ActionQueue_Backend
         $this->_daemonStructName = $this->_options['queueName'] . $this->_options['redisDaemonSuffix'];
         $this->_deadLetterStructName = $this->_options['queueName'] . $this->_options['redisDeadLetterSuffix'];
 
-        // Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . ' options: ' . print_r($this->_options, true));
-
         $this->connect();
     }
 
@@ -134,7 +132,7 @@ class Tinebase_ActionQueue_Backend_Redis implements Tinebase_ActionQueue_Backend
             }
         }
         // remove from redis
-        $this->_redis->lRemove($this->_daemonStructName ,     $jobId, 0);
+        $this->_redis->lRem($this->_daemonStructName ,     $jobId, 0);
         $this->_redis->delete ($this->_dataStructName . ":" . $jobId);
     }
     
@@ -244,7 +242,7 @@ class Tinebase_ActionQueue_Backend_Redis implements Tinebase_ActionQueue_Backend
         $this->_redis->multi()
             ->hIncrBy($this->_dataStructName . ":" . $jobId, 'retry' , 1)
             ->hSet($this->_dataStructName . ':' . $jobId, 'time', time())
-            ->lRemove($this->_daemonStructName , $jobId)
+            ->lRem($this->_daemonStructName , $jobId)
             ->lPush  ($this->_queueStructName,   $jobId)
             ->exec();
     }
@@ -259,15 +257,10 @@ class Tinebase_ActionQueue_Backend_Redis implements Tinebase_ActionQueue_Backend
     {
         try {
             $encodedMessage = serialize($message);
-            
         } catch (Exception $e) {
             Tinebase_Core::getLogger()->err(
-                __METHOD__ . '::' . __LINE__ . " failed to serialize message: '{$message}'");
-            Tinebase_Core::getLogger()->err(
-                __METHOD__ . '::' . __LINE__ . " exception message: " . $e->getMessage());
-            Tinebase_Core::getLogger()->err(
-                __METHOD__ . '::' . __LINE__ . " exception stacktrace: " . $e->getTraceAsString());
-            
+                __METHOD__ . '::' . __LINE__ . ' Failed to serialize message: ' . print_r($message, true));
+            Tinebase_Exception::log($e);
             return null;
         }
         
@@ -323,7 +316,7 @@ class Tinebase_ActionQueue_Backend_Redis implements Tinebase_ActionQueue_Backend
      */
     public function peekJobId()
     {
-        return $this->_redis->lGet($this->_queueStructName, -1);
+        return $this->_redis->lindex($this->_queueStructName, -1);
     }
 
     /**
