@@ -439,7 +439,7 @@ class Setup_Backend_Mysql extends Setup_Backend_Abstract
 
         // hide password from shell via my.cnf
         $mycnf = $backupDir . '/my.cnf';
-        $this->_createMyConf($mycnf, $this->_config->database);
+        $this->createMyConf($mycnf, $this->_config->database);
 
         $ignoreTables = '';
         if (count($option['structTables']) > 0) {
@@ -499,7 +499,7 @@ class Setup_Backend_Mysql extends Setup_Backend_Abstract
 
         // hide password from shell via my.cnf
         $mycnf = $backupDir . '/my.cnf';
-        $this->_createMyConf($mycnf, $this->_config->database);
+        $this->createMyConf($mycnf, $this->_config->database);
 
         $cmd = "bzcat $mysqlBackupFile"
              . " | mysql --defaults-extra-file=$mycnf -f "
@@ -515,12 +515,13 @@ class Setup_Backend_Mysql extends Setup_Backend_Abstract
     /**
      * create my.cnf
      *
-     * @param $path
-     * @param $config
+     * @param string $path
+     * @param Zend_Config|null $config
      */
-    protected function _createMyConf($path, $config)
+    public function createMyConf(string $path, Zend_Config $config = null)
     {
-        $port = $config->port ? $config->port : 3306;
+        $config = $config ?? $this->_config->database;
+        $port = $config->port ?: 3306;
 
         $mycnfData = <<<EOT
 [client]
@@ -529,6 +530,15 @@ port = {$port}
 user = {$config->username}
 password = {$config->password}
 EOT;
+
+        // check mysqldump version
+        $version = exec('mysqldump --version');
+        // TODO find out about version 9+
+        if (preg_match('/Ver 8/', $version)) {
+            $mycnfData .= "\n[mysqldump]
+column-statistics=0\n";
+        }
+
         file_put_contents($path, $mycnfData);
     }
 
