@@ -5,7 +5,7 @@
  * @package     Tinebase
  * @subpackage  Backend
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
- * @copyright   Copyright (c) 2007-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2007-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  * @author      Philipp Schüle <p.schuele@metaways.de>
  * 
  * @todo        think about removing the appendForeignRecord* functions
@@ -175,14 +175,20 @@ abstract class Tinebase_Backend_Sql_Abstract extends Tinebase_Backend_Abstract i
         }
     }
 
-    public function addSelectHook(callable $callable)
+    public function addSelectHook(Tinebase_Backend_Sql_SelectHook $hook): void
     {
-        $this->_selectHooks[] = $callable;
+        if (!isset($this->_selectHooks[$hook->getKey()])) {
+            $this->_selectHooks[$hook->getKey()] = new SplObjectStorage();
+        }
+        $this->_selectHooks[$hook->getKey()]->attach($hook);
     }
 
-    public function resetSelectHooks()
+    public function removeSelectHook(Tinebase_Backend_Sql_SelectHook $hook): void
     {
-        $this->_selectHooks = [];
+        $this->_selectHooks[$hook->getKey()]->detach($hook);
+        if (0 === $this->_selectHooks[$hook->getKey()]->count()) {
+            unset($this->_selectHooks[$hook->getKey()]);
+        }
     }
 
     /*************************** getters and setters *********************************/
@@ -480,6 +486,7 @@ abstract class Tinebase_Backend_Sql_Abstract extends Tinebase_Backend_Abstract i
         
         $stmt = $this->_db->query($select);
         $queryResult = $stmt->fetchAll();
+        $stmt->closeCursor();
         
         $result = $this->_rawDataToRecordSet($queryResult);
         
@@ -511,6 +518,7 @@ abstract class Tinebase_Backend_Sql_Abstract extends Tinebase_Backend_Abstract i
             
         $stmt = $this->_db->query($select);
         $queryResult = $stmt->fetchAll();
+        $stmt->closeCursor();
         
         //if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . ' ' . print_r($queryResult, true));
         
@@ -537,6 +545,9 @@ abstract class Tinebase_Backend_Sql_Abstract extends Tinebase_Backend_Abstract i
             // clone pagination to prevent accidental change of original object
             $pagination = clone($_pagination);
         }
+        if (!$pagination->model) {
+            $pagination->model = $this->_modelName;
+        }
         
         // legacy: $_cols param was $_onlyIds (boolean) ...
         if ($_cols === TRUE) {
@@ -568,7 +579,7 @@ abstract class Tinebase_Backend_Sql_Abstract extends Tinebase_Backend_Abstract i
         
         $this->_addSecondarySort($pagination);
         $this->_appendForeignSort($pagination, $select);
-        $pagination->appendPaginationSql($select);
+        $pagination->appendPaginationSql($select, $getDeleted);
         
         Tinebase_Backend_Sql_Abstract::traitGroup($select);
         
@@ -877,8 +888,10 @@ abstract class Tinebase_Backend_Sql_Abstract extends Tinebase_Backend_Abstract i
         
         $this->_addForeignTableJoins($select, $cols);
 
-        foreach ($this->_selectHooks as $hook) {
-            $hook($select);
+        /** @var SplObjectStorage $objs */
+        foreach ($this->_selectHooks as $objs) {
+            $objs->rewind();
+            $objs->current()->manipulateSelect($select);
         }
         
         return $select;
@@ -1689,8 +1702,7 @@ abstract class Tinebase_Backend_Sql_Abstract extends Tinebase_Backend_Abstract i
     public static function traitGroup(Zend_Db_Select $select)
     {
         // not needed for MySQL backends
-        if ($select->getAdapter() instanceof Zend_Db_Adapter_Pdo_Mysql
-            && ! Setup_Backend_Mysql::dbSupportsVersion($select->getAdapter(), 'mysql >= 8')) {
+        if ($select->getAdapter() instanceof Zend_Db_Adapter_Pdo_Mysql) {
             return;
         }
         
