@@ -38,6 +38,16 @@ class Tinebase_Backend_Sql_Adapter_Pdo_Mysql extends Zend_Db_Adapter_Pdo_Mysql
         }
     }
 
+    public function __sleep()
+    {
+        throw new Tinebase_Exception_Backend_Database('cant serialize db connection');
+    }
+
+    public function __wakeup()
+    {
+        throw new Tinebase_Exception_Backend_Database('cant serialize db connection');
+    }
+
     /**
      * @param $dbConfigArray
      * @return string charset
@@ -77,7 +87,8 @@ class Tinebase_Backend_Sql_Adapter_Pdo_Mysql extends Zend_Db_Adapter_Pdo_Mysql
         if ((false !== $db->query('SHOW TABLES LIKE "' . SQL_TABLE_PREFIX . 'access_log"')->fetchColumn(0) &&
                 ($str = $db->query('SHOW CREATE TABLE ' . SQL_TABLE_PREFIX . 'access_log')->fetchColumn(1)) &&
                 strpos($str, 'utf8mb4') === false
-            ) || (Tinebase_Core::getDbVariable('innodb_large_prefix', $db) !== 'ON' &&
+            ) || (!Setup_Backend_Mysql::dbSupportsVersion($db, 'mysql > 8') &&
+                    Tinebase_Core::getDbVariable('innodb_large_prefix', $db) !== 'ON' &&
                     Setup_Backend_Mysql::dbSupportsVersion($db, 'mariadb < 10.3 | mysql > 5.5')
                 )) {
             Tinebase_Core::getCache()->save(0, $cacheId);
