@@ -4,7 +4,7 @@
  * @subpackage  Config
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Philipp Schüle <p.schuele@metaways.de>
- * @copyright   Copyright (c) 2012-2020 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2012-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  */
 
 /**
@@ -15,6 +15,8 @@
  */
 class Felamimail_Config extends Tinebase_Config_Abstract
 {
+    const APP_NAME = 'Felamimail';
+
     /**
      * is email body cached
      *
@@ -58,6 +60,11 @@ class Felamimail_Config extends Tinebase_Config_Abstract
      */
     const FEATURE_TINE20_FLAG = 'tine20Flag';
 
+    /**
+     * allow only send password download link as attachment
+     */
+    const FEATURE_ONLY_PW_DOWNLOAD_LINK = 'onlyPwDownloadLink';
+
     /**
      * show reply-to field in message compose dialog
      *
@@ -311,6 +318,14 @@ class Felamimail_Config extends Tinebase_Config_Abstract
                     self::TYPE                  => self::TYPE_BOOL,
                     self::DEFAULT_STR           => true,
                 ],
+                self::FEATURE_ONLY_PW_DOWNLOAD_LINK   => [
+                    self::LABEL                 => 'Only password download link',
+                    //_('Only password download link')
+                    self::DESCRIPTION           => 'Allow only password download link',
+                    //_('Allow only password download link')
+                    self::TYPE                  => self::TYPE_BOOL,
+                    self::DEFAULT_STR           => false,
+                ],
                 self::FEATURE_TINE20_FLAG   => [
                     self::LABEL                 => 'Tine 2.0 Flag',
                     //_('Tine 2.0 Flag')
