@@ -4,7 +4,7 @@
  * @subpackage  Config
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Cornelius Weiss <c.weiss@metaways.de>
- * @copyright   Copyright (c) 2011-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2011-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  */
 
 /**
@@ -140,6 +140,13 @@ class Calendar_Config extends Tinebase_Config_Abstract
      * @var string
      */
     const DISABLE_EXTERNAL_IMIP = 'disableExternalImip';
+
+    /**
+     * DISABLE_EXTERNAL_IMIP_NOTIFICATION
+     *
+     * @var string
+     */
+    const DISABLE_EXTERNAL_NOTIFICATIONS = 'disableExternalNotifications';
     
     /**
      * SKIP_DOUBLE_EVENTS
@@ -188,7 +195,6 @@ class Calendar_Config extends Tinebase_Config_Abstract
      */
     const FEATURE_POLLS = 'featurePolls';
 
-
     /**
      * EVENT_VIEW
      *
@@ -208,6 +214,11 @@ class Calendar_Config extends Tinebase_Config_Abstract
      */
     const FEATURE_EVENT_NOTIFICATION_CONFIRMATION = 'featureEventNotificationConfirmation';
 
+    /**
+     * @var string
+     */
+    const ORGANIZER_IMPLICIT_EDIT_GRANT = 'organizerImplicitEditGrant';
+
     /**
      * @var string
      */
@@ -251,7 +262,6 @@ class Calendar_Config extends Tinebase_Config_Abstract
     const FREEBUSY_INFO_ALLOW_CALENDAR = 40;
     const FREEBUSY_INFO_ALLOW_ALL_ATTENDEE = 50;
 
-
     /**
      * (non-PHPdoc)
      * @see tine20/Tinebase/Config/Definition::$_properties
@@ -405,6 +415,16 @@ class Calendar_Config extends Tinebase_Config_Abstract
                 'default' => 'REQ'
             )
         ),
+        self::ORGANIZER_IMPLICIT_EDIT_GRANT => [
+            //_('Organizer has implicit edit grant')
+            'label'                 => 'Organizer has implicit edit grant',
+            'description'           => 'Organizer has implicit edit grant',
+            'type'                  => Tinebase_Config_Abstract::TYPE_BOOL,
+            'clientRegistryInclude' => false,
+            'setByAdminModule'      => false,
+            'setBySetupModule'      => true,
+            'default'               => true,
+        ],
         self::RESOURCE_TYPES => array(
             //_('Resource Types Available')
             'label'                 => 'Resource Types Available',
@@ -516,6 +536,17 @@ class Calendar_Config extends Tinebase_Config_Abstract
             'setBySetupModule'      => true,
             'default'               => false,
         ),
+        self::DISABLE_EXTERNAL_NOTIFICATIONS => array(
+            //_('Disable notification for external organizers')
+            'label'                 => 'Disable notification for external organizers',
+            //_('Disable notification for external organizers')
+            'description'           => 'Disable notification for external organizers',
+            'type'                  => Tinebase_Config_Abstract::TYPE_BOOL,
+            'clientRegistryInclude' => false,
+            'setByAdminModule'      => true,
+            'setBySetupModule'      => true,
+            'default'               => false,
+        ),
         self::SKIP_DOUBLE_EVENTS => array(
             //_('(CalDAV) Skip double events from personal or shared calendar')
             'label'                 => '(CalDAV) Skip double events from personal or shared calendar',
