@@ -33,6 +33,11 @@ abstract class Tinebase_Config_Abstract implements Tinebase_Config_Interface
     const SETBYSETUPMODULE      = 'setBySetupModule';
     const TYPE                  = 'type';
 
+    /**
+     * status transitions
+     */
+    public const TRANSITION_TARGET_STATUS = 'targetStatus';
+
     /**
      * object config type
      * 
@@ -158,7 +163,13 @@ abstract class Tinebase_Config_Abstract implements Tinebase_Config_Interface
      * @var array
      */
     protected static $_serverPlugins = array();
-    
+
+    /**
+     * (non-PHPdoc)
+     * @see tine20/Tinebase/Config/Definition::$_properties
+     */
+    protected static $_properties = [];
+
     /**
      * get config object for application
      * 
@@ -770,12 +781,14 @@ abstract class Tinebase_Config_Abstract implements Tinebase_Config_Interface
 
         if (Tinebase_Core::get(Tinebase_Core::SHAREDCACHE)) {
             if (isset($appFilter)) {
-                list($key, $value) = each($appFilter);
-                $appName = $key === 'name' ? $value : Tinebase_Application::getInstance()->getApplicationById($value)->name;
+                foreach ($appFilter as $key => $value) {
+                    $appName = $key === 'name' ? $value : Tinebase_Application::getInstance()->getApplicationById($value)->name;
+                    Tinebase_Core::getCache()->remove('cachedAppConfig_' . $appName);
+                }
             } else {
                 $appName = $this->_appName;
+                Tinebase_Core::getCache()->remove('cachedAppConfig_' . $appName);
             }
-            Tinebase_Core::getCache()->remove('cachedAppConfig_' . $appName);
         }
 
         Tinebase_Cache_PerRequest::getInstance()->reset('Tinebase_Config_Abstract');
@@ -1002,4 +1015,30 @@ abstract class Tinebase_Config_Abstract implements Tinebase_Config_Interface
 
         return false;
     }
+
+    /**
+     * @param string $configKey
+     * @param string|null $method
+     * @return false|mixed
+     */
+    public function getHookClass(string $configKey, string $method = null)
+    {
+        $hookClass = Tinebase_Config::getInstance()->get($configKey);
+        if ($hookClass) {
+            if (! class_exists($hookClass)) {
+                @include($hookClass . '.php');
+            }
+
+            if (class_exists($hookClass)) {
+                $hook = new $hookClass();
+                if (! method_exists($hook, $method)) {
+                    if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__
+                        . ' Method not found in hook class');
+                    return false;
+                }
+                return $hook;
+            }
+        }
+        return false;
+    }
 }
