@@ -172,6 +172,11 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
                 } catch (Felamimail_Exception_IMAPMessageNotFound $feimnf) {
                     $result->addRecord($folder);
                     continue;
+                } catch (Felamimail_Exception $fe) {
+                    if (Tinebase_Core::isLogLevel(Zend_Log::WARN)) Tinebase_Core::getLogger()->warn(
+                        __METHOD__ . '::' . __LINE__ .  ' Error during updateMessageCache: ' . $fe->getMessage()
+                        . ' ... ignoring this folder for the moment: ' . $folder->getId());
+                    continue;
                 }
                 
                 if ($this->_messagesDeletedOnIMAP($folder) || $this->_messagesToBeAddedToCache($folder) || $this->_messagesMissingFromCache($folder) ) {
@@ -181,7 +186,8 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
             }
         }
 
-        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ .  " Found " . count($result) . ' folders that need an update.');
+        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(
+            __METHOD__ . '::' . __LINE__ .  " Found " . count($result) . ' folders that need an update.');
         
         return $result;
     }
@@ -447,15 +453,24 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
                                 throw new Felamimail_Exception_IMAPMessageNotFound('Message not found on IMAP');
                             }
 
-                            // message does not exist on imap server anymore, remove from local cache
                             if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) {
-                                Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . " messageUid {$latestMessageUid} not found => remove from cache");
+                                Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                                    . " MessageUid {$latestMessageUid} not found on IMAP server => remove from cache");
                             }
 
                             $lastFailedUid = $latestMessageUid;
 
                             $latestMessage = $this->_backend->get($latestMessageId);
-                            $this->_backend->delete($latestMessage);
+                            try {
+                                $this->_backend->delete($latestMessage);
+                            } catch (Zend_Db_Statement_Exception $zdse) {
+                                if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) {
+                                    Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__
+                                        . " Might have a lock wait timeout - try again later (error: " . $zdse->getMessage() . ')');
+                                }
+                                $_folder->cache_status = Felamimail_Model_Folder::CACHE_STATUS_INCOMPLETE;
+                                break;
+                            }
 
                             $decrementMessagesCounter++;
                             if (!$latestMessage->hasSeenFlag()) {
@@ -749,6 +764,7 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
      */
     protected function _fetchAndAddMessages(Felamimail_Model_Folder $_folder, Felamimail_Backend_ImapProxy $_imap)
     {
+        /** @var Felamimail_Backend_Imap $_imap */
         $messageSequenceStart = $this->_imapMessageSequence + 1;
         
         // add new messages
@@ -796,9 +812,9 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
      */
     protected function _addMessagesToCacheAndIncreaseCounters($_messages, $_folder)
     {
-        foreach ($_messages as $uid => $message) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-                .  " Add message $uid to cache");
+        foreach ($_messages as $message) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                .  " Add message " . $message['uid'] . " to cache");
             if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
                 .  ' ' . print_r($message, TRUE));
 
@@ -843,7 +859,8 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
             
             if ($this->_timeLeft()) {
                 // add missing messages
-                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ .  " Retrieve message from {$_folder->imap_totalcount} to 1");
+                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+                    __METHOD__ . '::' . __LINE__ .  " Retrieve message from {$_folder->imap_totalcount} to 1");
                 
                 $begin = $_folder->cache_job_lowestuid > 0 ? $_folder->cache_job_lowestuid : $this->_imapMessageSequence;
                 
@@ -1384,8 +1401,9 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
             $_folder->quota_usage = 0;
             $_folder->quota_limit = 0;
         }
-        
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__ . ' ' . print_r($quota, TRUE));
+
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+            __METHOD__ . '::' . __LINE__ . ' ' . print_r($quota, TRUE));
     }
     
     /**
@@ -1398,6 +1416,10 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
      */
     public function getMessageSummary($messageUid, $accountId, $folderId = NULL)
     {
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+            __METHOD__ . '::' . __LINE__ . ' messageUid/folder ' . $messageUid . ' / ' . $folderId);
+
+        /** @var Felamimail_Backend_Imap $imap */
         $imap = Felamimail_Backend_ImapFactory::factory($accountId);
         
         if ($folderId !== null) {
@@ -1411,8 +1433,6 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
             }
         }
         
-        $summary = $imap->getSummary($messageUid, NULL, TRUE);
-        
-        return $summary;
+        return $imap->getSummary($messageUid, NULL, TRUE);
     }
 }
