@@ -95,13 +95,13 @@ class Sales_Controller_Contract extends Sales_Controller_NumberableAbstract
     /**
      * @see Tinebase_Controller_Record_Abstract::update()
      */
-    public function update(Tinebase_Record_Interface $_record, $_duplicateCheck = TRUE)
+    public function update(Tinebase_Record_Interface $_record, $_duplicateCheck = TRUE, $_updateDeleted = false)
      {
         if ($_duplicateCheck) {
             $this->_checkNumberUniqueness($_record, true);
         }
         $this->_checkNumberType($_record);
-        return parent::update($_record, $_duplicateCheck);
+        return parent::update($_record, $_duplicateCheck, $_updateDeleted);
     }
 
     /**
@@ -388,7 +388,7 @@ class Sales_Controller_Contract extends Sales_Controller_NumberableAbstract
             }
             
             foreach($models as $model) {
-                $filter = new Sales_Model_ProductFilter(array(array('field' => 'accountable', 'operator' => 'equals', 'value' => $model)));
+                $filter = Tinebase_Model_Filter_FilterGroup::getFilterForModel(Sales_Model_Product::class, array(array('field' => 'accountable', 'operator' => 'equals', 'value' => $model)));
                 $product = Sales_Controller_Product::getInstance()->search($filter)->getFirstRecord();
                 
                 if (! $product) {
