@@ -19,7 +19,6 @@
  */
 class Admin_Controller_EmailAccount extends Tinebase_Controller_Record_Abstract
 {
-    protected $_masterUser = null;
 
     /**
      * the constructor
@@ -82,7 +81,7 @@ class Admin_Controller_EmailAccount extends Tinebase_Controller_Record_Abstract
     public function get($_id, $_EmailAccountId = NULL, $_getRelatedData = TRUE, $_getDeleted = FALSE)
     {
         $this->_checkRight('get');
-
+        
         return $this->_backend->get($_id);
     }
 
@@ -100,7 +99,12 @@ class Admin_Controller_EmailAccount extends Tinebase_Controller_Record_Abstract
     {
         $this->_checkRight('get');
 
-        return $this->_backend->search($_filter, $_pagination, $_getRelations, $_onlyIds, $_action);
+        $result = $this->_backend->search($_filter, $_pagination, $_getRelations, $_onlyIds, $_action);
+        // we need to unset the accounts grants to make the admin grid actions work for all accounts
+        $result->account_grants = null;
+        $this->resolveAccountEmailUsers($result);
+
+        return $result;
     }
 
     /**
@@ -130,7 +134,8 @@ class Admin_Controller_EmailAccount extends Tinebase_Controller_Record_Abstract
         $this->_checkRight('create');
 
         $account = $this->_backend->create($_record);
-
+        $this->_inspectAfterCreate($account, $_record);
+        
         return $account;
     }
     
@@ -141,23 +146,23 @@ class Admin_Controller_EmailAccount extends Tinebase_Controller_Record_Abstract
      * @param   array $_additionalArguments
      * @return  Tinebase_Record_Interface
      */
-    public function update(Tinebase_Record_Interface $_record, $_additionalArguments = array())
+    public function update(Tinebase_Record_Interface $_record, $_additionalArguments = array(), $_updateDeleted = false)
     {
         $this->_checkRight('update');
 
-        $currentAccount = $this->get($_record->getId());
+        $currentAccount = $this->get($_record->getId(), null, true, $_updateDeleted);
 
         $raii = false;
-        if ($this->_sieveBackendSupportsMasterPassword($_record)) {
-            $raii = $this->prepareAccountForSieveAdminAccess($_record->getId());
+        if (Tinebase_EmailUser::sieveBackendSupportsMasterPassword($_record)) {
+            $raii = Tinebase_EmailUser::prepareAccountForSieveAdminAccess($_record->getId());
         }
 
         $this->_inspectBeforeUpdate($_record, $currentAccount);
         $account = $this->_backend->update($_record);
         $this->_inspectAfterUpdate($account, $_record, $currentAccount);
 
-        if ($raii && $this->_sieveBackendSupportsMasterPassword($_record)) {
-            $this->removeSieveAdminAccess();
+        if ($raii && Tinebase_EmailUser::sieveBackendSupportsMasterPassword($_record)) {
+            Tinebase_EmailUser::removeSieveAdminAccess();
             unset($raii);
         }
 
@@ -165,32 +170,16 @@ class Admin_Controller_EmailAccount extends Tinebase_Controller_Record_Abstract
     }
 
     /**
-     * check if imap/sieve backend supports setting a sieve master password
+     * inspect creation of one record (after create)
      *
-     * @param $account
-     * @return bool
+     * @param   Felamimail_Model_Account $_createdRecord
+     * @param   Felamimail_Model_Account $_record
+     * @return  void
      */
-    protected function _sieveBackendSupportsMasterPassword($account)
+    protected function _inspectAfterCreate($_createdRecord, Tinebase_Record_Interface $_record)
     {
-        if (! in_array($account->type, [
-            Felamimail_Model_Account::TYPE_SYSTEM,
-            Felamimail_Model_Account::TYPE_SHARED,
-            Felamimail_Model_Account::TYPE_USER_INTERNAL,
-        ])) {
-            return false;
-        }
-
-        $imapEmailBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::IMAP);
-        if (method_exists($imapEmailBackend, 'checkMasterUserTable')) {
-            try {
-                $imapEmailBackend->checkMasterUserTable();
-                return true;
-            } catch (Tinebase_Exception_NotFound $tenf) {
-                return false;
-            }
-        }
-
-        return false;
+        $this->updateAccountEmailUsers($_record);
+        $this->resolveAccountEmailUsers($_createdRecord);
     }
 
     /**
@@ -202,12 +191,18 @@ class Admin_Controller_EmailAccount extends Tinebase_Controller_Record_Abstract
      */
     protected function _inspectBeforeUpdate($_record, $_oldRecord)
     {
+        // if user of email account changes and if migration checkbox is checked, it needs to be unchecked
+        if ($_record->user_id !== $_oldRecord->user_id && $_record->type === Felamimail_Model_Account::TYPE_USER) {
+            $_record->migration_approved = false;
+        }
+        
         if ($_record->email !== $_oldRecord->email && $_record->type === Felamimail_Model_Account::TYPE_SYSTEM) {
             // change user email address
             $user = Admin_Controller_User::getInstance()->get($_record->user_id);
             $user->accountEmailAddress = $_record->email;
             Admin_Controller_User::getInstance()->update($user);
         }
+        $this->updateAccountEmailUsers($_record);
     }
 
     /**
@@ -232,6 +227,8 @@ class Admin_Controller_EmailAccount extends Tinebase_Controller_Record_Abstract
             // remove xprops from user
             Tinebase_EmailUser_XpropsFacade::setXprops($user, null, false);
             Admin_Controller_User::getInstance()->updateUserWithoutEmailPluginUpdate($user);
+        } else {
+            $this->resolveAccountEmailUsers($updatedRecord);
         }
     }
 
@@ -275,83 +272,6 @@ class Admin_Controller_EmailAccount extends Tinebase_Controller_Record_Abstract
         parent::_checkRight($_action);
     }
 
-    /**
-     * @param string $_accountId
-     * @param string $_rightToCheck
-     * @return Tinebase_RAII|boolean
-     */
-    public function prepareAccountForSieveAdminAccess($_accountId, $_rightToCheck = Admin_Acl_Rights::VIEW_EMAILACCOUNTS)
-    {
-        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::'
-            . __LINE__ . ' Account id: ' . $_accountId);
-
-        Admin_Controller_EmailAccount::getInstance()->checkRight($_rightToCheck);
-
-        $oldAccountAcl = Felamimail_Controller_Account::getInstance()->doContainerACLChecks(false);
-        $oldSieveAcl = Felamimail_Controller_Sieve::getInstance()->doAclCheck(false);
-
-        $raii = new Tinebase_RAII(function() use($oldAccountAcl, $oldSieveAcl) {
-            Felamimail_Controller_Account::getInstance()->doContainerACLChecks($oldAccountAcl);
-            Felamimail_Controller_Sieve::getInstance()->doAclCheck($oldSieveAcl);
-        });
-
-        $account = $this->get($_accountId);
-
-        // create sieve master user account here
-        try {
-            $this->_setSieveMasterPassword($account);
-        } catch (Tinebase_Exception_NotFound $tenf) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::'
-                . __LINE__ . ' ' . $tenf->getMessage());
-            return false;
-        }
-
-        // sieve login
-        try {
-            Felamimail_Backend_SieveFactory::factory($account);
-        } catch (Felamimail_Exception_Sieve $fes) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::ERR)) Tinebase_Core::getLogger()->err(__METHOD__ . '::'
-                . __LINE__ . ' ' . $fes->getMessage());
-            return false;
-        }
-
-        return $raii;
-    }
-
-    protected function _setSieveMasterPassword(Felamimail_Model_Account $account)
-    {
-        $this->_masterUser = Tinebase_Record_Abstract::generateUID(8);
-        if (empty($account->user)) {
-            $account->user = $this->_getAccountUsername($account);
-        }
-        $account->password = Tinebase_Record_Abstract::generateUID(20);
-        $imapEmailBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::IMAP);
-        if (method_exists($imapEmailBackend, 'setMasterPassword')) {
-            $imapEmailBackend->setMasterPassword($this->_masterUser, $account->password);
-        }
-    }
-
-    protected function _getAccountUsername($account)
-    {
-        if ($account->type === Felamimail_Model_Account::TYPE_SYSTEM) {
-            $record = Tinebase_User::getInstance()->getFullUserById($account->user_id);
-        } else {
-            $record  = $account;
-        }
-        $user = Tinebase_EmailUser_XpropsFacade::getEmailUserFromRecord($record);
-        $imapEmailBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::IMAP);
-        $imapLoginname = $imapEmailBackend->getLoginName($user->getId(), null, $account->email);
-        return $imapLoginname . '*' . $this->_masterUser;
-    }
-
-    public function removeSieveAdminAccess()
-    {
-        $imapEmailBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::IMAP);
-        if (method_exists($imapEmailBackend, 'removeMasterPassword')) {
-            $imapEmailBackend->removeMasterPassword($this->_masterUser);
-        }
-    }
-
     /**
      * @param Tinebase_Model_User|string|null $user
      * @return Felamimail_Model_Account|null
@@ -361,4 +281,64 @@ class Admin_Controller_EmailAccount extends Tinebase_Controller_Record_Abstract
     {
         return $this->_backend->getSystemAccount($user);
     }
+
+    /**
+     * @param Felamimail_Model_Account $account
+     */
+    public function updateAccountEmailUsers(Felamimail_Model_Account $account)
+    {
+        $this->checkRight('MANAGE_ACCOUNTS');
+
+        // set emailUserId im xprops if not set
+        if (! Tinebase_Config::getInstance()->{Tinebase_Config::EMAIL_USER_ID_IN_XPROPS}) {
+            return;
+        }
+
+        if (isset($account['email_imap_user'])) {
+            $fullUser = Tinebase_EmailUser_XpropsFacade::getEmailUserFromRecord($account);
+            $newFullUser = clone($fullUser);
+
+            $emailUserBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::IMAP);
+            $emailUserBackend->updateUser($fullUser, $newFullUser);
+        }
+    }
+
+    /**
+     * set emailUserId im xprops if not set
+     *
+     * @param Tinebase_Record_RecordSet|Felamimail_Model_Account $_records
+     */
+    public function resolveAccountEmailUsers($_records)
+    {
+        if (! Tinebase_Config::getInstance()->{Tinebase_Config::EMAIL_USER_ID_IN_XPROPS}) {
+            return;
+        }
+
+        $_records = $_records instanceof Tinebase_Record_RecordSet ? $_records : [$_records];
+
+        foreach ($_records as $_record) {
+            if (!isset($_record->xprops()[Felamimail_Model_Account::XPROP_EMAIL_USERID_IMAP])) {
+                try {
+                    $user = Tinebase_User::getInstance()->getFullUserById($_record->user_id);
+                } catch (Tinebase_Exception_NotFound $e) {
+                    continue;
+                }
+                
+                if (!isset($user->xprops()[Tinebase_Model_FullUser::XPROP_EMAIL_USERID_IMAP])) {
+                    // still no XPROP_EMAIL_USERID_IMAP ...
+                    continue;
+                }
+                Tinebase_EmailUser_XpropsFacade::setXprops($_record,
+                    $user->xprops()[Tinebase_Model_FullUser::XPROP_EMAIL_USERID_IMAP], false);
+            }
+
+            $fullUser = Tinebase_EmailUser_XpropsFacade::getEmailUserFromRecord($_record);
+
+            $emailUserBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::IMAP);
+            $smtpUserBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::SMTP);
+
+            $_record->email_imap_user = $emailUserBackend->getEmailuser($fullUser)->toArray();
+            $_record->email_smtp_user = $smtpUserBackend->getEmailuser($fullUser)->toArray();
+        }
+    }
 }
