@@ -209,7 +209,7 @@ class Felamimail_Controller_Folder extends Tinebase_Controller_Abstract implemen
      *
      * @param string|Felamimail_Model_Account $_accountId
      * @param string $_folderName to create
-     * @param string $_parentFolder
+     * @param string $_parentFolder parent folder globalname
      * @return Felamimail_Model_Folder
      * @throws Felamimail_Exception_IMAPServiceUnavailable
      * @throws Tinebase_Exception_SystemGeneric
@@ -234,19 +234,22 @@ class Felamimail_Controller_Folder extends Tinebase_Controller_Abstract implemen
 
             // create new folder
             $folder = new Felamimail_Model_Folder(array(
-                'localname'     => $foldername,
-                'globalname'    => $globalname,
-                'account_id'    => $account->getId(),
-                'parent'        => $_parentFolder
+                'localname' => $foldername,
+                'globalname' => $globalname,
+                'account_id' => $account->getId(),
+                'parent' => $_parentFolder,
             ));
+            $folder->supports_condstore = $this->supportsCondStore($folder, $account, $imap);
             
             $folder = $this->_backend->create($folder);
             
-            if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . ' Create new folder: ' . $globalname);
+            if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(
+                __METHOD__ . '::' . __LINE__ . ' Create new folder: ' . $globalname);
             
         } catch (Zend_Mail_Storage_Exception $zmse) {
             // perhaps the folder already exists
-            if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . ' Could not create new folder: ' . $globalname . ' (' . $zmse->getMessage() . ')');
+            if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(
+                __METHOD__ . '::' . __LINE__ . ' Could not create new folder: ' . $globalname . ' (' . $zmse->getMessage() . ')');
             
             // reload folder cache of parent
             $parentSubs = $this->_cacheController->update($account, $_parentFolder);
@@ -256,7 +259,11 @@ class Felamimail_Controller_Folder extends Tinebase_Controller_Abstract implemen
             }
 
             $translation = Tinebase_Translation::getTranslation('Felamimail');
-            $nodeExistException = new Tinebase_Exception_SystemGeneric($translation->translate('Folder with this name already exists!'));
+            $nodeExistException = new Tinebase_Exception_SystemGeneric(str_replace(
+                ['{0}'],
+                [$globalname],
+                $translation->translate('Folder with name {0} already exists!')
+            ));
             $nodeExistException->setTitle($translation->translate('Failure on create folder'));
             throw $nodeExistException;
         }
@@ -266,7 +273,50 @@ class Felamimail_Controller_Folder extends Tinebase_Controller_Abstract implemen
         
         return $folder;
     }
-    
+
+    /**
+     * check if folder support condstore: try to exmime folder on imap server if supports_condstore is null
+     *
+     * @param string|Felamimail_Model_Folder $folder
+     * @param Felamimail_Model_Account|null $account
+     * @param Felamimail_Backend_ImapProxy|null $imap
+     * @return boolean
+     */
+    public function supportsCondStore($folder, Felamimail_Model_Account $account = null, $imap = null)
+    {
+        if (is_string($folder) || $folder->supports_condstore === null) {
+            $folderName = is_string($folder) ? $folder : $folder->globalname;
+
+            if (! $imap) {
+                if (!$account) {
+                    if ($folder instanceof Felamimail_Model_Folder) {
+                        $account = Felamimail_Controller_Account::getInstance()->get($folder->account_id);
+                    } else {
+                        throw new Felamimail_Exception('no valid account found for folder');
+                    }
+                }
+                $imap = Felamimail_Backend_ImapFactory::factory($account);
+            }
+
+            try {
+                $folderData = $imap->examineFolder(Felamimail_Model_Folder::encodeFolderName($folderName));
+
+                $result = isset($folderData['highestmodseq']) || array_key_exists('highestmodseq', $folderData);
+                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ .
+                    ' Folder ' . $folderName . ' supports condstore: ' . intval($result));
+
+                return $result;
+
+            } catch (Zend_Mail_Storage_Exception $zmse) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(
+                    __METHOD__ . '::' . __LINE__ . " Could not examine folder $folderName. Skipping it.");
+                return null;
+            }
+        }
+
+        return $folder->supports_condstore;
+    }
+
     /**
      * prepare foldername given by user (remove some bad chars)
      * 
@@ -288,6 +338,7 @@ class Felamimail_Controller_Folder extends Tinebase_Controller_Abstract implemen
      */
     public function update(Felamimail_Model_Folder $_folder)
     {
+        $_folder->supports_condstore = $this->supportsCondStore($_folder);
         return $this->_backend->update($_folder);
     }
     
@@ -362,7 +413,7 @@ class Felamimail_Controller_Folder extends Tinebase_Controller_Abstract implemen
     /**
      * delete folder in cache
      * 
-     * @param string|Felamimail_Model_Account $_account
+     * @param string|Felamimail_Model_Account $_accountId
      * @param Felamimail_Model_Folder $_folder
      */
     protected function _deleteFolderInCache($_accountId, $_folder)
@@ -699,4 +750,33 @@ class Felamimail_Controller_Folder extends Tinebase_Controller_Abstract implemen
         
         return $this->_backend->search($filter);
     }
+
+    /**
+     * reload folder cache on primary account - only do this once an hour (with caching)
+     *
+     * @param Felamimail_Model_Account $account
+     * @return boolean
+     */
+    public function reloadFolderCacheOnAccount($account)
+    {
+        if (Tinebase_Core::getPreference($this->_applicationName)->{Felamimail_Preference::DEFAULTACCOUNT} !== $account->getId()) {
+            return false;
+        }
+
+        $cache = Tinebase_Core::getCache();
+        $cacheId = Tinebase_Helper::convertCacheId('_reloadFolderCacheOnPrimaryAccount' . $account->getId());
+        if ($cache->test($cacheId)) {
+            return $cache->load($cacheId);
+        }
+
+        try {
+            Felamimail_Controller_Cache_Folder::getInstance()->update($account->getId(), '', TRUE);
+        } catch (Exception $e) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(
+                __METHOD__ . '::' . __LINE__ . ' Could not update account folder cache: ' . $e->getMessage()
+            );
+        }
+        $cache->save(true, $cacheId, [], 3600);
+        return true;
+    }
 }
