@@ -125,7 +125,15 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         $flags = ($_flags !== null) ? (array)$_flags : null;
 
         $imapBackend = $this->_getBackendAndSelectFolder(NULL, $folder);
-        $imapBackend->appendMessage($message, $folder->globalname, $flags);
+        try {
+            $imapBackend->appendMessage($message, $folder->globalname, $flags);
+        } catch (Zend_Mail_Storage_Exception $zmse) {
+            if ($zmse->getMessage() === 'cannot create message, please check if the folder exists and your flags') {
+                throw new Tinebase_Exception_NotFound('Folder ' . $folder->globalname . ' not found');
+            } else {
+                throw $zmse;
+            }
+        }
     }
 
     /**
@@ -218,7 +226,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         }
 
         $headers = $this->getMessageHeaders($_message, $_partId, true);
-        $body = $this->getMessageBody($_message, $_partId, $mimeType, $_account, true);
+        $body = $this->getMessageBody($_message, $_partId, $mimeType, $_account);
         $attachments = array();
         if ($body === '' && $_partId === null && isset($headers['content-transfer-encoding']) && $headers['content-transfer-encoding'] === 'base64') {
             // maybe we have a single part message that needs to be treated like an attachment
@@ -271,6 +279,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
      */
     public function sendReadingConfirmation($messageId)
     {
+        /** @var Felamimail_Model_Message $message */
         $message = $this->get($messageId);
         $this->_checkMessageAccount($message);
         $message->sendReadingConfirmation();
@@ -317,22 +326,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
             }
         }
 
-        // PGP MIME Version 1
-        if (isset($_message->structure['contentType']) && $_message->structure['contentType'] == 'multipart/encrypted'
-            && isset($_message->structure['parts'][1]['subType'])
-            && $_message->structure['parts'][1]['subType'] == 'pgp-encrypted') {
-            $identification = $this->getMessagePart($_message, 1)->getContent();
-
-            if (strpos($identification, 'Version: 1') !== FALSE) {
-                $amored = $this->getMessagePart($_message, 2)->getContent();
-
-                $preparedParts->addRecord(new Felamimail_Model_PreparedMessagePart(array(
-                    'id' => $_message->getId() . '_2',
-                    'contentType' => 'application/pgp-encrypted',
-                    'preparedData' => $amored,
-                )));
-            }
-        }
+        $this->_processPGPMimeVersion1Part($_message, $preparedParts);
 
         // PGP INLINE
         if (strpos($_message->body, '-----BEGIN PGP MESSAGE-----') !== false) {
@@ -349,6 +343,33 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         $_message->preparedParts = $preparedParts;
     }
 
+    protected function _processPGPMimeVersion1Part($message, $preparedParts)
+    {
+        try {
+            $structure = $message->structure;
+        } catch (Zend_Mail_Protocol_Exception $zmpe) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::ERR)) Tinebase_Core::getLogger()->err(__METHOD__ . '::' . __LINE__
+                . ' Error while fetching structure, could not process PGP part: ' . $zmpe);
+            $structure = null;
+        }
+        if (isset($structure['contentType']) && $structure['contentType'] == 'multipart/encrypted'
+            && isset($structure['parts'][1]['subType'])
+            && $structure['parts'][1]['subType'] == 'pgp-encrypted')
+        {
+            $identification = $this->getMessagePart($message, 1)->getContent();
+
+            if (strpos($identification, 'Version: 1') !== FALSE) {
+                $amored = $this->getMessagePart($message, 2)->getContent();
+
+                $preparedParts->addRecord(new Felamimail_Model_PreparedMessagePart(array(
+                    'id' => $message->getId() . '_2',
+                    'contentType' => 'application/pgp-encrypted',
+                    'preparedData' => $amored,
+                )));
+            }
+        }
+    }
+
     /**
      * get foreign message parts
      *
@@ -441,8 +462,8 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
             . ' Fetching ' . $messageId . '[' . $partId . '] part with iMIP data ...');
 
+        /** @var Felamimail_Model_Message $message */
         $message = $this->get($messageId);
-
         $iMIPPartStructure = $message->getPartStructure($partId);
         $iMIP = $this->_getForeignMessagePart($message, $partId, $iMIPPartStructure);
 
@@ -463,6 +484,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         if ($_id instanceof Felamimail_Model_Message) {
             $message = $_id;
         } else {
+            /** @var Felamimail_Model_Message $message */
             $message = $this->get($_id);
         }
 
@@ -485,8 +507,9 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
 
     protected function _getPartStructureFromAttachments($message, $partId)
     {
-        $attachment = array_filter($message->attachments, function($el) use ($partId) {
-            return isset($el['partId']) && $el['partId'] === $partId;
+        $attachments = $message->attachments instanceof Tinebase_Record_RecordSet ? $message->attachments->toArray() : $message->attachments;
+        $attachment = array_filter($attachments, function($attach) use ($partId) {
+            return isset($attach['partId']) && $attach['partId'] === $partId;
         });
         if (count($attachment) >= 1) {
             $partAttachment = array_pop($attachment);
@@ -670,7 +693,8 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
             $cacheId = $this->_getMessageBodyCacheId($message, $_partId, $_contentType, $_account);
 
             if ($cache->test($cacheId)) {
-                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . ' Getting Message from cache.');
+                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+                    __METHOD__ . '::' . __LINE__ . ' Getting Message from cache.');
                 return $cache->load($cacheId);
             }
         }
@@ -693,7 +717,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
     /**
      * get message body cache id
      *
-     * @param string|Felamimail_Model_Message $_messageId
+     * @param string|Felamimail_Model_Message $_message
      * @param string $_partId
      * @param string $_contentType
      * @param Felamimail_Model_Account $_account
@@ -868,6 +892,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         // TODO could be improved by adding on demand button if loading external resources is allowed
         //   or only load uris of known recipients
         if (Felamimail_Config::getInstance()->get(Felamimail_Config::FILTER_EMAIL_URIS)) {
+            /** @var HTMLPurifier_URIDefinition $uri */
             $uri = $config->getDefinition('URI');
             $uri->addFilter(new Felamimail_HTMLPurifier_URIFilter_TransformURI(), $config);
         }
@@ -970,7 +995,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
      * get imap backend and folder (and select folder)
      *
      * @param string $_folderId
-     * @param Felamimail_Backend_Folder &$_folder
+     * @param Felamimail_Backend_Folder $_folder
      * @param boolean $_select
      * @param Felamimail_Backend_ImapProxy $_imapBackend
      * @return Felamimail_Backend_ImapProxy
@@ -1004,7 +1029,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
     /**
      * get attachments of message
      *
-     * @param array $_structure
+     * @param string|Felamimail_Model_Message $_messageId
      * @param string $_partId
      * @param boolean $_skipEmptyAttachments
      * @return array
@@ -1012,6 +1037,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
     public function getAttachments($_messageId, $_partId = null, $_skipEmptyAttachments = false)
     {
         if (!$_messageId instanceof Felamimail_Model_Message) {
+            /** @var Felamimail_Model_Message $message */
             $message = $this->_backend->get($_messageId);
         } else {
             $message = $_messageId;
@@ -1033,8 +1059,11 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
 
         $attachments = array();
         foreach ($structure['parts'] as $part) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-                . ' ' . print_r($part, TRUE));
+            if (! $part) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                    . ' Skipping empty part');
+                continue;
+            }
 
             if ($part['type'] == 'multipart') {
                 $attachments = $attachments + $this->getAttachments($message, $part['partId']);
@@ -1061,7 +1090,10 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
                     if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
                         . ' Got winmail.dat attachment (contentType=' . $part['contentType'] . '). Trying to extract files ...');
 
-                    if (preg_match('/^application\/.{0,4}ms-tnef$/', $part['contentType']) || $part['contentType'] == 'text/plain') {
+                    if (preg_match('/^application\/.{0,4}ms-tnef$/', $part['contentType'])
+                        || $part['contentType'] === 'text/plain'
+                        || $part['contentType'] === 'application/octet-stream'
+                    ) {
                         $expanded = $this->_expandWinMailDat($_messageId, $part['partId']);
 
                         if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
@@ -1074,6 +1106,9 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
                                 . ' Skipping empty winmail.dat attachment.');
                             continue;
                         }
+                    } else {
+                        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                            . ' Unsupported winmail.dat content-type. Skipping ...');
                     }
                 }
 
@@ -1178,13 +1213,17 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
             }
         }
 
-        asort($files);
+        ksort($files);
+
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+            . ' Winmail contents:  ' . print_r($files, true));
+
         return $files;
     }
 
     /**
-     * @param $datFile
-     * @param $path
+     * @param string $datFile
+     * @param string $path
      * @throws Tinebase_Exception_NotFound
      */
     protected function _extractWinMailDatToDir($datFile, $path)
@@ -1199,8 +1238,8 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
     }
 
     /**
-     * @param $message
-     * @param $attachment
+     * @param Felamimail_Model_Message $message
+     * @param array $attachment
      * @param bool $extract
      * @return false|string
      * @throws Tinebase_Exception_NotFound
@@ -1245,7 +1284,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
     /**
      * delete messages from cache by folder
      *
-     * @param $_folder
+     * @param Felamimail_Model_Folder $_folder
      */
     public function deleteByFolder(Felamimail_Model_Folder $_folder)
     {
@@ -1324,7 +1363,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
     }
 
     /**
-     * @param $nodeId
+     * @param string $nodeId
      * @return Felamimail_Model_Message
      */
     public function getMessageFromNode($nodeId)
@@ -1422,7 +1461,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
     }
 
     /**
-     * @param $uid
+     * @param string $uid
      * @param Felamimail_Model_Account $account
      * @param Felamimail_Model_Folder $draftFolder
      * @throws Felamimail_Exception_IMAPInvalidCredentials
@@ -1441,15 +1480,15 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
             __METHOD__ . '::' . __LINE__ . ' Remove old draft with uid ' . $uid);
         $imap = Felamimail_Backend_ImapFactory::factory($account);
-        $imap->selectFolder($draftFolder->globalname);
+        $imap->selectFolder(Felamimail_Model_Folder::encodeFolderName($draftFolder->globalname));
         $imap->addFlags([$uid], [Zend_Mail_Storage::FLAG_DELETED]);
 
         return true;
     }
 
     /**
-     * @param $uid
-     * @param $accountid
+     * @param string $uid
+     * @param string $accountid
      * @return bool
      * @throws Felamimail_Exception_IMAPInvalidCredentials
      */
@@ -1493,7 +1532,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
 
     /**
      * @param Felamimail_Model_Message $message
-     * @param $newSubject
+     * @param string $newSubject
      * @return Felamimail_Model_Message
      * @throws Felamimail_Exception_IMAP
      */
@@ -1501,26 +1540,29 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
     {
         $folder = Felamimail_Controller_Folder::getInstance()->get($message->folder_id);
         $account = Felamimail_Controller_Account::getInstance()->get($message->account_id);
-
-        $updatedMessage = clone($message);
-        $updatedMessage->subject = $newSubject;
         $imap = Felamimail_Backend_ImapFactory::factory($account);
-        $mailToAppend = Felamimail_Controller_Message_Send::getInstance()->createMailForSending(
-            $updatedMessage,
-            $account,
-            $_nonPrivateRecipients,
-            true
-        );
-        $transport = new Felamimail_Transport();
-        $mailAsString = $transport->getRawMessage($mailToAppend);
+        $updatedMessage = clone($message);
+
+        $mailAsString = $this->getMessageRawContent($updatedMessage);
+        $mailAsString = $this->_replaceHeaderInRawMessage($mailAsString, 'subject', $newSubject);
+
         $uid = $imap->appendMessage(
             $mailAsString,
             Felamimail_Model_Folder::encodeFolderName($folder->globalname),
             []
         );
-
+        
         if ($uid) {
             $updatedMessage->messageuid = $uid;
+
+            //append flags from original message to updated message
+            foreach ($updatedMessage->flags as $flag) {
+               $supportedFlags = array_keys(Felamimail_Controller_Message_Flags::getInstance()->getSupportedFlags(FALSE));
+                
+              if (in_array($flag, $supportedFlags)) {
+                   $imap->addFlags($updatedMessage->messageuid, [$flag]);
+                }
+            }
         } else {
             throw new Felamimail_Exception_IMAP('appendMessage failed');
         }
@@ -1530,61 +1572,16 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
             $imap->addFlags([$message->messageuid], [Zend_Mail_Storage::FLAG_DELETED]);
         }
 
+        $updatedMessage->subject = $newSubject;
         return $updatedMessage;
     }
 
-    /**
-     * copy message with
-     * @param Felamimail_Model_Message $message
-     * @param $wrapTo
-     * @param $targetFolder
-     * @return Felamimail_Model_Message
-     * @throws Felamimail_Exception
-     * @throws Felamimail_Exception_IMAP
-     * @throws Felamimail_Exception_IMAPInvalidCredentials
-     * @throws Tinebase_Exception_Record_DefinitionFailure
-     * @throws Tinebase_Exception_Record_Validation
-     * @throws Zend_Mail_Transport_Exception
-     */
-    public function copyMessageWithAttachment(Felamimail_Model_Message $message, $wrapTo, $targetFolder)
+    protected function _replaceHeaderInRawMessage($mailAsString, $header, $newValue)
     {
-        $account = Felamimail_Controller_Account::getInstance()->get($message->account_id);
-
-        $updatedMessage = clone($message);
-        $updatedMessage->subject = $wrapTo['subject'];
-        $updatedMessage->to = $wrapTo['to'];
-        $updatedMessage->original_id = $message->getId(); // doesnt work
-        $updatedMessage->attachments =  [new Tinebase_Model_TempFile([
-            'type'  => Felamimail_Model_Message::CONTENT_TYPE_MESSAGE_RFC822,
-            'name'  => $message->subject,
-        ], TRUE)];
-
-        $imap = Felamimail_Backend_ImapFactory::factory($account);
-        $mailToAppend = Felamimail_Controller_Message_Send::getInstance()->createMailForSending(
-            $updatedMessage,
-            $account,
-            $_nonPrivateRecipients,
-            true
-        );
-        $transport = new Felamimail_Transport();
-        $mailAsString = $transport->getRawMessage($mailToAppend);
-        $uid = $imap->appendMessage(
-            $mailAsString,
-            Felamimail_Model_Folder::encodeFolderName($targetFolder->globalname),
-            []
-        );
-
-        if ($uid) {
-            $updatedMessage->messageuid = $uid;
-        } else {
-            throw new Felamimail_Exception_IMAP('appendMessage failed');
-        }
-
-        // remove old message
-        if ($message->messageuid) {
-            $imap->addFlags([$message->messageuid], [Zend_Mail_Storage::FLAG_DELETED]);
-        }
-        
-        return $updatedMessage;
+        return preg_replace(
+            // find header (also replaces multiline headers!)
+            '/(' . ucfirst($header) . ':) .*\n( .*\n)*/',
+            '${1} ' . mb_encode_mimeheader($newValue) . "\n",
+            $mailAsString);
     }
 }
