@@ -91,12 +91,9 @@ class Felamimail_Controller_Message_Send extends Felamimail_Controller_Message
         $account = Felamimail_Controller_Account::getInstance()->get($_message->account_id);
 
         // only check send grant for shared accounts
-        if ($account->type === Felamimail_Model_Account::TYPE_SHARED) {
-            // TODO generalize that? Tinebase_Core::getUser()->hasGrant() anyone?
-            $userGrants = Felamimail_Controller_Account::getInstance()->getGrantsOfAccount(Tinebase_Core::getUser(), $account);
-            if (!$userGrants->{Felamimail_Model_AccountGrants::GRANT_ADD}) {
-                throw new Tinebase_Exception_AccessDenied('User is not allowed to send a message with this account');
-            }
+        if ($account->type === Felamimail_Model_Account::TYPE_SHARED && !$account->account_grants
+                ->{Felamimail_Model_AccountGrants::GRANT_ADD}) {
+            throw new Tinebase_Exception_AccessDenied('User is not allowed to send a message with this account');
         }
 
         try {
@@ -205,9 +202,16 @@ class Felamimail_Controller_Message_Send extends Felamimail_Controller_Message
         try {
             $originalMessage = ($originalMessageId) ? $this->get($originalMessageId) : NULL;
         } catch (Tinebase_Exception_NotFound $tenf) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ 
-                . ' Did not find original message (' . $originalMessageId . ')');
-            $originalMessage = NULL;
+            try {
+                // maybe original id was a tree node (sent from Filemanager)
+                $originalMessage = Felamimail_Controller_Message::getInstance()->getMessageFromNode($originalMessageId);
+                $partId = 1;
+            } catch (Tinebase_Exception_NotFound $tenf) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                    . ' Did not find original message (' . $originalMessageId . ')');
+                $translation = Tinebase_Translation::getTranslation('Felamimail');
+                throw new Tinebase_Exception_NotFound($translation->_('Original message not found, email was moved or deleted'));
+            }
         }
         
         $_message->original_id      = $originalMessage;
@@ -712,7 +716,13 @@ class Felamimail_Controller_Message_Send extends Felamimail_Controller_Message
      */
     protected function _addReplyHeaders(Felamimail_Model_Message $message)
     {
-        $originalHeaders = Felamimail_Controller_Message::getInstance()->getMessageHeaders($message->original_id);
+        try {
+            $originalHeaders = Felamimail_Controller_Message::getInstance()->getMessageHeaders($message->original_id);
+        } catch (Tinebase_Exception_InvalidArgument $teia) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Message not available for reply headers / maybe it is a filed message ... (' .  $teia->getMessage() . ')');
+            return;
+        }
         if (!isset($originalHeaders['message-id'])) {
             // no message-id -> skip this
             return;
@@ -1123,6 +1133,7 @@ class Felamimail_Controller_Message_Send extends Felamimail_Controller_Message
         if (! $attachment) {
             throw new Tinebase_Exception_NotFound('node attachment not found');
         }
+        /* @var $stream \GuzzleHttp\Psr7\CachingStream */
         $stream = $attachment['contentstream'];
         $stream->rewind();
         $content = $stream->getContents();
