@@ -141,7 +141,7 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
      *   2) remove code duplication (xprops loops)
      *   3) find out, why xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION) does not return an array in some cases
      */
-    public function update(Tinebase_Record_Interface $_record, $_duplicateCheck = true)
+    public function update(Tinebase_Record_Interface $_record, $_duplicateCheck = true, $_updateDeleted = false)
     {
         // be careful, don't put $_record in here, like that parent_id might be spoofed! It must be only the id!
         $path = Tinebase_Model_Tree_Node_Path::createFromStatPath(
@@ -204,7 +204,7 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
             }
         }
 
-        return parent::update($_record, $_duplicateCheck);
+        return parent::update($_record, $_duplicateCheck, $_updateDeleted);
     }
 
     /**
@@ -378,6 +378,7 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
         $this->resolveGrants($record);
 
         if (Tinebase_Model_Tree_FileObject::TYPE_FOLDER === $record->type) {
+            $record->path = rtrim($record->path, '/') . '/';
             $context = $this->getRequestContext();
             if (is_array($context) && isset($context['quotaResult'])) {
                 $context['quotaResult'] = $this->_backend->getEffectiveAndLocalQuota($record);
@@ -503,7 +504,7 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
             if ($parents[$fileNode->parent_id] === false) {
                 $result->removeRecord($fileNode);
             } else {
-                $fileNode->path = $parents[$fileNode->parent_id] . '/' . $fileNode->name;
+                $fileNode->path = $parents[$fileNode->parent_id] . '/' . $fileNode->name . ( 'folder' === $fileNode->type ? '/' : '');
             }
         }
 
@@ -616,21 +617,21 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
         $result = new Tinebase_Record_RecordSet('Tinebase_Model_Tree_Node', array(
             array(
                 'name'   => $translate->_('My folders'),
-                'path'   => '/' . Tinebase_FileSystem::FOLDER_TYPE_PERSONAL . '/' . Tinebase_Core::getUser()->accountLoginName,
+                'path'   => '/' . Tinebase_FileSystem::FOLDER_TYPE_PERSONAL . '/' . Tinebase_Core::getUser()->accountLoginName . '/',
                 'type'   => Tinebase_Model_Tree_FileObject::TYPE_FOLDER,
                 'id'     => 'myUser',
                 'grants' => array(),
             ),
             array(
                 'name' => $translate->_('Shared folders'),
-                'path' => '/' . Tinebase_FileSystem::FOLDER_TYPE_SHARED,
+                'path' => '/' . Tinebase_FileSystem::FOLDER_TYPE_SHARED . '/',
                 'type' => Tinebase_Model_Tree_FileObject::TYPE_FOLDER,
                 'id' => Tinebase_FileSystem::FOLDER_TYPE_SHARED,
                 'grants' => array(),
             ),
             array(
                 'name' => $translate->_('Other users folders'),
-                'path' => '/' . Tinebase_FileSystem::FOLDER_TYPE_PERSONAL,
+                'path' => '/' . Tinebase_FileSystem::FOLDER_TYPE_PERSONAL . '/',
                 'type' => Tinebase_Model_Tree_FileObject::TYPE_FOLDER,
                 'id' => Tinebase_Model_Container::TYPE_OTHERUSERS,
                 'grants' => array(),
@@ -1055,10 +1056,10 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
             ? new Tinebase_Record_RecordSet('Tinebase_Model_Tree_Node', array($_records)) : $_records;
 
         $app = Tinebase_Application::getInstance()->getApplicationByName($this->_applicationName);
-        $flatpathWithoutBasepath = Tinebase_Model_Tree_Node_Path::removeAppIdFromPath($_path->flatpath, $app);
+        $flatpathWithoutBasepath = rtrim(Tinebase_Model_Tree_Node_Path::removeAppIdFromPath($_path->flatpath, $app), '/');
         if ($records) {
             foreach ($records as $record) {
-                $record->path = $flatpathWithoutBasepath . '/' . $record->name;
+                $record->path = $flatpathWithoutBasepath . '/' . $record->name . ( 'folder' === $record->type ? '/' : '');
             }
         }
 
@@ -1324,7 +1325,18 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
                 $newNode = $this->_backend->copy($_source->statpath, $_destination->statpath);
                 break;
             case 'move':
-                $newNode = $this->_backend->rename($_source->statpath, $_destination->statpath);
+                try {
+                    $newNode = $this->_backend->rename($_source->statpath, $_destination->statpath);
+                } catch (Zend_Db_Statement_Exception $zdse) {
+                    if (Tinebase_Exception::isDbDuplicate($zdse)) {
+                        if (Tinebase_Core::isLogLevel(Zend_Log::ERR)) Tinebase_Core::getLogger()->err(
+                            __METHOD__ . '::' . __LINE__ . ' ' . $zdse->getMessage());
+                        throw new Tinebase_Exception_SystemGeneric('The destination already exists.');
+                    } else {
+                        throw $zdse;
+                    }
+                }
+
                 break;
         }
 
@@ -1419,12 +1431,11 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
      */
     protected function _moveFolderNode($source, $destination, $_forceOverwrite = FALSE)
     {
-        $this->_backend->checkPathACL($source, 'get', FALSE);
+        $this->_backend->checkPathACL($source->getParent(), 'delete');
         
         $destinationParentPathRecord = $destination->getParent();
-        $destinationNodeName = NULL;
         
-        $this->_backend->checkPathACL($destinationParentPathRecord, 'update');
+        $this->_backend->checkPathACL($destinationParentPathRecord, 'add');
         // TODO do we need this if??
         //if ($source->getParent()->flatpath != $destinationParentPathRecord->flatpath) {
             try {
@@ -1452,13 +1463,8 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
         if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
             . ' Rename Folder ' . $source->statpath . ' -> ' . $destination->statpath);
 
-        $this->_backend->rename($source->statpath, $destination->statpath);
+        $movedNode = $this->_backend->rename($source->statpath, $destination->statpath);
 
-        $movedNode = $this->_backend->stat($destination->statpath);
-        if ($destinationNodeName !== NULL) {
-            $movedNode->name = $destinationNodeName;
-        }
-        
         return $movedNode;
     }
 
