@@ -120,6 +120,7 @@ class Calendar_Controller_Resource extends Tinebase_Controller_Record_Abstract
                 }
             }
 
+
             // apply event grants
             if ($grant->{Calendar_Model_ResourceGrants::EVENTS_ADD}) {
                 $grant->{Tinebase_Model_Grants::GRANT_ADD} = true;
@@ -185,7 +186,7 @@ class Calendar_Controller_Resource extends Tinebase_Controller_Record_Abstract
             $container = Tinebase_Container::getInstance()->addContainer(new Tinebase_Model_Container(array(
                 'name' => $_record->name,
                 'hierarchy' => $_record->hierarchy,
-                'color' => '#333399',
+                'color' => $_record->color ?? '#333399',
                 'type' => Tinebase_Model_Container::TYPE_SHARED,
                 'backend' => $this->_backend->getType(),
                 'application_id' => $appId,
@@ -267,7 +268,7 @@ class Calendar_Controller_Resource extends Tinebase_Controller_Record_Abstract
      * @return  Tinebase_Record_Interface
      * @throws  Tinebase_Exception_AccessDenied
      */
-    public function update(Tinebase_Record_Interface $_record, $_duplicateCheck = true)
+    public function update(Tinebase_Record_Interface $_record, $_duplicateCheck = true, $_updateDeleted = false)
     {
         // we better make this in one transaction, we don't want to update them separately
         $transactionId = Tinebase_TransactionManager::getInstance()->startTransaction(Tinebase_Core::getDb());
@@ -290,9 +291,10 @@ class Calendar_Controller_Resource extends Tinebase_Controller_Record_Abstract
             }
             unset($_record->grants);
 
-            $result = parent::update($_record);
+            $result = parent::update($_record, true, $_updateDeleted);
 
-            if ($container->name !== $result->name || $container->hierarchy !== $result->hierarchy) {
+            if ($container->name !== $result->name || $container->hierarchy !== $result->hierarchy || $container->color !== $result->color) {
+                $container->color = $result->color;
                 $container->name = $result->name;
                 $container->hierarchy = $result->hierarchy;
 
