@@ -70,6 +70,11 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
         return self::$_instance;
     }
 
+    public static function destroyInstance()
+    {
+        self::$_instance = null;
+    }
+
     /**
      * get list of full accounts -> renamed to search full users
      *
@@ -184,24 +189,6 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
         );
     }
 
-    /**
-     * set the pin for a given account
-     *
-     * @param  Tinebase_Model_FullUser  $_account the account
-     * @param  string                   $_password the new password
-     * @return void
-     */
-    public function setAccountPin(Tinebase_Model_FullUser $_account, $_password)
-    {
-        $this->checkRight('MANAGE_ACCOUNTS');
-
-        $this->_userBackend->setPin($_account, $_password);
-
-        Tinebase_Core::getLogger()->info(
-            __METHOD__ . '::' . __LINE__ .
-            ' Set new pin for user ' . $_account->accountLoginName);
-    }
-
     /**
      * update user
      *
@@ -373,13 +360,13 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
     protected function _updateCurrentUser($updatedUser)
     {
         $currentUser = Tinebase_Core::getUser();
-        if ($currentUser->getId() === $updatedUser->getId()) {
+        if ($currentUser->getId() === $updatedUser->getId() && Tinebase_Session::isStarted()) {
             // update current user in session!
             Tinebase_Core::set(Tinebase_Core::USER, $updatedUser);
             Tinebase_Session::getSessionNamespace()->currentAccount = $updatedUser;
         }
     }
-    
+
     /**
      * create user
      *
@@ -396,6 +383,11 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
         // avoid forging accountId, gets created in backend
         unset($_user->accountId);
         
+        $event = new Admin_Event_BeforeAddAccount([
+            'account' => $_user,
+        ]);
+        Tinebase_Event::fireEvent($event);
+        
         if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(
             __METHOD__ . '::' . __LINE__ . ' Create new user ' . $_user->accountLoginName);
 
@@ -406,7 +398,7 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
             $_passwordRepeat = '';
         }
         if (!$_ignorePwdPolicy) {
-            Tinebase_User::getInstance()->checkPasswordPolicy($_password, $_user);
+            Tinebase_User_PasswordPolicy::checkPasswordPolicy($_password, $_user);
         }
 
         try {
@@ -442,7 +434,9 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
 
         } catch (Exception $e) {
             Tinebase_TransactionManager::getInstance()->rollBack();
-            Tinebase_Exception::log($e);
+            if (! $e instanceof Tinebase_Exception_SystemGeneric) {
+                Tinebase_Exception::log($e);
+            }
             throw $e;
         }
 
@@ -470,13 +464,16 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
     {
         try {
             $existing = Tinebase_User::getInstance()->getUserByLoginName($user->accountLoginName);
+            if ($existing->is_deleted) {
+                return true;
+            }
             if ($user->getId() === NULL || $existing->getId() !== $user->getId()) {
                 throw new Tinebase_Exception_SystemGeneric('Login name already exists. Please choose another one.');
             }
         } catch (Tinebase_Exception_NotFound $tenf) {
         }
         
-        return TRUE;
+        return true;
     }
     
     /**
@@ -514,35 +511,36 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
             $user->accountPrimaryGroup = $defaultUserGroup->getId();
         }
     }
-    
+
     /**
      * delete accounts
      *
-     * @param   mixed $_accountIds  array of account ids
+     * @param mixed $_accountIds array of account ids
      * @return  array with success flag
      * @throws  Tinebase_Exception_Record_NotAllowed
+     * @throws Tinebase_Exception_Confirmation
      */
     public function delete($_accountIds)
     {
         $this->checkRight('MANAGE_ACCOUNTS');
         
         $groupsController = Admin_Controller_Group::getInstance();
-        
+
         foreach ((array)$_accountIds as $accountId) {
             if ($accountId === Tinebase_Core::getUser()->getId()) {
                 $message = 'You are not allowed to delete yourself!';
                 Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__ . ' ' . $message);
                 throw new Tinebase_Exception_AccessDenied($message);
             }
-            
+        }
+        
+        $this->_checkAccountDeletionConfig($_accountIds);
+        
+        foreach ((array)$_accountIds as $accountId) {
             Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . " about to remove user with id: {$accountId}");
             
             $oldUser = $this->get($accountId);
-
-            $eventBefore = new Admin_Event_BeforeDeleteAccount();
-            $eventBefore->account = $oldUser;
-            Tinebase_Event::fireEvent($eventBefore);
-
+            
             $memberships = $groupsController->getGroupMemberships($accountId);
             if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . " removing user from groups: " . print_r($memberships, true));
             
@@ -608,4 +606,53 @@ class Admin_Controller_User extends Tinebase_Controller_Abstract
             Tinebase_User::getInstance()->updateUserInSqlBackend($user);
         }
     }
+    
+    protected function _checkAccountDeletionConfig($_accountIds)
+    {
+        $context = $this->getRequestContext();
+
+        if ($context && is_array($context) && 
+            (array_key_exists('clientData', $context) && array_key_exists('confirm', $context['clientData'])
+            || array_key_exists('confirm', $context))) {
+            return;
+        }
+
+        $userData = '<br />';
+
+        foreach ((array)$_accountIds as $accountId) {
+            $oldUser = $this->get($accountId)->getTitle();
+            $userData .= "$oldUser <br />";
+        }
+
+        $translation = Tinebase_Translation::getTranslation($this->_applicationName);
+        $configs = Tinebase_Config::getInstance()->getDefinition(Tinebase_Config::ACCOUNT_DELETION_EVENTCONFIGURATION);
+        
+        $exception = new Tinebase_Exception_Confirmation(
+            $translation->_('Delete user will trigger the [V] events, do you still want to execute this action?'));
+        
+        foreach ($configs['content'] as $key => $content) {
+            switch ($key) {
+                case Tinebase_Config::ACCOUNT_DELETION_DELETE_PERSONAL_CONTAINER:
+                case Tinebase_Config::ACCOUNT_DELETION_KEEP_AS_CONTACT:
+                case Tinebase_Config::ACCOUNT_DELETION_KEEP_ORGANIZER_EVENTS:
+                case Tinebase_Config::ACCOUNT_DELETION_KEEP_AS_EXTERNAL_ATTENDER:
+                case Tinebase_Config::ACCOUNT_DELETION_DELETE_PERSONAL_FOLDERS:
+                case Tinebase_Config::ACCOUNT_DELETION_DELETE_EMAIL_ACCOUNTS:
+                    $label = $translation->_($content['label']);
+                    $enable = Tinebase_Config::getInstance()->get(Tinebase_Config::ACCOUNT_DELETION_EVENTCONFIGURATION)->{$key};
+                    $enable =  $enable === true ? '[V]' : '[ ]';
+                $userData .= "<br /> $enable $label";
+                    break;
+                case Tinebase_Config::ACCOUNT_DELETION_ADDITIONAL_TEXT:
+                    $text = Tinebase_Config::getInstance()->get(Tinebase_Config::ACCOUNT_DELETION_EVENTCONFIGURATION)->{$key};
+                    $userData .= "<br /> $text <br />";
+                    break;
+                default;
+                    break;
+            }
+        }
+        
+        $exception->setInfo($userData);
+        throw $exception;
+    }
 }
