@@ -1,4 +1,5 @@
 <?php
+
 /**
  * Tine 2.0
  *
@@ -6,7 +7,7 @@
  * @subpackage  Frontend
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Lars Kneschke <l.kneschke@metaways.de>
- * @copyright   Copyright (c) 2011-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2011-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  *
  */
 
@@ -400,6 +401,15 @@ class Calendar_Convert_Event_VCalendar_Abstract extends Tinebase_Convert_VCalend
             $sabrePropertyParser = new Calendar_Convert_Event_VCalendar_SabrePropertyParser($vcalendar);
             foreach ($event->xprops()[Calendar_Model_Event::XPROPS_IMIP_PROPERTIES] as $prop) {
                 try {
+                    $propArr = explode("\r\n", $prop);
+                    $prop = array_shift($propArr);
+                    foreach ($propArr as $line) {
+                        if ($line[0] === "\t" || $line[0] === ' ') {
+                            $prop .= substr($line, 1);
+                        } else {
+                            $prop .= $line;
+                        }
+                    }
                     $propObj = $sabrePropertyParser->parseProperty($prop);
                     $vevent->__set($propObj->name, $propObj);
                 } catch (\Sabre\VObject\ParseException $svope) {
@@ -501,14 +511,16 @@ class Calendar_Convert_Event_VCalendar_Abstract extends Tinebase_Convert_VCalend
         
         Calendar_Model_Attender::resolveAttendee($event->attendee, FALSE, $event);
 
+        /** @var Calendar_Model_Attender $eventAttendee */
         foreach($event->attendee as $eventAttendee) {
             $attendeeEmail = $eventAttendee->getEmail();
 
+            $role = in_array($eventAttendee->role, ['REQ', 'OPT']) ? $eventAttendee->role : 'REQ';
             $parameters = array(
                 'CN'       => $eventAttendee->getName(),
                 'CUTYPE'   => $this->_getAttendeeCUType($eventAttendee),
                 'PARTSTAT' => $eventAttendee->status,
-                'ROLE'     => "{$eventAttendee->role}-PARTICIPANT",
+                'ROLE'     => "{$role}-PARTICIPANT",
                 'RSVP'     => $eventAttendee->isSame($this->_calendarUser) ? 'TRUE' : 'FALSE',
             );
             if (strpos($attendeeEmail, '@') !== false) {
@@ -1146,7 +1158,7 @@ class Calendar_Convert_Event_VCalendar_Abstract extends Tinebase_Convert_VCalend
                          */
                         $url = $property->getValue();
                         $urlParts = parse_url($url);
-                        $host = $urlParts['host'];
+                        $host = $urlParts['host'] ?? null;
                         $name = pathinfo($urlParts['path'], PATHINFO_BASENAME);
 
                         // iCal 10.7 places URI before uploading
@@ -1308,6 +1320,9 @@ class Calendar_Convert_Event_VCalendar_Abstract extends Tinebase_Convert_VCalend
         } else {
             $date = date_create($dateString);
         }
+        if (! $date) {
+            throw new Tinebase_Exception_UnexpectedValue('Could not create DateTime from date string: ' . $dateString);
+        }
         $date->setTimezone(new DateTimeZone('UTC'));
         return $date;
     }
