@@ -5,7 +5,7 @@
  * @package     Tinebase
  * @subpackage  Server
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
- * @copyright   Copyright (c) 2007-2018 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2007-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  * @author      Philipp Schüle <p.schuele@metaways.de>
  *
  */
@@ -94,7 +94,9 @@ class Tinebase_Core
      * constant for database adapter
      */
     const DB = 'dbAdapter';
-    
+
+    const DB_EXTERNAL = 'dbExt';
+
     /**
      * constant for database adapter name
      * 
@@ -249,7 +251,7 @@ class Tinebase_Core
         $request = self::getRequest();
 
         // we need to initialize sentry at the very beginning to catch ALL errors
-        $ravenClient = self::setupSentry();
+        self::setupSentry();
         
         // check transaction header
         if ($request->getHeaders()->has('X-TINE20-TRANSACTIONID')) {
@@ -257,8 +259,10 @@ class Tinebase_Core
             if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
                 . " Client transaction $transactionId");
             Tinebase_Log_Formatter::setTransactionId(substr($transactionId, 0, 5));
-            if ($ravenClient) {
-                $ravenClient->tags['transaction_id'] = $transactionId;
+            if (Tinebase_Core::isRegistered('SENTRY')) {
+                Sentry\configureScope(function (\Sentry\State\Scope $scope) use ($transactionId): void {
+                    $scope->setTag('transaction_id', $transactionId);
+                });
             }
         }
 
@@ -305,7 +309,9 @@ class Tinebase_Core
      */
     public static function isHttpsRequest()
     {
-        return (! empty($_SERVER['HTTPS']) && strtoupper($_SERVER['HTTPS']) != 'OFF');
+        return (!empty($_SERVER['HTTPS']) && strtolower($_SERVER['HTTPS']) !== 'off') ||
+            (!empty($_SERVER['HTTP_X_FORWARDED_PROTO']) && strtolower($_SERVER['HTTP_X_FORWARDED_PROTO']) === 'https')
+            || (!empty($_SERVER['HTTP_X_FORWARDED_SSL']) && strtolower($_SERVER['HTTP_X_FORWARDED_SSL']) === 'on');
     }
     
     /**
@@ -545,8 +551,10 @@ class Tinebase_Core
 
         // be aware of race condition between is_file and include_once => somebody may have deleted the file
         // yes it does get deleted! => check result of include_once
-        if (TINE20_BUILDTYPE !== 'DEVELOPMENT' && is_file($cacheFile) && true === @include_once($cacheFile) &&
-                class_exists('Tine20Container')) {
+        if (defined('TINE20_BUILDTYPE') && TINE20_BUILDTYPE !== 'DEVELOPMENT' &&
+            is_file($cacheFile) && true === @include_once($cacheFile) &&
+            class_exists('Tine20Container'))
+        {
             /** @noinspection PhpUndefinedClassInspection */
             $container = new Tine20Container();
         } else {
@@ -571,7 +579,8 @@ class Tinebase_Core
         $container = new ContainerBuilder();
 
         $container->register(RequestInterface::class)
-            ->setFactory('\Zend\Diactoros\ServerRequestFactory::fromGlobals');
+            ->setFactory('\Laminas\Diactoros\ServerRequestFactory::fromGlobals')
+            ->setPublic(true);
 
         try {
             $applications = Tinebase_Application::getInstance()->getApplications();
@@ -676,9 +685,9 @@ class Tinebase_Core
             $buildType = Tinebase_Core::detectBuildType();
         }
         define('TINE20_BUILDTYPE', $buildType);
-        define('TINE20_CODENAME',      '2020.08');
-        define('TINE20_PACKAGESTRING', '2020.08.8');
-        define('TINE20_RELEASETIME', '2021-01-21 10:28:14');
+        define('TINE20_CODENAME',      '2021.12');
+        define('TINE20_PACKAGESTRING', '2021.12.1');
+        define('TINE20_RELEASETIME', '2021-12-16 11:48:28');
     }
 
     /**
@@ -1092,7 +1101,39 @@ class Tinebase_Core
         
         return $db;
     }
-    
+
+    /**
+     * @param string $dbName
+     * @return Zend_Db_Adapter_Abstract
+     * @throws Tinebase_Exception_Backend_Database
+     */
+    public static function setupDatabaseConnectionByName(string $dbName): Zend_Db_Adapter_Abstract
+    {
+        $dbConfig = self::getConfig();
+
+        if (!isset($dbConfig->{Tinebase_Config::EXTERNAL_DATABASE})) {
+            die ("external database section not found in central configuration file.\n");
+        }
+
+        $dbConfig = $dbConfig->{Tinebase_Config::EXTERNAL_DATABASE};
+        if (!isset($dbConfig->{$dbName})) {
+            die ("external database section with name '$dbName' not found in central configuration file.\n");
+        }
+
+        $dbConfig = $dbConfig->{$dbName};
+        if (!isset($dbConfig->useUtf8mb4)) {
+            die ("external database section with name '$dbName' does not provide mandatory useUtf8mb4 flag.\n");
+        }
+        if (!isset($dbConfig->tableprefix)) {
+            $dbConfig->tableprefix = SQL_TABLE_PREFIX;
+        }
+
+        $db = self::createAndConfigureDbAdapter($dbConfig->toArray());
+        $db->table_prefix = $dbConfig->tableprefix;
+
+        return $db;
+    }
+
     /**
      * create db adapter and configure it for Tine 2.0
      * 
@@ -1109,9 +1150,13 @@ class Tinebase_Core
         }
 
         if ($dbBackend === NULL) {
+            if (!isset($dbConfigArray['adapter'])) {
+                $dbConfigArray['adapter'] = self::PDO_MYSQL;
+            }
             $constName = 'self::' . strtoupper($dbConfigArray['adapter']);
             if (empty($dbConfigArray['adapter']) || ! defined($constName)) {
-                self::getLogger()->warn(__METHOD__ . '::' . __LINE__ . ' Wrong/no db adapter configured (' . $dbConfigArray['adapter'] . '). Using default: ' . self::PDO_MYSQL);
+                self::getLogger()->notice(__METHOD__ . '::' . __LINE__
+                    . ' Wrong db adapter configured (' . $dbConfigArray['adapter'] . '). Using default: ' . self::PDO_MYSQL);
                 $dbBackend = self::PDO_MYSQL;
                 $dbConfigArray['adapter'] = self::PDO_MYSQL;
             } else {
@@ -1500,29 +1545,19 @@ class Tinebase_Core
      *
      * @param string $index
      * @param mixed $value
+     * @param bool $returnCurrent
+     * @return null|mixed
      * @throws Tinebase_Exception_InvalidArgument
      */
-    public static function set($index, $value)
+    public static function set($index, $value, $returnCurrent = false)
     {
+        $retVal = $returnCurrent ? self::get($index) : null;
         if ($index === self::USER) {
-            if ($value === null) {
-                throw new Tinebase_Exception_InvalidArgument('Invalid user object!');
-            }
-            if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) {
-                if ($value instanceof Tinebase_Model_FullUser) {
-                    $userString =  $value->accountLoginName;
-                } else if ($value instanceof Tinebase_Model_User) {
-                    $userString = $value->accountDisplayName;
-                } else {
-                    $userString = var_export($value, true);
-                }
-                
-                Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . ' Setting user ' . $userString);
-                Tinebase_Log_Formatter::resetUsername();
-            }
+            self::setUser($value);
+        } else {
+            Zend_Registry::set($index, $value);
         }
-        
-        Zend_Registry::set($index, $value);
+        return $retVal;
     }
 
     /**
@@ -1681,11 +1716,47 @@ class Tinebase_Core
     /**
      * set current user account
      *
-     * @param Tinebase_Model_FullUser $user the user account record
+     * @param mixed $user the user account record / string
+     * @return mixed
      */
     public static function setUser($user)
     {
-        self::set(self::USER, $user);
+        if ($user === null) {
+            throw new Tinebase_Exception_InvalidArgument('Invalid user object!');
+        }
+
+        if ($user instanceof Tinebase_Model_User) {
+            if (($oldUser = self::getUser()) && $oldUser instanceof Tinebase_Model_User &&
+                    $user->getId() === $oldUser->getId()) {
+                return $user;
+            }
+            $userString = $user->accountDisplayName;
+        } else {
+            $userString = var_export($user, true);
+        }
+
+        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) {
+            Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . ' Setting user ' . $userString);
+            Tinebase_Log_Formatter::resetUsername();
+        }
+
+        if (Tinebase_Core::isRegistered('SENTRY')) {
+            Sentry\configureScope(function (\Sentry\State\Scope $scope) use ($user, $userString): void {
+                $scope->setUser([
+                    'id' => $user instanceof Tinebase_Model_User ? $user->getId() : '',
+                    'email' => $user instanceof Tinebase_Model_User ? $user->accountEmailAddress : '',
+                    'user' => $userString,
+                ]);
+            });
+        }
+
+        Zend_Registry::set(self::USER, $user);
+        
+        // now that we have the right user => proper acls => flush all acls caches
+        // MC not only flushes its cache, it recreates the already created models
+        Tinebase_ModelConfiguration::resetAllCreatedModels();
+
+        return $user;
     }
 
     /**
@@ -1781,6 +1852,25 @@ class Tinebase_Core
         return self::get(self::DB);
     }
 
+    /**
+     * @param string $dbName
+     * @return Zend_Db_Adapter_Abstract
+     * @throws Tinebase_Exception_InvalidArgument
+     */
+    public static function getExternalDb(string $dbName): Zend_Db_Adapter_Abstract
+    {
+        if (!is_array($externalDbs = self::get(self::DB_EXTERNAL))) {
+            $externalDbs = [];
+        }
+        if (!isset($externalDbs[$dbName])) {
+            $db = self::setupDatabaseConnectionByName($dbName);
+            $externalDbs[$dbName] = $db;
+            self::set(self::DB_EXTERNAL, $externalDbs);
+        }
+
+        return $externalDbs[$dbName];
+    }
+
     /**
      * checks if the DB is registered already
      *
@@ -1891,12 +1981,12 @@ class Tinebase_Core
         } else {
             $protocol = parse_url($configUrl, PHP_URL_SCHEME);
             $hostname = parse_url($configUrl, PHP_URL_HOST);
-            $pathname = rtrim(str_replace($protocol . '://' . $hostname, '', $configUrl), '/');
+            $pathname = parse_url($configUrl, PHP_URL_PATH);
         }
 
         switch ($part) {
             case self::GET_URL_PATH:
-                $url = $pathname;
+                $url = '' === $pathname || null === $pathname ? '/' : $pathname;
                 break;
             case self::GET_URL_HOST:
                 $url = $hostname;
@@ -2144,9 +2234,17 @@ class Tinebase_Core
      * @param string $submodule
      * @return string
      */
-    public static function getTineUserAgent($submodule = '')
+    public static function getTineUserAgent(string $submodule = '')
     {
-        return 'Tine 2.0 ' . $submodule . ' (version ' . TINE20_CODENAME . ' - ' . TINE20_PACKAGESTRING . ')';
+        $userAgent = Tinebase_Config::getInstance()->get(Tinebase_Config::BRANDING_TITLE);
+        if (! empty($submodule)) {
+            $userAgent .= ' ' . $submodule;
+        }
+        if (defined('TINE20_CODENAME') && defined('TINE20_PACKAGESTRING') ) {
+            $userAgent .= ' (Version ' . TINE20_CODENAME . ' - ' . TINE20_PACKAGESTRING . ')';
+        }
+
+        return $userAgent;
     }
 
     /**
@@ -2349,12 +2447,12 @@ class Tinebase_Core
     /**
      * setup sentry Raven_Client
      *
-     * @return Raven_Client
+     * @return void
      */
     public static function setupSentry()
     {
         if (self::isRegistered('SENTRY')) {
-            return self::getSentry();
+            return;
         }
 
         $tinebaseConfig = Setup_Controller::getInstance()->isInstalled('Tinebase')
@@ -2362,42 +2460,30 @@ class Tinebase_Core
             : self::getConfig();
         $sentryServerUri = $tinebaseConfig->{Tinebase_Config::SENTRY_URI};
         if (! $sentryServerUri) {
-            return null;
+            return;
         }
 
         Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . ' Registering Sentry Error Handler');
 
-        if (! defined('TINE20_CODENAME')) {
+        if (! defined('TINE20_CODENAME') || ! defined('TINE20_PACKAGESTRING')) {
             self::setupBuildConstants();
         }
 
-        $config = [
+        Sentry\init([
+            'dsn' => $sentryServerUri,
+            'max_breadcrumbs' => 50,
+            'error_types' => Tinebase_Config::getInstance()->{Tinebase_Config::SENTRY_LOGLEVL},
             'release' => TINE20_CODENAME . ' ' . TINE20_PACKAGESTRING,
-            'tags' => array(
+            'environment' => defined('TINE20_BUILDTYPE') && TINE20_BUILDTYPE === 'DEVELOPMENT'
+                ? 'development'
+                : 'production',
+            'tags' => [
                 'php_version' => phpversion(),
-            ),
-        ];
-        $client = new Tinebase_Sentry_Raven_Client($sentryServerUri, $config);
-        $serializer = new Tinebase_Sentry_Raven_Serializer();
-        $client->setSerializer($serializer);
-        $error_handler = new Raven_ErrorHandler($client, false,
-            Tinebase_Config::getInstance()->{Tinebase_Config::SENTRY_LOGLEVL});
-        $error_handler->registerExceptionHandler();
-        $error_handler->registerErrorHandler();
-        $error_handler->registerShutdownFunction();
-
-        self::set('SENTRY', $client);
-
-        return $client;
-    }
-
-    /**
-     * @return Raven_client|null
-     */
-    public static function getSentry()
-    {
-        $sentryClient = Tinebase_Core::isRegistered('SENTRY') ? Tinebase_Core::get('SENTRY') : null;
-        return $sentryClient;
+                'tine_url' => Tinebase_Config::getInstance()->get(Tinebase_Config::TINE20_URL) ?: 'unknown',
+                'request_id' => Tinebase_Log_Formatter::getRequestId(),
+            ],
+        ]);
+        self::set('SENTRY', true);
     }
 
     /**
