@@ -110,7 +110,6 @@ class Tinebase_CustomField implements Tinebase_Controller_SearchInterface
      */
     public function addCustomField(Tinebase_Model_CustomField_Config $_record)
     {
-
         $transId = Tinebase_TransactionManager::getInstance()->startTransaction(Tinebase_Core::getDb());
         try {
             try {
@@ -128,13 +127,13 @@ class Tinebase_CustomField implements Tinebase_Controller_SearchInterface
             $transId = null;
 
             if ($_record->is_system) {
-                $app = Tinebase_Application::getInstance()->getApplicationById($_record->application_id);
+                Tinebase_Application::getInstance()->getApplicationById($_record->application_id);
                 /** @var Tinebase_Record_Interface $model */
                 $model = $_record->model;
                 // clear the MC cache
                 $model::resetConfiguration();
 
-                Setup_SchemaTool::updateAllSchema();
+                Setup_SchemaTool::updateSchema([$model]);
             }
 
             if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) {
@@ -232,10 +231,7 @@ class Tinebase_CustomField implements Tinebase_Controller_SearchInterface
         $cacheId = Tinebase_Helper::convertCacheId('getCustomFieldsForApplication' . $cfIndex);
         $result = $cache->load($cacheId);
         
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-            . ' Before - MEMORY: ' . memory_get_usage(TRUE)/1024/1024 . ' MBytes');
-        
-        if (! $result) {
+        if (false === $result) {
             $filterValues = array(array(
                 'field'     => 'application_id', 
                 'operator'  => 'equals', 
@@ -260,23 +256,23 @@ class Tinebase_CustomField implements Tinebase_Controller_SearchInterface
                 }
                 $result = $this->_backendConfig->search($filter);
             } finally {
-                $this->_backendConfig->setNoSystemCFs();
+                if ($_getSystemCFs) {
+                    $this->_backendConfig->setNoSystemCFs();
+                }
             }
 
         
             if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
                 . ' Got ' . count($result) . ' uncached custom fields for app id ' . $applicationId . ' (cacheid: ' . $cacheId . ')');
-            if (Tinebase_Core::isLogLevel(Zend_Log::TRACE) && (count($result) > 0)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-                . print_r($result->toArray(), TRUE));
             
             $cache->save($result, $cacheId, array('customfields'));
+        } else {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Got ' . count($result) . ' cached custom fields for app id ' . $applicationId . ' (cacheid: ' . $cacheId . ')');
         }
         
         $this->_cfByApplicationCache[$cfIndex] = $result;
         
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-            . ' After - MEMORY: ' . memory_get_usage(TRUE)/1024/1024 . ' MBytes');
-        
         return $result;
     }
     
