@@ -218,7 +218,7 @@ class Tinebase_EmailUser_Imap_Dovecot extends Tinebase_EmailUser_Sql implements
         'emailGID'          => 'gid', 
         'emailLastLogin'    => 'last_login',
         'emailMailQuota'    => 'quota_bytes',
-        #'emailSieveQuota'   => 'quota_message',
+        'emailSieveQuota'   => 'quota_message',
     
         'emailMailSize'     => 'storage',
         'emailSieveSize'    => 'messages',
@@ -235,7 +235,7 @@ class Tinebase_EmailUser_Imap_Dovecot extends Tinebase_EmailUser_Sql implements
         'emailGID'          => 'USERTABLE',
         'emailLastLogin'    => 'USERTABLE',
         'emailMailQuota'    => 'USERTABLE',
-        #'emailSieveQuota'   => 'USERTABLE',
+        'emailSieveQuota'   => 'USERTABLE',
 
         'emailMailSize'     => 'QUOTATABLE',
         'emailSieveSize'    => 'QUOTATABLE',
@@ -293,7 +293,49 @@ class Tinebase_EmailUser_Imap_Dovecot extends Tinebase_EmailUser_Sql implements
         $this->_config['emailUID']    = $this->_config['uid'];
         $this->_config['emailGID']    = $this->_config['gid'];
     }
-    
+
+    /**
+     * interceptor before update
+     *
+     * @param array{loginname:string, domain:string, userid:string} $emailUserData
+     */
+    protected function _beforeUpdate(&$emailUserData)
+    {
+        $result = $this->_getExistingUser($emailUserData);
+        if (count($result) > 0) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::'
+                . __LINE__ . ' Found old record - Switching from USERID ' . print_r($result, true) . ' to ' . $emailUserData['userid']);
+            $emailUserData['oldUserId'] = $result[0];
+        }
+    }
+
+    /**
+     * interceptor before add
+     *
+     * @param array{loginname:string, domain:string, userid:string} $emailUserData
+     */
+    protected function _beforeAdd(&$emailUserData)
+    {
+        // prevent duplicate loginname
+        $result = $this->_getExistingUser($emailUserData);
+        if (count($result) > 0) {
+            $translate = Tinebase_Translation::getTranslation('Tinebase');
+            throw new Tinebase_Exception_SystemGeneric($translate->_('Email account already exists'));
+        }
+    }
+
+    protected function _getExistingUser($emailUserData)
+    {
+        $select = $this->_getSelect();
+        $select->where($this->_db->quoteIdentifier($this->_userTable . '.' . 'loginname') . " = ?",
+            $emailUserData['loginname']);
+        if (isset($emailUserData['userid'])) {
+            $select->where($this->_db->quoteIdentifier($this->_userTable . '.' . 'userid') . " != ?",
+                $emailUserData['userid']);
+        }
+        return $select->query()->fetchAll(Zend_Db::FETCH_COLUMN, 0);
+    }
+
     /**
      * get the basic select object to fetch records from the database
      *  
@@ -341,12 +383,8 @@ class Tinebase_EmailUser_Imap_Dovecot extends Tinebase_EmailUser_Sql implements
             $select->where($this->_db->quoteIdentifier($this->_userTable . '.' . 'instancename') . ' = ?',
                 $this->_config['instanceName']);
         } else if (isset($this->_config['domain']) && ! empty($this->_config['domain'])) {
-            $domains = Tinebase_EmailUser::getAllowedDomains();
-            if (count($domains) === 0) {
-                $domains = [$this->_config['domain']];
-            }
-            $select->where($this->_db->quoteIdentifier($this->_userTable . '.' . 'domain') . ' IN (?)',
-                $domains);
+            $select->where($this->_db->quoteIdentifier($this->_userTable . '.' . 'domain') . ' = ?',
+                $this->_config['domain']);
         } else {
             $select->where($this->_db->quoteIdentifier($this->_userTable . '.' . 'domain') . " = ''");
         }
@@ -425,11 +463,11 @@ class Tinebase_EmailUser_Imap_Dovecot extends Tinebase_EmailUser_Sql implements
                         case 'emailGID':
                             $rawData[$property] = !empty($this->_config['gid']) ? $this->_config['gid'] : $value;
                             break;
+                        case 'emailSieveQuota':
                         case 'emailMailQuota':
                             $rawData[$property] = (empty($value) || $value < (1024 * 1024)) ? 0 :
                                 (int)($value / (1024 * 1024));
                             break;
-                            
                         default:
                             $rawData[$property] = $value;
                             break;
@@ -448,18 +486,15 @@ class Tinebase_EmailUser_Imap_Dovecot extends Tinebase_EmailUser_Sql implements
 
         $emailUsername = $this->getEmailUserName($_user, $_newUserProperties->accountEmailAddress);
 
-        if (strpos($_newUserProperties->accountEmailAddress, '@') !== false) {
-            list($localPart, $domain) = explode('@', $_newUserProperties->accountEmailAddress, 2);
-        } else {
-            list($localPart, $usernamedomain) = explode('@', $emailUsername, 2);
-            $domain = empty($this->_config['domain']) ? $usernamedomain : $this->_config['domain'];
-        }
-        $rawData['domain'] = $domain;
+        list($localPart, $usernamedomain) = explode('@', $emailUsername, 2);
+        $domain = empty($this->_config['domain']) ? $usernamedomain : $this->_config['domain'];
 
         if (isset($this->_config['instanceName'])) {
             $rawData['instancename'] = $this->_config['instanceName'];
         }
 
+        $rawData['domain'] = $domain;
+
         $rawData[$this->_propertyMapping['emailHome']] = $this->_getEmailHome($emailUsername, $localPart, $domain);
         $rawData[$this->_propertyMapping['emailUsername']] = $emailUsername;
 
