@@ -145,6 +145,24 @@ abstract class Tinebase_EmailUser_Sql extends Tinebase_User_Plugin_Abstract
         
         $this->_db->delete($this->_userTable, $where);
     }
+
+
+    /**
+     * delete all email users
+     *
+     */
+    public function deleteAllEmailUsers()
+    {
+        $where = $this->_appendClientIdOrDomain();
+
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+            . ' ' . print_r($where, TRUE));
+
+        $rowCount = $this->_db->delete($this->_userTable, $where);
+
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ .
+            ' delete : ' . $rowCount . ' rows');
+    }
     
     /**
      * append domain if set or domain IS NULL
@@ -160,11 +178,7 @@ abstract class Tinebase_EmailUser_Sql extends Tinebase_User_Plugin_Abstract
             $cond = $this->_db->quoteInto($this->_db->quoteIdentifier($this->_userTable . '.' . 'client_idnr') . ' = ?', $this->_clientId);
         } else {
             if ((isset($this->_config['domain']) || array_key_exists('domain', $this->_config)) && ! empty($this->_config['domain'])) {
-                $domains = Tinebase_EmailUser::getAllowedDomains();
-                if (count($domains) === 0) {
-                    $domains = [$this->_config['domain']];
-                }
-                $cond = $this->_db->quoteInto($this->_db->quoteIdentifier($this->_userTable . '.' . 'domain') . ' IN (?)', $domains);
+                $cond = $this->_db->quoteInto($this->_db->quoteIdentifier($this->_userTable . '.' . 'domain') . ' = ?',   $this->_config['domain']);
             } else {
                 $cond = $this->_db->quoteIdentifier($this->_userTable . '.' . 'domain') . " =''";
             }
@@ -295,6 +309,8 @@ abstract class Tinebase_EmailUser_Sql extends Tinebase_User_Plugin_Abstract
                 substr($_userId, 0,32) . '#~#%') . ')'
         );
         $this->_appendClientIdOrDomain($where);
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ .
+            ' where: ' . print_r($where, true));
         
         $this->_db->update($this->_userTable, $values, $where);
     }
@@ -344,7 +360,7 @@ abstract class Tinebase_EmailUser_Sql extends Tinebase_User_Plugin_Abstract
             }
             
             $insertData = $emailUserData;
-            $this->_beforeAddOrUpdate($insertData);
+            $this->_beforeAdd($insertData);
 
             $insertData = array_intersect_key($insertData, $this->getSchema());
             $this->_db->insert($this->_userTable, $insertData);
@@ -361,17 +377,25 @@ abstract class Tinebase_EmailUser_Sql extends Tinebase_User_Plugin_Abstract
             throw $zdse;
         }
     }
-    
+
     /**
      * interceptor before add
-     * 
-     * @param array $emailUserData
+     *
+     * @param array{loginname:string, domain:string, userid:string} $emailUserData
      */
-    protected function _beforeAddOrUpdate(&$emailUserData)
+    protected function _beforeAdd(&$emailUserData)
     {
-        
     }
-    
+
+    /**
+     * interceptor before update
+     *
+     * @param array{loginname:string, domain:string, userid:string} $emailUserData
+     */
+    protected function _beforeUpdate(&$emailUserData)
+    {
+    }
+
     /**
      * interceptor after add
      * 
@@ -429,35 +453,46 @@ abstract class Tinebase_EmailUser_Sql extends Tinebase_User_Plugin_Abstract
 
         if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
             . ' Updating ' . $this->_userTable . ' user ' . $emailUserData[$this->_propertyMapping['emailUsername']]);
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-            . ' ' . print_r($emailUserData, TRUE));
         
-        $where = array(
-            $this->_db->quoteInto($this->_db->quoteIdentifier($this->_propertyMapping['emailUserId']) . ' = ?', $emailUserData[$this->_propertyMapping['emailUserId']])
-        );
-        $this->_appendClientIdOrDomain($where);
-        
-        try {
-            $transactionId = Tinebase_TransactionManager::getInstance()->startTransaction($this->_db);
-            
-            $updateData = $emailUserData;
-            
-            $this->_beforeAddOrUpdate($updateData);
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+            . ' emailUserData :  ' . print_r($emailUserData, true));
 
-            $updateData = array_intersect_key($updateData, $this->getSchema());
+        $transactionId = Tinebase_TransactionManager::getInstance()->startTransaction($this->_db);
+
+        $updateData = $emailUserData;
+
+        $this->_beforeUpdate($updateData);
+
+        $id = $updateData['oldUserId'] ?? $emailUserData[$this->_propertyMapping['emailUserId']];
+        $where = [
+            $this->_db->quoteInto(
+                $this->_db->quoteIdentifier($this->_propertyMapping['emailUserId']) . ' = ?', $id
+            )
+        ];
+        $this->_appendClientIdOrDomain($where);
+
+        $updateData = array_intersect_key($updateData, $this->getSchema());
+        try {
             $this->_db->update($this->_userTable, $updateData, $where);
-            
-            $this->_afterAddOrUpdate($emailUserData);
-            
-            Tinebase_TransactionManager::getInstance()->commitTransaction($transactionId);
-            
-            $this->inspectGetUserByProperty($_updatedUser);
-            
         } catch (Zend_Db_Statement_Exception $zdse) {
-            Tinebase_TransactionManager::getInstance()->rollBack();
-            Tinebase_Core::getLogger()->err(__METHOD__ . '::' . __LINE__ . ' Error while updating email user');
-            throw $zdse;
+            if (! Tinebase_Exception::isDbDuplicate($zdse)) {
+                Tinebase_Core::getLogger()->err(__METHOD__ . '::' . __LINE__ . ' Error while updating email user');
+                Tinebase_TransactionManager::getInstance()->rollBack();
+
+                throw $zdse;
+            } else {
+                Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__ . ' Duplicate: '
+                    . $zdse);
+                $translate = Tinebase_Translation::getTranslation('Tinebase');
+                throw new Tinebase_Exception_SystemGeneric($translate->_('Email account already exists'));
+            }
         }
+
+        $this->_afterAddOrUpdate($emailUserData);
+
+        Tinebase_TransactionManager::getInstance()->commitTransaction($transactionId);
+
+        $this->inspectGetUserByProperty($_updatedUser);
     }
     
     /**
@@ -558,6 +593,18 @@ abstract class Tinebase_EmailUser_Sql extends Tinebase_User_Plugin_Abstract
         return $result;
     }
 
+    /**
+     * @param Tinebase_Model_FullUser $_user
+     * @return Tinebase_Model_EmailUser of Tinebase_Model_EmailUser
+     */
+    public function getEmailUser(Tinebase_Model_FullUser $_user): ?Tinebase_Model_EmailUser
+    {
+        $rawUser = (array)$this->getRawUserById($_user);
+
+        // convert data to Tinebase_Model_EmailUser
+        return $this->_rawDataToRecord($rawUser);
+    }
+    
     /**
      * returns array with keys mailQuota and mailSize
      *
@@ -775,4 +822,33 @@ abstract class Tinebase_EmailUser_Sql extends Tinebase_User_Plugin_Abstract
 
         return str_replace($search, $replace, $this->_config['emailHome']);
     }
+
+
+    /**
+     * backup user to a dump file
+     *
+     * @param array $option
+     */
+    public function backup($option)
+    {
+        $backupDir = $option['backupDir'];
+
+        // hide password from shell via my.cnf
+        $domain = $this->_config['domain'];
+        $mycnf = $backupDir . '/my.cnf';
+
+        $mysqlBackEnd = new Setup_Backend_Mysql();
+        $mysqlBackEnd->createMyConf($mycnf);
+
+        //create the dump via mysqldump with --where to select the data we want to export
+        $cmd = "mysqldump --defaults-extra-file=$mycnf "
+            ."--single-transaction --max_allowed_packet=512M "
+            ."--opt --no-tablespaces "
+            . escapeshellarg($this->_config['dbname']) . ' '
+            . escapeshellarg($this->_userTable)
+            .' --where="' . "domain='$domain'" . '"'
+            ." | bzip2 > $backupDir/tine20_dovecot.sql.bz2";
+
+        exec($cmd);
+    }
 }
