@@ -38,8 +38,7 @@ trait Tinebase_Export_DocumentPdfTrait
         array $_additionalOptions = [],
         $_previewService = null
     ) {
-        $this->_previewService = $_previewService !== null ? $_previewService : static::$previewService !== null ?
-            static::$previewService : Tinebase_Core::getPreviewService();
+        $this->_previewService = $_previewService ?: (static::$previewService ?: Tinebase_Core::getPreviewService());
 
         $this->_format = 'pdf';
 
@@ -55,7 +54,11 @@ trait Tinebase_Export_DocumentPdfTrait
     public function write($_target = null)
     {
         $tempfile = Tinebase_TempFile::getTempPath() . '.' . $this->_getOldFormat();
-        parent::write($tempfile);
+        if ($this instanceof Tinebase_Export_Xls) {
+            parent::write($tempfile);
+        } else {
+            parent::save($tempfile);
+        }
 
         $this->_parentFile = $tempfile;
 
@@ -111,4 +114,4 @@ trait Tinebase_Export_DocumentPdfTrait
     {
         return parent::getDownloadFilename($_appName, $_format);
     }
-}
\ No newline at end of file
+}
