@@ -13,7 +13,7 @@ use \Psr\Http\Server\RequestHandlerInterface;
 use \Psr\Http\Server\MiddlewareInterface;
 use \Psr\Http\Message\ServerRequestInterface;
 use \Psr\Http\Message\ResponseInterface;
-use \Zend\Diactoros\Response;
+use \Laminas\Diactoros\Response;
 
 /**
  * FastRoute middleware, continues if a route matched, puts the matched Tinebase_Expressive_RouteHandler in the request
@@ -48,12 +48,13 @@ class Tinebase_Expressive_Middleware_FastRoute implements MiddlewareInterface
         $uri = preg_replace('/\/+$/', '', $uri);
 
         // if the tine20 server is located in a subdir, we need to remove the server path from the uri
-        $serverPath = Tinebase_Core::getUrl(Tinebase_Core::GET_URL_PATH);
-        $uri = preg_replace('/^' . preg_quote($serverPath, '/') . '/', '', $uri);
+        if ('/' !== ($serverPath = Tinebase_Core::getUrl(Tinebase_Core::GET_URL_PATH))) {
+            $uri = preg_replace('/^' . preg_quote($serverPath, '/') . '/', '', $uri);
+        }
 
         if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::'
             . __LINE__ . " FastRoute dispatching:\n" . $request->getMethod() . ' '. $uri . array_reduce(array_keys($request->getHeaders()), function($headers, $name) use ($request)  {
-                return $headers .= "\n$name: {$request->getHeaderLine($name)}";
+                return $headers .= PHP_EOL . $name . ': ' . ('authorization' === strtolower($name) ? '*****' : $request->getHeaderLine($name));
             }, ''));
 
         $routeInfo = $dispatcher->dispatch($request->getMethod(), $uri);
