@@ -13,7 +13,7 @@ use \Psr\Http\Server\RequestHandlerInterface;
 use \Psr\Http\Server\MiddlewareInterface;
 use \Psr\Http\Message\ServerRequestInterface;
 use \Psr\Http\Message\ResponseInterface;
-use \Zend\Diactoros\Response;
+use \Laminas\Diactoros\Response;
 
 /**
  * examines the response object and the request headers. Decides how to envelop the response
@@ -87,10 +87,10 @@ class Tinebase_Expressive_Middleware_ResponseEnvelop implements MiddlewareInterf
                 $headerStr .= "$name: {$values[0]}\n";
             }
 
-            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
-                __METHOD__ . '::' . __LINE__ . " Response headers: " . $headerStr);
-            if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(
-                __METHOD__ . '::' . __LINE__ . " Response body: " . $body->getContents());
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) {
+                Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . " Response headers: " . $headerStr);
+                Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . " Response body: " . $body->getContents());
+            }
         }
         return $response;
     }
