@@ -9,7 +9,7 @@
  * @author      Paul Mehrer <p.mehrer@metaways.de>
  */
 
-use \Zend\Diactoros\Response;
+use \Laminas\Diactoros\Response;
 
 /**
  * Tinebase Expressive Response class, the result object is stored here and awaits processing
@@ -21,4 +21,4 @@ class Tinebase_Expressive_Response extends Response
 {
     /** @var Tinebase_Record_RecordSet|Tinebase_Record_Interface */
     public $resultObject = null;
-}
\ No newline at end of file
+}
