@@ -42,13 +42,6 @@ class Felamimail_Frontend_ActiveSync extends ActiveSync_Frontend_Abstract implem
         Syncroton_Command_Sync::FILTER_1_MONTH_BACK,
     );
     
-    /**
-     * felamimail message controller
-     *
-     * @var Felamimail_Controller_Message
-     */
-    protected $_messageController;
-    
     /**
      * felamimail account
      * 
@@ -789,7 +782,27 @@ class Felamimail_Frontend_ActiveSync extends ActiveSync_Frontend_Abstract implem
         Felamimail_Controller_Folder::getInstance()->rename($fmailFolder->account_id, $folder->displayName, $fmailFolder->globalname);
         return $folder;
     }
-    
+
+    /**
+     * (non-PHPdoc)
+     * @see Syncroton_Data_IData::createFolder()
+     */
+    public function createFolder(Syncroton_Model_IFolder $folder)
+    {
+        if (empty($folder->parentId)) {
+            $account = $this->_getAccount();
+            $parentGlobalname = '';
+        } else {
+            $parent = Felamimail_Controller_Folder::getInstance()->get($folder->parentId);
+            $account = Felamimail_Controller_Account::getInstance()->get($parent->account_id);
+            $parentGlobalname = $parent->globalname;
+        }
+        $newFolder = Felamimail_Controller_Folder::getInstance()->create($account, $folder->displayName, $parentGlobalname);
+        $folder->serverId = $newFolder->getId();
+
+        return $folder;
+    }
+
     /**
      * (non-PHPdoc)
      * @see ActiveSync_Frontend_Abstract::toTineModel()
@@ -914,9 +927,8 @@ class Felamimail_Frontend_ActiveSync extends ActiveSync_Frontend_Abstract implem
         try {
             $folders = Felamimail_Controller_Folder::getInstance()->search($filter);
         } catch (Felamimail_Exception_IMAPInvalidCredentials $feiic) {
-            Tinebase_Exception::log($feiic, null, array(
-                'accountname' => $account->name
-            ));
+            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(
+                __METHOD__ . '::' . __LINE__ . ' ' . $feiic->getMessage());
             return array();
         }
         
