@@ -453,4 +453,128 @@ class Addressbook_Frontend_Cli extends Tinebase_Frontend_Cli_Abstract
 
         echo "Added privateData grant to $counter shared containers" . PHP_EOL;
     }
+
+
+    /**
+     * @param Zend_Console_Getopt $opts
+     * $opts -> container_id, fields and sprecialChar
+     * e.x -- --method=Addressbook.removeSpecialChar container_id='1234' fields='n_given,n_family' specialChar='\\'
+     * all Contacts with '\' in n_given and n_family remove '\'
+     * default fields n_given n_middle n_family
+     * @throws Tinebase_Exception_AccessDenied
+     * @throws Tinebase_Exception_InvalidArgument
+     */
+    public function removeSpecialChar(Zend_Console_Getopt $opts)
+    {
+        $args = $this->_parseArgs($opts);
+        $filter = [];
+        if (!isset($args['fields'])) {
+            $args['fields'] = $fields = ['n_given', 'n_middle', 'n_family'];
+        }
+
+        if (isset($args['container_id'])) {
+            $filter[] = [['field' => 'container_id', 'operator' => 'equals', 'value' => $args['container_id']]];
+        }
+
+        $fieldsFilter = [];
+        foreach ($args['fields'] as $field) {
+            $fieldsFilter[] = ['field' => $field, 'operator' => 'contains', 'value' => $args['specialChar']];
+        }
+
+        $filter[] = ['condition' => 'OR', 'filters' => $fieldsFilter];
+
+        $filter = Tinebase_Model_Filter_FilterGroup::getFilterForModel(Addressbook_Model_Contact::class, $filter);
+        $results = Addressbook_Controller_Contact::getInstance()->search($filter);
+
+        foreach ($results as $record) {
+            foreach ($args['fields'] as $field) {
+                if (isset($record[$field])) {
+                    $record[$field] = str_replace($args['specialChar'], '', $record[$field]);
+                }
+            }
+            Addressbook_Controller_Contact::getInstance()->update($record);
+        }
+
+    }
+
+    /**
+     * usage: method=Addressbook.importMailList csv=test.csv domain=secondarydomains
+     *csv file = "listname","listEmailAdress"
+     * @param Zend_Console_Getopt $opts
+     * @return false
+     * @throws Tinebase_Exception_AccessDenied
+     * @throws Tinebase_Exception_InvalidArgument
+     */
+    public function importMailList(Zend_Console_Getopt $opts)
+    {
+        $args = $this->_parseArgs($opts);
+        $csv = $args['csv'];
+
+        $config = Tinebase_Config::getInstance()->get(Tinebase_Config::SMTP)->toArray();
+        $domain = isset($args['domain']) ? $config[$args['domain']]: $config['primarydomain'];
+        if (!$csv) {
+            return 2;
+        }
+
+        $stream = fopen($csv, 'r');
+        if (!$stream) {
+            echo "file could not be opened: " . $csv . "\n";
+            return 2;
+        }
+        while ($line = fgetcsv($stream, 0, ',')) {
+            $list = Addressbook_Controller_List::getInstance()->search(Tinebase_Model_Filter_FilterGroup::getFilterForModel(
+                Addressbook_Model_List::class, [
+                ['field' => 'name', 'operator' => 'equals', 'value' => $line[0],
+            ]]))->getFirstRecord();
+
+            if(!$list) {
+                $list = Addressbook_Controller_List::getInstance()->create(new Addressbook_Model_List(
+                    ['name' => $line[0]]));
+            }
+
+            if( !isset($list->email) || $list->email === '') {
+                $list->email = $line[1] . '@' . $domain;
+            }
+            $list->list_type = 'MAILINGLIST';
+            $list->xprops()[Addressbook_Model_List::XPROP_USE_AS_MAILINGLIST] = 1;
+            Addressbook_Controller_List::getInstance()->update($list);
+        }
+        fclose($stream);
+        return 0;
+    }
+
+    /**
+     *    -d (dry run)
+     *    e.g. php tine20.php --method=Addressbook.clearUserContactsWithoutUser -d
+     * @param Zend_Console_Getopt $opts
+     * @return int
+     */
+    public function clearUserContactsWithoutUser(Zend_Console_Getopt $opts) {
+        $count = 0;
+        $backend = new Addressbook_Backend_Sql();
+
+        if ($opts->d) {
+            echo "Dry-run \n";;
+        }
+
+        $filter = Tinebase_Model_Filter_FilterGroup::getFilterForModel(Addressbook_Model_Contact::class,
+            [['field' => 'type', 'operator' => 'equals', 'value' => 'user']]);
+
+        $userContacts = Addressbook_Controller_Contact::getInstance()->search($filter);
+        foreach ($userContacts as $userContact) {
+            try {
+                Admin_Controller_User::getInstance()->get($userContact['account_id']);
+            }catch(Tinebase_Exception_NotFound $e) {
+                if ($opts->d) {
+                    echo "will remove contact: " . $userContact['n_fileas'] . " id: " . $userContact->getId() . "\n";
+                    continue;
+                }
+                $backend->delete($userContact->getId());
+                echo "remove contact: " . $userContact['n_fileas'] . "\n";
+                $count++;
+            }
+        }
+        echo "remove: " . $count . " contacts \n";
+        return 0;
+    }
 }
