@@ -118,6 +118,8 @@ class Setup_Frontend_Cli
             $this->_setConfig($_opts);
         } elseif(isset($_opts->clear_cache)) {
             $this->_clearCache($_opts);
+        } elseif(isset($_opts->clear_cache_dir)) {
+            $this->_clearCacheDir($_opts);
         } elseif(isset($_opts->create_admin)) {
             $this->_createAdminUser($_opts);
         } elseif(isset($_opts->getconfig)) {
@@ -172,9 +174,14 @@ class Setup_Frontend_Cli
         
         if ($_opts->install === true) {
             if (Setup_Controller::getInstance()->isInstalled('Tinebase')) {
-                // nothing to do
+                if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(
+                    __METHOD__ . '::' . __LINE__ . ' Already installed ... nothing to do.');
                 return 0;
             }
+
+            if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(
+                __METHOD__ . '::' . __LINE__ . ' Installing ...');
+
             $applications = $controller->getInstallableApplications();
             $applications = array_keys($applications);
         } else {
@@ -476,7 +483,9 @@ class Setup_Frontend_Cli
      */
     protected function _update(Zend_Console_Getopt $_opts)
     {
-        $result = Setup_Controller::getInstance()->updateApplications();
+        $options = $this->_parseRemainingArgs($_opts->getRemainingArgs());
+        $strict = isset($options['strict']) && $options['strict'];
+        $result = Setup_Controller::getInstance()->updateApplications(null, $strict);
         echo "Updated " . $result['updated'] . " application(s).\n";
         if ($_opts->v && count($result['updates']) > 0) {
             print_r($result['updates']);
@@ -522,9 +531,28 @@ class Setup_Frontend_Cli
             }
         }
         
-        $controller->uninstallApplications($applications->name);
+        if (in_array('Tinebase', $applications->name) && $_opts->removemailaccounts) {
+            $this->_removemailaccounts();
+        }
         
-        echo "Successfully uninstalled " . count($applications) . " applications.\n";
+        $uninstallCount = $controller->uninstallApplications($applications->name);
+        
+        echo "Successfully uninstalled " . $uninstallCount . " applications.\n";
+    }
+
+    protected function _removemailaccounts()
+    {
+        if (Tinebase_EmailUser::manages(Tinebase_Config::SMTP)) {
+            echo "Deleting SMTP mailaccounts...\n";
+            $smtpBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::SMTP);
+            $smtpBackend->deleteAllEmailUsers();
+        }
+
+        if (Tinebase_EmailUser::manages(Tinebase_Config::IMAP)) {
+            echo "Deleting IMAP mailaccounts...\n";
+            $imapBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::IMAP);
+            $imapBackend->deleteAllEmailUsers();
+        }
     }
     
     /**
@@ -824,6 +852,7 @@ class Setup_Frontend_Cli
         $results = Setup_Controller::getInstance()->checkRequirements();
         if ($results['success']) {
           echo "OK - All requirements are met\n";
+          echo $results['resultOptionalBinaries']['result']['message'] . "\n";
         } else {
           echo "ERRORS - The following requirements are not met: \n";
           foreach ($results['results'] as $result) {
@@ -831,6 +860,7 @@ class Setup_Frontend_Cli
               echo "- " . strip_tags($result['message']) . "\n";
             }
           }
+          echo $results['resultOptionalBinaries']['result']['message'] . "\n";
         }
     }
     
@@ -926,7 +956,17 @@ class Setup_Frontend_Cli
         $cachesCleared = Setup_Controller::getInstance()->clearCache();
         if ($_opts->v) {
             echo "Caches cleared: " . print_r($cachesCleared, true) . "\n";
-        }
+        } 
+    }
+
+    /**
+     * clears cache directories
+     * 
+     * @param Zend_Console_Getopt $_opts
+     */
+    protected function _clearCacheDir(Zend_Console_Getopt $_opts)
+    {
+        Setup_Controller::getInstance()->clearCacheDir();
     }
 
     /**
@@ -1233,11 +1273,13 @@ class Setup_Frontend_Cli
             throw new Tinebase_Exception_Backend_Database('you are not using mysql');
         }
 
-        if (($ilp = $db->query('SELECT @@innodb_large_prefix')->fetchColumn()) !== '1') {
-            throw new Tinebase_Exception_Backend_Database('innodb_large_prefix seems not be turned on: ' . $ilp);
-        }
-        if (($iff = $db->query('SELECT @@innodb_file_format')->fetchColumn()) !== 'Barracuda') {
-            throw new Tinebase_Exception_Backend_Database('innodb_file_format seems not to be Barracuda: ' . $iff);
+        if (!Setup_Backend_Mysql::dbSupportsVersion($db, 'mysql > 8')) {
+            if (($ilp = $db->query('SELECT @@innodb_large_prefix')->fetchColumn()) !== '1') {
+                throw new Tinebase_Exception_Backend_Database('innodb_large_prefix seems not be turned on: ' . $ilp);
+            }
+            if (($iff = $db->query('SELECT @@innodb_file_format')->fetchColumn()) !== 'Barracuda') {
+                throw new Tinebase_Exception_Backend_Database('innodb_file_format seems not to be Barracuda: ' . $iff);
+            }
         }
         if (($ift = $db->query('SELECT @@innodb_file_per_table')->fetchColumn()) !== '1') {
             throw new Tinebase_Exception_Backend_Database('innodb_file_per_table seems not to be turned on: ' . $ift);
