@@ -151,6 +151,73 @@ class Tinebase_Frontend_Cli_Abstract
         return 0;
     }
 
+    /**
+     * setContainerGrantsReadOnly
+     *
+     * - see setContainerGrants for filter params, application can be added via app=Addressbook
+     * - supports -v (verbose) and -d (dry-run) flags
+     * - sets all containers of all container-based models to read-only for all current grant-users of the container
+     * - default admin role gets admin grant for the containers
+     * - NOTE: this does not have an undo button!
+     * - HINT: use backup tine20_container_acl table first to be able to restore the previous acl:
+     *   $ mysqldump $DBCONNECT tine20 tine20_container_acl > $BACKUPFILE
+     *   $ mysql $DBCONNECT tine20 < $BACKUPFILE
+     *
+     * @param Zend_Console_Getopt $_opts
+     */
+    public function setContainerGrantsReadOnly(Zend_Console_Getopt $_opts)
+    {
+        $this->_checkAdminRight();
+        $data = $this->_parseArgs($_opts);
+        Tinebase_Container::getInstance()->doSearchAclFilter(false);
+        $containers = $this->_getContainers($data);
+        $adminGroup = Tinebase_Group::getInstance()->getDefaultAdminGroup();
+        $counter = 0;
+        foreach ($containers as $container) {
+            $currentGrants = Tinebase_Container::getInstance()->getGrantsOfContainer($container, true);
+            if ($_opts->v) {
+                print_r($container->toArray());
+                print_r($currentGrants->toArray());
+            }
+            $newGrants = new Tinebase_Record_RecordSet(Tinebase_Model_Grants::class);
+            foreach ($currentGrants as $grant) {
+                if ($grant->account_id === $adminGroup->getId()) {
+                    // skip
+                    continue;
+                }
+                $newGrants->addRecord(new Tinebase_Model_Grants([
+                    Tinebase_Model_Grants::GRANT_READ => true,
+                    Tinebase_Model_Grants::GRANT_SYNC => $grant->syncGrant || $grant->admitGrant,
+                    'account_type' => $grant->account_type,
+                    'account_id' => $grant->account_id,
+                ]));
+            }
+            $adminGrants = new Tinebase_Model_Grants([
+                'account_type' => Tinebase_Acl_Rights::ACCOUNT_TYPE_GROUP,
+                'account_id' => $adminGroup->getId(),
+            ]);
+            $adminGrants->sanitizeAccountIdAndFillWithAllGrants();
+            $newGrants->addRecord($adminGrants);
+
+            if ($_opts->v) {
+                if ($_opts->d) {
+                    echo "[DRY-RUN]";
+                }
+                echo "Setting container " . $container->name . " (ID " . $container->getId() . ") to read-only for non-admins:\n";
+                print_r($newGrants->toArray());
+            }
+            if (! $_opts->d) {
+                Tinebase_Container::getInstance()->setGrants($container, $newGrants, true);
+            }
+            $counter++;
+        }
+        if ($_opts->d) {
+            echo "[DRY-RUN]";
+        }
+        echo "Updated grants for " . $counter . " containers.\n";
+        return 0;
+    }
+
     /**
      * create demo data
      * 
@@ -187,6 +254,10 @@ class Tinebase_Frontend_Cli_Abstract
                 $set = isset($data['set']) ? $data['set'] : null;
                 $this->_createImportDemoDataFromSet($set);
                 break;
+            case "eml":
+                $import = new Felamimail_Import_Eml();
+                $import->importEmlEmail();
+                break;
             case "all":
             case "":
             default:
@@ -324,9 +395,9 @@ class Tinebase_Frontend_Cli_Abstract
     protected function _getContainers($_params)
     {
         $application = Tinebase_Application::getInstance()->getApplicationByName($this->_applicationName);
-        $containerFilterData = array(
-            array('field' => 'application_id', 'operator' => 'equals', 'value' => $application->getId()),
-        );
+        $containerFilterData = [
+            ['field' => 'application_id', 'operator' => 'equals', 'value' => $application->getId()]
+        ];
 
         foreach (['id', 'name', 'type'] as $field) {
             if (isset($_params[$field])) {
@@ -633,7 +704,7 @@ class Tinebase_Frontend_Cli_Abstract
                 try {
                     Tinebase_Config::getInstance()->set(Tinebase_Config::CRONUSERID, $cronuser->getId());
                 } catch (Zend_Db_Statement_Exception $zdse) {
-                    if (! Tinebase_Exception::isDbDuplicate($e)) {
+                    if (! Tinebase_Exception::isDbDuplicate($zdse)) {
                         throw $zdse;
                     }
                 }
@@ -744,6 +815,11 @@ class Tinebase_Frontend_Cli_Abstract
             ['field' => 'container_id', 'operator' => 'equals', 'value' => $containerId],
         ]);
 
+        $this->_export($exportClass, $filter, $options);
+    }
+
+    protected function _export($exportClass, $filter = null, $options = [])
+    {
         $export = new $exportClass($filter, null, $options);
         $filename = $export->generate();
         if (! $filename) {
@@ -757,10 +833,10 @@ class Tinebase_Frontend_Cli_Abstract
                         Tinebase_Application::getInstance()->getApplicationByName('Filemanager'));
                     $targetPath = $nodePath->statpath . '/' . basename($file);
                     Tinebase_FileSystem::getInstance()->copyTempfile($tempFile, $targetPath);
-                    echo 'Exported container ' . $containerId . ' to Filemanager path ' . $options['fm_path'] . '/' . basename($file) ."\n";
+                    echo 'Exported to Filemanager path ' . $options['fm_path'] . '/' . basename($file) ."\n";
                 }
             } else {
-                echo 'Exported container ' . $containerId . ' into file ' . $filename . "\n";
+                echo 'Exported into file ' . $filename . "\n";
             }
         }
     }
