@@ -5,7 +5,7 @@
  * @subpackage  Frontend
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Philipp Schuele <p.schuele@metaways.de>
- * @copyright   Copyright (c) 2007-2015 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2007-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  *
  * @todo        add functions again (__call interceptor doesn't work because of the reflection api)
  * @todo        check if we can add these functions to the reflection without implementing them here
@@ -45,7 +45,15 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      * @var array
      */
     protected $_configuredModels = array(
-        'Product',
+        Sales_Model_Document_Address::MODEL_NAME_PART,
+        Sales_Model_Document_Customer::MODEL_NAME_PART,
+        Sales_Model_Document_Boilerplate::MODEL_NAME_PART,
+        Sales_Model_Product::MODEL_NAME_PART,
+        Sales_Model_SubProductMapping::MODEL_NAME_PART,
+        Sales_Model_Document_Offer::MODEL_NAME_PART,
+        Sales_Model_DocumentPosition_Offer::MODEL_NAME_PART,
+        Sales_Model_Document_Order::MODEL_NAME_PART,
+        Sales_Model_DocumentPosition_Order::MODEL_NAME_PART,
         'Contract',
         'Division',
         'CostCenter',
@@ -53,6 +61,7 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         'Offer',
         'Address',
         'ProductAggregate',
+        'Boilerplate'
     );
     
     /**
@@ -171,7 +180,7 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         }
         // TODO: resolve this in controller
         if (! empty($contract['products']) && is_array($contract['products'])) {
-            $cc = Sales_Controller_Product::getInstance()->search(new Sales_Model_ProductFilter(array()));
+            $cc = Sales_Controller_Product::getInstance()->search(Tinebase_Model_Filter_FilterGroup::getFilterForModel(Sales_Model_Product::class, array()));
             for ($i = 0; $i < count($contract['products']); $i++) {
                 $costCenter = $cc->filter('id', $contract['products'][$i]['product_id'])->getFirstRecord();
                 if ($costCenter) {
@@ -198,15 +207,18 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     protected function _resolveAssignedAccountables(&$assignedAccountables)
     {
-        $model = 'WebAccounting_Model_ProxmoxVM';
         $assignedAccountableIds = [];
         foreach ($assignedAccountables as $accountable) {
             $assignedAccountableIds[] = $accountable['id'];
         }
-        if (count($assignedAccountableIds) > 0) {
+        if (count($assignedAccountableIds) > 0
+            && Tinebase_Application::getInstance()->isInstalled('WebAccounting', true)
+            && class_exists('WebAccounting_Controller_ProxmoxVM')
+        ) {
             if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
                 __METHOD__ . '::' . __LINE__ . ' resolving accountables: '
                 . print_r($assignedAccountableIds, true));
+            $model = 'WebAccounting_Model_ProxmoxVM';
             $accountables = WebAccounting_Controller_ProxmoxVM::getInstance()->search(
                 Tinebase_Model_Filter_FilterGroup::getFilterForModel($model, [
                     ['field' => 'id', 'operator' => 'in', 'value' => $assignedAccountableIds]
@@ -249,60 +261,15 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         return $this->_delete($ids, Sales_Controller_Contract::getInstance());
     }
 
-    /*************************** products functions *****************************/
+    /*************************** procuct aggregate functions *************************/
 
-    /**
-     * Search for records matching given arguments
-     *
-     * @param  array $filter
-     * @param  array $paging
-     * @return array
-     */
-    public function searchProducts($filter, $paging)
-    {
-        return $this->_search($filter, $paging, Sales_Controller_Product::getInstance(), 'Sales_Model_ProductFilter');
-    }
-    
     public function searchProductAggregates($filter, $paging)
     {
         return $this->_search($filter, $paging, Sales_Controller_ProductAggregate::getInstance(), 'Sales_Model_ProductAggregateFilter');
     }
     
-    /**
-     * Return a single record
-     *
-     * @param   string $id
-     * @return  array record data
-     */
-    public function getProduct($id)
-    {
-        return $this->_get($id, Sales_Controller_Product::getInstance());
-    }
+    /*************************** costcenter functions *****************************/
 
-    /**
-     * creates/updates a record
-     *
-     * @param  array $recordData
-     * @return array created/updated record
-     */
-    public function saveProduct($recordData)
-    {
-        return $this->_save($recordData, Sales_Controller_Product::getInstance(), 'Product');
-    }
-
-    /**
-     * deletes existing records
-     *
-     * @param  array $ids
-     * @return string
-     */
-    public function deleteProducts($ids)
-    {
-        return $this->_delete($ids, Sales_Controller_Product::getInstance());
-    }
-    
-    // costcenter methods
-    
     /**
      * Search for records matching given arguments
      *
@@ -407,16 +374,6 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     public function searchCustomers($filter, $paging)
     {
         $result = $this->_search($filter, $paging, Sales_Controller_Customer::getInstance(), 'Sales_Model_CustomerFilter');
-        
-        for ($i = 0; $i < count($result['results']); $i++) {
-            if (isset($result['results'][$i]['postal_id'])) {
-                $result['results'][$i]['postal_id'] = Sales_Controller_Address::getInstance()->resolveVirtualFields($result['results'][$i]['postal_id']);
-            }
-            if (! empty($result['results'][$i]['billing'])) {
-                $result['results'][$i]['billing'] = Sales_Controller_Address::getInstance()->resolveMultipleVirtualFields($result['results'][$i]['billing']);
-            }
-        }
-        
         return $result;
     }
     
@@ -438,56 +395,12 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      * @param  boolean $duplicateCheck
      *
      * @return array created/updated record
+     * 
+     * @todo move code to customer controller inspect functions
      */
     public function saveCustomer($recordData, $duplicateCheck = TRUE)
     {
-        $postalAddress = array();
-        foreach($recordData as $field => $value) {
-            if (strpos($field, 'adr_') !== FALSE && ! empty($value)) {
-                $postalAddress[substr($field, 4)] = $value;
-                unset($recordData[$field]);
-            }
-        }
-        if (!isset($postalAddress['seq']) && isset($recordData['postal_id']) && isset($recordData['postal_id']['seq'])) {
-            $postalAddress['seq'] = $recordData['postal_id']['seq'];
-        }
-    
-        foreach (array('cpextern_id', 'cpintern_id') as $prop) {
-            if (isset($recordData[$prop]) && is_array($recordData[$prop])) {
-                $recordData[$prop] = $recordData[$prop]['id'];
-            }
-        }
-    
         $ret = $this->_save($recordData, Sales_Controller_Customer::getInstance(), 'Customer', 'id', array($duplicateCheck));
-        $postalAddress['customer_id'] = $ret['id'];
-    
-        $addressController = Sales_Controller_Address::getInstance();
-        $filter = new Sales_Model_AddressFilter(array(array('field' => 'type', 'operator' => 'equals', 'value' => 'postal')));
-        $filter->addFilter(new Tinebase_Model_Filter_Text(
-            array('field' => 'customer_id', 'operator' => 'equals', 'value' => $ret['id'])
-        ));
-    
-        $postalAddressRecord = $addressController->search($filter)->getFirstRecord();
-    
-        // delete if fields are empty
-        if (empty($postalAddress) && $postalAddressRecord) {
-            $addressController->delete(array($postalAddressRecord->getId()));
-            $postalAddressRecord = NULL;
-        } else {
-            // create if none has been found
-            if (! $postalAddressRecord) {
-                $postalAddressRecord = $addressController->create(new Sales_Model_Address($postalAddress));
-            } else {
-                // update if it has changed
-                $postalAddress['id'] = $postalAddressRecord->getId();
-                $postalAddressRecordToUpdate = new Sales_Model_Address($postalAddress);
-                $diff = $postalAddressRecord->diff($postalAddressRecordToUpdate);
-                if (! empty($diff)) {
-                    $postalAddressRecord = $addressController->update($postalAddressRecordToUpdate);
-                }
-            }
-        }
-    
         return $this->getCustomer($ret['id']);
     }
     
@@ -546,53 +459,7 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     public function saveSupplier($recordData, $duplicateCheck = TRUE)
     {
-        $postalAddress = array();
-        foreach($recordData as $field => $value) {
-            if (strpos($field, 'adr_') !== FALSE && ! empty($value)) {
-                $postalAddress[substr($field, 4)] = $value;
-                unset($recordData[$field]);
-            }
-        }
-        if (!isset($postalAddress['seq']) && isset($recordData['postal_id']) && isset($recordData['postal_id']['seq'])) {
-            $postalAddress['seq'] = $recordData['postal_id']['seq'];
-        }
-        
-        foreach (array('cpextern_id', 'cpintern_id') as $prop) {
-            if (isset($recordData[$prop]) && is_array($recordData[$prop])) {
-                $recordData[$prop] = $recordData[$prop]['id'];
-            }
-        }
-        
         $ret = $this->_save($recordData, Sales_Controller_Supplier::getInstance(), 'Sales_Model_Supplier', 'id', array($duplicateCheck));
-        $postalAddress['customer_id'] = $ret['id'];
-        
-        $addressController = Sales_Controller_Address::getInstance();
-        $filter = new Sales_Model_AddressFilter(array(array('field' => 'type', 'operator' => 'equals', 'value' => 'postal')));
-        $filter->addFilter(new Tinebase_Model_Filter_Text(
-            array('field' => 'customer_id', 'operator' => 'equals', 'value' => $ret['id'])
-        ));
-        
-        $postalAddressRecord = $addressController->search($filter)->getFirstRecord();
-        
-        // delete if fields are empty
-        if (empty($postalAddress) && $postalAddressRecord) {
-            $addressController->delete(array($postalAddressRecord->getId()));
-            $postalAddressRecord = NULL;
-        } else {
-            // create if none has been found
-            if (! $postalAddressRecord) {
-                $postalAddressRecord = $addressController->create(new Sales_Model_Address($postalAddress));
-            } else {
-                // update if it has changed
-                $postalAddress['id'] = $postalAddressRecord->getId();
-                $postalAddressRecordToUpdate = new Sales_Model_Address($postalAddress);
-                $diff = $postalAddressRecord->diff($postalAddressRecordToUpdate);
-                if (! empty($diff)) {
-                    $postalAddressRecord = $addressController->update($postalAddressRecordToUpdate);
-                }
-            }
-        }
-        
         return $this->getSupplier($ret['id']);
     }
     
@@ -656,20 +523,6 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         return $this->_delete($ids, Sales_Controller_OrderConfirmation::getInstance());
     }
     
-    // customer address method - addresses are dependent records, so we need a search method, no more (relation picker combo)
-    
-    /**
-     * Search for records matching given arguments
-     *
-     * @param  array $filter
-     * @param  array $paging
-     * @return array
-     */
-    public function searchAddresss($filter, $paging)
-    {
-        return $this->_search($filter, $paging, Sales_Controller_Address::getInstance(), 'Sales_Model_AddressFilter');
-    }
-    
     // invoice methods
     
     /**
@@ -771,8 +624,8 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         
         if (isset($recordData['relations']) && is_array($recordData['relations'])) {
             foreach($recordData['relations'] as $relation) {
-                if ($relation['related_model'] == 'Sales_Model_Customer' && isset($relation['related_record'])) {
-                    $foundCustomer = $relation['related_record'];
+                if ($relation['related_model'] == 'Sales_Model_Customer' && isset($relation['related_id'])) {
+                    $foundCustomer = $relation['related_id'];
                     break;
                 }
             }
@@ -781,10 +634,10 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         if (isset($recordData['relations']) && is_array($recordData['relations']) && ! $foundCustomer) {
             foreach($recordData['relations'] as $relation) {
                 if ($relation['related_model'] == 'Sales_Model_Contract') {
-                    $foundContractRecord = Sales_Controller_Contract::getInstance()->get($relation['related_record']['id']);
+                    $foundContractRecord = Sales_Controller_Contract::getInstance()->get($relation['related_id']);
                     foreach($foundContractRecord->relations as $relation) {
                         if ($relation['related_model'] == 'Sales_Model_Customer') {
-                            $foundCustomer = $relation['related_record'];
+                            $foundCustomer = $relation['related_id'];
                             $customerCalculated = TRUE;
                             break 2;
                         }
@@ -800,8 +653,7 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                 'related_degree'         => Tinebase_Model_Relation::DEGREE_SIBLING,
                 'related_model'          => 'Sales_Model_Customer',
                 'related_backend'        => Tasks_Backend_Factory::SQL,
-                'related_id'             => $foundCustomer['id'],
-                'related_record'         => $foundCustomer,
+                'related_id'             => $foundCustomer,
                 'type'                   => 'CUSTOMER'
             )));
         }
@@ -825,7 +677,8 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                 }
             }
         }
-        
+
+        /*
         if (isset($recordData['relations']) && is_array($recordData['relations'])) {
             for ($i = 0; $i < count($recordData['relations']); $i++) {
                 if (isset($recordData['relations'][$i]['related_record']['product_id'])) {
@@ -839,7 +692,7 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                     }
                 }
             }
-        }
+        }*/
 
         return $this->_save($recordData, Sales_Controller_Invoice::getInstance(), 'Invoice', 'id', array($duplicateCheck));
     }
@@ -900,7 +753,7 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         if (is_array($recordData['relations'])) {
             foreach($recordData['relations'] as $relation) {
                 if ($relation['related_model'] == 'Sales_Model_Supplier') {
-                    $foundSupplier = $relation['related_record'];
+                    $foundSupplier = $relation['related_id'];
                     break;
                 }
             }
@@ -913,7 +766,7 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         #if (is_array($recordData["costcenter_id"])) {
         #    $recordData["costcenter_id"] = $recordData["costcenter_id"]['id'];
         #}
-        
+        /*
         if (is_array($recordData['relations'])) {
             for ($i = 0; $i < count($recordData['relations']); $i++) {
                 if (isset($recordData['relations'][$i]['related_record']['product_id'])) {
@@ -927,7 +780,7 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                     }
                 }
             }
-        }
+        }*/
 
         return $this->_save($recordData, Sales_Controller_PurchaseInvoice::getInstance(), 'PurchaseInvoice', 'id', array($duplicateCheck));
     }
@@ -942,6 +795,64 @@ class Sales_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     {
         return $this->_delete($ids, Sales_Controller_PurchaseInvoice::getInstance());
     }
+
+    public function getApplicableBoilerplates(string $type, string $date = null, string $customerId = null, string $category = null)
+    {
+        $filter = [
+            ['field' => \Sales_Model_Boilerplate::FLD_MODEL, 'operator' => 'equals', 'value' => $type]
+        ];
+        
+        if (!$date) {
+            $date = Tinebase_DateTime::now();
+        }
+        $filter[] = ['field' => \Sales_Model_Boilerplate::FLD_FROM, 'operator' => 'before_or_equals', 'value' => $date];
+        $filter[] = ['field' => \Sales_Model_Boilerplate::FLD_UNTIL, 'operator' => 'after_or_equals', 'value' => $date];
+
+        $filter[] = ['field' => \Sales_Model_Boilerplate::FLD_DOCUMENT_CATEGORY, 'operator' => 'equals', 'value' =>
+            $category ?: Sales_Config::DOCUMENT_CATEGORY_DEFAULT];
+
+        if ($customerId) {
+            $filter[] = [
+                'condition' => Tinebase_Model_Filter_FilterGroup::CONDITION_OR,
+                'filters'   => [
+                    ['field' => \Sales_Model_Boilerplate::FLD_CUSTOMER, 'operator' => 'equals', 'value' => null],
+                    ['field' => \Sales_Model_Boilerplate::FLD_CUSTOMER, 'operator' => 'equals', 'value' => $customerId],
+                ],
+            ];
+        } else {
+            $filter[] = ['field' => \Sales_Model_Boilerplate::FLD_CUSTOMER, 'operator' => 'equals', 'value' => null];
+        }
+
+        $result = new Tinebase_Record_RecordSet(Sales_Model_Boilerplate::class);
+
+        $names = [];
+        foreach (Sales_Controller_Boilerplate::getInstance()->search(
+                Tinebase_Model_Filter_FilterGroup::getFilterForModel(Sales_Model_Boilerplate::class, $filter))
+                 as $boilerplate) {
+            if (isset($names[$boilerplate->{Sales_Model_Boilerplate::FLD_NAME}])) {
+                $current = $result->getById($names[$boilerplate->{Sales_Model_Boilerplate::FLD_NAME}]->getId());
+                if ($current->{Sales_Model_Boilerplate::FLD_CUSTOMER} &&
+                        !$boilerplate->{Sales_Model_Boilerplate::FLD_CUSTOMER}) {
+                    continue;
+                }
+                if ((!$current->{Sales_Model_Boilerplate::FLD_CUSTOMER} &&
+                        $boilerplate->{Sales_Model_Boilerplate::FLD_CUSTOMER}) ||
+                        ($boilerplate->{Sales_Model_Boilerplate::FLD_FROM} ||
+                        $boilerplate->{Sales_Model_Boilerplate::FLD_UNTIL})) {
+                    $result->removeRecord($names[$boilerplate->{Sales_Model_Boilerplate::FLD_NAME}]);
+                } else {
+                    continue;
+                }
+            }
+            $names[$boilerplate->{Sales_Model_Boilerplate::FLD_NAME}] = $boilerplate;
+            $result->addRecord($boilerplate);
+        }
+
+        return [
+            'totalcount' => $result->count(),
+            'results' => array_values($this->_multipleRecordsToJson($result)),
+        ];
+    }
     
     /*************************** offer functions *****************************/
     
