@@ -8,7 +8,7 @@
  * @subpackage  Frontend
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Philipp Schüle <p.schuele@metaways.de>
- * @copyright   Copyright (c) 2007-2016 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2007-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  *
  */
 class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
@@ -151,6 +151,13 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         try {
             $result = Felamimail_Controller_Cache_Message::getInstance()->getFolderStatus($filter);
         } catch (Exception $e) {
+            if ($e instanceof Felamimail_Exception_IMAPInvalidCredentials) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(
+                    __METHOD__ . '::' . __LINE__ . ' ' . $e->getMessage());
+            } else {
+                Tinebase_Exception::log($e);
+            }
+
             // we have to convert this exception because the frontend does not handle the imap errors well...
             throw new Tinebase_Exception_SystemGeneric('Failed to get folder status: ' . $e->getMessage());
         }
@@ -342,6 +349,18 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         ];
     }
 
+    /**
+     * import message into target folder
+     * 
+     * @param $targetFolderId
+     * @param $tempFile
+     */
+    public function importMessage($targetFolderId, $tempFileId)
+    {
+        $tempFile = Tinebase_TempFile::getInstance()->get($tempFileId);
+        Felamimail_Controller_Message::getInstance()->appendMessage($targetFolderId, file_get_contents($tempFile->path));
+    }
+    
     /**
      * add given flags to given messages
      *
@@ -357,7 +376,7 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         Tinebase_Session::writeClose(true);
         
         // as long as we get array of ids or filter data from the client, we need to do this legacy handling (1 dimensional -> ids / 2 dimensional -> filter data)
-        if (! empty($filterData) && is_array($filterData[0])) {
+        if (! empty($filterData) && is_array($filterData) && is_array($filterData[0])) {
             $filter = new Felamimail_Model_MessageFilter(array());
             $filter->setFromArrayInUsersTimezone($filterData);
         } else {
@@ -461,7 +480,17 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         
         return $this->_recordToJson($folder);
     }
-    
+
+    public function getAttachmentCache($id, $createPreviewInstantly = true)
+    {
+        $old = Tinebase_FileSystem::getInstance()->_getTreeNodeBackend()->doSynchronousPreviewCreation($createPreviewInstantly);
+        try {
+            return $this->_get($id, Felamimail_Controller_AttachmentCache::getInstance());
+        } finally {
+            Tinebase_FileSystem::getInstance()->_getTreeNodeBackend()->doSynchronousPreviewCreation($old);
+        }
+    }
+
     /**
      * send reading confirmation
      * 
@@ -482,14 +511,15 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     /**
      * search accounts
      * 
-     * @param  array $filter
+     * @param array $filter
+     * @param array $paging
      * @return array
      */
-    public function searchAccounts($filter)
+    public function searchAccounts(array $filter, array $paging = [])
     {
         $accounts = $this->_search($filter, '', Felamimail_Controller_Account::getInstance(), 'Felamimail_Model_AccountFilter');
         // add signatures and remove ADB list type from result set
-        // TODO move this to a better place (default filter?)
+        // TODO move this to a better place (default filter? separate api?)
         foreach ($accounts['results'] as $idx => $account) {
             if (in_array($account['type'], [
                 Felamimail_Model_Account::TYPE_SHARED,
@@ -497,9 +527,17 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                 Felamimail_Model_Account::TYPE_USER_INTERNAL,
                 Felamimail_Model_Account::TYPE_SYSTEM,
             ])) {
-                $fullAccount = $this->getAccount($account['id']);
-                $this->_reloadFolderCacheOnPrimaryAccount($fullAccount);
-                $accounts['results'][$idx] = $fullAccount;
+                $account = Felamimail_Controller_Account::getInstance()->get($account['id']);
+                Felamimail_Controller_Folder::getInstance()->reloadFolderCacheOnAccount($account);
+                if ($account->type === Felamimail_Model_Account::TYPE_SYSTEM &&
+                    Felamimail_Config::getInstance()->featureEnabled(
+                        Felamimail_Config::FEATURE_ACCOUNT_MOVE_NOTIFICATIONS) &&
+                    ! $account->sieve_notification_move
+                ) {
+                    // TODO add new status for sieve_notification_move: "never" (+ "auto" if feature is active, but not already set, and "active")
+                    // Felamimail_Controller_Account::getInstance()->autoCreateMoveNotifications($account);
+                }
+                $accounts['results'][$idx] = $this->_recordToJson($account);
             } else {
                 unset($accounts['results'][$idx]);
                 $accounts['totalcount']--;
@@ -511,35 +549,6 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         return $accounts;
     }
 
-    /**
-     * reload folder cache on primary account - only do this once an hour (with caching)
-     *
-     * @param $account
-     * @return boolean
-     */
-    protected function _reloadFolderCacheOnPrimaryAccount($account)
-    {
-        if (Tinebase_Core::getPreference($this->_applicationName)->{Felamimail_Preference::DEFAULTACCOUNT} !== $account['id']) {
-            return false;
-        }
-
-        $cache = Tinebase_Core::getCache();
-        $cacheId = Tinebase_Helper::convertCacheId('_reloadFolderCacheOnPrimaryAccount' . $account['id']);
-        if ($cache->test($cacheId)) {
-            return $cache->load($cacheId);
-        }
-
-        try {
-            $this->updateFolderCache($account['id'], '');
-        } catch (Exception $e) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(
-                __METHOD__ . '::' . __LINE__ . ' Could not update account folder cache: ' . $e->getMessage()
-            );
-        }
-        $cache->save(true, $cacheId, [], 3600);
-        return true;
-    }
-    
     /**
      * get account data
      *
@@ -725,34 +734,8 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     public function doMailsBelongToAccount($mails)
     {
-        $contactFilter = new Addressbook_Model_ContactFilter([
-            [
-                'field' => 'type',
-                'operator' => 'equals',
-                'value' => Addressbook_Model_Contact::CONTACTTYPE_USER
-            ],
-            [
-                'condition' => 'OR',
-                'filters' => [
-                    [
-                        'field' => 'email',
-                        'operator' => 'in',
-                        'value' => $mails
-                    ],
-                    [
-                        'field' => 'email_home',
-                        'operator' => 'in',
-                        'value' => $mails
-                    ]
-                ]
-            ]
-        ]);
-        
-        $contacts = Addressbook_Controller_Contact::getInstance()->search($contactFilter);
-        
-        $usermails = array_filter(array_merge($contacts->email, $contacts->email_home));
-        
-        return array_diff($mails, $usermails);
+        $mails = Addressbook_Controller_Contact::getInstance()->doMailsBelongToAccount($mails);
+        return $mails;
     }
 
     /**
@@ -819,6 +802,10 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         $message = Felamimail_Controller_Message::getInstance()->getCompleteMessage($messageId);
         $pipeLine = new Tinebase_BL_Pipe($rs, false);
         $pipeLine->execute($message);
+
+        return [
+            'status' => 'success'
+        ];
     }
 
     /**
@@ -826,12 +813,21 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      *
      * @param $accountId
      * @param $fields
-     * @return Felamimail_Model_Account
+     * @param bool $forceConnect
+     * @return array
      * @throws Tinebase_Exception_SystemGeneric
      */
-    public function testIMapSettings($accountId , $fields)
+    public function testIMapSettings($accountId, $fields, $forceConnect = false)
     {
         $account = Felamimail_Controller_Account::getInstance()->get($accountId);
+        
+        // only test connection for external user account by default
+        if (!$forceConnect && $account->type !== Felamimail_Model_Account::TYPE_USER) {
+            return [
+                'status' => 'success'
+            ];
+        }
+        
         $params = [];
         
         if (is_array($fields)) {
@@ -856,23 +852,39 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         $params->password = isset($fields['password']) ? $fields['password'] : '';
         $params->port     = isset($fields['port'])     ? $fields['port']     : null;
         $params->ssl      = isset($fields['ssl'])      ? $fields['ssl']      : false;
+        $params->account = $account;
+
+        $fieldsWithoutPw = $fields;
+        unset($fieldsWithoutPw['password']);
+        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(
+            ' Trying connection with params: ' . print_r($fieldsWithoutPw, true)
+        );
 
-        //avoid null $_id error
-        $emailUserBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::IMAP);
-        $emailUser = Tinebase_EmailUser_XpropsFacade::getEmailUserFromRecord($account);
-        $userInBackend = $emailUserBackend->getRawUserById($emailUser);
-        
-        if ($userInBackend) {
-            $params->account = $account;
-        }
-        
         try {
             $backend = new Felamimail_Backend_Imap($params);
         } catch (Exception $e) {
-            throw new Tinebase_Exception_SystemGeneric($e->getMessage());
+
+            $fieldsWithoutPw = $fields;
+            unset($fieldsWithoutPw['password']);
+            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(
+                __METHOD__ . '::' . __LINE__ . ' Connection failed: ' . $e
+            );
+
+            switch ($e->getCode()) {
+                case 910: // Felamimail_Exception_IMAP
+                    throw new Tinebase_Exception_SystemGeneric('General IMAP error.');
+                case 911: // Felamimail_Exception_IMAPServiceUnavailable
+                    throw new Tinebase_Exception_SystemGeneric('No connection to IMAP server.');
+                case 912: // Felamimail_Exception_IMAPInvalidCredentials
+                    throw new Tinebase_Exception_SystemGeneric('Cannot login, user or password wrong.');
+                default:
+                    throw new Tinebase_Exception_SystemGeneric($e->getMessage());
+            }
         }
-        
-        return $account;
+
+        return [
+            'status' => 'success'
+        ];
     }
 
     /**
@@ -880,13 +892,22 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      *
      * @param $accountId
      * @param $fields
-     * @return Felamimail_Model_Account
+     * @param bool $forceConnect
+     * @return array
      * @throws Tinebase_Exception_SystemGeneric
      * @throws Zend_Exception
      */
-    public function testSmtpSettings($accountId, $fields)
+    public function testSmtpSettings($accountId, $fields, $forceConnect = false)
     {
+        $account = Felamimail_Controller_Account::getInstance()->get($accountId);
         
+        //only test connection for external user account by default 
+        if (!$forceConnect && $account->type !== Felamimail_Model_Account::TYPE_USER) {
+            return [
+                'status' => 'success'
+            ];
+        }
+
         if ('' === $fields['smtp_user'] && isset($fields['user'])) {
             $fields['smtp_user'] = $fields['user'];
         }
@@ -904,8 +925,6 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
             throw new Tinebase_Exception_SystemGeneric($translation->_('SMTP Credentials missing'));
         }
 
-        $account = Felamimail_Controller_Account::getInstance()->get($accountId);
-        
         foreach ($fields as $key => $field) {
             $account[$key] = $fields[$key];
         }
@@ -932,8 +951,9 @@ class Felamimail_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         } catch (Exception $e) {
             throw new Tinebase_Exception_SystemGeneric($e->getMessage());
         }
-        
-        return $account;
+
+        return [
+            'status' => 'success'
+        ];
     }
-    
 }
