@@ -5,7 +5,7 @@
  * @package     Tinebase
  * @subpackage  Server
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
- * @copyright   Copyright (c) 2007-2020 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2007-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  * @author      Lars Kneschke <l.kneschke@metaways.de>
  * 
  */
@@ -29,12 +29,6 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     protected $_applicationName = 'Tinebase';
     
-    /**
-     *
-     * @var boolean
-     */
-    protected $_hasCaptcha = null;
-
     /**
      * All full configured models
      *
@@ -44,8 +38,28 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         'BLConfig',
         'ImportExportDefinition',
         'LogEntry',
-        'Tree_Node'
+        'Tree_Node',
+        Tinebase_Model_MFA_HOTPUserConfig::MODEL_NAME_PART,
+        Tinebase_Model_MFA_TOTPUserConfig::MODEL_NAME_PART,
+        Tinebase_Model_MFA_UserConfig::MODEL_NAME_PART,
+        Tinebase_Model_MFA_PinUserConfig::MODEL_NAME_PART,
+        Tinebase_Model_MFA_SmsUserConfig::MODEL_NAME_PART,
+        Tinebase_Model_MFA_WebAuthnUserConfig::MODEL_NAME_PART,
+        Tinebase_Model_MFA_YubicoOTPUserConfig::MODEL_NAME_PART,
+        Tinebase_Model_CommunityIdentNr::MODEL_NAME_PART,
+        Tinebase_Model_AuthToken::MODEL_NAME_PART,
     ];
+    
+    public function __construct()
+    {
+        if (!Tinebase_Config::getInstance()->featureEnabled(
+            Tinebase_Config::FEATURE_COMMUNITY_IDENT_NR)
+        ) {
+            $this->_configuredModels = array_diff($this->_configuredModels, [
+                Tinebase_Model_CommunityIdentNr::MODEL_NAME_PART
+            ]);
+        }
+    }
 
     /**
      * wait for changes
@@ -167,11 +181,11 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     /**
      * Search for roles
      *
-     * @param  array $_filter
-     * @param  array $_paging
+     * @param array $filter
+     * @param array $paging
      * @return array
      */
-    public function searchRoles($filter, $paging)
+    public function searchRoles(array $filter, array $paging)
     {
         $result = array(
             'results'     => array(),
@@ -202,12 +216,12 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     }
 
     /**
-     * @param        $oldPassword
-     * @param        $newPassword
+     * @param string $oldPassword
+     * @param string $newPassword
      * @param string $pwType
      * @return array
      */
-    protected function _changePwOrPin($oldPassword, $newPassword, $pwType = 'password')
+    protected function _changePwOrPin(string $oldPassword, string $newPassword, string $pwType = 'password')
     {
         $response = array(
             'success'      => TRUE
@@ -306,10 +320,11 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     }
 
     /**
-     * @param $commencement
-     * @param $termOfContractInMonths
-     * @param $automaticContractExtensionInMonths
-     * @param $cancellationPeriodInMonths
+     * @param string $commencement
+     * @param string $termOfContractInMonths
+     * @param string $automaticContractExtensionInMonths
+     * @param integer $cancellationPeriodInMonths
+     * @param Tinebase_DateTime $today
      * @return array
      */
     public function getTerminationDeadline(
@@ -561,11 +576,11 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      *
      * @param  string $username the username
      * @param  string $password the password
-     * @param  string $securitycode the security code(captcha)
-     * @param  string $otp  the second factor password
+     * @param  string $MFAUserConfigId config for mfa device to use
+     * @param  string $MFAPassword otp from mfa device
      * @return array
      */
-    public function login($username, $password, $securitycode = null, $otp = null)
+    public function login(string $username, string $password, string $MFAUserConfigId = null, string $MFAPassword = null)
     {
         try {
             Tinebase_Core::startCoreSession();
@@ -578,14 +593,11 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                 'errorMessage' => "Could not start session!",
             );
         }
-        
-        if (is_array(($response = $this->_getCaptchaResponse($securitycode)))) {
-            return $response;
-        }
 
-        // TODO move security code here and use params
+        Tinebase_Controller::getInstance()->forceUnlockLoginArea();
         Tinebase_Controller::getInstance()->setRequestContext(array(
-            'otp' => $otp
+            'MFAPassword' => $MFAPassword,
+            'MFAId'       => $MFAUserConfigId
         ));
 
         // try to login user
@@ -593,8 +605,7 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
             $username,
             $password,
             Tinebase_Core::get(Tinebase_Core::REQUEST),
-            self::REQUEST_TYPE,
-            $securitycode
+            self::REQUEST_TYPE
         );
         
         if ($success === true) {
@@ -605,10 +616,10 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     }
 
     /**
-     * @param $oidcResponse
+     * @param string $oidcResponse
      * @return array
      */
-    public function openIDCLogin($oidcResponse)
+    public function openIDCLogin(string $oidcResponse)
     {
         Tinebase_Core::startCoreSession();
 
@@ -624,80 +635,37 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
             return $this->_getLoginFailedResponse();
         }
     }
-
-    /**
-     * Returns TRUE if there is a captcha
-     * @return boolean
-     */
-    protected function _hasCaptcha()
-    {
-        if ($this->_hasCaptcha === null){
-            $this->_hasCaptcha = isset(Tinebase_Core::getConfig()->captcha->count) && Tinebase_Core::getConfig()->captcha->count != 0;
-        }
-        
-        return $this->_hasCaptcha;
-    }
-    
-    /**
-     *
-     * @param string $securitycode
-     * @return array | NULL
-     */
-    protected function _getCaptchaResponse($securitycode)
-    {
-        if ($this->_hasCaptcha()) {
-            $config_count = Tinebase_Core::getConfig()->captcha->count;
-            
-            $count = (isset(Tinebase_Session::getSessionNamespace()->captcha['count'])
-                ? Tinebase_Session::getSessionNamespace()->captcha['count']
-                : 1
-            );
-            
-            if ($count >= $config_count) {
-                $aux = isset(Tinebase_Session::getSessionNamespace()->captcha['code'])
-                    ? Tinebase_Session::getSessionNamespace()->captcha['code']
-                    : null;
-                
-                if ($aux != $securitycode) {
-                    $rets = Tinebase_Controller::getInstance()->makeCaptcha(); 
-                    $response = array(
-                        'success'      => false,
-                        'errorMessage' => "Wrong username or password!",
-                        'c1'           => $rets['1']
-                    );
-                    
-                    return $response;
-                }
-            }
-        }
-        
-        return null;
-    }
     
     /**
+     * create login response
      *
      * @param string $username
      * @return array
      */
     protected function _getLoginSuccessResponse($username)
     {
-            $response = array(
-                'success'        => true,
-                'account'        => Tinebase_Core::getUser()->getPublicUser()->toArray(),
-                'sessionId'      => Tinebase_Core::getSessionId(),
-                'jsonKey'        => Tinebase_Core::get('jsonKey'),
-                'welcomeMessage' => "Welcome to Tine 2.0!"
-            );
-             
+        $response = array(
+            'success' => true,
+            'account' => Tinebase_Core::getUser()->getPublicUser()->toArray(),
+            'sessionId' => Tinebase_Core::getSessionId(),
+            'jsonKey' => Tinebase_Core::get('jsonKey'),
+            'welcomeMessage' => "Welcome to Tine 2.0!"
+        );
+
+        if (!headers_sent()) {
             if (Tinebase_Config::getInstance()->get(Tinebase_Config::REUSEUSERNAME_SAVEUSERNAME, 0)) {
                 // save in cookie (expires in 2 weeks)
-                setcookie('TINE20LASTUSERID', $username, time()+60*60*24*14);
+                setcookie('TINE20LASTUSERID', $username, time() + 60 * 60 * 24 * 14);
             } else {
                 setcookie('TINE20LASTUSERID', '', 0);
             }
 
             $this->_setCredentialCacheCookie();
-            
+        } else {
+            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(
+                __METHOD__ . '::' . __LINE__ . ' Could not set cookies - headers already sent');
+        }
+
         return $response;
     }
     
@@ -705,7 +673,7 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      *
      * @return array
      */
-    protected function _getLoginFailedResponse()
+    public function _getLoginFailedResponse()
     {
         $response = array(
             'success'      => false,
@@ -714,27 +682,6 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         
         Tinebase_Auth_CredentialCache::getInstance()->getCacheAdapter()->resetCache();
         
-        if ($this->_hasCaptcha()) {
-            $config_count = Tinebase_Core::getConfig()->captcha->count;
-            
-            if (!isset(Tinebase_Session::getSessionNamespace()->captcha['count'])) {
-                Tinebase_Session::getSessionNamespace()->captcha['count'] = 1;
-            } else {
-                Tinebase_Session::getSessionNamespace()->captcha['count'] = Tinebase_Session::getSessionNamespace()->captcha['count'] + 1;
-            }
-            
-            if (Tinebase_Session::getSessionNamespace()->captcha['count'] >= $config_count) {
-                $rets = Tinebase_Controller::getInstance()->makeCaptcha(); 
-                $response = array(
-                    'success'      => false,
-                    'errorMessage' => "Wrong username or password!",
-                    'c1'           => $rets['1']
-                );
-            }
-        } else {
-            Tinebase_Session::destroyAndMantainCookie();
-        }
-        
         return $response;
     }
 
@@ -747,7 +694,6 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     {
         if (!Tinebase_Core::isRegistered(Tinebase_Core::USERCREDENTIALCACHE)) {
             Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__ . ' Something went wrong with the CredentialCache / no CC registered.');
-            
             return false;
         }
         
@@ -817,8 +763,17 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         $registryData = $this->_getAnonymousRegistryData();
         
         if (Tinebase_Core::isRegistered(Tinebase_Core::USER)) {
-            $userRegistryData = $this->_getUserRegistryData();
-            $registryData += $userRegistryData;
+            if (Tinebase_AreaLock::getInstance()->hasLock(Tinebase_Model_AreaLockConfig::AREA_LOGIN) &&
+                    Tinebase_AreaLock::getInstance()->isLocked(Tinebase_Model_AreaLockConfig::AREA_LOGIN)) {
+                $areaConfig = Tinebase_AreaLock::getInstance()->getLastAuthFailedAreaConfig();
+                $e = new Tinebase_Exception_AreaLocked('mfa required');
+                $e->setArea($areaConfig->{Tinebase_Model_AreaLockConfig::FLD_AREA_NAME});
+                $e->setMFAUserConfigs($areaConfig->getUserMFAIntersection(Tinebase_Core::getUser()));
+                $registryData['areaLockedException'] = $e->toArray();
+            } else {
+                $userRegistryData = $this->_getUserRegistryData();
+                $registryData += $userRegistryData;
+            }
         }
         
         return $registryData;
@@ -857,9 +812,6 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         $registryData =  array(
             'modSsl'           => Tinebase_Auth::getConfiguredBackend() == Tinebase_Auth::MODSSL,
 
-             // secondfactor config
-            'secondFactor' => $this->_getSecondFactorConfig(),
-
             // sso
             'sso'               => Tinebase_Config::getInstance()->{Tinebase_Config::SSO}->{Tinebase_Config::SSO_ACTIVE},
 
@@ -879,6 +831,7 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
             'setupRequired'     => Setup_Controller::getInstance()->setupRequired(),
             'defaultUsername'   => $defaultUsername,
             'defaultPassword'   => $defaultPassword,
+            'allowBrowserPasswordManager'=> Tinebase_Config::getInstance()->get(Tinebase_Config::ALLOW_BROWSER_PASSWORD_MANAGER),
             'denySurveys'       => Tinebase_Core::getConfig()->denySurveys,
             'titlePostfix'      => Tinebase_Config::getInstance()->get(Tinebase_Config::PAGETITLEPOSTFIX),
             'redirectUrl'       => Tinebase_Config::getInstance()->get(Tinebase_Config::REDIRECTURL),
@@ -908,15 +861,6 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         
         return $registryData;
     }
-
-    /**
-     * @return array|null
-     */
-    protected function _getSecondFactorConfig()
-    {
-        $config = Tinebase_AreaLock::getInstance()->getAreaConfig(Tinebase_Model_AreaLockConfig::AREA_LOGIN);
-        return $config ? $config->toArray() : null;
-    }
     
     /**
      * get user registry
@@ -998,7 +942,8 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     {
         $registryData = array();
         
-        if (Tinebase_Core::getUser()) {
+        if (Tinebase_Core::getUser() && (!Tinebase_AreaLock::getInstance()->hasLock(Tinebase_Model_AreaLockConfig::AREA_LOGIN) ||
+                !Tinebase_AreaLock::getInstance()->isLocked(Tinebase_Model_AreaLockConfig::AREA_LOGIN))) {
             $userApplications = Tinebase_Core::getUser()->getApplications(/* $_anyRight */ TRUE);
             $clientConfig = Tinebase_Config::getInstance()->getClientRegistryConfig();
             
@@ -1082,27 +1027,21 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         Tinebase_CustomField::getInstance()->resolveConfigGrants($customfields);
         $appRegistry['customfields'] = $customfields->toArray();
 
-        // add preferences for app
         try {
             $prefRegistry = $this->_getAppPreferencesForRegistry($application);
             $appRegistry = array_merge_recursive($appRegistry, $prefRegistry);
-        } catch (Tinebase_Exception_AccessDenied $tead) {
-            // do not add prefs if user has no run right
-        }
-
-        $customAppRegistry = $this->_getCustomAppRegistry($application);
-        if (empty($customAppRegistry)) {
-            // TODO always get this from app controller (and remove from _getCustomAppRegistry)
-            try {
+            $customAppRegistry = $this->_getCustomAppRegistry($application);
+            if (empty($customAppRegistry)) {
+                // TODO always get this from app controller (and remove from _getCustomAppRegistry)
                 $appController = Tinebase_Core::getApplicationInstance($application->name);
                 $models = $appController->getModels();
                 $appRegistry['models'] = Tinebase_ModelConfiguration::getFrontendConfigForModels($models);
-            } catch (Tinebase_Exception_AccessDenied $tead) {
-                // do not add prefs if user has no run right
+            } else {
+                $appRegistry = array_merge_recursive($appRegistry, $customAppRegistry);
             }
-
-        } else {
-            $appRegistry = array_merge_recursive($appRegistry, $customAppRegistry);
+        } catch (Tinebase_Exception_AccessDenied $tead) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Do not add app registry data. Exception message: ' . $tead->getMessage());
         }
 
         if (! isset($appRegistry['importDefinitions'])) {
@@ -1364,7 +1303,7 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     /**
      * gets the userProfile config
      *
-     * @return @array
+     * @return array
      */
     public function getUserProfileConfig()
     {
@@ -1558,14 +1497,21 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     public function autoComplete($appName, $modelName, $property, $startswith)
     {
         $recordClassName = $appName . '_Model_' . $modelName;
-        $controller      = Tinebase_Core::getApplicationInstance($appName, $modelName);
+
+        $controller = Tinebase_Core::getApplicationInstance($appName, $modelName);
+
+        if (! method_exists($controller, 'search')) {
+            throw new Tinebase_Exception_InvalidArgument('Controller needs search() method');
+        }
 
         if (! class_exists($recordClassName)) {
-            throw new Tinebase_Exception_InvalidArgument('A record class for the given appName and modelName does not exist!');
+            throw new Tinebase_Exception_InvalidArgument(
+                'A record class for the given appName and modelName does not exist!');
         }
         
         if (! $controller) {
-            throw new Tinebase_Exception_InvalidArgument('A controller for the given appName and modelName does not exist!');
+            throw new Tinebase_Exception_InvalidArgument(
+                'A controller for the given appName and modelName does not exist!');
         }
 
         /** @var Tinebase_Model_Filter_FilterGroup $filter */
@@ -1592,11 +1538,43 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         return $result;
     }
 
+    public function getWebAuthnAuthenticateOptionsForMFA(string $accountLoginName, string $mfaId)
+    {
+        $account = Tinebase_User::getInstance()->getFullUserByLoginName($accountLoginName);
+        
+        /** @var Tinebase_Model_MFA_UserConfig $userCfg */
+        $userCfg = $account->mfa_configs->getById($mfaId);
+        /** @var Tinebase_Model_MFA_WebAuthnConfig $config */
+        $config = Tinebase_Auth_MFA::getInstance($userCfg->{Tinebase_Model_MFA_UserConfig::FLD_MFA_CONFIG_ID})
+            ->getAdapter()->getConfig();
+
+        return Tinebase_Auth_Webauthn::getWebAuthnRequestOptions($config, $account->getId())->jsonSerialize();
+    }
+
+    public function getWebAuthnRegisterPublicKeyOptionsForMFA(string $mfaId, ?string $accountId = null)
+    {
+        if (null !== $accountId) {
+            if (!Tinebase_Core::getUser()->hasRight(Tinebase_Config::APP_NAME, Tinebase_Acl_Rights::ADMIN)) {
+                throw new Tinebase_Exception_AccessDenied('user has not right to register webauthn devices for other users');
+            }
+            $user = Tinebase_User::getInstance()->getFullUserById($accountId);
+        } else {
+            $user = Tinebase_Core::getUser();
+        }
+
+        /** @var Tinebase_Model_MFA_WebAuthnConfig $config */
+        $config = Tinebase_Auth_MFA::getInstance($mfaId)->getAdapter()->getConfig();
+
+        return Tinebase_Auth_Webauthn::getWebAuthnCreationOptions(true, $user, $config)->jsonSerialize();
+    }
+
     /**
-     * Toogles advanced search preference
+     * Toggles advanced search preference
      *
-     * @param $state
+     * @param string|integer $state
      * @return true
+     *
+     * @todo still needed?
      */
     public function toogleAdvancedSearch($state)
     {
@@ -1716,12 +1694,12 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     /**
      * returns the replication modification logs
      *
-     * @param $sequence
+     * @param int $sequence
      * @param int $limit
      * @return array
      * @throws Tinebase_Exception_AccessDenied
      */
-    public function getReplicationModificationLogs($sequence, $limit = 100)
+    public function getReplicationModificationLogs(int $sequence, int $limit = 100)
     {
         if (! Tinebase_Core::getUser()->hasRight('Tinebase', Tinebase_Acl_Rights::REPLICATION)) {
             throw new Tinebase_Exception_AccessDenied('you do not have access to modlogs');
@@ -1736,43 +1714,6 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         return $result;
     }
 
-    /**
-     * returns the replication modification logs
-     *
-     * @param $hash
-     * @return array
-     * @throws Tinebase_Exception_AccessDenied
-     * @throws Tinebase_Exception_Backend
-     * @throws Tinebase_Exception_NotFound
-     */
-    public function getBlob($hash)
-    {
-        if (! Tinebase_Core::getUser()->hasRight('Tinebase', Tinebase_Acl_Rights::REPLICATION)) {
-            throw new Tinebase_Exception_AccessDenied('you do not have access to blobs');
-        }
-
-        $fileObject = new Tinebase_Model_Tree_FileObject(array('hash' => $hash), true);
-        $path = $fileObject->getFilesystemPath();
-
-        if (is_file($path)) {
-            if (!($fh = fopen($path, 'r'))) {
-                throw new Tinebase_Exception_Backend('could not open blob file: ' . $hash);
-            }
-            if (!stream_filter_append($fh, 'convert.base64-encode', STREAM_FILTER_READ)) {
-                throw new Tinebase_Exception_Backend('could not append stream filter');
-            }
-            $data = stream_get_contents($fh);
-            fclose($fh);
-        } else {
-            throw new Tinebase_Exception_NotFound('could not find blob: ' . $hash);
-        }
-
-        return array(
-            'success' => true,
-            'data'    => $data
-        );
-    }
-
     /**
      * @return array
      */
@@ -1813,4 +1754,14 @@ class Tinebase_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         return $this->_search($filter, $pagination, Tinebase_Record_Path::getInstance(),
             Tinebase_Model_PathFilter::class);
     }
+
+    /**
+     * @param array $_communityNumber
+     * @return mixed
+     */
+    public function aggregatePopulation(array $_communityNumber)
+    {
+        $result = Tinebase_Controller_CommunityIdentNr::getInstance()->aggregatePopulation(new Tinebase_Model_CommunityIdentNr($_communityNumber));
+        return $result->toArray();
+    }
 }
