@@ -2,23 +2,16 @@
 /**
  * Tine 2.0
  *
- * @package     Admin
- * @subpackage  Frontend
- * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
- * @author      Lars Kneschke <l.kneschke@metaways.de>
- * @copyright   Copyright (c) 2007-2019 Metaways Infosystems GmbH (http://www.metaways.de)
- * 
- * @todo        try to split this into smaller parts (record proxy should support 'nested' json frontends first)
- * @todo        use functions from Tinebase_Frontend_Json_Abstract
- */
-
-/**
- * backend class for Zend_Json_Server
- *
  * This class handles all Json requests for the admin application
  *
  * @package     Admin
  * @subpackage  Frontend
+ * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
+ * @author      Lars Kneschke <l.kneschke@metaways.de>
+ * @copyright   Copyright (c) 2007-2021 Metaways Infosystems GmbH (http://www.metaways.de)
+ * 
+ * @todo        try to split this into smaller parts (record proxy should support 'nested' json frontends first)
+ * @todo        use functions from Tinebase_Frontend_Json_Abstract
  */
 class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
 {
@@ -34,15 +27,20 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     protected $_manageSAM = false;
     
+    /**
+     * @var bool
+     */
+    protected $_hasMasterSieveAccess;
+
     /**
      * constructs Admin_Frontend_Json
      */
     public function __construct()
     {
-        // manage samba sam?
         if (isset(Tinebase_Core::getConfig()->samba)) {
             $this->_manageSAM = Tinebase_Core::getConfig()->samba->get('manageSAM', false);
         }
+        $this->_hasMasterSieveAccess = Tinebase_EmailUser::sieveBackendSupportsMasterPassword();
     }
     
     /**
@@ -57,6 +55,7 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
 
         $registryData = array(
             'manageSAM'                     => $this->_manageSAM,
+            'masterSieveAccess'             => $this->_hasMasterSieveAccess,
             'defaultPrimaryGroup'           => Tinebase_Group::getInstance()->getDefaultGroup()->toArray(),
             'defaultInternalAddressbook'    => (
                     isset($appConfigDefaults[Admin_Model_Config::DEFAULTINTERNALADDRESSBOOK])
@@ -289,12 +288,14 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     public function searchUsers($filter, $paging)
     {
-        $sort = (isset($paging['sort']))    ? $paging['sort']   : 'accountDisplayName';
-        $dir  = (isset($paging['dir']))     ? $paging['dir']    : 'ASC';
-        
-        $result = $this->getUsers($filter[0]['value'], $sort, $dir, isset($paging['start']) ? $paging['start'] : 0,
-            isset($paging['limit']) ? $paging['limit'] : null);
-        $result['filter'] = $filter[0];
+        $result = $this->getUsers(
+            $filter[0]['value'] ?? null,
+            $paging['sort'] ?? 'accountDisplayName',
+            $paging['dir'] ?? 'ASC',
+            $paging['start'] ?? 0,
+            $paging['limit'] ?? null
+        );
+        $result['filter'] = $filter[0] ?? [];
         
         return $result;
     }
@@ -335,31 +336,35 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     public function saveUser($recordData)
     {
+        parent::_setRequestContext(Admin_Controller_User::getInstance());
+        
         $password = (isset($recordData['accountPassword'])) ? $recordData['accountPassword'] : '';
         if (! empty($password)) {
             Tinebase_Core::getLogger()->addReplacement($password);
         }
 
-        // dehydrate primary group id
+        // dehydrate primary group id + groups
         if (isset($recordData['accountPrimaryGroup'])
             && is_array($recordData['accountPrimaryGroup'])
             && isset($recordData['accountPrimaryGroup']['id'])
         ) {
             $recordData['accountPrimaryGroup'] = $recordData['accountPrimaryGroup']['id'];
         }
-        
+
+        if (isset($recordData['groups']['results'])) {
+            $recordData['groups'] = array_map(function($group) {
+                return $group['id'];
+            }, $recordData['groups']['results']);
+        }
+
         $account = new Tinebase_Model_FullUser();
-        
-        // always re-evaluate fullname
-        unset($recordData['accountFullName']);
-        
         try {
             $account->setFromJsonInUsersTimezone($recordData);
             if (isset($recordData['sambaSAM'])) {
                 $account->sambaSAM = new Tinebase_Model_SAMUser($recordData['sambaSAM']);
             }
             
-            if (isset($recordData['emailUser'])) {
+            if (isset($recordData['emailUser']) && ! empty($recordData['accountEmailAddress'])) {
                 $account->emailUser = new Tinebase_Model_EmailUser($recordData['emailUser']);
                 $account->imapUser  = new Tinebase_Model_EmailUser($recordData['emailUser']);
                 $account->smtpUser  = new Tinebase_Model_EmailUser($recordData['emailUser']);
@@ -424,6 +429,7 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     public function deleteUsers($ids)
     {
+        parent::_setRequestContext(Admin_Controller_User::getInstance());
         Admin_Controller_User::getInstance()->delete($ids);
         
         $result = array(
@@ -484,26 +490,25 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     }
 
     /**
-     * reset password for given account
-     *
+     * returns possible mfa adapter for given user
+     * 
      * @param array|string $account Tinebase_Model_FullUser data or account id
-     * @param string $password the new password
-     * @return array
+     * @retujrn array id => user_config_class
      */
-    public function resetPin($account, $password)
+    public function getPossibleMFAs($account)
     {
-        if (is_array($account)) {
-            $account = new Tinebase_Model_FullUser($account);
-        } else {
-            $account = Tinebase_User::factory(Tinebase_User::getConfiguredBackend())->getFullUserById($account);
+        $result = [];
+
+        $mfas = Tinebase_Config::getInstance()->{Tinebase_Config::MFA};
+        if (is_iterable($mfas->records)) {
+            foreach ($mfas->records as $mfaConfig) {
+                $result[] = [
+                    'mfa_config_id' => $mfaConfig->id,
+                    'config_class' => $mfaConfig->user_config_class,
+                ];
+            }
         }
-
-        $controller = Admin_Controller_User::getInstance();
-        $controller->setAccountPin($account, $password);
-
-        $result = array(
-            'success' => TRUE
-        );
+        
         return $result;
     }
 
@@ -857,7 +862,7 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
             unset($tagData['id']);
         }
         
-        $tag = new Tinebase_Model_FullTag($tagData);
+        $tag = new Tinebase_Model_Tag($tagData);
         $tag->rights = new Tinebase_Record_RecordSet('Tinebase_Model_TagRight', $tagData['rights']);
         
         if ( empty($tag->id) ) {
@@ -1122,18 +1127,18 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         $additionalArguments = ((isset($recordData['note']) || array_key_exists('note', $recordData))) ? array(array('note' => $recordData['note'])) : array();
         return $this->_save($recordData, Admin_Controller_Container::getInstance(), 'Tinebase_Model_Container', 'id', $additionalArguments);
     }
-    
+
     /**
      * deletes existing records
      *
-     * @param  array  $ids 
+     * @param  array  $ids
      * @return array
      */
     public function deleteContainers($ids)
     {
         return $this->_delete($ids, Admin_Controller_Container::getInstance());
-    }    
-    
+    }
+
     /****************************** Customfield ******************************/
 
     /**
@@ -1418,6 +1423,22 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         );
     }
 
+    /**
+     * save quotas
+     * @param string $application
+     * @param array $additionalData
+     * @return false[]|mixed|Tinebase_Config_Struct|Tinebase_Model_Tree_Node
+     * @throws Tinebase_Exception
+     * @throws Tinebase_Exception_AccessDenied
+     * @throws Tinebase_Exception_Backend_Database_LockTimeout
+     * @throws Tinebase_Exception_NotFound
+     */
+    public function saveQuota(string $application, $recordData = null, array $additionalData = [])
+    {
+        parent::_setRequestContext(Admin_Controller_Quota::getInstance());
+        return Admin_Controller_Quota::getInstance()->updateQuota($application, $recordData, $additionalData);
+    }
+
     public function searchQuotaNodes($filter = null)
     {
         if (! Tinebase_Core::getUser()->hasRight('Admin', Admin_Acl_Rights::VIEW_QUOTA_USAGE)) {
@@ -1460,7 +1481,7 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
             $filterArray = $filter->toArray();
             if (null !== $pathArray) {
                 $filterArray[] = $pathArray;
-        }
+            }
             $filter = new Tinebase_Model_Tree_Node_Filter($filterArray, '', array('ignoreAcl' => true));
 
             $pathFilters = $filter->getFilter('path', true);
@@ -1501,9 +1522,10 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                     $emailNode->name = 'Emails';
                     $emailNode->path = $virtualPath;
                     $imapUsageQuota = $imapBackend->getTotalUsageQuota();
-                    $emailNode->quota = $imapUsageQuota['mailQuota'];
+                    $emailNode->quota = $imapUsageQuota['mailQuota'] * 1024 * 1024;
                     $emailNode->size = $imapUsageQuota['mailSize'];
                     $emailNode->revision_size = $emailNode->size;
+                    $emailNode->xprops('customfields')['emailQuotas'] = $imapUsageQuota;
                     $records->addRecord($emailNode);
                 }
             } elseif ($isFelamimailInstalled && '/' === $path) {
@@ -1516,8 +1538,9 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                     $imapUsageQuota = $imapBackend->getTotalUsageQuota();
                     $node = $records->filter('name',
                         Tinebase_Application::getInstance()->getApplicationByName('Felamimail')->getId())->getFirstRecord();
-                    $node->quota += $imapUsageQuota['mailQuota'];
+                    $node->quota += $imapUsageQuota['mailQuota']  * 1024 * 1024;;
                     $node->size += $imapUsageQuota['mailSize'];
+                    $node->xprops('customfields')['emailQuotas'] = $imapUsageQuota;
                 }
             }
 
@@ -1567,20 +1590,29 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                 $node = new Tinebase_Model_Tree_Node(array(), true);
                 $node->parent_id = $parent_id;
                 $node->name = $domain;
-                $node->quota = $usageQuota['mailQuota'];
+                $node->quota = $usageQuota['mailQuota'] * 1024 * 1024;
                 $node->size = $usageQuota['mailSize'];
                 $node->revision_size = $usageQuota['mailSize'];
                 $node->setId(md5($domain));
                 $node->type = Tinebase_Model_Tree_FileObject::TYPE_FOLDER;
+                $node->xprops('customfields')['emailQuotas'] = $usageQuota;
+                $node->xprops('customfields')['domain'] = $domain;
                 $result->addRecord($node);
             }
         } elseif (count($pathParts = explode('/', $path)) === 1) {
             $parent_id = md5($pathParts[0]);
             $accountIds = [];
             $nodeIds = [];
-
+            $accounts = Admin_Controller_EmailAccount::getInstance()->search();
+            foreach ($accounts as $account) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+                    __METHOD__ . '::' . __LINE__ . ' account node data: '
+                    . print_r($account, true));
+            }
+            
+            $emailUsers = $imapBackend->getAllEmailUsers($pathParts[0]);
             /** @var Tinebase_Model_EmailUser $emailUser */
-            foreach ($imapBackend->getAllEmailUsers($pathParts[0]) as $emailUser) {
+            foreach ($emailUsers as $emailUser) {
                 $node = new Tinebase_Model_Tree_Node(array(), true);
                 $node->parent_id = $parent_id;
                 $node->name = $emailUser->emailUsername;
@@ -1589,12 +1621,23 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                 $node->revision_size = $emailUser->emailMailSize;
                 $node->setId($emailUser->emailUserId);
                 $node->type = Tinebase_Model_Tree_FileObject::TYPE_FOLDER;
+                $node->xprops('customfields')['emailUser'] = $emailUser->toArray();
+                $node->xprops('customfields')['isPersonalNode'] = true;
                 $result->addRecord($node);
                 list($accountId) = explode('@', $emailUser->emailUsername);
                 $nodeIds[$accountId] = $emailUser->emailUserId;
                 $accountIds[] = $accountId;
-            }
 
+                foreach ($accounts as $account) {
+                    if ($account instanceof Felamimail_Model_Account && !empty($account->xprops)) {
+                        if (isset($account->xprops['emailUserIdImap']) && $emailUser->emailUserId === $account->xprops['emailUserIdImap']) {
+                            $node->name = $account->email;
+                            $node->xprops('customfields')['emailAccountId'] = $account['id'];
+                        }
+                    }
+                }
+            }
+            
             /** @var Tinebase_Model_User $user */
             foreach (Tinebase_User::getInstance()->getMultiple($accountIds) as $user) {
                 if (isset($nodeIds[$user->accountId])) {
@@ -1605,7 +1648,7 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
 
         return $result;
     }
-
+    
     /****************************** common ******************************/
     
     /**
@@ -1616,7 +1659,12 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     protected function _recordToJson($_record)
     {
-        $result = parent::_recordToJson($_record);
+        if ($_record instanceof Felamimail_Model_Account) {
+            $converter = new Admin_Convert_EmailAccount_Json(get_class($_record));
+            $result = $converter->fromTine20Model($_record);
+        } else {
+            $result = parent::_recordToJson($_record);
+        }
 
         if ($_record instanceof Tinebase_Model_Container) {
             $result['account_grants'] = Tinebase_Frontend_Json_Container::resolveAccounts($_record['account_grants']->toArray());
@@ -1659,6 +1707,56 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                     }
                 }
                 break;
+            case Tinebase_Model_Tree_Node::class:
+                // check if we filtered for /personal and expand accountid's
+                if ($_filter) {
+                    $filter = $_filter->getFilter('path', true);
+                    $path = $filter[0]->getValue();
+                    $filemanager_id = Tinebase_Application::getInstance()->getApplicationByName('Filemanager')->getId();
+                    
+                    foreach ($_records as $record) {
+                        if (empty($record->name) || !$record instanceof Tinebase_Model_Tree_Node) {
+                            $userData = Tinebase_User::getInstance()->getNonExistentUser('Tinebase_Model_FullUser')->toArray();
+                            $record->name = $userData['accountLoginName'];
+                            
+                            continue;
+                        }
+                        
+                        try {
+                            // generic effective quota infos
+                            if (strpos($path, $filemanager_id )) {
+                                if ($quotas = Tinebase_FileSystem::getInstance()->getEffectiveAndLocalQuota($record)) {
+                                    $record->xprops('customfields')['effectiveAndLocalQuota'] = $quotas;
+                                }
+                            }
+                            
+                            // user personalFSQuota quota under /Filemanager/folders/personal
+                            if ($path === '/' . $filemanager_id . '/folders/personal') {
+                                $userData = Admin_Controller_User::getInstance()->get($record->name)->toArray();
+                                $record->quota = $userData['xprops']['personalFSQuota'] ?? 0;
+                                $record->xprops('customfields')['isPersonalNode'] = true;
+                                $record->xprops('customfields')['accountLoginName'] = $userData['accountLoginName'];
+                                $record->xprops('customfields')['accountId'] = $record->name;
+                                $record->name = $userData['accountDisplayName'];
+                            }
+    
+                            // total quota for /Filemanager
+                            if ($record->name === $filemanager_id || $path === '/' . $filemanager_id) {
+                                $record->quota = Tinebase_FileSystem_Quota::getRootQuotaBytes();
+                            } 
+                        } catch (Tinebase_Exception_NotFound $e) {
+                            $userData = Tinebase_User::getInstance()->getNonExistentUser('Tinebase_Model_FullUser')->toArray();
+                            $record->name = $userData['accountLoginName'];
+                        }
+                    }
+
+                    // only return exist users
+                    $_records = $_records->filter(function($record) {
+                        return $record->name !== 'unknown';
+                    });
+                    // check if there is helper function
+                }
+                break;
         }
         
         return parent::_multipleRecordsToJson($_records, $_filter, $_pagination);
@@ -1674,12 +1772,13 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     public function getSieveVacation($id)
     {
-        $raii = Admin_Controller_EmailAccount::getInstance()->prepareAccountForSieveAdminAccess($id);
-
-        $result = (new Felamimail_Frontend_Json())->getVacation($id);
-
-        Admin_Controller_EmailAccount::getInstance()->removeSieveAdminAccess();
+        $raii = Tinebase_EmailUser::prepareAccountForSieveAdminAccess($id);
 
+        try {
+            $result = (new Felamimail_Frontend_Json())->getVacation($id);
+        } finally {
+            Tinebase_EmailUser::removeSieveAdminAccess();
+        }
         //for unused variable check
         unset($raii);
         return $result;
@@ -1688,18 +1787,18 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
     /**
      * set sieve vacation for account
      *
-     * @param  array $recordData
+     * @param array $recordData
      * @return array
      */
     public function saveSieveVacation($recordData)
     {
-        $raii = Admin_Controller_EmailAccount::getInstance()->prepareAccountForSieveAdminAccess(
+        $raii = Tinebase_EmailUser::prepareAccountForSieveAdminAccess(
             $recordData['id'], Admin_Acl_Rights::MANAGE_EMAILACCOUNTS);
-
-        $result = (new Felamimail_Frontend_Json())->saveVacation($recordData);
-
-        Admin_Controller_EmailAccount::getInstance()->removeSieveAdminAccess();
-
+        try {
+            $result = (new Felamimail_Frontend_Json())->saveVacation($recordData);
+        } finally {
+            Tinebase_EmailUser::removeSieveAdminAccess();
+        }
         //for unused variable check
         unset($raii);
         return $result;
@@ -1713,17 +1812,36 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     public function getSieveRules($accountId)
     {
-        $raii = Admin_Controller_EmailAccount::getInstance()->prepareAccountForSieveAdminAccess($accountId);
-
-        $result = (new Felamimail_Frontend_Json())->getRules($accountId);
-
-        Admin_Controller_EmailAccount::getInstance()->removeSieveAdminAccess();
-
-        //for unused variable check
+        $raii = Tinebase_EmailUser::prepareAccountForSieveAdminAccess($accountId);
+        try {
+            $result = (new Felamimail_Frontend_Json())->getRules($accountId);
+        } finally {
+            Tinebase_EmailUser::removeSieveAdminAccess();
+        }
+//for unused variable check
         unset($raii);
         return $result;
     }
 
+    /**
+     * get sieve rules for account
+     *
+     * @param  string $accountId
+     * @return string
+     */
+    public function getSieveScript($accountId)
+    {
+        $raii = Tinebase_EmailUser::prepareAccountForSieveAdminAccess($accountId);
+        try {
+            $result = Felamimail_Controller_Sieve::getInstance()->getSieveScript($accountId);
+        } finally {
+            Tinebase_EmailUser::removeSieveAdminAccess();
+        }
+        // for unused variable check
+        unset($raii);
+        return $result->getSieve();
+    }
+
     /**
      * set sieve rules for account
      *
@@ -1733,13 +1851,13 @@ class Admin_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      */
     public function saveRules($accountId, $rulesData)
     {
-        $raii = Admin_Controller_EmailAccount::getInstance()->prepareAccountForSieveAdminAccess(
+        $raii = Tinebase_EmailUser::prepareAccountForSieveAdminAccess(
             $accountId, Admin_Acl_Rights::MANAGE_EMAILACCOUNTS);
-
-        $result = (new Felamimail_Frontend_Json())->saveRules($accountId, $rulesData);
-
-        Admin_Controller_EmailAccount::getInstance()->removeSieveAdminAccess();
-
+        try {
+            $result = (new Felamimail_Frontend_Json())->saveRules($accountId, $rulesData);
+        } finally {
+            Tinebase_EmailUser::removeSieveAdminAccess();
+        }
         //for unused variable check
         unset($raii);
         return $result;
