@@ -271,14 +271,18 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      * do search count request only when resultset is equal
      * to $pagination->limit or we are not on the first page
      *
-     * @param $filter
-     * @param $pagination
+     * @param Tinebase_Model_Filter_FilterGroup $filter
+     * @param Tinebase_Model_Pagination $pagination
      * @param Tinebase_Controller_SearchInterface $controller the record controller
-     * @param $totalCountMethod
+     * @param string $totalCountMethod
      * @param integer $resultCount
      * @return array
      */
-    protected function _getSearchTotalCount($filter, $pagination, $controller, $totalCountMethod, $resultCount)
+    protected function _getSearchTotalCount(Tinebase_Model_Filter_FilterGroup $filter,
+                                            Tinebase_Model_Pagination $pagination,
+                                            Tinebase_Controller_SearchInterface $controller,
+                                            string $totalCountMethod,
+                                            int $resultCount)
     {
         if ($controller instanceof Tinebase_Controller_Abstract) {
             $this->_setRequestContext($controller);
@@ -623,9 +627,9 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
                 $nodes = Tinebase_FileSystem::getInstance()->getTreeNodeChildren($nodeId);
                 $result = $this->_multipleRecordsToJson($nodes);
             }
-        } catch (Exception $e) {
+        } catch (Throwable $t) {
             if (Tinebase_Core::isLogLevel(Zend_Log::WARN)) Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__
-                . ' Could not get template files: ' . $e);
+                . ' Could not get template files: ' . $t);
         }
     
         return array(
@@ -779,37 +783,49 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      * magic method for json api
      *
      * @param string $method
-     * @param array  $args
-     * @return mixed
+     * @param array $args
+     * @return array|string[]|void
      */
     public function __call($method, array $args)
     {
         // provides api for default application methods
-        if (preg_match('/^(get|save|search|delete|import)([a-z0-9]+)/i', $method, $matches)) {
+        if (preg_match('/^(get|save|search|delete|import)([A-Za-z0-9_]+)/i', $method, $matches)) {
             $apiMethod = $matches[1];
             $model = in_array($apiMethod, array('search', 'delete', 'import')) ? substr($matches[2],0,-1) : $matches[2];
             $modelController = Tinebase_Core::getApplicationInstance($this->_applicationName, $model);
             // resolve custom fields by default
             $modelController->resolveCustomfields(true);
+
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+                __METHOD__ . '::' . __LINE__ . ' Calling ' . $apiMethod . ' with controller '
+                . get_class($modelController) . ' args: ' . print_r($args, true));
+
             switch ($apiMethod) {
                 case 'get':
                     return $this->_get($args[0], $modelController);
-                    break;
                 case 'save':
                     return $this->_save($args[0], $modelController, $model);
-                    break;
                 case 'search':
                     $filterName = $this->_applicationName . '_Model_' . $model . 'Filter';
+                    if (!isset($args[1])) {
+                        $args[1] = '';
+                    }
                     return $this->_search($args[0], $args[1], $modelController, $filterName, /* $_getRelations */ true);
-                    break;
                 case 'delete':
                     return $this->_delete($args[0], $modelController);
-                    break;
                 case 'import':
                     // model controller is not needed - but we fetch it for checking if model exists and user has run right
                     // $tempFileId, $definitionId, $importOptions, $clientRecordData
+                    if (!isset($args[1])) {
+                        $args[1] = '';
+                    }
+                    if (!isset($args[2])) {
+                        $args[2] = [];
+                    }
+                    if (!isset($args[3])) {
+                        $args[3] = [];
+                    }
                     return $this->_import($args[0], $args[1], $args[2], $args[3]);
-                    break;
             }
         }
     }
