@@ -54,13 +54,10 @@ class Calendar_Frontend_WebDAV_Container extends Tinebase_WebDav_Container_Abstr
             return $child;
         }
         
-        $modelName = $this->_application->name . '_Model_' . $this->_model;
-        
-        if ($_name instanceof $modelName) {
+        if ($_name instanceof Calendar_Model_Event) {
             $object = $_name;
         } else {
-            $filterClass = $this->_application->name . '_Model_' . $this->_model . 'Filter';
-            $filter = new $filterClass(array(
+            $filter = new Calendar_Model_EventFilter(array(
                 array(
                     'field'     => 'container_id',
                     'operator'  => 'equals',
@@ -87,9 +84,9 @@ class Calendar_Frontend_WebDAV_Container extends Tinebase_WebDav_Container_Abstr
             }
 
             if (!empty($object->base_event_id) && $object->getId() !== $object->base_event_id &&
-                    null !== $this->_getController()->search(new $filterClass([
+                    null !== ($tmp = $this->_getController()->search(new Calendar_Model_EventFilter([
                         ['field' => 'id', 'operator' => 'equals', 'value' => $object->base_event_id]
-                    ]), null, false, false, 'sync')->getFirstRecord()) {
+                    ]), null, false, false, 'sync')->getFirstRecord()) && $tmp->container_id === $this->_container->getId()) {
                 throw new Sabre\DAV\Exception\NotFound('Object not found');
             }
         }
