@@ -152,10 +152,18 @@ class Calendar_Frontend_WebDAV_Event extends Sabre\DAV\File implements Sabre\Cal
         // check if there is already an existing event with this ID
         // this can happen when the invitation email is faster then the caldav update or
         // or when an event gets moved to another container
-        $existingEvent = Calendar_Controller_MSEventFacade::getInstance()->getExistingEventByUID($event->uid,
-            $event->hasExternalOrganizer(), 'sync', null, true);
+        if (null === ($existingEvent = Calendar_Controller_MSEventFacade::getInstance()->getExistingEventByUID(
+                $event->uid, $event->hasExternalOrganizer(), 'sync', null, true))) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Did not find existing event by UID - trying to find one by id (' . $event->uid . ')');
+            $existingEvent = Calendar_Controller_MSEventFacade::getInstance()->getExistingEventById($event->uid,
+                $event->hasExternalOrganizer(), 'sync', null, true);
+        }
         
         if ($existingEvent === null) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Creating new event');
+
             self::checkWriteAccess($converter);
             $retry = false;
             try {
@@ -193,6 +201,8 @@ class Calendar_Frontend_WebDAV_Event extends Sabre\DAV\File implements Sabre\Cal
             
             $vevent = new self($container, $event);
         } else {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Update existing event');
 
             if ($existingEvent->hasExternalOrganizer() && is_numeric($existingEvent->external_seq) &&
                     (int)$event->external_seq < (int)$existingEvent->external_seq) {
@@ -203,6 +213,12 @@ class Calendar_Frontend_WebDAV_Event extends Sabre\DAV\File implements Sabre\Cal
                 if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG))
                     Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . ' recovering already deleted event');
 
+                if (!$existingEvent->hasExternalOrganizer() &&
+                        (!$existingEvent->organizer instanceof Addressbook_Model_Contact ||
+                            $existingEvent->organizer->account_id !== $container->getOwner())) {
+                    throw new Sabre\DAV\Exception\PreconditionFailed('only organizer may recover deleted events');
+                }
+
                 // @TODO have a undelete/recover workflow beginning in controller
                 $existingEvent->is_deleted = 0;
                 $existingEvent->deleted_by = NULL;
@@ -220,27 +236,12 @@ class Calendar_Frontend_WebDAV_Event extends Sabre\DAV\File implements Sabre\Cal
                 Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . ' update existing event');
 
             $vevent = new self($container, $existingEvent);
-            /** @var Calendar_Model_Event $existingEvent */
-            $existingEvent = clone $existingEvent;
-            $existingEvent->alarms = $event->alarms;
-            $existingEvent->transp = $event->transp;
-            if (null === ($contactId = $container->getOwner())) {
-                $contactId = Tinebase_Core::getUser()->contact_id;
-            } else {
-                $contactId = Tinebase_User::getInstance()->getUserById($contactId)->contact_id;
-            }
-            if (null !== ($attender = $event->attendee->find('user_id', $contactId))) {
-                if (null !== ($oldAttender = $existingEvent->attendee->find('user_id', $contactId))) {
-                    $existingEvent->attendee->removeRecord($oldAttender);
-                    $attender->setId($oldAttender->getId());
-                }
-                $existingEvent->attendee->addRecord($attender);
-            }
+            $event = static::_allowOnlyAttendeeProperties($existingEvent, $event, $container);
 
             $calCtrl = Calendar_Controller_Event::getInstance();
             $oldCalenderAcl = $calCtrl->doContainerACLChecks();
             try {
-                if ($existingEvent->hasExternalOrganizer()) {
+                if ($event->hasExternalOrganizer()) {
                     $calCtrl->doContainerACLChecks(false);
                 }
                 $vobject = Calendar_Convert_Event_VCalendar_Abstract::getVObject($vobjectData);
@@ -254,10 +255,14 @@ class Calendar_Frontend_WebDAV_Event extends Sabre\DAV\File implements Sabre\Cal
                         break;
                     }
                 }
-                $vcalendar = $converter->fromTine20Model($existingEvent);
+                $vcalendar = $converter->fromTine20Model($event);
                 if (null !== $xTine20Container) {
                     static::_addXPropsToVEvent($vcalendar, $xTine20Container);
                 }
+                // set a dummy if-match header
+                if (!Tinebase_Core::getRequest()->getHeaders()->has('If-Match')) {
+                    Tinebase_Core::getRequest()->getHeaders()->addHeader(new Zend\Http\Header\IfMatch('dummy'));
+                }
                 $vevent->put($vcalendar->serialize());
             } finally {
                 $calCtrl->doContainerACLChecks($oldCalenderAcl);
@@ -267,8 +272,30 @@ class Calendar_Frontend_WebDAV_Event extends Sabre\DAV\File implements Sabre\Cal
         return $vevent;
     }
 
+    protected static function _allowOnlyAttendeeProperties(Calendar_Model_Event $_origEvent, Calendar_Model_Event $_event, Tinebase_Model_Container $_container)
+    {
+        $event = clone $_origEvent;
+        $event->alarms = $_event->alarms;
+        $event->transp = $_event->transp;
+        if (null === ($contactId = $_container->getOwner())) {
+            $contactId = Tinebase_Core::getUser()->contact_id;
+        } else {
+            $contactId = Tinebase_User::getInstance()->getUserById($contactId)->contact_id;
+        }
+        /** @var Calendar_Model_Attender $attender */
+        if (null !== ($attender = $_event->attendee->find('user_id', $contactId))) {
+            if (null !== ($oldAttender = $event->attendee->find('user_id', $contactId))) {
+                $event->attendee->removeRecord($oldAttender);
+                $attender->setId($oldAttender->getId());
+            }
+            $event->attendee->addRecord($attender);
+        }
+
+        return $event;
+    }
+
     /**
-     * @param $converter
+     * @param Calendar_Convert_Event_VCalendar_Abstract $converter
      * @throws \Sabre\DAV\Exception\Forbidden
      */
     public static function checkWriteAccess($converter)
@@ -278,9 +305,11 @@ class Calendar_Frontend_WebDAV_Event extends Sabre\DAV\File implements Sabre\Cal
             'Calendar_Convert_Event_VCalendar_Generic',
             'Calendar_Convert_Event_VCalendar_KDE',
         ])) {
+            $useragent = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : 'unknown';
             if (Tinebase_Core::isLogLevel(Zend_Log::WARN))
-                Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__ . ' update by '
-                 . $converterClass . ' client not allowed. See Calendar_Convert_Event_VCalendar_Factory for supported clients.');
+                Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__ . ' Update by '
+                 . $converterClass . ' client not allowed. See Calendar_Convert_Event_VCalendar_Factory for supported clients.'
+                 . ' User-Agent: ' . $useragent);
             throw new Sabre\DAV\Exception\Forbidden('write access denied for unknown client');
         }
     }
@@ -492,52 +521,77 @@ class Calendar_Frontend_WebDAV_Event extends Sabre\DAV\File implements Sabre\Cal
         }
         // Converting to UTF-8, if needed
         $cardData = Sabre\DAV\StringUtil::ensureUTF8($cardData);
-        
-        #Sabre_CalDAV_ICalendarUtil::validateICalendarObject($cardData, array('VEVENT', 'VFREEBUSY'));
-        
         $vobject = Calendar_Convert_Event_VCalendar_Abstract::getVObject($cardData);
+        $xTine20Container = null;
         foreach ($vobject->children() as $component) {
             if (isset($component->{'X-TINE20-CONTAINER'})) {
-                $xTine20Container = $component->{'X-TINE20-CONTAINER'};
+                $xTine20Container = $component->{'X-TINE20-CONTAINER'}->getValue();
                 break;
             }
         }
-        
-        // concurrency management is based on etag in CalDAV
-        $event = $this->_getConverter()->toTine20Model($vobject, $this->getRecord(), array(
+
+        // clone, otherwise $this->_event and $event would be the same object
+        $event = $this->_getConverter()->toTine20Model($vobject, clone $this->getRecord(), array(
             Calendar_Convert_Event_VCalendar_Abstract::OPTION_USE_SERVER_MODLOG => true,
         ));
 
         if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG))
             Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . " " . print_r($event->toArray(), true));
 
-
         $currentEvent = $this->getRecord();
+        if (null !== $xTine20Container && $currentEvent->container_id !== $xTine20Container &&
+                $currentEvent->attendee->find('displaycontainer_id', $xTine20Container) === null) {
+            $xTine20Container = null;
+        }
+        $inDisplayContainer = $currentEvent->attendee->find('displaycontainer_id', $this->_container->getId()) !== null;
+        $currentOwnAttendee = Calendar_Model_Attender::getOwnAttender($currentEvent->attendee);
+        $xTine20ContainerAttendee = $xTine20Container ?
+            $currentEvent->attendee->find('displaycontainer_id', $xTine20Container) : null;
         $currentContainer = Tinebase_Container::getInstance()->getContainerById($currentEvent->container_id);
+        $currentContainer->resolveGrantsAndPath();
 
-        // client sends CalDAV event -> handle a container move
-        if (isset($xTine20Container)) {
-            if ($xTine20Container->getValue() == $currentContainer->getId()) {
+        // no If-Match header -> no moves / displaycontainer changes
+        if (!Tinebase_Core::getRequest()->getHeaders()->has('If-Match')) {
+            $event = static::_allowOnlyAttendeeProperties($currentEvent, $event, $this->_container);
+
+            // no xTineContainer
+        } elseif (null === $xTine20Container) {
+            // target container is not a current displaycontainer and we have admin on origin container or are organizer
+            // move to target container
+            if (!$inDisplayContainer && ($currentContainer->account_grants->{Tinebase_Model_Grants::GRANT_ADMIN} ||
+                    $currentEvent->organizer === Tinebase_Core::getUser()->contact_id ||
+                    $currentEvent->organizer === Calendar_Controller_MSEventFacade::getInstance()->getCalendarUser()->user_id)) {
                 $event->container_id = $this->_container->getId();
-            } else {
-                // @TODO allow organizer to move original cal when he edits the displaycal event?
-                if ($this->_container->type == Tinebase_Model_Container::TYPE_PERSONAL) {
-                    Calendar_Controller_MSEventFacade::getInstance()->setDisplaycontainer($event, $this->_container->getId());
+            // target container is not a current displaycontainer and is not the origin container ( and we are not organizer or admin on origin)
+                // set as new displaycontainer for OUR attendee (not currentCalendarUsers attendee!)
+            } elseif (!$inDisplayContainer && $currentOwnAttendee && $event->container_id !== $this->_container->getId()) {
+                Calendar_Controller_MSEventFacade::getInstance()->setDisplaycontainer($event, $this->_container->getId(),
+                    $currentOwnAttendee);
+            } // else do nothing
+
+        } else { // we have a xTineContainer
+            // the xTineContainer is the origin container => do the move
+            if ($event->container_id === $xTine20Container) {
+                // grant check?
+                /* ($currentContainer->account_grants->{Tinebase_Model_Grants::GRANT_ADMIN} ||
+                    $currentEvent->organizer === Calendar_Controller_MSEventFacade::getInstance()->getCalendarUser()->user_id)) {
+*/
+                $event->container_id = $this->_container->getId();
+
+                // WE (not the currentCalendarUser) are an attendee and xTineContainer was our displaycontainer
+                // => change our displaycontainer
+            } elseif ($currentOwnAttendee && $currentOwnAttendee->displaycontainer_id === $xTine20Container) {
+                if ($xTine20Container !== $this->_container->getId()) {
+                    Calendar_Controller_MSEventFacade::getInstance()->setDisplaycontainer($event,
+                        $this->_container->getId(), $currentOwnAttendee);
                 }
-            }
-        }
 
-        // event was created by current user -> allow container move
-        else if ($currentEvent->created_by == Tinebase_Core::getUser()->getId()) {
-            $event->container_id = $this->_container->getId();
-        }
-
-        // client sends event from iMIP invitation -> only allow displaycontainer move
-        else {
-            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG))
-                Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . " X-TINE20-CONTAINER not present -> restrict container moves");
-            if ($this->_container->type == Tinebase_Model_Container::TYPE_PERSONAL) {
-                Calendar_Controller_MSEventFacade::getInstance()->setDisplaycontainer($event, $this->_container->getId());
+                // problem here is:
+                // secretary has admin on boss calendar, boss forwards imip to secretary with secretary being an attendee too
+                // now what?!
+            } elseif ($xTine20ContainerAttendee && $xTine20Container !== $this->_container->getId()) {
+                Calendar_Controller_MSEventFacade::getInstance()->setDisplaycontainer($event,
+                    $this->_container->getId(), $xTine20ContainerAttendee);
             }
         }
 
