@@ -5,7 +5,7 @@
  * @package     Tinebase
  * @subpackage  Group
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
- * @copyright   Copyright (c) 2008-2020 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2008-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  * @author      Lars Kneschke <l.kneschke@metaways.de>
  */
 
@@ -362,8 +362,14 @@ class Tinebase_Group_Sql extends Tinebase_Group_Abstract
         if ($this instanceof Tinebase_Group_Interface_SyncAble) {
             $this->addGroupMemberInSyncBackend($_groupId, $_accountId);
         }
-        
-        $this->addGroupMemberInSqlBackend($_groupId, $_accountId);
+
+        try {
+            $this->addGroupMemberInSqlBackend($_groupId, $_accountId);
+        } catch (Zend_Db_Statement_Exception $zdse) {
+            if (! Tinebase_Exception::isDbDuplicate($zdse)) {
+                throw $zdse;
+            }
+        }
     }
     
     /**
@@ -387,8 +393,17 @@ class Tinebase_Group_Sql extends Tinebase_Group_Abstract
                 'group_id'      => $groupId,
                 'account_id'    => $accountId
             );
-        
-            $this->groupMembersTable->insert($data);
+
+            try {
+                $this->groupMembersTable->insert($data);
+            } catch (Zend_Db_Statement_Exception $zdse) {
+                if (Tinebase_Exception::isDbDuplicate($zdse)) {
+                    if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(
+                        __METHOD__ . '::' . __LINE__ . ' Membership already exists');
+                } else {
+                    throw $zdse;
+                }
+            }
             
             $this->_clearCache(array(
                 'getGroupMembers'     => $groupId,
@@ -893,50 +908,52 @@ class Tinebase_Group_Sql extends Tinebase_Group_Abstract
      */
     public function applyReplicationModificationLog(Tinebase_Model_ModificationLog $modification)
     {
-        switch ($modification->change_type) {
-            case Tinebase_Timemachine_ModificationLog::CREATED:
-                $diff = new Tinebase_Record_Diff(json_decode($modification->new_value, true));
-                $record = new Tinebase_Model_Group($diff->diff);
-                Addressbook_Controller_List::getInstance()->createOrUpdateByGroup($record);
-                Tinebase_Timemachine_ModificationLog::setRecordMetaData($record, 'create');
-                $this->addGroup($record);
-                break;
-
-            case Tinebase_Timemachine_ModificationLog::UPDATED:
-                $diff = new Tinebase_Record_Diff(json_decode($modification->new_value, true));
-                if (isset($diff->diff['members']) && is_array($diff->diff['members'])) {
-                    $toAdd = array_diff($diff->diff['members'], $diff->oldData['members']);
-                    $toDelete = array_diff($diff->oldData['members'], $diff->diff['members']);
-                    $members = array_unique(array_merge($toAdd,
-                        array_diff($this->getGroupMembers($modification->record_id), $toDelete)));
-                    $this->setGroupMembers($modification->record_id, $members);
-                    $record = $this->getGroupById($modification->record_id);
-                    $record->members = $this->getGroupMembers($record->getId());
+        try {
+            switch ($modification->change_type) {
+                case Tinebase_Timemachine_ModificationLog::CREATED:
+                    $diff = new Tinebase_Record_Diff(json_decode($modification->new_value, true));
+                    $record = new Tinebase_Model_Group($diff->diff);
                     Addressbook_Controller_List::getInstance()->createOrUpdateByGroup($record);
-                } else {
-                    $record = $this->getGroupById($modification->record_id);
-                    $currentRecord = clone $record;
-                    $record->applyDiff($diff);
-                    $record->members = $this->getGroupMembers($record->getId());
-                    Addressbook_Controller_List::getInstance()->createOrUpdateByGroup($record);
-                    Tinebase_Timemachine_ModificationLog::setRecordMetaData($record, 'update', $currentRecord);
-                    $this->updateGroup($record);
-                }
-                break;
+                    Tinebase_Timemachine_ModificationLog::setRecordMetaData($record, 'create');
+                    $this->addGroup($record);
+                    break;
 
-            case Tinebase_Timemachine_ModificationLog::DELETED:
-                try {
+                case Tinebase_Timemachine_ModificationLog::UPDATED:
+                    $diff = new Tinebase_Record_Diff(json_decode($modification->new_value, true));
                     $record = $this->getGroupById($modification->record_id);
-                    if (!empty($record->list_id)) {
-                        Addressbook_Controller_List::getInstance()->delete($record->list_id);
+                    if (isset($diff->diff['members']) && is_array($diff->diff['members'])) {
+                        $toAdd = array_diff($diff->diff['members'], $diff->oldData['members']);
+                        $toDelete = array_diff($diff->oldData['members'], $diff->diff['members']);
+                        $members = array_unique(array_merge($toAdd,
+                            array_diff($this->getGroupMembers($modification->record_id), $toDelete)));
+                        $this->setGroupMembers($modification->record_id, $members);
+                        $record->members = $this->getGroupMembers($record->getId());
+                        Addressbook_Controller_List::getInstance()->createOrUpdateByGroup($record);
+                    } else {
+                        $currentRecord = clone $record;
+                        $record->applyDiff($diff);
+                        $record->members = $this->getGroupMembers($record->getId());
+                        Addressbook_Controller_List::getInstance()->createOrUpdateByGroup($record);
+                        Tinebase_Timemachine_ModificationLog::setRecordMetaData($record, 'update', $currentRecord);
+                        $this->updateGroup($record);
                     }
-                    $this->deleteGroups($modification->record_id);
-                } catch (Tinebase_Exception_Record_NotDefined $e) {}
-                break;
+                    break;
 
-            default:
-                throw new Tinebase_Exception('unknown Tinebase_Model_ModificationLog->old_value: ' . $modification->old_value);
-        }
+                case Tinebase_Timemachine_ModificationLog::DELETED:
+                    try {
+                        $record = $this->getGroupById($modification->record_id);
+                        if (!empty($record->list_id)) {
+                            Addressbook_Controller_List::getInstance()->delete($record->list_id);
+                        }
+                        $this->deleteGroups($modification->record_id);
+                    } catch (Tinebase_Exception_Record_NotDefined $e) {
+                    }
+                    break;
+
+                default:
+                    throw new Tinebase_Exception('unknown Tinebase_Model_ModificationLog->old_value: ' . $modification->old_value);
+            }
+        } catch (Tinebase_Exception_Record_NotDefined $groupNotFound){}
     }
 
     /**
