@@ -49,6 +49,7 @@ abstract class Tinebase_Import_Abstract implements Tinebase_Import_Interface
         'postMappingHook'   => null,
         // if this is set, always resolve (one of:  mergeTheirs, mergeMine, keep
         'duplicateResolveStrategy' => null,
+        'passwordGenerator' => null,
     );
     
     /**
@@ -265,6 +266,9 @@ abstract class Tinebase_Import_Abstract implements Tinebase_Import_Interface
                     $recordToImport = $this->_createRecordToImport($processedRecordData);
                     if ($resolveStrategy !== 'discard') {
                         $importedRecord = $this->_importRecord($recordToImport, $resolveStrategy, $processedRecordData);
+                        if (!$importedRecord) {
+                            continue 2;
+                        }
                         $this->_inspectAfterImport($importedRecord);
                     } else {
                         if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
@@ -548,7 +552,10 @@ abstract class Tinebase_Import_Abstract implements Tinebase_Import_Interface
                     case 'int':
                     case 'integer':
                         $data[$key] = (integer) $_data[$key];
-                        break; 
+                        break;
+                    case 'float':
+                        $data[$key] = (float) str_replace(',', '.', (String)$_data[$key]);
+                        break;
                     case 'string':
                         $data[$key] = (string) $_data[$key];
                         break;
@@ -665,7 +672,6 @@ abstract class Tinebase_Import_Abstract implements Tinebase_Import_Interface
     {
         // check if related record exists
         $controller = Tinebase_Core::getApplicationInstance($field['related_model']);
-        $filterModel = $field['related_model'] . 'Filter';
         $operator = isset($field['operator']) ? $field['operator'] : 'equals';
         
         $filterValueToAdd = '';
@@ -685,7 +691,7 @@ abstract class Tinebase_Import_Abstract implements Tinebase_Import_Interface
             }
         }
         
-        $filter = new $filterModel(array(
+        $filter = Tinebase_Model_Filter_FilterGroup::getFilterForModel($field['related_model'], array(
                 array('field' => $field['filter'], 'operator' => $operator, 'value' => $value . $filterValueToAdd)
         ));
         $result = $controller->search($filter, null, /* $_getRelations */ true);
@@ -709,10 +715,7 @@ abstract class Tinebase_Import_Abstract implements Tinebase_Import_Interface
             'remark'        => $relationType == 'PRODUCT' ? array('quantity' => 1) : null,
         );
 
-        if ($record) {
-            $relation['related_id'] = $record->getId();
-            $recordArray = $record->toArray();
-        } else {
+        if (!$record) {
             if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) {
                 Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
                     . ' Create new related record');
@@ -723,31 +726,29 @@ abstract class Tinebase_Import_Abstract implements Tinebase_Import_Interface
             if (! empty($filterValueToAdd)) {
                 $recordArray[str_replace($relationType . '_', '', $field['filterValueAdd'])] = trim($filterValueToAdd);
             }
-        }
 
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) {
-            Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-                . ' Import data:' . print_r($data, true));
-        }
-
-        // add more data for this relation if available
-        foreach ($data as $key => $value) {
-            $regex = '/^' . preg_quote($relationType, '/') . '_/';
-            if (preg_match($regex, $key)) {
-                $relatedField = preg_replace($regex, '', $key);
-                $recordArray[$relatedField] = trim($value);
+            // add more data for this relation if available
+            foreach ($data as $key => $value) {
+                $regex = '/^' . preg_quote($relationType, '/') . '_/';
+                if (preg_match($regex, $key)) {
+                    $relatedField = preg_replace($regex, '', $key);
+                    $recordArray[$relatedField] = trim($value);
+                }
             }
+
+            // we don't need related record relations
+            unset($recordArray['relations']);
+
+            if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) {
+                Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
+                    . ' Related record: ' . print_r($recordArray, true));
+            }
+
+            $ctrl = Tinebase_Core::getApplicationInstance($field['related_model']);
+            $record = $ctrl->create(new $field['related_model']($recordArray));
+
         }
-
-        // we don't need related record relations
-        unset($recordArray['relations']);
-
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) {
-            Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-                . ' Related record: ' . print_r($recordArray, true));
-        }
-
-        $relation['related_record'] = $recordArray;
+        $relation['related_id'] = $record->getId();
 
         return $relation;
     }
@@ -786,17 +787,19 @@ abstract class Tinebase_Import_Abstract implements Tinebase_Import_Interface
      * @param Tinebase_Record_Interface $_record
      * @param string $_resolveStrategy
      * @param array $_recordData not needed here but in other import classes (i.a. Admin_Import_Csv)
-     * @return Tinebase_Record_Interface the imported record
+     * @return null|Tinebase_Record_Interface the imported record
      * @throws Tinebase_Exception_Record_Validation
      */
     protected function _importRecord($_record, $_resolveStrategy = NULL, $_recordData = array())
     {
         $_record->isValid(TRUE);
-        
+
+        $oldRollback = Tinebase_TransactionManager::getInstance()->unitTestForceSkipRollBack();
         if ($this->_options['dryrun']) {
             if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
                 . ' Doing Dry-Run ... (transaction will be rolled-back)');
             Tinebase_TransactionManager::getInstance()->startTransaction(Tinebase_Core::getDb());
+            Tinebase_TransactionManager::getInstance()->unitTestForceSkipRollBack(true);
         }
         if($_record->has('tags')){
             $this->_handleTags($_record, $_resolveStrategy);
@@ -810,6 +813,7 @@ abstract class Tinebase_Import_Abstract implements Tinebase_Import_Interface
         $this->_importResult['results']->addRecord($importedRecord);
         
         if ($this->_options['dryrun']) {
+            Tinebase_TransactionManager::getInstance()->unitTestForceSkipRollBack($oldRollback);
             Tinebase_TransactionManager::getInstance()->rollBack();
         } else if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) {
             Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . ' Successfully imported record with id ' . $importedRecord->getId());
