@@ -19,6 +19,9 @@
  */
 class Admin_Import_User_Csv extends Tinebase_Import_Csv_Abstract
 {
+    protected $_createdPasswords = [];
+    protected $_createdAccounts = [];
+
     /**
      * additional config options
      * 
@@ -32,10 +35,29 @@ class Admin_Import_User_Csv extends Tinebase_Import_Csv_Abstract
         'accountEmailDomain'            => '',
         'samba'                         => '',
         'accountLoginShell'             => '',
-        'pin'                           => '',
         'userNameSchema'                => 1
     );
-    
+
+    /**
+     * init import result data
+     */
+    protected function _initImportResult()
+    {
+        parent::_initImportResult();
+        $this->_createdPasswords = [];
+        $this->_createdAccounts = [];
+    }
+
+    public function getCreatedPasswords(): array
+    {
+        return $this->_createdPasswords;
+    }
+
+    public function getCreatedAccounts(): array
+    {
+        return $this->_createdAccounts;
+    }
+
     /**
      * set controller
      *
@@ -88,10 +110,8 @@ class Admin_Import_User_Csv extends Tinebase_Import_Csv_Abstract
             if (isset($_recordData['accountHomeDirectoryPrefix'])) {
                 $this->_options['accountHomeDirectoryPrefix'] = $_recordData['accountHomeDirectoryPrefix'];
             }
-            if (isset($_recordData['pin'])) {
-                $this->_options['pin'] = $_recordData['pin'];
-            }
 
+            $record->applyTwigTemplates();
             $password = $record->applyOptionsAndGeneratePassword($this->_options, (isset($_recordData['password'])) ? $_recordData['password'] : NULL);
             Tinebase_Event::fireEvent(new Admin_Event_BeforeImportUser($record, $this->_options));
             
@@ -99,6 +119,8 @@ class Admin_Import_User_Csv extends Tinebase_Import_Csv_Abstract
             if ($record->isValid()) {
                 if (!$this->_options['dryrun']) {
                     $record = $this->_controller->create($record, $password, $password);
+                    $this->_createdPasswords[$record->getId()] = $password;
+                    $this->_createdAccounts[$record->getId()] = $record;
                 } else {
                     $this->_importResult['results']->addRecord($record);
                 }
@@ -133,15 +155,4 @@ class Admin_Import_User_Csv extends Tinebase_Import_Csv_Abstract
                             );
         return $result;
     }
-
-    /**
-     * add pin for user
-     * @param $importedRecord
-     */
-    protected function _inspectAfterImport($importedRecord)
-    {
-         if($this->_options['pin']){
-             $this->_controller->setAccountPin($importedRecord,$this->_options['pin']);
-         }
-    }
 }
