@@ -40,7 +40,6 @@ class Tinebase_ImportExportDefinition extends Tinebase_Controller_Record_Abstrac
         $this->_modelName = 'Tinebase_Model_ImportExportDefinition';
         $this->_applicationName = 'Tinebase';
         $this->_purgeRecords = FALSE;
-        $this->_doContainerACLChecks = FALSE;
 
         // set backend with activated modlog
         $this->_backend = new Tinebase_Backend_Sql(array(
@@ -97,8 +96,17 @@ class Tinebase_ImportExportDefinition extends Tinebase_Controller_Record_Abstrac
         /** @var Tinebase_Model_ImportExportDefinition $definition */
         foreach ($result as $definition) {
             if ($definition->plugin_options) {
-                $config = Tinebase_ImportExportDefinition::getInstance()->
-                    getOptionsAsZendConfigXml($definition, array());
+                try {
+                    $config = Tinebase_ImportExportDefinition::getInstance()->getOptionsAsZendConfigXml(
+                        $definition, array()
+                    );
+                } catch (Tinebase_Exception_InvalidArgument $teia) {
+                    if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(
+                        __METHOD__ . '::' . __LINE__
+                        . ' Removing export definition because'
+                        . ' exception was thrown: ' . $teia->getMessage());
+                    $toRemove[] = $definition;
+                }
                 if (!empty($config->template)) {
                     if (strpos($config->template, 'tine20://') === false) {
                         continue;
@@ -228,7 +236,13 @@ class Tinebase_ImportExportDefinition extends Tinebase_Controller_Record_Abstrac
             $xmlConfig = (empty($_definition->plugin_options))
                 ? '<?xml version="1.0" encoding="UTF-8"?><config></config>'
                 : $_definition->plugin_options;
-            $config = new Zend_Config_Xml($xmlConfig, /* section = */ null, /* runtime mods allowed = */ true);
+            try {
+                $config = new Zend_Config_Xml($xmlConfig, /* section = */ null, /* runtime mods allowed = */ true);
+            } catch (Throwable $t) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                    . ' Invalid XML: ' . $xmlConfig . ' Exception: ' . $t);
+                throw new Tinebase_Exception_InvalidArgument('XML config is invalid');
+            }
             $cache->save($config, $cacheId);
         } else {
             $config = $cache->load($cacheId);
@@ -272,12 +286,14 @@ class Tinebase_ImportExportDefinition extends Tinebase_Controller_Record_Abstrac
             Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . ' Updating definition: ' . $definition->name);
             $definition->setId($existing->getId());
             $definition->is_deleted = $existing->is_deleted;
-            $result = $this->_backend->update($definition);
+            $definition->container_id = $existing->container_id;
+            // also update deleted
+            $result = $this->update($definition, true, true);
             
         } catch (Tinebase_Exception_NotFound $tenf) {
             // does not exist
             Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . ' Creating import/export definion from file: ' . $_filename);
-            $result = $this->_backend->create($definition);
+            $result = $this->create($definition);
         }
         
         return $result;
@@ -345,4 +361,73 @@ class Tinebase_ImportExportDefinition extends Tinebase_Controller_Record_Abstrac
 
         return $definition;
     }
+
+    /**
+     * sets personal container id if container id is missing in record - can be overwritten to set a different container
+     *
+     * @param $_record
+     * @throws Tinebase_Exception_SystemGeneric
+     */
+    protected function _setContainer(Tinebase_Record_Interface $_record)
+    {
+        if (!$_record->container_id) {
+            $_record->container_id = self::getDefaultImportExportContainer()->getId();
+        }
+    }
+
+    protected static $defaultContainer = null;
+
+    public static function resetDefaultContainer()
+    {
+        static::$defaultContainer = null;
+    }
+
+    public static function getDefaultImportExportContainer(): Tinebase_Model_Container
+    {
+        if (null === static::$defaultContainer) {
+            if (!($containerId = Tinebase_Config::getInstance()->{Tinebase_Config::IMPORT_EXPORT_DEFAULT_CONTAINER})) {
+                static::$defaultContainer = self::createDefaultImportExportContainer();
+                Tinebase_Config::getInstance()->{Tinebase_Config::IMPORT_EXPORT_DEFAULT_CONTAINER} = static::$defaultContainer->getId();
+            } else {
+                static::$defaultContainer = Tinebase_Container::getInstance()->getContainerById($containerId);
+            }
+        }
+
+        return static::$defaultContainer;
+    }
+
+    protected static function createDefaultImportExportContainer(): Tinebase_Model_Container
+    {
+        if (Tinebase_Core::isReplica()) {
+            try {
+                return Tinebase_Container::getInstance()->getContainerByName(Tinebase_Model_ImportExportDefinition::class,
+                    'Internal Import/Export Container', Tinebase_Model_Container::TYPE_SHARED);
+            } catch (Tinebase_Exception_NotFound $tenf) {
+                throw new Tinebase_Exception_Record_NotAllowed('on replicas, default container needs to replicated from master');
+            }
+        }
+        $container = new Tinebase_Model_Container(array(
+            'name'              => 'Internal Import/Export Container',
+            'type'              => Tinebase_Model_Container::TYPE_SHARED,
+            'backend'           => 'Sql',
+            'application_id'    => Tinebase_Core::getTinebaseId(),
+            'model'             => Tinebase_Model_ImportExportDefinition::class,
+        ));
+
+        $grants = Tinebase_Model_Grants::getDefaultGrants([
+            Tinebase_Model_Grants::GRANT_ADD => true,
+            Tinebase_Model_Grants::GRANT_EDIT => true,
+            Tinebase_Model_Grants::GRANT_DELETE => true,
+        ]);
+        $anybody = $grants->find('account_id', Tinebase_Core::getUser()->getId());
+        if (Tinebase_Config::getInstance()->get(Tinebase_Config::ANYONE_ACCOUNT_DISABLED)) {
+            $grants->removeRecord($anybody);
+        } else {
+            $anybody->account_id = 0;
+            $anybody->account_type = Tinebase_Acl_Rights::ACCOUNT_TYPE_ANYONE;
+            $anybody->{Tinebase_Model_Grants::GRANT_ADMIN} = false;
+        }
+
+        return Tinebase_Container::getInstance()->addContainer($container, $grants, true);
+    }
 }
