@@ -17,6 +17,8 @@
  */
 class Tinebase_Log_Formatter_Db extends Tinebase_Log_Formatter
 {
+    const NOUSERID = 'no_user_id';
+
     /**
      * Formats data into a array compatible to database
      *
@@ -27,7 +29,7 @@ class Tinebase_Log_Formatter_Db extends Tinebase_Log_Formatter
     {
         $data = $this->getLogData($event);
         $data['id'] = Tinebase_Record_Abstract::generateUID();
-        $data['user'] = Tinebase_Core::getUser()->getId();
+        $data['user'] = is_object(Tinebase_Core::getUser()) ? Tinebase_Core::getUser()->getId() : self::NOUSERID;
 
         $timestamp = new Tinebase_DateTime($data['timestamp']);
         $data['timestamp'] = $timestamp->toString();
