@@ -376,12 +376,10 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
         }
         
         if (isset($_data['user_id']) && is_array($_data['user_id'])) {
-            if ((isset($_data['user_id']['accountId']) || array_key_exists('accountId', $_data['user_id']))) {
+            if (isset($_data['user_id']['accountId'])) {
                 // NOTE: we need to support accounts, cause the client might not have the contact, e.g. when the attender is generated from a container owner
                 $_data['user_id'] = Addressbook_Controller_Contact::getInstance()->getContactByUserId($_data['user_id']['accountId'], true)->getId();
-            } elseif ((isset($_data['user_id']['group_id']) || array_key_exists('group_id', $_data['user_id']))) {
-                $_data['user_id'] = is_array($_data['user_id']['group_id']) ? $_data['user_id']['group_id'][0] : $_data['user_id']['group_id'];
-            } else if ((isset($_data['user_id']['id']) || array_key_exists('id', $_data['user_id']))) {
+            } elseif (isset($_data['user_id']['id'])) {
                 $_data['user_id'] = $_data['user_id']['id'];
             }
         }
@@ -465,7 +463,7 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
             // update object by reference
             $attendeeToKeep->status = isset($newSettings['partStat']) ? $newSettings['partStat'] : $attendeeToKeep->status;
             $attendeeToKeep->role   = isset($newSettings['role']) && in_array($newSettings['role'], $systemRoles) &&
-                (!isset($attendeesToKeep['role']) || in_array($attendeesToKeep['role'], $systemRoles)) ? $newSettings['role'] : $attendeesToKeep['role'];
+                in_array($attendeeToKeep->role, $systemRoles) ? $newSettings['role'] : $attendeeToKeep->role;
         }
 
         // new attendess to add to event
@@ -608,6 +606,32 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
             }
         }
     }
+
+    public static function enforceListIdForGroups(Tinebase_Record_RecordSet $_attendees)
+    {
+        $groups = [];
+        $lists = [];
+        foreach ($_attendees->filter('user_type', Calendar_Model_Attender::USERTYPE_GROUP) as $groupAttendee) {
+            if ($groupAttendee->user_id instanceof Tinebase_Record_Interface) {
+                if ($groupAttendee->user_id instanceof Tinebase_Model_Group && !empty($groupAttendee->user_id->list_id)) {
+                    $groupAttendee->user_id = Addressbook_Controller_List::getInstance()->get($groupAttendee->user_id->list_id);
+                }
+            } else {
+                if (!isset($groups[$groupAttendee->user_id]) && !isset($lists[$groupAttendee->user_id])) {
+                    try {
+                        $lists[$groupAttendee->user_id] = Addressbook_Controller_List::getInstance()
+                            ->get($groupAttendee->user_id);
+                    } catch (Tinebase_Exception_NotFound $tenf) {
+                        $groups[$groupAttendee->user_id] = Tinebase_Group::getInstance()
+                            ->getGroupById($groupAttendee->user_id);
+                    }
+                }
+                if (isset($groups[$groupAttendee->user_id])) {
+                    $groupAttendee->user_id = $groups[$groupAttendee->user_id]->list_id;
+                }
+            }
+        }
+    }
     
    /**
     * check if contact with given email exists in addressbook and creates it if not
@@ -700,8 +724,11 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
             $listId = null;
         
             if ($groupAttender->user_id instanceof Addressbook_Model_List) {
-                $listId = $groupAttender->user_id->getId();
-            } else if ($groupAttender->user_id !== NULL) {
+                $groupAttender->user_id = $listId = $groupAttender->user_id->getId();
+            } elseif ($groupAttender->user_id instanceof Tinebase_Model_Group &&
+                    !empty($groupAttender->user_id->list_id)) {
+                $groupAttender->user_id = $listId = $groupAttender->user_id->list_id;
+            } elseif ($groupAttender->user_id !== NULL) {
                 try {
                     $list = Addressbook_Controller_List::getInstance()->get($groupAttender->user_id);
                     $listId = $list->getId();
@@ -710,7 +737,7 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
                     $group = Tinebase_Group::getInstance()->getGroupById($groupAttender->user_id);
                     if (!empty($group->list_id)) {
                         Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__  . ' fixme: depricated use of  group id');
-                        $listId = $group->list_id;
+                        $groupAttender->user_id = $listId = $group->list_id;
                     }
                 }
             } else {
@@ -1105,7 +1132,7 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
                     // first fetch the groups, then the lists identified by list_id
                     $typeMap[$type] = Tinebase_Group::getInstance()->getMultiple(array_unique($ids));
                     $listIds = array_unique(array_merge($typeMap[$type]->list_id, $ids));
-                    $typeMap['list'] = Addressbook_Controller_List::getInstance()->getMultiple($listIds, true);
+                    $typeMap[$type] = Addressbook_Controller_List::getInstance()->getMultiple($listIds, true);
                     break;
                 case self::USERTYPE_RESOURCE:
                     $typeMap[$type] = Calendar_Controller_Resource::getInstance()->getMultiple(array_unique($ids), true);
@@ -1135,21 +1162,13 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
                     // already resolved from cache
                     continue;
                 }
-                
-                if ($attender->user_type == self::USERTYPE_GROUP) {
-                    $attendeeTypeSet = $typeMap[$attender->user_type];
-                    $idx = $attendeeTypeSet->getIndexById($attender->user_id);
-                    if ($idx !== false) {
-                        $group = $attendeeTypeSet[$idx];
-                        $attendeeTypeSet = $typeMap['list'];
-                        $idx = $attendeeTypeSet->getIndexById($group->list_id);
-                    } else {
-                        $attendeeTypeSet = $typeMap['list'];
-                        $idx = $attendeeTypeSet->getIndexById($attender->user_id);
+
+                $attendeeTypeSet = $typeMap[$attender->user_type];
+                $idx = $attendeeTypeSet->getIndexById($attender->user_id);
+                if (false == $idx && self::USERTYPE_GROUP === $attender->user_type) {
+                    if (null !== ($list = $attendeeTypeSet->find('group_id', $attender->user_id))) {
+                        $idx = $attendeeTypeSet->getIndexById($list->getId());
                     }
-                } else {
-                    $attendeeTypeSet = $typeMap[$attender->user_type];
-                    $idx = $attendeeTypeSet->getIndexById($attender->user_id);
                 }
                 
                 if ($idx !== false) {
@@ -1201,12 +1220,25 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
         if ($eventAttendees instanceof Tinebase_Record_RecordSet && $_sort) {
             $eventAttendees->sort(function(Calendar_Model_Attender $a1, Calendar_Model_Attender $a2) {
                 try {
-                    return $a1->getName() > $a2->getName();
+                    return strcmp($a1->getName(), $a2->getName());
+
+                    // ok time for some fun, enjoy:
+                    // if attender has no name, we sort him bigger (end of list)
                 } catch (Tinebase_Exception_InvalidArgument $teia) {
                     if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE))
                         Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__
                             . ' ' . $teia->getMessage());
-                    return true;
+                    try {
+                        $a1->getName();
+                    } catch (Tinebase_Exception_InvalidArgument $teia) {
+                        try {
+                            $a2->getName();
+                        } catch (Tinebase_Exception_InvalidArgument $teia) {
+                            return 0;
+                        }
+                        return 1;
+                    }
+                    return -1;
                 }
             });
         }
