@@ -113,6 +113,8 @@ class Calendar_Model_Event extends Tinebase_Record_Abstract
         ),
         'description'          => array(Zend_Filter_Input::ALLOW_EMPTY => true          ),
         'geo'                  => array(Zend_Filter_Input::ALLOW_EMPTY => true, Zend_Filter_Input::DEFAULT_VALUE => NULL),
+        'adr_lon'              => array(Zend_Filter_Input::ALLOW_EMPTY => true, Zend_Filter_Input::DEFAULT_VALUE => NULL),
+        'adr_lat'              => array(Zend_Filter_Input::ALLOW_EMPTY => true, Zend_Filter_Input::DEFAULT_VALUE => NULL),
         'location'             => array(Zend_Filter_Input::ALLOW_EMPTY => true          ),
         'organizer'            => array(Zend_Filter_Input::ALLOW_EMPTY => false,        ),
         'priority'             => array(Zend_Filter_Input::ALLOW_EMPTY => true, 'Int'   ),
@@ -315,7 +317,7 @@ class Calendar_Model_Event extends Tinebase_Record_Abstract
         if (empty($exdates)) return;
 
         usort($exdates, function (Tinebase_DateTime $a, Tinebase_DateTime $b) {
-            return $a->isLater($b);
+            return $a->compare($b);
         });
 
         $this->exdate = $exdates;
@@ -693,6 +695,14 @@ class Calendar_Model_Event extends Tinebase_Record_Abstract
             $_data['geo'] = NULL;
         }
         
+        if (empty($_data['adr_lon'])) {
+            $_data['adr_lon'] = NULL;
+        }
+
+        if (empty($_data['adr_lat'])) {
+            $_data['adr_lat'] = NULL;
+        }
+        
         if (empty($_data['class'])) {
             $_data['class'] = self::CLASS_PUBLIC;
         }
@@ -868,6 +878,23 @@ class Calendar_Model_Event extends Tinebase_Record_Abstract
         return $this->summary;
     }
 
+    public static function resolveRelationId(string $id, $record = null)
+    {
+        if (strpos($id, 'fakeid') === 0) {
+            if (is_array($record)) {
+                $record = new Calendar_Model_Event(null, true);
+                $record->setFromJsonInUsersTimezone($record);
+            }
+            if (!$record instanceof Calendar_Model_Event) {
+                $record = Calendar_Controller_Event::getInstance()->get($id);
+            }
+            $record = Calendar_Controller_Event::getInstance()->createRecurException($record);
+            return $record->getId();
+        }
+
+        return $id;
+    }
+
     // TODO remove the runConvert methods when migration to Modelconfig!
     public function runConvertToRecord()
     {
