@@ -5,7 +5,7 @@
  * @package     Tinebase
  * @subpackage  User
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
- * @copyright   Copyright (c) 2007-2018 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2007-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  * @author      Lars Kneschke <l.kneschke@metaways.de>
  */
 
@@ -39,7 +39,7 @@
  * @property    Tinebase_Model_EmailUser    smtpUser
  * @property    Tinebase_DateTime           accountLastPasswordChange      date when password was last changed
  * @property    bool                         password_must_change
- *
+ * @property    Tinebase_Record_RecordSet   mfa_configs
  */
 class Tinebase_Model_FullUser extends Tinebase_Model_User
 {
@@ -72,6 +72,7 @@ class Tinebase_Model_FullUser extends Tinebase_Model_User
         'hasTags'           => false,
         'hasXProps'         => true,
         'modlogActive'      => true,
+        self::HAS_DELETED_TIME_UNIQUE => true,
         'hasAttachments'    => false,
         'createModule'      => false,
         'exposeHttpApi'     => false,
@@ -89,6 +90,10 @@ class Tinebase_Model_FullUser extends Tinebase_Model_User
 
         'filterModel'       => [],
 
+        self::TABLE         => [
+            self::NAME          => 'accounts'
+        ],
+
         'fields'            => [
             'accountLoginName'              => [
                 'type'                          => 'string',
@@ -116,10 +121,6 @@ class Tinebase_Model_FullUser extends Tinebase_Model_User
             'accountEmailAddress'           => [
                 'type'                          => 'string',
                 'validators'                    => [Zend_Filter_Input::ALLOW_EMPTY => true],
-                'inputFilters'                  => [
-                    Zend_Filter_StringTrim::class => null,
-                    Zend_Filter_StringToLower::class => null,
-                ],
             ],
             'accountFullName'               => [
                 'type'                          => 'string',
@@ -127,7 +128,11 @@ class Tinebase_Model_FullUser extends Tinebase_Model_User
                 'inputFilters'                  => [Zend_Filter_StringTrim::class => null],
             ],
             'contact_id'                    => [
-                //'type'                          => 'record',
+                self::TYPE                      => self::TYPE_RECORD,
+                self::CONFIG                    => [
+                    self::APP_NAME                  => Addressbook_Config::APP_NAME,
+                    self::MODEL_NAME                => Addressbook_Model_Contact::MODEL_PART_NAME,
+                ],
                 'validators'                    => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'accountLastLogin'              => [
@@ -212,11 +217,22 @@ class Tinebase_Model_FullUser extends Tinebase_Model_User
                     self::VISIBILITY_DISPLAYED,
                 ], Zend_Filter_Input::DEFAULT_VALUE => self::VISIBILITY_DISPLAYED],
             ],
-            'password_must_change' => [
-                'type'                  => 'boolean',
-                'default'               => false,
-                'validators'            => [Zend_Filter_Input::ALLOW_EMPTY => true],
+            'password_must_change'          => [
+                'type'                          => 'boolean',
+                'default'                       => false,
+                'validators'                    => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
+            'mfa_configs'             => [
+                self::TYPE                      => self::TYPE_RECORDS,
+                self::OMIT_MOD_LOG              => true,
+                self::CONFIG                    => [
+                    self::STORAGE                   => self::TYPE_JSON,
+                    self::APP_NAME                  => Tinebase_Config::APP_NAME,
+                    self::MODEL_NAME                => Tinebase_Model_MFA_UserConfig::MODEL_NAME_PART,
+                ],
+                self::VALIDATORS                => [Zend_Filter_Input::ALLOW_EMPTY => true],
+                self::LABEL                     => 'Area lock configurations', // _('Area lock configurations')
+            ]
         ],
     ];
 
@@ -234,11 +250,6 @@ class Tinebase_Model_FullUser extends Tinebase_Model_User
         if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
             . ' ' . print_r($options, TRUE));
         
-        if (! isset($this->accountLoginName)) {
-            $this->accountLoginName = Tinebase_User::getInstance()->generateUserName($this, (isset($options['userNameSchema'])) ? $options['userNameSchema'] : 1);
-            $this->accountFullName = Tinebase_User::getInstance()->generateAccountFullName($this);
-        }
-        
         if (empty($this->accountPrimaryGroup)) {
             if (! empty($options['group_id'])) {
                 $groupId = $options['group_id'];
@@ -281,8 +292,10 @@ class Tinebase_Model_FullUser extends Tinebase_Model_User
         
         if (! empty($password)) {
             $userPassword = $password;
-        } else if (! empty($options['password'])) {
+        } elseif (! empty($options['password'])) {
             $userPassword = $options['password'];
+        } elseif (! empty($options['passwordGenerator']) && is_callable($options['passwordGenerator'])) {
+            $userPassword = $options['passwordGenerator']($this);
         }
         
         $this->_addEmailUser($userPassword);
