@@ -36,7 +36,9 @@ class Tinebase_Model_FullUserFilter extends Tinebase_Model_Filter_FilterGroup
         'id'             => array('filter' => 'Tinebase_Model_Filter_Id'),
         'query'          => array('filter' => 'Tinebase_Model_Filter_Query', 'options' => array('fields' => array('login_name', 'full_name'))),
         'login_name'     => array('filter' => 'Tinebase_Model_Filter_Text'),
+        'email'          => array('filter' => 'Tinebase_Model_Filter_Text'),
         'full_name'      => array('filter' => 'Tinebase_Model_Filter_Text'),
+        'display_name'   => array('filter' => 'Tinebase_Model_Filter_Text'),
         'status'         => array('filter' => 'Tinebase_Model_Filter_Text'),
         'last_login'     => array('filter' => 'Tinebase_Model_Filter_DateTime'),
     );
