@@ -146,6 +146,43 @@ class Tinebase_Model_Grants extends Tinebase_Record_Abstract
         return $allGrants;
     }
 
+    public function appliesToUser(Tinebase_Model_FullUser $user): bool
+    {
+        switch ($this->account_type) {
+            case Tinebase_Acl_Rights::ACCOUNT_TYPE_GROUP:
+                if (! in_array($user->getId(), Tinebase_Group::getInstance()->getGroupMembers($this->account_id))) {
+                    if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
+                        . ' Current user not member of group ' . $this->account_id);
+                    return false;
+                }
+                break;
+            case Tinebase_Acl_Rights::ACCOUNT_TYPE_USER:
+                if ($user->getId() !== $this->account_id) {
+                    if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
+                        . ' Grant not available for current user (account_id of grant: ' . $this->account_id . ')');
+                    return false;
+                }
+                break;
+            case Tinebase_Acl_Rights::ACCOUNT_TYPE_ROLE:
+                $userId = $user->getId();
+                foreach (Tinebase_Acl_Roles::getInstance()->getRoleMembers($this->account_id) as $roleMember) {
+                    if (Tinebase_Acl_Rights::ACCOUNT_TYPE_USER === $roleMember['account_type'] &&
+                        $userId === $roleMember['account_id']) {
+                        return true;
+                    }
+                    if (Tinebase_Acl_Rights::ACCOUNT_TYPE_GROUP === $roleMember['account_type'] &&
+                        in_array($user->getId(), Tinebase_Group::getInstance()->getGroupMembers($roleMember['account_id']))) {
+                        return true;
+                    }
+                }
+                if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
+                    . ' Current user not member of role ' . $this->account_id);
+                return false;
+        }
+
+        return true;
+    }
+
     /**
      * checks record grant
      * 
@@ -174,39 +211,7 @@ class Tinebase_Model_Grants extends Tinebase_Record_Abstract
             return false;
         }
         
-        switch ($this->account_type) {
-            case Tinebase_Acl_Rights::ACCOUNT_TYPE_GROUP:
-                if (! in_array($user->getId(), Tinebase_Group::getInstance()->getGroupMembers($this->account_id))) {
-                    if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__ 
-                        . ' Current user not member of group ' . $this->account_id);
-                    return false;
-                }
-                break;
-            case Tinebase_Acl_Rights::ACCOUNT_TYPE_USER:
-                if ($user->getId() !== $this->account_id) {
-                    if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__ 
-                        . ' Grant not available for current user (account_id of grant: ' . $this->account_id . ')');
-                    return false;
-                }
-                break;
-            case Tinebase_Acl_Rights::ACCOUNT_TYPE_ROLE:
-                $userId = $user->getId();
-                foreach (Tinebase_Acl_Roles::getInstance()->getRoleMembers($this->account_id) as $roleMember) {
-                    if (Tinebase_Acl_Rights::ACCOUNT_TYPE_USER === $roleMember['account_type'] &&
-                            $userId === $roleMember['account_id']) {
-                        return true;
-                    }
-                    if (Tinebase_Acl_Rights::ACCOUNT_TYPE_GROUP === $roleMember['account_type'] &&
-                        in_array($user->getId(), Tinebase_Group::getInstance()->getGroupMembers($roleMember['account_id']))) {
-                        return true;
-                    }
-                }
-                if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-                    . ' Current user not member of role ' . $this->account_id);
-                return false;
-        }
-        
-        return true;
+        return $this->appliesToUser($user);
     }
 
     /**
