@@ -52,6 +52,7 @@ class Tinebase_Model_ImportExportDefinition extends Tinebase_Record_NewAbstract
     const FLDS_FORMAT = 'format';
     const FLDS_FILENAME = 'filename';
     const FLDS_FILTER = 'filter';
+    const FLDS_CONTAINER_ID = 'container_id';
 
     /**
      * key in $_validators/$_properties array for the filed which
@@ -116,6 +117,8 @@ class Tinebase_Model_ImportExportDefinition extends Tinebase_Record_NewAbstract
         'exposeHttpApi'     => false,
         'exposeJsonApi'     => true,
         'copyEditAction'    => true,
+        self::CONTAINER_PROPERTY => self::FLDS_CONTAINER_ID,
+        self::HAS_PERSONAL_CONTAINER => false,
 
 
         'appName'           => 'Tinebase',
@@ -243,4 +246,20 @@ class Tinebase_Model_ImportExportDefinition extends Tinebase_Record_NewAbstract
         $filter = json_decode($this->{self::FLDS_FILTER}, true);
         return Tinebase_Model_Filter_FilterGroup::getFilterForModel($this->model, is_array($filter) ? $filter : []);
     }
+
+    public function runConvertToRecord()
+    {
+        if (isset($this->_data['deleted_time']) && $this->_data['deleted_time'] == '1970-01-01 00:00:00') {
+            unset($this->_data['deleted_time']);
+        }
+        parent::runConvertToRecord();
+    }
+
+    public function runConvertToData()
+    {
+        if (array_key_exists('deleted_time', $this->_data) && null === $this->_data['deleted_time']) {
+            unset($this->_data['deleted_time']);
+        }
+        parent::runConvertToData();
+    }
 }
