@@ -22,9 +22,12 @@
  * @property    string      $email
  * @property    string      $type                 type of list
  * @property    string      $emails
+ * @property    string      $list_type
  */
 class Addressbook_Model_List extends Tinebase_Record_Abstract
 {
+    const MODEL_NAME_PART = 'List';
+    
     /**
      * list type: list (user defined lists)
      * 
@@ -63,6 +66,7 @@ class Addressbook_Model_List extends Tinebase_Record_Abstract
         'name',
         'description',
         'email',
+        'account_only'
     );
 
     /**
@@ -78,7 +82,7 @@ class Addressbook_Model_List extends Tinebase_Record_Abstract
      * @var array
      */
     protected static $_modelConfiguration = array(
-        'recordName'        => 'List', // gettext('GENDER_List)
+        'recordName'        => 'List', // gettext('GENDER_List')
         'recordsName'       => 'Lists', // ngettext('List', 'Lists', n)
         'hasRelations'      => true,
         'hasCustomFields'   => true,
@@ -91,8 +95,8 @@ class Addressbook_Model_List extends Tinebase_Record_Abstract
 
         'containerProperty' => 'container_id',
 
-        'containerName'     => 'Lists',
-        'containersName'    => 'Lists',
+        'containerName'     => 'List', // gettext('GENDER_List')
+        'containersName'    => 'Lists', // ngettext('List', 'Lists', n)
         'containerUsesFilter' => true, // TODO true?
 
         'titleProperty'     => 'name',//array('%s - %s', array('number', 'title')),
@@ -167,7 +171,8 @@ class Addressbook_Model_List extends Tinebase_Record_Abstract
             ),
             'list_type'         => array(
                 'label'             => 'List type', //_('List type')
-                'type'              => 'string',
+                'type'              => 'keyfield',
+                'name'              => Addressbook_Config::LIST_TYPE,
                 'validators'        => array(Zend_Filter_Input::ALLOW_EMPTY => true),
             ),
             'group_id'          => array(
@@ -188,7 +193,7 @@ class Addressbook_Model_List extends Tinebase_Record_Abstract
             ),
             'memberroles'       => array(
                 'label'             => null, // TODO fill this?
-                'type'              => 'string',
+                'type'              => 'virtual',
                 'validators'        => array(Zend_Filter_Input::ALLOW_EMPTY => true),
             ),
             'paths'             => array(
