@@ -31,7 +31,7 @@ class Sales_Model_Supplier extends Tinebase_Record_Abstract
      * @var array
      */
     protected static $_modelConfiguration = array(
-        'recordName'        => 'Supplier',
+        'recordName'        => 'Supplier', // gettext('GENDER_Supplier')
         'recordsName'       => 'Suppliers', // ngettext('Supplier', 'Suppliers', n)
         'hasRelations'      => TRUE,
         'hasCustomFields'   => TRUE,
@@ -173,6 +173,22 @@ class Sales_Model_Supplier extends Tinebase_Record_Abstract
                 ),
                 'type'   => 'virtual',
             ),
+            'adr_name' => [
+                'config' => [
+                    'duplicateOmit' => TRUE,
+                    'label'         => 'Name', //_('Name')
+                    'shy'           => TRUE
+                ],
+                'type'   => 'virtual',
+            ],
+            'adr_email' => [
+                'config' => [
+                    'duplicateOmit' => TRUE,
+                    'label'         => 'Email', //_('Name')
+                    'shy'           => TRUE
+                ],
+                'type'   => 'virtual',
+            ],
             'adr_street' => array(
                 'config' => array(
                     'duplicateOmit' => TRUE,
