@@ -29,6 +29,8 @@
  */
 class Tinebase_Model_Tree_FileObject extends Tinebase_Record_Abstract
 {
+    public const TABLE_NAME = 'tree_fileobjects';
+
     /**
      * key in $_validators/$_properties array for the filed which 
      * represents the identifier
@@ -231,13 +233,6 @@ class Tinebase_Model_Tree_FileObject extends Tinebase_Record_Abstract
     ];
 
     protected static $_isReplicable = true;
-
-    public static function modelConfigHook(array &$_definition)
-    {
-        // legacy :-/
-        $_definition['is_deleted'][self::NULLABLE] = true;
-        $_definition['is_deleted'][self::UNSIGNED] = true;
-    }
     
     /**
      * converts a string or Addressbook_Model_List to a list id
