@@ -152,9 +152,13 @@ class Tinebase_Model_Tree_Node extends Tinebase_Record_Abstract
                 'options'           => [
                     'idProperty'        => 'object_id',
                 ],
+                'label' => 'File Contents', // _('File Contents')
+                'jsConfig' => ['operators' => ['wordstartswith']]
             ],
             'isIndexed'         => [
-                'filter'            => Tinebase_Model_Tree_Node_IsIndexedFilter::class,
+                'label' => 'Indexed',    // _('Indexed')
+                'filter' => Tinebase_Model_Tree_Node_IsIndexedFilter::class,
+                'jsConfig' => ['valueType' => 'bool']
             ],
         ],
 
@@ -182,7 +186,8 @@ class Tinebase_Model_Tree_Node extends Tinebase_Record_Abstract
                 self::FILTER_DEFINITION     => [
                     self::FILTER                => Tinebase_Model_Filter_Text::class,
                     self::OPTIONS               => ['binary' => true]
-                ]
+                ],
+                self::INPUT_FILTERS         => [Zend_Filter_StringTrim::class => NULL],
             ],
             'islink'                        => [
                 'type'                          => self::TYPE_BOOLEAN,
@@ -213,12 +218,12 @@ class Tinebase_Model_Tree_Node extends Tinebase_Record_Abstract
                 self::NULLABLE                  => true,
             ],
             'revisionProps'                 => [
-                'type'                          => 'text',
+                'type'                          => self::TYPE_JSON,
                 self::NULLABLE                  => true,
                 'validators'                    => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
             'notificationProps'             => [
-                'type'                          => 'text',
+                'type'                          => self::TYPE_JSON,
                 self::NULLABLE                  => true,
                 'validators'                    => [Zend_Filter_Input::ALLOW_EMPTY => true],
             ],
@@ -456,21 +461,23 @@ class Tinebase_Model_Tree_Node extends Tinebase_Record_Abstract
     {
         $fileObjectTime = [
             self::FILTER    => Tinebase_Model_Filter_DateTime::class,
-            self::OPTIONS   => ['tablename' => 'tree_fileobjects']
+            self::OPTIONS   => ['tablename' => Tinebase_Model_Tree_FileObject::TABLE_NAME]
         ];
         $fileObjectUser = [
             self::FILTER    => Tinebase_Model_Filter_User::class,
-            self::OPTIONS   => ['tablename' => 'tree_fileobjects']
+            self::OPTIONS   => ['tablename' => Tinebase_Model_Tree_FileObject::TABLE_NAME]
         ];
 
         $_definition['created_by'][self::DOCTRINE_IGNORE] = true;
         $_definition['created_by'][self::FILTER_DEFINITION] = $fileObjectUser;
+        $_definition['created_by'][self::TABLE] = Tinebase_Model_Tree_FileObject::TABLE_NAME;
 
         $_definition['creation_time'][self::DOCTRINE_IGNORE] = true;
         $_definition['creation_time'][self::FILTER_DEFINITION] = $fileObjectTime;
 
         $_definition['last_modified_by'][self::DOCTRINE_IGNORE] = true;
         $_definition['last_modified_by'][self::FILTER_DEFINITION] = $fileObjectUser;
+        $_definition['last_modified_by'][self::TABLE] = Tinebase_Model_Tree_FileObject::TABLE_NAME;
 
         $_definition['last_modified_time'][self::DOCTRINE_IGNORE] = true;
         $_definition['last_modified_time'][self::FILTER_DEFINITION] = $fileObjectTime;
@@ -479,6 +486,7 @@ class Tinebase_Model_Tree_Node extends Tinebase_Record_Abstract
 
         $_definition['deleted_by'][self::DOCTRINE_IGNORE] = true;
         $_definition['deleted_by'][self::FILTER_DEFINITION] = $fileObjectUser;
+        $_definition['deleted_by'][self::TABLE] = Tinebase_Model_Tree_FileObject::TABLE_NAME;
     }
 
     public function runConvertToRecord()
@@ -626,4 +634,9 @@ class Tinebase_Model_Tree_Node extends Tinebase_Record_Abstract
         }
         return 0;
     }
+
+    public function getContainerId(): ?string
+    {
+        return $this->parent_id;
+    }
 }
