@@ -347,7 +347,18 @@ abstract class Tinebase_Record_Abstract extends Tinebase_ModelConfiguration_Cons
         }
         return $this->_properties[$this->_identifier];
     }
-    
+
+    public function getContainerId(): ?string
+    {
+        $containerId = isset($this->_properties['container_id']) ? $this->_properties['container_id'] : null;
+        if (is_object($containerId)) {
+            $containerId = $containerId->getId();
+        } elseif (is_array($containerId)) {
+            $containerId = $containerId['id'];
+        }
+        return $containerId;
+    }
+
     /**
      * gets application the records belongs to
      * 
@@ -1342,6 +1353,7 @@ abstract class Tinebase_Record_Abstract extends Tinebase_ModelConfiguration_Cons
         $translation = Tinebase_Translation::getTranslation(preg_replace('/_.*/', '', static::class), $locale);
         return $translation->translate(preg_replace('/.*_/', '', static::class));
     }
+
     /**
      * returns the foreignId fields (used in Tinebase_Convert_Json)
      * @return array
@@ -1381,7 +1393,11 @@ abstract class Tinebase_Record_Abstract extends Tinebase_ModelConfiguration_Cons
                     /** @var Tinebase_Model_Converter_Interface $converter */
                     $this->_properties[$key] = $converter->convertToRecord($this, $key, $this->_properties[$key]);
                 } elseif ($converter instanceof Tinebase_Model_Converter_RunOnNullInterface) {
-                    $this->_properties[$key] = $converter->convertToRecord($this, $key, null);
+                    try {
+                        $this->_properties[$key] = $converter->convertToRecord($this, $key, null);
+                    } catch (Tinebase_Exception_NotFound $tenf) {
+                        Tinebase_Exception::log($tenf);
+                    }
                 }
             }
         }
@@ -1405,6 +1421,11 @@ abstract class Tinebase_Record_Abstract extends Tinebase_ModelConfiguration_Cons
         }
     }
 
+    public static function resolveRelationId(string $id, $record = null)
+    {
+        return $id;
+    }
+
     public static function getSimpleModelName($application, $model)
     {
         $appName = is_string($application) ? $application : $application->name;
