@@ -332,6 +332,17 @@ class Tinebase_Record_NewAbstract extends Tinebase_ModelConfiguration_Const impl
         return $this->__get(static::$_configurationObject->getIdProperty());
     }
 
+    public function getContainerId(): ?string
+    {
+        $containerId = $this->__get(static::$_configurationObject->getContainerProperty());
+        if (is_object($containerId)) {
+            $containerId = $containerId->getId();
+        } elseif (is_array($containerId)) {
+            $containerId = $containerId['id'];
+        }
+        return $containerId;
+    }
+
     /**
      * gets application the records belongs to
      *
@@ -1127,6 +1138,11 @@ class Tinebase_Record_NewAbstract extends Tinebase_ModelConfiguration_Const impl
         }
     }
 
+    public static function resolveRelationId(string $id, $record = null)
+    {
+        return $id;
+    }
+
     /**
      * @param Tinebase_Record_RecordSet $_recordSet
      * @param Tinebase_Record_RecordSetDiff $_recordSetDiff
@@ -1559,7 +1575,7 @@ class Tinebase_Record_NewAbstract extends Tinebase_ModelConfiguration_Const impl
 
             foreach ($toConvert as $convertField => &$value) {
                 if (! method_exists($value, 'setTimezone')) {
-                    throw new Tinebase_Exception_Record_Validation($convertField . ' must be a method setTimezone');
+                    throw new Tinebase_Exception_Record_Validation($field . ' must have a method setTimezone');
                 }
                 $value->setTimezone($_timezone);
             }
