@@ -40,12 +40,14 @@ class Setup_Server_Cli implements Tinebase_Server_Interface
                 'check_requirements'        => 'Check if all requirements are met to install and run tine20',
                 'create_admin'              => 'Create new admin user (or reactivate if already exists)',
                 'clear_cache'               => 'Clears all caches',
+                'clear_cache_dir'           => 'Clears cache directories', 
                 'install-s'                 => 'Install applications [all if nothing installed yet] or comma separated list (use "all" as parameter to install all available apps);'
                     . ' To specify the login name and login password of the admin user that is created during installation, append \' -- adminLoginName="admin" adminPassword="password"\''
                     . ' To add imap or smtp settings, append (for example) \' -- imap="host:mail.example.org,port:143,dbmail_host:localhost" smtp="ssl:tls"\'',
                 'update-s'                  => 'Update applications [All] or comma separated list - supports verbose mode (-v)',
                 'update_needed'             => 'returns "Update required" and return code 1 if update is required',
                 'uninstall-s'               => 'Uninstall application [All] or comma separated list',
+                    'removemailaccounts'    => 'Only usable with uninstall. Removes all mail accounts belonging to this installation',
                 'install_dump'              => 'Install Tine from a backup
                          Examples:
                            setup.php --install_dump -- db=1 files=1 backupDir=/backup/tine20 keepTinebaseID=1
@@ -68,7 +70,7 @@ class Setup_Server_Cli implements Tinebase_Server_Interface
                            setup.php --updateAllAccountsWithAccountEmail -- fromInstance=master.mytine20.com',
                 'backup'                    => 'backup config and data
                          Examples:
-                           setup.php --backup -- config=1 db=1 files=1 backupDir=/backup/tine20 noTimestamp=1 novalidate=1',
+                           setup.php --backup -- config=1 db=1 files=1 emailusers=1 backupDir=/backup/tine20 noTimestamp=1 novalidate=1',
                 'restore'                   => 'restore config and data
                          Examples:
                            setup.php --restore -- config=1 db=1 files=1 backupDir=/backup/tine20',
@@ -116,6 +118,7 @@ class Setup_Server_Cli implements Tinebase_Server_Interface
             empty($opts->updateAllAccountsWithAccountEmail) &&
             empty($opts->create_admin) &&
             empty($opts->clear_cache) &&
+            empty($opts->clear_cache_dir) &&
             empty($opts->setconfig) &&
             empty($opts->backup) &&
             empty($opts->restore) &&
