@@ -5,14 +5,14 @@
  * @package     Tinebase
  * @subpackage  Server
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
- * @copyright   Copyright (c) 2017-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2017-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  * @author      Paul Mehrer <p.mehrer@metaways.de>
  */
 
 use \Psr\Http\Message\RequestInterface;
-use \Zend\Diactoros\Response;
-use \Zend\Diactoros\Response\EmitterInterface;
-use \Zend\Diactoros\Response\SapiEmitter;
+use \Laminas\Diactoros\Response;
+use \Zend\HttpHandlerRunner\Emitter\EmitterInterface;
+use \Zend\HttpHandlerRunner\Emitter\SapiEmitter;
 use \Zend\Stratigility\MiddlewarePipe;
 
 /**
@@ -28,7 +28,7 @@ class Tinebase_Server_Expressive extends Tinebase_Server_Abstract implements Tin
     /**
      * the request
      *
-     * @var \Zend\Diactoros\Request
+     * @var \Laminas\Diactoros\Request
      */
     protected $_request = NULL;
 
@@ -72,6 +72,8 @@ class Tinebase_Server_Expressive extends Tinebase_Server_Abstract implements Tin
      */
     public function handle(\Zend\Http\Request $request = null, $body = null)
     {
+        Tinebase_AreaLock::getInstance()->activatedByFE();
+
         // TODO session handling in middle ware? this is a question!
         try {
             if (Tinebase_Session::sessionExists()) {
@@ -90,8 +92,6 @@ class Tinebase_Server_Expressive extends Tinebase_Server_Abstract implements Tin
             if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
                 .' Is Routing request. uri: ' . $this->_request->getUri()->getPath() . '?'
                 . $this->_request->getUri()->getQuery() . ' method: ' . $this->_request->getMethod());
-            if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::'
-                . __LINE__ .' REQUEST: ' . print_r($this->_request, true));
 
             $responsePrototype = new Response();
 
