@@ -68,8 +68,7 @@ class ActiveSync_Server_Http extends Tinebase_Server_Abstract implements Tinebas
             }
 
             if ($authResult !== true) {
-                header('WWW-Authenticate: Basic realm="ActiveSync for Tine 2.0"');
-                header('HTTP/1.1 401 Unauthorized');
+                $this->_unauthorized();
                 return;
             }
 
@@ -101,6 +100,12 @@ class ActiveSync_Server_Http extends Tinebase_Server_Abstract implements Tinebas
         }
     }
 
+    protected function _unauthorized()
+    {
+        header('WWW-Authenticate: Basic realm="ActiveSync for Tine 2.0"');
+        header('HTTP/1.1 401 Unauthorized');
+    }
+
     /**
      * @param Throwable $e
      * @throws Throwable
@@ -121,6 +126,8 @@ class ActiveSync_Server_Http extends Tinebase_Server_Abstract implements Tinebas
     protected function _checkDenyList()
     {
         $denyList = ActiveSync_Config::getInstance()->get(ActiveSync_Config::USER_AGENT_DENY_LIST);
+        // NOTE: Outlook app destroys your privacy. it mirrors all content on ms servers. if you like to use it, use exchange/m365 as well!
+        $denyList[] = '/Outlook-iOS-Android.*/';
         foreach ($denyList as $deny) {
             if (isset($_SERVER['HTTP_USER_AGENT']) && preg_match($deny, $_SERVER['HTTP_USER_AGENT'])) {
                 Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__ . ' User agent blocked: ' . $_SERVER['HTTP_USER_AGENT']);
@@ -177,6 +184,9 @@ class ActiveSync_Server_Http extends Tinebase_Server_Abstract implements Tinebas
      */
     protected function _authenticate($_username, $_password, \Zend\Http\Request $request)
     {
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+            . ' ActiveSync Authentication untransformed username: ' . $_username);
+
         $pos = strrchr($_username, '\\');
         
         if($pos !== false) {
