@@ -6,7 +6,7 @@
  * @subpackage  Session
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Guilherme Striquer Bisotto <guilherme.bisotto@serpro.gov.br>
- * @copyright   Copyright (c) 2014-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2014-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  * 
  */
 
@@ -100,6 +100,8 @@ abstract class Tinebase_Session_Abstract extends Zend_Session_Namespace
     public static function destroyAndRemoveCookie()
     {
         if (self::sessionExists()) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+                __METHOD__ . '::' . __LINE__ . ' Destroying session');
             Zend_Session::destroy(true, true);
         }
     }
@@ -119,6 +121,8 @@ abstract class Tinebase_Session_Abstract extends Zend_Session_Namespace
      */
     public static function writeClose($readonly = true)
     {
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+            __METHOD__ . '::' . __LINE__ . ' Closing session (readonly: ' . (integer) $readonly . ')');
         Zend_Session::writeClose($readonly);
     }
     
@@ -258,24 +262,26 @@ abstract class Tinebase_Session_Abstract extends Zend_Session_Namespace
 
                 if (!ini_set('session.save_handler', 'files'))
                 {
-                    Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__ . " ini set didn´t work. session.save_handler = " . ini_get('session.save_handler'));
+                    Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__
+                        . " ini set didn´t work. session.save_handler = " . ini_get('session.save_handler'));
                 }
 
-                
-                $lastSessionCleanup = Tinebase_Config::getInstance()->get(Tinebase_Config::LAST_SESSIONS_CLEANUP_RUN);
-                if ($lastSessionCleanup instanceof DateTime && $lastSessionCleanup > Tinebase_DateTime::now()->subHour(2)) {
-                    Zend_Session::setOptions(array(
-                        'gc_probability' => 0,
-                        'gc_divisor'     => 100
-                    ));
-                } else if (@opendir($sessionSavepath) !== FALSE) {
-                    Zend_Session::setOptions(array(
-                        'gc_probability' => 1,
-                        'gc_divisor'     => 100
-                    ));
-                } else {
-                    Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__
-                        . " Unable to initialize automatic session cleanup. Check permissions to " . $sessionSavepath);
+                if (!$config->session || !$config->session->nocleanup) {
+                    $lastSessionCleanup = Tinebase_Config::getInstance()->get(Tinebase_Config::LAST_SESSIONS_CLEANUP_RUN);
+                    if ($lastSessionCleanup instanceof DateTime && $lastSessionCleanup > Tinebase_DateTime::now()->subHour(2)) {
+                        Zend_Session::setOptions(array(
+                            'gc_probability' => 0,
+                            'gc_divisor' => 100
+                        ));
+                    } else if (@opendir($sessionSavepath) !== FALSE) {
+                        Zend_Session::setOptions(array(
+                            'gc_probability' => 1,
+                            'gc_divisor' => 100
+                        ));
+                    } else {
+                        Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__
+                            . " Unable to initialize automatic session cleanup. Check permissions to " . $sessionSavepath);
+                    }
                 }
                 
                 break;
@@ -358,56 +364,9 @@ abstract class Tinebase_Session_Abstract extends Zend_Session_Namespace
                 'hash_function'   => 1
              )
         );
-        
-        if (isset($_SERVER['REQUEST_URI'])) {
-            $request = Tinebase_Core::get(Tinebase_Core::REQUEST);
 
-            // fallback to request uri
-            $baseUri = $_SERVER['REQUEST_URI'];
-
-            if ($request) {
-                if ($request->getHeaders()->has('X-FORWARDED-HOST')) {
-                    /************** Apache 2.4 with mod_proxy ****************
-                     * Apache set's X-FORWARDED-HOST and REFERER
-                     * 
-                     * ProxyPass /tine20 http://192.168.122.158/tine20
-                     * <Location /tine20>
-                     *      ProxyPassReverse http://192.168.122.158/tine20
-                     * </Location>
-                     * 
-                     * ProxyPass /192.168.122.158/tine20 http://192.168.122.158/tine20
-                     * <Location /192.168.122.158/tine20>
-                     *     ProxyPassReverse http://192.168.122.158/tine20
-                     * </Location>
-                     */
-                    if ($request->getHeaders()->has('REFERER')) {
-                        $refererUri = \Zend\Uri\UriFactory::factory($request->getHeaders()->get('REFERER')->getFieldValue());
-                        $baseUri = $refererUri->getPath();
-                    } else {
-                        $exploded = explode("/", $_SERVER['REQUEST_URI']);
-                        if (strtolower($exploded[1]) == strtolower($_SERVER['HTTP_HOST'])) {
-                             $baseUri = '/' . $_SERVER['HTTP_HOST'] . (($baseUri == '/') ? '' : $baseUri);
-                        }
-                    }
-                    
-                } else {
-                    $baseUri = $request->getBasePath();
-                }
-            }
-
-            // strip of index.php
-            if (substr($baseUri, -9) === 'index.php') {
-                $baseUri = dirname($baseUri);
-            }
-            
-            // strip of trailing /
-            $baseUri = rtrim($baseUri, '/');
-            
-            // fix for windows server with backslash directory separator
-            $baseUri = str_replace(DIRECTORY_SEPARATOR, '/', $baseUri);
-            
-            $options['cookie_path'] = $baseUri;
-        }
+        $baseUri = Tinebase_Core::getUrl(Tinebase_Core::GET_URL_PATH);
+        $options['cookie_path'] = $baseUri;
         
         if (!empty($_SERVER['HTTPS']) && strtoupper($_SERVER['HTTPS']) != 'OFF') {
             $options['cookie_secure'] = true;
