@@ -7,6 +7,8 @@
  * @license     http://www.gnu.org/licenses/agpl.html AGPL3
  * @copyright   Copyright (c) 2019-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  * @author      Philipp Schüle <p.schuele@metaways.de>
+ *
+ * this ist 2020.11 (ONLY!)
  */
 class Felamimail_Setup_Update_13 extends Setup_Update_Abstract
 {
@@ -14,6 +16,7 @@ class Felamimail_Setup_Update_13 extends Setup_Update_Abstract
     const RELEASE013_UPDATE002 = __CLASS__ . '::update002';
     const RELEASE013_UPDATE003 = __CLASS__ . '::update003';
     const RELEASE013_UPDATE004 = __CLASS__ . '::update004';
+    const RELEASE013_UPDATE005 = __CLASS__ . '::update005';
 
     static protected $_allUpdates = [
         self::PRIO_NORMAL_APP_STRUCTURE => [
@@ -34,6 +37,12 @@ class Felamimail_Setup_Update_13 extends Setup_Update_Abstract
                 self::FUNCTION_CONST                => 'update004',
             ],
         ],
+        self::PRIO_NORMAL_APP_UPDATE => [
+            self::RELEASE013_UPDATE005          => [
+                self::CLASS_CONST                   => self::class,
+                self::FUNCTION_CONST                => 'update005',
+            ],
+        ],
     ];
 
     public function update001()
@@ -121,6 +130,11 @@ class Felamimail_Setup_Update_13 extends Setup_Update_Abstract
             $this->setTableVersion('felamimail_cache_message', 13);
         }
 
-        $this->addApplicationUpdate('Felamimail', '13.2', self::RELEASE013_UPDATE004);
+        $this->addApplicationUpdate('Felamimail', '13.3', self::RELEASE013_UPDATE004);
+    }
+
+    public function update005()
+    {
+        $this->addApplicationUpdate('Felamimail', '13.4', self::RELEASE013_UPDATE005);
     }
 }
