@@ -265,6 +265,34 @@ class Tinebase_Timemachine_ModificationLog implements Tinebase_Controller_Interf
 
         return $totalCount;
     }
+
+    /**
+     * clear mod log table
+     * - if $date param is omitted, exception is thrown
+     * 
+     * @param Tinebase_DateTime $date
+     * @return bool
+     */
+    public function clearTable($date = NULL)
+    {
+        
+        if(empty($date)){
+            throw new Tinebase_Exception_InvalidArgurment("Date not set");
+        }
+        
+        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
+            . ' Removing all modification log entries before ' . $date->toString());
+        
+        $db = $this->_backend->getAdapter();
+        $where = array(
+            $db->quoteInto($db->quoteIdentifier('modification_time') . ' <= ?', $date->toString())
+        );
+        $deletedRows = $db->delete($this->_backend->getTablePrefix() . $this->_backend->getTableName(), $where);
+        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
+            . ' Removed ' . $deletedRows . ' rows.');
+        
+        return true;
+    }
     
     /**
      * Returns modification of a given record in a given timespan
@@ -350,7 +378,7 @@ class Tinebase_Timemachine_ModificationLog implements Tinebase_Controller_Interf
             array('field' => 'application_id', 'operator' => 'equals',  'value' => $applicationId),
         ));
         $paging = new Tinebase_Model_Pagination(array(
-            'sort' => 'seq'
+            'sort' => 'instance_seq'
         ));
         
         return $this->_backend->search($filter, $paging);
@@ -863,21 +891,31 @@ class Tinebase_Timemachine_ModificationLog implements Tinebase_Controller_Interf
 
         if (! $diff->isEmpty()) {
             $updateMetaData = array('seq' => ($notNullRecord->has('seq')) ? $notNullRecord->seq : 0);
-            $last_modified_time = $notNullRecord->last_modified_time;
-            if (!empty($last_modified_time)) {
-                $updateMetaData['last_modified_time'] = $last_modified_time;
-            }
-            $last_modified_by   = $notNullRecord->last_modified_by;
-            if (!empty($last_modified_by)) {
-                $updateMetaData['last_modified_by'] = $last_modified_by;
-            }
             $commonModLog = $this->_getCommonModlog($_model, $_backend, $updateMetaData, $_id);
             $commonModLog->new_value = json_encode($diff->toArray());
             if (null === $_newRecord) {
+                if (!empty($notNullRecord->deleted_time)) {
+                    $commonModLog->modification_time = $notNullRecord->deleted_time;
+                }
+                if (!empty($notNullRecord->deleted_by)) {
+                    $commonModLog->modification_account = $notNullRecord->deleted_by;
+                }
                 $commonModLog->change_type = self::DELETED;
             } elseif(null === $_curRecord) {
+                if (!empty($notNullRecord->creation_time)) {
+                    $commonModLog->modification_time = $notNullRecord->creation_time;
+                }
+                if (!empty($notNullRecord->created_by)) {
+                    $commonModLog->modification_account = $notNullRecord->created_by;
+                }
                 $commonModLog->change_type = self::CREATED;
             } else {
+                if (!empty($notNullRecord->last_modified_time)) {
+                    $commonModLog->modification_time = $notNullRecord->last_modified_time;
+                }
+                if (!empty($notNullRecord->last_modified_by)) {
+                    $commonModLog->modification_account = $notNullRecord->last_modified_by;
+                }
                 $commonModLog->change_type = self::UPDATED;
             }
 
@@ -1085,6 +1123,8 @@ class Tinebase_Timemachine_ModificationLog implements Tinebase_Controller_Interf
                         }
                     }
 
+                    $undoneModlogs->addRecord($modlog);
+
                     // this is the legacy code for old data in existing installations
                 } else {
 
@@ -1192,9 +1232,12 @@ class Tinebase_Timemachine_ModificationLog implements Tinebase_Controller_Interf
      */
     public static function increaseRecordSequence(Tinebase_Record_Interface $newRecord, Tinebase_Record_Interface $curRecord = NULL)
     {
-        if (is_object($curRecord) && $curRecord->has('seq')) {
-            $newRecord->seq = (int) $curRecord->seq +1;
-            
+        if ($newRecord->has('seq')) {
+            if (is_object($curRecord)) {
+                $newRecord->seq = (int) $curRecord->seq + 1;
+            } else {
+                $newRecord->seq = (int) $newRecord->seq + 1;
+            }
             if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ .
                 ' Increasing seq of ' . get_class($newRecord) . ' with id ' . $newRecord->getId() .
                 ' from ' . ($newRecord->seq - 1) . ' to ' . $newRecord->seq);
@@ -1254,23 +1297,23 @@ class Tinebase_Timemachine_ModificationLog implements Tinebase_Controller_Interf
 
         // check if we are a replication slave
         if (empty($tine20Url) || empty($tine20LoginName) || empty($tine20Password)) {
-            return true;
+            return;
         }
 
         $fileObject = new Tinebase_Model_Tree_FileObject(array('hash' => $hash), true);
         $path = $fileObject->getFilesystemPath();
         if (is_file($path)) {
             if (Tinebase_FileSystem::getInstance()->checkHashFile($hash)) {
-                return true;
+                return;
             }
             if (!unlink($path)) {
                 throw new Tinebase_Exception_Backend('could not unlink file: ' . $path);
             }
         }
 
-        $tine20Service = new Zend_Service_Tine20($tine20Url, new Zend_Http_Client(null, [
+        $tine20Service = new Zend_Service_Tine20($tine20Url, ($httpClient = new Zend_Http_Client(null, [
             'timeout' => 25
-        ]));
+        ])));
 
         $authResponse = $tine20Service->login($tine20LoginName, $tine20Password);
         if (!is_array($authResponse) || !isset($authResponse['success']) || $authResponse['success'] !== true) {
@@ -1278,39 +1321,61 @@ class Tinebase_Timemachine_ModificationLog implements Tinebase_Controller_Interf
         }
         unset($authResponse);
 
-        $tinebaseProxy = $tine20Service->getProxy('Tinebase');
-        /** @noinspection PhpUndefinedMethodInspection */
-        $response = $tinebaseProxy->getBlob($hash);
-        if (!is_array($response) || !isset($response['success']) || true !== $response['success'] ||
-                !isset($response['data'])) {
-            throw new Tinebase_Exception_Backend('could not fetch blob from master successfully: ' . $hash);
-        }
-
         if (!is_dir(dirname($path))) {
             mkdir(dirname($path));
-        }
-        // no warning desired, we throw ourselves only if required below => @fopen
-        if (!($fh = @fopen($path, 'x'))) {
+        } else {
+            clearstatcache(true, $path);
             if (is_file($path) && Tinebase_FileSystem::getInstance()->checkHashFile($hash)) {
-                return true;
+                return;
             }
-            throw new Tinebase_Exception_Backend('could not create file: ' . $path);
         }
-        $success = false;
+
+        $httpClient->resetParameters();
+        $httpClient->setStream($path);
+        $httpClient->setParameterGet('method', 'Tinebase.getBlob');
+        $httpClient->setParameterGet('hash', $hash);
+
         try {
-            if (!stream_filter_append($fh, 'convert.base64-decode', STREAM_FILTER_WRITE)) {
-                throw new Tinebase_Exception_Backend('could not append stream filter');
+            $response = $httpClient->request(Zend_Http_Client::GET);
+            if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
+                . ' Tinebase.getBlob returned status code ' . $response->getStatus() . $response->getHeadersAsString());
+
+            if (200 === (int)$response->getStatus()) {
+                if ($response->getHeader('Content-encoding')) {
+                    switch ($response->getHeader('Content-encoding')) {
+                        case 'gzip':
+                        case 'deflate': // not sure if deflate works here?
+                            // this will close the stream underlying the response aka our hash file
+                            unset($response);
+                            $tmpFile = Tinebase_TempFile::getTempPath();
+                            $fh = null;
+                            unlink($tmpFile) && rename($path, $tmpFile) && ($fh = gzopen($tmpFile, 'rb')) &&
+                                file_put_contents($path, $fh);
+                            $fh && @fclose($fh);
+                            @unlink($tmpFile);
+                        default;
+                    }
+                }
             }
-            if (false === fwrite($fh, $response['data'])) {
-                throw new Tinebase_Exception_Backend('fetched blob from master could not written to disk: ' . $hash);
-            }
-            $success = true;
+
+            // this will close the stream underlying the response aka our hash file
+            unset($response);
         } finally {
-            fclose($fh);
-            if (!$success) {
-                unlink($path);
+            clearstatcache(true, $path);
+            if (is_file($path)) {
+                if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
+                    . ' filesize ' . filesize($path) . ' for hash ' . $hash);
+                if (Tinebase_FileSystem::getInstance()->checkHashFile($hash)) {
+                    return;
+                } else {
+                    unlink($path);
+                    $msg = 'checkHashFile failed';
+                }
+            } else {
+                $msg = 'file not created';
             }
         }
+        throw new Tinebase_Exception_Backend($msg);
     }
 
     /**
@@ -1475,12 +1540,16 @@ class Tinebase_Timemachine_ModificationLog implements Tinebase_Controller_Interf
 
                     $plain = "Error applying modlog: \n" . print_r($modification->toArray(), true);
                     $plain .= "\n\n" . $e->getMessage() . PHP_EOL . PHP_EOL . $e->getTraceAsString();
+                    $subject = 'replication client error';
+                    if (! empty(Tinebase_Config::getInstance()->{Tinebase_Config::TINE20_URL})) {
+                        $subject .= ' (' . Tinebase_Config::getInstance()->{Tinebase_Config::TINE20_URL} . ')';
+                    }
 
                     foreach ($config->{Tinebase_Config::ERROR_NOTIFICATION_LIST} as $recipient) {
                         $recipients = array(new Addressbook_Model_Contact(array('email' => $recipient), true));
                         try {
                             Tinebase_Notification::getInstance()->send(Tinebase_Core::getUser(), $recipients,
-                                'replication client error', $plain);
+                                $subject, $plain);
                         } catch (Exception $e) {
                             // skipping recipient
                             Tinebase_Exception::log($e);
@@ -1507,6 +1576,11 @@ class Tinebase_Timemachine_ModificationLog implements Tinebase_Controller_Interf
      */
     public static function defaultApply(Tinebase_Model_ModificationLog $_modification, $_controller)
     {
+        $oldValue = $_controller->doContainerACLChecks(false);
+        $raii = new Tinebase_RAII(function() use($_controller, $oldValue) {
+            $_controller->doContainerACLChecks($oldValue);
+        });
+
         switch ($_modification->change_type) {
             case Tinebase_Timemachine_ModificationLog::CREATED:
                 $diff = new Tinebase_Record_Diff(json_decode($_modification->new_value, true));
@@ -1529,6 +1603,8 @@ class Tinebase_Timemachine_ModificationLog implements Tinebase_Controller_Interf
             default:
                 throw new Tinebase_Exception('unknown Tinebase_Model_ModificationLog->change_type: ' . $_modification->change_type);
         }
+
+        unset($raii);
     }
 
     /**
