@@ -47,9 +47,12 @@ class Tinebase_Tree_Node extends Tinebase_Backend_Sql_Abstract
     protected $_revision = null;
 
     protected $_beforeCreateHook = [];
+    protected $_afterCreateHook = [];
     protected $_beforeUpdateHook = [];
     protected $_afterUpdateHook = [];
 
+    protected $_doSynchronousPreviewCreation = false;
+
     /**
      * NOTE: returns fake tree controller
      *       needed by Tinebase_Core::getApplicationInstance('Tinebase_Model_Tree_Node')
@@ -95,6 +98,11 @@ class Tinebase_Tree_Node extends Tinebase_Backend_Sql_Abstract
         $this->_beforeCreateHook[$key] = $hook;
     }
 
+    public function registerAfterCreateHook($key, $hook)
+    {
+        $this->_afterCreateHook[$key] = $hook;
+    }
+
     public function registerBeforeUpdateHook($key, $hook)
     {
         $this->_beforeUpdateHook[$key] = $hook;
@@ -105,6 +113,15 @@ class Tinebase_Tree_Node extends Tinebase_Backend_Sql_Abstract
         $this->_afterUpdateHook[$key] = $hook;
     }
 
+    public function doSynchronousPreviewCreation(?bool $synchronously = null): bool
+    {
+        $result = $this->_doSynchronousPreviewCreation;
+        if (null !== $synchronously) {
+            $this->_doSynchronousPreviewCreation = $synchronously;
+        }
+        return $result;
+    }
+
     /**
      * if set to an integer value, only revisions of that number will be selected
      * if set to null value, regular revision will be selected
@@ -208,7 +225,13 @@ class Tinebase_Tree_Node extends Tinebase_Backend_Sql_Abstract
             call_user_func($hook, $_record);
         }
 
-        return parent::create($_record);
+        $createdRecord = parent::create($_record);
+
+        foreach ($this->_afterCreateHook as $hook) {
+            call_user_func($hook, $createdRecord, $_record);
+        }
+
+        return $createdRecord;
     }
 
     /**
@@ -328,17 +351,37 @@ class Tinebase_Tree_Node extends Tinebase_Backend_Sql_Abstract
      */
     protected function _inspectForPreviewCreation(Tinebase_Model_Tree_Node $_newRecord, Tinebase_Model_Tree_Node $_oldRecord = null)
     {
-        if (! Tinebase_FileSystem::getInstance()->isPreviewActive()
-                || ($_oldRecord !== null && $_oldRecord->hash === $_newRecord->hash) || (int)$_newRecord->revision < 1 ||
-                empty($_newRecord->hash) || Tinebase_Model_Tree_FileObject::TYPE_FILE !== $_newRecord->type) {
+        if (! Tinebase_FileSystem::getInstance()->isPreviewActive()) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Skipping preview creation (preview not active)');
+            return;
+        }
+
+        if (($_oldRecord !== null && $_oldRecord->hash === $_newRecord->hash) || (int)$_newRecord->revision < 1 ||
+                empty($_newRecord->hash)) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Skipping preview creation (no new hash or revision empty)');
+            return;
+        }
+
+        if (Tinebase_Model_Tree_FileObject::TYPE_FILE !== $_newRecord->type) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Skipping preview creation (node is no TYPE_FILE)');
             return;
         }
 
         if (false === Tinebase_FileSystem_Previews::getInstance()->canNodeHavePreviews($_newRecord)) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Skipping preview creation (canNodeHavePreviews === false)');
             return;
         }
 
-        Tinebase_ActionQueueLongRun::getInstance()->queueAction('Tinebase_FOO_FileSystem_Previews.createPreviews', $_newRecord->getId(), $_newRecord->revision);
+        if ($this->_doSynchronousPreviewCreation) {
+            Tinebase_FileSystem_Previews::getInstance()->createPreviewsFromNode($_newRecord);
+        } else {
+            Tinebase_ActionQueue::getInstance(Tinebase_ActionQueue::QUEUE_LONG_RUN)->queueAction(
+                'Tinebase_FOO_FileSystem_Previews.createPreviews', $_newRecord->getId(), $_newRecord->revision);
+        }
     }
 
     /**
