@@ -17,8 +17,10 @@
  *
  * @package     Tinebase
  * @subpackage  User
+ *
+ * @method modlogActive($setTo = null)
+ * @method updatePluginUser($updatedUser, $newUserProperties, $skipEmailPlugins = false)
  */
- 
 abstract class Tinebase_User_Abstract implements Tinebase_User_Interface
 {
     /**
@@ -371,15 +373,20 @@ abstract class Tinebase_User_Abstract implements Tinebase_User_Interface
      */
     public function generateUserName($_account, $_schema = 1)
     {
-        if (! empty($_account->accountFirstName) && $_schema > 0 && method_exists($this, '_generateUserWithSchema' . $_schema)) {
-            $userName = call_user_func_array(array($this, '_generateUserWithSchema' . $_schema), array($_account));
+        if (Tinebase_Config::getInstance()->{Tinebase_Config::ACCOUNT_TWIG}->{Tinebase_Config::ACCOUNT_TWIG_LOGIN}) {
+            $userName = $_account->applyAccountTwig('accountLoginName', Tinebase_Config::getInstance()
+                ->{Tinebase_Config::ACCOUNT_TWIG}->{Tinebase_Config::ACCOUNT_TWIG_LOGIN});
         } else {
-            $userName = strtolower(substr(Tinebase_Helper::replaceSpecialChars($_account->accountLastName), 0, 10));
-        }
+            if (!empty($_account->accountFirstName) && $_schema > 0 && method_exists($this, '_generateUserWithSchema' . $_schema)) {
+                $userName = call_user_func_array(array($this, '_generateUserWithSchema' . $_schema), array($_account));
+            } else {
+                $userName = strtolower(substr(Tinebase_Helper::replaceSpecialChars($_account->accountLastName), 0, 10));
+            }
 
-        if (empty($userName)) {
-            // try email address
-            $userName = strtolower(substr(Tinebase_Helper::replaceSpecialChars($_account->accountEmailAddress), 0, 19));
+            if (empty($userName)) {
+                // try email address
+                $userName = strtolower(substr(Tinebase_Helper::replaceSpecialChars($_account->accountEmailAddress), 0, 19));
+            }
         }
         
         $userName = $this->_addSuffixToNameIfExists('accountLoginName', $userName);
@@ -609,6 +616,18 @@ abstract class Tinebase_User_Abstract implements Tinebase_User_Interface
         return count($ids);
     }
 
+    public function search(Tinebase_Model_FullUserFilter $filter)
+    {
+        $backend = new Tinebase_Backend_Sql(array(
+            'modelName' => Tinebase_Model_FullUser::class,
+            'tableName' => 'accounts',
+            'modlogActive' => true,
+        ));
+
+        return $this->getMultiple($backend->search($filter, null, Tinebase_Backend_Sql_Abstract::IDCOL),
+            Tinebase_Model_FullUser::class);
+    }
+
     /**
      * returns active users
      *
@@ -674,31 +693,6 @@ abstract class Tinebase_User_Abstract implements Tinebase_User_Interface
         }
     }
 
-    /**
-     * set PIN
-     *
-     * @param  string  $_userId
-     * @param  string  $_pin (only numbers are allowed)
-     * @return array
-     * @throws Tinebase_Exception_SystemGeneric
-     *
-     * TODO move to Tinebase_User_sql and replace with abstract fn here
-     * TODO replicate PIN?
-     */
-    public function setPin($_userId, $_pin)
-    {
-        if (preg_match('/[^0-9]+/', (string) $_pin)) {
-            throw new Tinebase_Exception_SystemGeneric('Only numbers are allowed for PINs'); // _('Only numbers are allowed for PINs')
-        }
-
-        if (strlen((string) $_pin) < Tinebase_Config::getInstance()->get(Tinebase_Config::USER_PIN_MIN_LENGTH)) {
-            throw new Tinebase_Exception_SystemGeneric('PIN too short'); // _('PIN too short')
-        }
-
-        $userId = $_userId instanceof Tinebase_Model_User ? $_userId->getId() : $_userId;
-        return $this->_updatePasswordProperty($userId, $_pin, 'pin');
-    }
-
     /******************* abstract functions *********************/
     
     /**
@@ -772,7 +766,14 @@ abstract class Tinebase_User_Abstract implements Tinebase_User_Interface
      * @param array $_accountIds
      */
     abstract public function deleteUsers(array $_accountIds);
-    
+
+    /**
+     * returns true if user backend does hard delete
+     *
+     * @return boolean
+     */
+    abstract public function isHardDeleteEnabled();
+
     /**
      * Get multiple users
      *
@@ -782,8 +783,92 @@ abstract class Tinebase_User_Abstract implements Tinebase_User_Interface
      */
     abstract public function getMultiple($_id, $_accountClass = 'Tinebase_Model_User');
 
+    /**
+     * @return string
+     */
     public function getModel()
     {
-        return Tinebase_Model_FullUser::class;
+        return Tinebase_Model_User::class;
     }
+
+    /**
+     * send welcome / password update mail to a user
+     *
+     * @param Tinebase_Model_FullUser $user
+     * @param string $newPw
+     * @param string|null $email
+     * @throws Tinebase_Exception_InvalidArgument
+     * @throws Tinebase_Exception_NotFound
+     * @throws Tinebase_Exception_Record_DefinitionFailure
+     * @throws Tinebase_Exception_Record_Validation
+     * @throws Zend_Mail_Protocol_Exception
+     */
+    public function sendPasswordChangeMail(Tinebase_Model_FullUser $user, $newPw, $email = null)
+    {
+        $recipient = Addressbook_Controller_Contact::getInstance()->getContactByUserId($user);
+        if ($email) {
+            $recipient->email = $email;
+        }
+
+        // @todo translate / add to config
+        $subject = 'Neues Tine 2.0 / E-Mail Passwort';
+        // TODO add only if configured
+        $emailSettings = "\r\nZugangsdaten für den Zugriff auf das Mailkonto über einen anderen E-Mail-Client:\r\n"
+            . "IMAP: Host: {{ imap.host }} Port: {{ imap.port }}\r\n"
+            . "SMTP: Host: {{ smtp.hostname }} Port: {{ smtp.port }}\r\n"
+            . "Benutzername: Ihre E-Mail Adresse ({{ email }})\r\n";
+        $message = "Guten Tag!\r\n\r\nIhr neues Tine 2.0 / E-Mail-Passwort lautet: {{ password|raw }}\r\n" .
+            "Bitte ändern Sie es gleich nach dem ersten Login.\r\n" .
+            "\r\nTine 2.0 URL: {{ tine20url }} (Benutzername: {{ username }})\r\n" .
+            $emailSettings .
+            "\r\nEinen schönen Tag wünscht: Ihr Metaways Team\r\n";
+
+        $tbConfig = Tinebase_Config::getInstance();
+        $twig = new Twig_Environment(new Twig_Loader_Array());
+
+        $message = $twig->createTemplate($message)->render([
+            'tine20url' => $tbConfig->get(Tinebase_Config::TINE20_URL),
+            'smtp' => $tbConfig->get(Tinebase_Config::SMTP)->toArray(),
+            'imap' => $tbConfig->get(Tinebase_Config::IMAP)->toArray(),
+            'password' => $newPw,
+            'email' => $user->accountEmailAddress,
+            'username' => $user->accountLoginName,
+        ]);
+
+        $smtp = Tinebase_Notification_Factory::getBackend(Tinebase_Notification_Factory::SMTP);
+        $smtp->send(
+            Tinebase_Core::getUser(),
+            $recipient,
+            $subject,
+            $message
+        );
+    }
+
+    /**
+     * fire user delete event (possible async from the action queue)
+     *
+     * @param  string $_userId the user(id) to delete
+     */
+    public function fireDeleteUserEvent(string $_userId)
+    {
+        $user = $this->getFullUserById($_userId);
+
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+            . ' Firing delete user event for: ' . $user->accountLoginName);
+
+        $raii = Tinebase_RAII::getTransactionManagerRAII();
+
+        $event = new Tinebase_Event_User_DeleteAccount(
+            Tinebase_Config::getInstance()->get(Tinebase_Config::ACCOUNT_DELETION_EVENTCONFIGURATION, new Tinebase_Config_Struct())->toArray()
+        );
+        $event->account = $user;
+        Tinebase_Event::fireEvent($event);
+
+        $raii->release();
+    }
+
+    abstract public function getUsersCount($_filter = null);
+
+    abstract public function addUserInSqlBackend(Tinebase_Model_FullUser $_user);
+    abstract public function updateUserInSqlBackend(Tinebase_Model_FullUser $_user);
 }
