@@ -1,11 +1,12 @@
 <?php
+
 /**
  * Tine 2.0
  * 
  * @package     Tinebase
  * @subpackage  User
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
- * @copyright   Copyright (c) 2007-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2007-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  * @author      Lars Kneschke <l.kneschke@metaways.de>
  * 
  * @todo        extend Tinebase_Application_Backend_Sql and replace some functions
@@ -28,7 +29,7 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
      *
      * @todo perhaps we can remove that and build model name from name of the class (replace 'Controller' with 'Model')
      */
-    protected $_modelName = 'Tinebase_Model_FullUser';
+    protected $_modelName = 'Tinebase_Model_User';
 
     /**
      * row name mapping 
@@ -67,7 +68,19 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
      * @var Zend_Db_Adapter_Abstract
      */
     protected $_db;
-    
+
+    /**
+     * hard delete users from db
+     *
+     * @var bool
+     *
+     * NOTE: hard delete is current default as groups and roles don't support soft delete, yet but have fk constraints
+     *  (for example primary user group) that make problems if only users are soft-deleted...
+     *
+     * TODO make it configurable or obsolete (soft-delete should be default or only option)
+     */
+    protected $_hardDeleteUser = true;
+
     /**
      * sql user plugins
      * 
@@ -90,7 +103,7 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
     /**
      * the constructor
      *
-     * @param  array $options Options used in connecting, binding, etc.
+     * @param array $_options Options used in connecting, binding, etc.
      */
     public function __construct(array $_options = array())
     {
@@ -137,7 +150,7 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
     }
 
     /**
-     * @param $classname
+     * @param string $classname
      * @return Tinebase_User_Plugin_SqlInterface
      */
     public function getSqlPlugin($classname)
@@ -184,21 +197,24 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
         
         if (!empty($_filter)) {
             $whereStatement = array();
-            $defaultValues  = array(
+            $defaultValues = array(
                 $this->rowNameMapping['accountLastName'], 
                 $this->rowNameMapping['accountFirstName'], 
-                $this->rowNameMapping['accountLoginName']
+                $this->rowNameMapping['accountLoginName'],
+                $this->rowNameMapping['accountEmailAddress'],
             );
 
             // prepare for case insensitive search
             foreach ($defaultValues as $defaultValue) {
-                $whereStatement[] = $this->_dbCommand->prepareForILike($this->_db->quoteIdentifier($defaultValue)) . ' LIKE ' . $this->_dbCommand->prepareForILike('?');
+                $whereStatement[] = $this->_dbCommand->prepareForILike(
+                        $this->_db->quoteIdentifier($this->_db->table_prefix . $this->_tableName . '.' . $defaultValue)
+                    ) . ' LIKE ' . $this->_dbCommand->prepareForILike('?');
             }
             
             $select->where('(' . implode(' OR ', $whereStatement) . ')', '%' . $_filter . '%');
         }
         
-        // @todo still needed?? either we use contacts from addressboook or full users now
+        // @todo still needed?? either we use contacts from addressbook or full users now
         // return only active users, when searching for simple users
         if ($_accountClass == 'Tinebase_Model_User') {
             $select->where($this->_db->quoteInto($this->_db->quoteIdentifier('status') . ' = ?', 'enabled'));
@@ -208,9 +224,11 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
 
         $stmt = $select->query();
         $rows = $stmt->fetchAll(Zend_Db::FETCH_ASSOC);
+        $stmt->closeCursor();
         
         $result = new Tinebase_Record_RecordSet($_accountClass, $rows, TRUE);
-        
+        $result->runConvertToRecord();
+
         return $result;
     }
     
@@ -341,17 +359,21 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
         $stmt = $select->query();
 
         $row = $stmt->fetch(Zend_Db::FETCH_ASSOC);
+        $stmt->closeCursor();
         if ($row === false) {
             throw new Tinebase_Exception_NotFound('User with ' . $_property . ' = ' . $value . ' not found.');
         }
 
         if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__ . ' ' . print_r($row, true));
 
+        $account = null;
         try {
+            /** @var Tinebase_Model_User $account */
             $account = new $_accountClass(NULL, TRUE);
-            $account->setFromArray($row);
+            $account->hydrateFromBackend($row);
+            $account->runConvertToRecord();
         } catch (Tinebase_Exception_Record_Validation $e) {
-            $validation_errors = $account->getValidationErrors();
+            $validation_errors = $account ? $account->getValidationErrors() : [];
             Tinebase_Core::getLogger()->err(__METHOD__ . '::' . __LINE__ . ' ' . $e->getMessage() . "\n" .
                 "Tinebase_Model_User::validation_errors: \n" .
                 print_r($validation_errors,true));
@@ -373,7 +395,14 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
             ->where($this->_db->quoteInto($this->_db->quoteIdentifier(SQL_TABLE_PREFIX . 'accounts.primary_group_id') . ' = ?', $groupId));
         $stmt = $select->query();
         $data = (array) $stmt->fetchAll(Zend_Db::FETCH_ASSOC);
-        $result = new Tinebase_Record_RecordSet('Tinebase_Model_FullUser', $data, true);
+        $stmt->closeCursor();
+        $result = new Tinebase_Record_RecordSet('Tinebase_Model_FullUser');
+        foreach ($data as $row) {
+            $user = new Tinebase_Model_FullUser([], true);
+            $user->hydrateFromBackend($row);
+            $result->addRecord($user);
+        }
+        $result->runConvertToRecord();
         return $result;
     }
     
@@ -433,6 +462,7 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
             'contact_id',
             'openid',
             'visibility',
+            'mfa_configs',
             'NOW()', // only needed for debugging
         );
 
@@ -474,6 +504,10 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
                 )
             );
 
+        if (!$this->isHardDeleteEnabled()) {
+            $select->where($this->_db->quoteIdentifier(SQL_TABLE_PREFIX . 'accounts.is_deleted') . ' = 0');
+        }
+
         return $select;
     }
 
@@ -490,7 +524,7 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
     {
         $userId = $_userId instanceof Tinebase_Model_User ? $_userId->getId() : $_userId;
         $user = $_userId instanceof Tinebase_Model_FullUser ? $_userId : $this->getFullUserById($userId);
-        $this->checkPasswordPolicy($_password, $user);
+        Tinebase_User_PasswordPolicy::checkPasswordPolicy($_password, $user);
 
         $accountData = $this->_updatePasswordProperty($userId, $_password, 'password', $_encrypt, $_mustChange);
         $this->_setPluginsPassword($user, $_password, $_encrypt);
@@ -502,8 +536,8 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
     }
 
     /**
-     * @param        $_userId
-     * @param        $_password
+     * @param string $_userId
+     * @param string $_password
      * @param string $_property
      * @param boolean $_encrypt
      * @param boolean|null $_mustChange user needs to change pw next time
@@ -593,119 +627,6 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
             : $user->getId();
     }
 
-    /**
-     * ensure password policy
-     * 
-     * @param string $password
-     * @param Tinebase_Model_FullUser $user
-     * @throws Tinebase_Exception_PasswordPolicyViolation
-     */
-    public function checkPasswordPolicy($password, Tinebase_Model_FullUser $user)
-    {
-        if (! Tinebase_Config::getInstance()->get(Tinebase_Config::USER_PASSWORD_POLICY)->{Tinebase_Config::PASSWORD_POLICY_ACTIVE}) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ 
-                . ' No password policy enabled');
-            return;
-        }
-        
-        $policy = array(
-            Tinebase_Config::PASSWORD_POLICY_ONLYASCII              => '/[^\x00-\x7F]/',
-            Tinebase_Config::PASSWORD_POLICY_MIN_LENGTH             => null,
-            Tinebase_Config::PASSWORD_POLICY_MIN_WORD_CHARS         => '/[\W]*/',
-            Tinebase_Config::PASSWORD_POLICY_MIN_UPPERCASE_CHARS    => '/[^A-Z]*/',
-            Tinebase_Config::PASSWORD_POLICY_MIN_SPECIAL_CHARS      => '/[\w]*/',
-            Tinebase_Config::PASSWORD_POLICY_MIN_NUMBERS            => '/[^0-9]*/',
-            Tinebase_Config::PASSWORD_POLICY_FORBID_USERNAME        => $user->accountLoginName,
-        );
-
-        $failedTests = array();
-        foreach ($policy as $key => $regex) {
-            $result = $this->_testPolicy($password, $key, $regex);
-            if ($result !== true) {
-                $failedTests[$key] = $result;
-            }
-        }
-        
-        if (! empty($failedTests)) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
-                . ' ' . print_r($failedTests, true));
-
-            $translation = Tinebase_Translation::getTranslation();
-            $msg = $translation->_('Password failed to match the following policy requirements: ');
-            foreach($failedTests as $key => $result) {
-                $msg .= "\n- " . $result;
-            }
-
-            throw new Tinebase_Exception_PasswordPolicyViolation($msg);
-        }
-    }
-    
-    /**
-     * test password policy
-     * 
-     * @param string $password
-     * @param string $configKey
-     * @param string $regex
-     * @return mixed
-     */
-    protected function _testPolicy($password, $configKey, $regex = null)
-    {
-        $result = true;
-
-        $configValue = Tinebase_Config::getInstance()->get(Tinebase_Config::USER_PASSWORD_POLICY)->{$configKey};
-
-        $translation = Tinebase_Translation::getTranslation();
-        $configDefinition = Tinebase_Config::getInstance()->getDefinition(Tinebase_Config::USER_PASSWORD_POLICY);
-        $description = $translation->translate($configDefinition['content'][$configKey]['description']);
-        $description = preg_replace("/\.$/", "", $description);
-
-        switch ($configKey) {
-            case Tinebase_Config::PASSWORD_POLICY_ONLYASCII:
-                if ($configValue && $regex !== null) {
-                    $nonAsciiFound = preg_match($regex, $password, $matches);
-                    
-                    if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
-                        __METHOD__ . '::' . __LINE__ . ' ' . print_r($matches, true));
-                    
-                    $result = ($nonAsciiFound) ? $description : true;
-                }
-                
-                break;
-                
-            case Tinebase_Config::PASSWORD_POLICY_FORBID_USERNAME:
-                if ($configValue) {
-                    if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
-                        __METHOD__ . '::' . __LINE__ . ' Testing if password is part of username "' . $regex . '"');
-                    
-                    if (! empty($password)) {
-                        $result = preg_match('/' . preg_quote($password, '/') . '/i', $regex) ?
-                            $description :
-                            true;
-                    }
-                }
-                
-                break;
-                
-            default:
-                // check min length restriction
-                $minLength = $configValue;
-                if ($minLength > 0) {
-                    $reduced = ($regex) ? preg_replace($regex, '', $password) : $password;
-                    $charCount = strlen(utf8_decode($reduced));
-                    if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
-                        . ' Found ' . $charCount . '/' . $minLength . ' chars for ' . $configKey /*. ': ' . $reduced */);
-                    
-                    if ($charCount < $minLength) {
-                        $result = $description . ': ' . $minLength;
-                    }
-                }
-                
-                break;
-        }
-        
-        return $result;
-    }
-    
     /**
      * set the status of the user
      *
@@ -753,7 +674,7 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
             $this->_db->quoteInto($this->_db->quoteIdentifier('id') . ' = ?', $accountId)
         );
 
-        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->INFO(__METHOD__ . ' ' . __LINE__
+        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . ' ' . __LINE__
             . ' ' . $_status . ' user with id ' . $accountId);
 
         $result = $accountsTable->update($accountData, $where);
@@ -859,7 +780,8 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
     /**
      * update contact data(first name, last name, ...) of user
      * 
-     * @param Addressbook_Model_Contact $contact
+     * @param Addressbook_Model_Contact $_contact
+     * @return integer
      */
     public function updateContact(Addressbook_Model_Contact $_contact)
     {
@@ -965,10 +887,10 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
     }
 
     /**
-     * @param $plugin
-     * @param $user
-     * @param $newUserProperties
-     * @param $method
+     * @param mixed $plugin
+     * @param mixed $user
+     * @param mixed $newUserProperties
+     * @param string $method (add|update|inspectGetUserByProperty|delete)
      *
      * TODO support different imap/smtp xprops
      */
@@ -978,39 +900,12 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
             $method = 'inspect' . ucfirst($method) . 'User';
         }
 
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+            . ' Calling CRUD method ' . $method . ' in plugin ' . (is_object($plugin) ? get_class($plugin) : $plugin));
+
         // add email user xprops here if configured
         if (Tinebase_EmailUser::isEmailUserPlugin($plugin) && Tinebase_Config::getInstance()->{Tinebase_Config::EMAIL_USER_ID_IN_XPROPS}) {
-            if ($method === 'inspectAddUser' && empty($user->accountEmailAddress)) {
-                // do not add plugin user if user has no email adress
-                return;
-            }
-
-            $pluginUser = clone($user);
-            Tinebase_EmailUser_XpropsFacade::setIdFromXprops($user, $pluginUser, $method !== 'inspectGetUserByProperty');
-            if ($newUserProperties) {
-                $updatePluginUser = clone($newUserProperties);
-                Tinebase_EmailUser_XpropsFacade::setIdFromXprops($user, $updatePluginUser);
-                $params = [$pluginUser, $updatePluginUser];
-            } else {
-                $params = [$pluginUser];
-                $updatePluginUser = null;
-            }
-            call_user_func_array([$plugin, $method], $params);
-
-            // return email user properties to $user
-            // TODO do this always?
-            if ($method === 'inspectGetUserByProperty' || $method === 'inspectUpdateUser') {
-                foreach (['smtpUser', 'emailUser', 'imapUser'] as $prop) {
-                    if ($pluginUser->{$prop}) {
-                        $user->{$prop} = $pluginUser->{$prop};
-                    }
-                }
-            }
-
-            // save new/missing xprops in user
-            if ($updatePluginUser) {
-                Tinebase_EmailUser_XpropsFacade::setXprops($user, $updatePluginUser->getId());
-            }
+            $this->_inspectEmailPluginCRUD($plugin, $user, $newUserProperties, $method);
         } else {
             if ($newUserProperties) {
                 $params = [$user, $newUserProperties];
@@ -1020,7 +915,85 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
             call_user_func_array([$plugin, $method], $params);
         }
     }
-    
+
+    /**
+     * @param mixed $plugin
+     * @param mixed $user
+     * @param mixed $newUserProperties
+     * @param string $method (inspectAddUser|inspectUpdateUser|inspectGetUserByProperty|inspectDeleteUser)
+     */
+    protected function _inspectEmailPluginCRUD($plugin, $user, $newUserProperties, $method)
+    {
+        if ($method === 'inspectAddUser' && empty($user->accountEmailAddress)) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+                __METHOD__ . '::' . __LINE__ . ' Do not add plugin user as user has no email address');
+            return;
+        }
+
+        $xprop = strpos(get_class($plugin), 'Imap') !== false
+            ? Tinebase_EmailUser_XpropsFacade::XPROP_EMAIL_USERID_IMAP
+            : Tinebase_EmailUser_XpropsFacade::XPROP_EMAIL_USERID_SMTP;
+
+        if ($method === 'inspectUpdateUser' && empty($user->accountEmailAddress)
+            && isset($user->xprops()[$xprop]) && $user->xprops()[$xprop]
+        ) {
+            if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(
+                __METHOD__ . '::' . __LINE__ . ' Remove plugin user as email address has been removed');
+            $this->_inspectEmailPluginCRUD($plugin, $user, $newUserProperties, 'inspectDeleteUser');
+            return;
+        }
+
+        $pluginUser = clone($user);
+        Tinebase_EmailUser_XpropsFacade::setIdFromXprops($user, $pluginUser, $method !== 'inspectGetUserByProperty', $xprop);
+        if ($newUserProperties) {
+            $updatePluginUser = clone($newUserProperties);
+            Tinebase_EmailUser_XpropsFacade::setIdFromXprops($user, $updatePluginUser);
+            $params = [$pluginUser, $updatePluginUser];
+        } else {
+            $params = [$pluginUser];
+            $updatePluginUser = null;
+        }
+        call_user_func_array([$plugin, $method], $params);
+
+        // return email user properties to $user
+        // TODO do this always?
+        // TODO remove on inspectDeleteUser?
+        if ($method === 'inspectGetUserByProperty' || $method === 'inspectUpdateUser') {
+            foreach (['smtpUser', 'emailUser', 'imapUser'] as $prop) {
+                if ($pluginUser->{$prop}) {
+                    $user->{$prop} = $pluginUser->{$prop};
+                }
+            }
+        }
+
+        if ($updatePluginUser) {
+            if ($method === 'inspectDeleteUser') {
+                $user->xprops()[$xprop] = null;
+            } else {
+                $user->xprops()[$xprop] = $updatePluginUser->getId();
+            }
+        }
+    }
+
+    protected function treatMFA(Tinebase_Model_FullUser $_user, Tinebase_Model_FullUser $oldUser = null)
+    {
+        if ($_user->mfa_configs) {
+            if (!$_user->mfa_configs->isValid()) {
+                throw new Tinebase_Exception_Backend('mfa configs are not valid: ' .
+                    print_r($_user->mfa_configs->getValidationErrors(), true));
+            }
+            if ($oldUser && $oldUser->mfa_configs) {
+                /** @var Tinebase_Model_MFA_UserConfig $userCfg */
+                foreach ($oldUser->mfa_configs as $userCfg) {
+                    $userCfg->updateUserOldRecordCallback($_user, $oldUser);
+                }
+            }
+            foreach ($_user->mfa_configs as $userCfg) {
+                $userCfg->updateUserNewRecordCallback($_user, $oldUser);
+            }
+        }
+    }
+
     /**
      * updates an user
      * 
@@ -1028,7 +1001,6 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
      *
      * @param Tinebase_Model_FullUser $_user
      * @return Tinebase_Model_FullUser
-     * @throws 
      */
     public function updateUserInSqlBackend(Tinebase_Model_FullUser $_user)
     {
@@ -1046,6 +1018,7 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
             $_user->visibility = 'hidden';
             $_user->contact_id = null;
         }
+        $this->treatMFA($_user, $oldUser);
         $accountData = $this->_recordToRawData($_user);
         // don't update id
         unset($accountData['id']);
@@ -1065,7 +1038,8 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
             $accountData[$this->rowNameMapping['accountStatus']] = $_user->accountStatus;
         }
         
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__ . ' ' . print_r($accountData, true));
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+            __METHOD__ . '::' . __LINE__ . ' ' . print_r($accountData, true));
 
         try {
             $accountsTable = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'accounts'));
@@ -1097,6 +1071,8 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
     {
         $visibility = $_user->visibility;
 
+        $_user->applyTwigTemplates();
+
         if ($this instanceof Tinebase_User_Interface_SyncAble) {
             $userFromSyncBackend = $this->addUserToSyncBackend($_user);
             if ($userFromSyncBackend !== NULL) {
@@ -1162,6 +1138,7 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
             $_user->visibility = Tinebase_Model_FullUser::VISIBILITY_HIDDEN;
             $_user->contact_id = null;
         }
+        $this->treatMFA($_user);
         
         $accountData = $this->_recordToRawData($_user);
         // persist status for new users!
@@ -1190,10 +1167,12 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
      */
     protected function _recordToRawData(Tinebase_Record_Interface $_user)
     {
+        $_user->runConvertToData();
+
         $accountData = array(
             'id'                => $_user->accountId,
             'login_name'        => $_user->accountLoginName,
-            'expires_at'        => ($_user->accountExpires instanceof DateTime ? $_user->accountExpires->get(Tinebase_Record_Abstract::ISO8601LONG) : NULL),
+            'expires_at'        => ($_user->accountExpires instanceof Tinebase_DateTime ? $_user->accountExpires->get(Tinebase_Record_Abstract::ISO8601LONG) : NULL),
             'primary_group_id'  => $_user->accountPrimaryGroup,
             'home_dir'          => $_user->accountHomeDirectory,
             'login_shell'       => $_user->accountLoginShell,
@@ -1210,11 +1189,12 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
             'creation_time'         => $_user->creation_time,
             'last_modified_by'      => $_user->last_modified_by,
             'last_modified_time'    => $_user->last_modified_time,
-            'is_deleted'            => $_user->is_deleted ? $_user->is_deleted : 0,
+            'is_deleted'            => $_user->is_deleted ?: 0,
             'deleted_time'          => $_user->deleted_time,
             'deleted_by'            => $_user->deleted_by,
             'seq'                   => $_user->seq,
             'xprops'                => $_user->xprops,
+            'mfa_configs'     => $_user->mfa_configs,
         );
         
         $unsetIfEmpty = array('seq', 'creation_time', 'created_by', 'last_modified_by', 'last_modified_time');
@@ -1226,10 +1206,10 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
 
         if (!$this->_userHasXpropsField()) {
             unset($accountData['xprops']);
-        } elseif (isset($accountData['xprops']) && is_array($accountData['xprops'])) {
-            $accountData['xprops'] = json_encode($accountData['xprops']);
         }
-        
+
+        $_user->runConvertToRecord();
+
         return $accountData;
     }
     
@@ -1242,7 +1222,7 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
     {
         $deletedUser = $this->deleteUserInSqlBackend($_userId);
         
-        if($this instanceof Tinebase_User_Interface_SyncAble) {
+        if ($this instanceof Tinebase_User_Interface_SyncAble) {
             $this->deleteUserInSyncBackend($deletedUser);
         }
         
@@ -1250,64 +1230,6 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
         foreach ($this->_sqlPlugins as $plugin) {
             $this->_inspectCRUD($plugin, $deletedUser, null, 'delete');
         }
-        
-    }
-
-    /**
-     * hard delete a user from DB, fire Tinebase_Event_User_DeleteAccount event
-     *
-     * @param  string|Tinebase_Model_FullUser $_userId the user(id) to delete
-     * @return Tinebase_Model_FullUser the deleted user
-     * @throws Exception
-     */
-    public function directDeleteUserInSqlBackend($_userId)
-    {
-        if ($_userId instanceof Tinebase_Model_FullUser) {
-            $user = $_userId;
-        } else {
-            $user = $this->getFullUserById($_userId);
-        }
-
-        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
-            . ' Deleting user ' . $user->accountLoginName);
-
-        $transactionId = Tinebase_TransactionManager::getInstance()->startTransaction($this->_db);
-
-        try {
-            $event = new Tinebase_Event_User_DeleteAccount(
-                Tinebase_Config::getInstance()->get(Tinebase_Config::ACCOUNT_DELETION_EVENTCONFIGURATION, new Tinebase_Config_Struct())->toArray()
-            );
-            $event->account = $user;
-            Tinebase_Event::fireEvent($event);
-
-            $accountsTable          = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'accounts'));
-            $groupMembersTable      = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'group_members'));
-            $roleMembersTable       = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'role_accounts'));
-
-            $where  = array(
-                $this->_db->quoteInto($this->_db->quoteIdentifier('account_id') . ' = ?', $user->getId()),
-            );
-            $groupMembersTable->delete($where);
-
-            $where  = array(
-                $this->_db->quoteInto($this->_db->quoteIdentifier('account_id')   . ' = ?', $user->getId()),
-                $this->_db->quoteInto($this->_db->quoteIdentifier('account_type') . ' = ?', Tinebase_Acl_Rights::ACCOUNT_TYPE_USER),
-            );
-            $roleMembersTable->delete($where);
-
-            $where  = array(
-                $this->_db->quoteInto($this->_db->quoteIdentifier('id') . ' = ?', $user->getId()),
-            );
-            $accountsTable->delete($where);
-
-            Tinebase_TransactionManager::getInstance()->commitTransaction($transactionId);
-        } catch (Exception $e) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . ' error while deleting account ' . $e->__toString());
-            Tinebase_TransactionManager::getInstance()->rollBack();
-            throw($e);
-        }
-
-        return $user;
     }
 
     /**
@@ -1330,32 +1252,13 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
         $transactionId = Tinebase_TransactionManager::getInstance()->startTransaction($this->_db);
 
         try {
-
-            $accountsTable          = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'accounts'));
-            $groupMembersTable      = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'group_members'));
-            $roleMembersTable       = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'role_accounts'));
-
-            $where  = array(
-                $this->_db->quoteInto($this->_db->quoteIdentifier('account_id') . ' = ?', $user->getId()),
-            );
-            $groupMembersTable->delete($where);
-
-            $where  = array(
-                $this->_db->quoteInto($this->_db->quoteIdentifier('account_id')   . ' = ?', $user->getId()),
-                $this->_db->quoteInto($this->_db->quoteIdentifier('account_type') . ' = ?', Tinebase_Acl_Rights::ACCOUNT_TYPE_USER),
-            );
-            $roleMembersTable->delete($where);
-
-            $where  = array(
-                $this->_db->quoteInto($this->_db->quoteIdentifier('id') . ' = ?', $user->getId()),
-            );
-            $accountsTable->update(array(   'is_deleted' => 1,
-                                            'status' => Tinebase_Model_User::ACCOUNT_STATUS_DISABLED,
-                                            'visibility' => Tinebase_Model_User::VISIBILITY_HIDDEN), $where);
-
-            Tinebase_ActionQueue::getInstance()->queueAction('Tinebase_FOO_User.directDeleteUserInSqlBackend', $user->getId());
-
-            $this->_writeModLog(null, $user);
+            if ($this->isHardDeleteEnabled()) {
+                Tinebase_User::getInstance()->fireDeleteUserEvent($user->getId());
+                $this->_hardDelete($user);
+            } else {
+                $this->_softDelete($user);
+                Tinebase_ActionQueue::getInstance()->queueAction('Tinebase_FOO_User.fireDeleteUserEvent', $user->getId());
+            }
 
             Tinebase_TransactionManager::getInstance()->commitTransaction($transactionId);
         } catch (Exception $e) {
@@ -1367,6 +1270,43 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
         return $user;
     }
 
+    protected function _hardDelete($user)
+    {
+        $accountsTable          = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'accounts'));
+        $groupMembersTable      = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'group_members'));
+        $roleMembersTable       = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'role_accounts'));
+
+        $where  = array(
+            $this->_db->quoteInto($this->_db->quoteIdentifier('account_id') . ' = ?', $user->getId()),
+        );
+        $groupMembersTable->delete($where);
+
+        $where  = array(
+            $this->_db->quoteInto($this->_db->quoteIdentifier('account_id')   . ' = ?', $user->getId()),
+            $this->_db->quoteInto($this->_db->quoteIdentifier('account_type') . ' = ?', Tinebase_Acl_Rights::ACCOUNT_TYPE_USER),
+        );
+        $roleMembersTable->delete($where);
+
+        $where  = array(
+            $this->_db->quoteInto($this->_db->quoteIdentifier('id') . ' = ?', $user->getId()),
+        );
+        $accountsTable->delete($where);
+    }
+
+    protected function _softDelete($user)
+    {
+        $accountsTable = new Tinebase_Db_Table(array('name' => SQL_TABLE_PREFIX . 'accounts'));
+        $where = array(
+            $this->_db->quoteInto($this->_db->quoteIdentifier('id') . ' = ?', $user->getId()),
+        );
+        $accountsTable->update(array('deleted_by' => Tinebase_Core::getUser()->getId(),
+            'deleted_time' => Tinebase_DateTime::now()->toString(),
+            'is_deleted' => 1,
+            'status' => Tinebase_Model_User::ACCOUNT_STATUS_DISABLED,
+            'visibility' => Tinebase_Model_User::VISIBILITY_HIDDEN), $where);
+        $this->_writeModLog(null, $user);
+    }
+
     /**
      * delete users
      * 
@@ -1407,7 +1347,7 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
      * @param  string  $_accountClass  type of model to return
      * @return Tinebase_Record_RecordSet of 'Tinebase_Model_User' or 'Tinebase_Model_FullUser'
      */
-    public function getMultiple($_id, $_accountClass = 'Tinebase_Model_FullUser') 
+    public function getMultiple($_id, $_accountClass = 'Tinebase_Model_User')
     {
         if (empty($_id)) {
             return new Tinebase_Record_RecordSet($_accountClass);
@@ -1418,9 +1358,11 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
         
         $stmt = $this->_db->query($select);
         $queryResult = $stmt->fetchAll();
+        $stmt->closeCursor();
         
         $result = new Tinebase_Record_RecordSet($_accountClass, $queryResult, TRUE);
-        
+        $result->runConvertToRecord();
+
         return $result;
     }
 
@@ -1655,4 +1597,12 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
         list($userPart, /*$domainPart*/) = explode('@', $user->accountEmailAddress);
         $user->accountEmailAddress = $userPart . '@' . $config['primarydomain'];
     }
+
+    /**
+     * @return bool
+     */
+    public function isHardDeleteEnabled()
+    {
+        return $this->_hardDeleteUser;
+    }
 }
