@@ -5,79 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of ActiveSync **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Persian (Iran) (http://www.transifex.com/tine20/tine20/language/fa_IR/)\nLanguage: fa_IR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "Default Address book"
-: ""
-
-, "The default address book to create new contacts in."
-: ""
-
-, "Default Calendar"
-: ""
-
-, "The default calendar to create new events in."
-: ""
-
-, "Default Task List"
-: ""
-
-, "The default task list to create new tasks in."
-: ""
-
-, "Sync Devices"
-: ""
-
-, "Device ID"
-: ""
-
-, "Devicetype"
-: ""
-
-, "Owner"
-: ""
-
-, "Policy"
-: ""
-
-, "ActiveSync Version"
-: ""
-
-, "User agent"
-: ""
-
-, "Model"
-: ""
-
-, "IMEI"
-: ""
-
-, "Friendly Name"
-: ""
-
-, "OS"
-: ""
-
-, "OS Language"
-: ""
-
-, "Phonenumber"
-: ""
-
-, "Sync Device, Sync Devices"
-: [
-  ""
- ,""
-
-]
-, "Device, Devices"
-: [
-  ""
- ,""
-
-]
-, "Devices"
-: ""
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Persian (Iran) (http://www.transifex.com/tine20/tine20/language/fa_IR/)\nLanguage: fa_IR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Active Sync"
 : ""
@@ -103,15 +31,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Set Sync Filter"
 : ""
 
+, "Sync Devices"
+: ""
+
 , "ID"
 : ""
 
+, "Device ID"
+: ""
+
 , "Device Type"
 : ""
 
+, "Owner"
+: ""
+
+, "Policy"
+: ""
+
+, "ActiveSync Version"
+: ""
+
+, "User agent"
+: ""
+
+, "Model"
+: ""
+
+, "IMEI"
+: ""
+
+, "Friendly Name"
+: ""
+
 , "Operating System"
 : ""
 
+, "OS Language"
+: ""
+
 , "Phone Number"
 : ""
 
@@ -154,10 +112,46 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Quicksearch"
 : ""
 
-, "Default Policy"
+, "Sync Device, Sync Devices"
+: [
+  ""
+ ,""
+
+]
+, "Device, Devices"
+: [
+  ""
+ ,""
+
+]
+, "Devices"
 : ""
 
-, "Default Policy installed during setup"
+, "Devicetype"
+: ""
+
+, "OS"
+: ""
+
+, "Phonenumber"
+: ""
+
+, "Default Address book"
+: ""
+
+, "The default address book to create new contacts in."
+: ""
+
+, "Default Calendar"
+: ""
+
+, "The default calendar to create new events in."
+: ""
+
+, "Default Task List"
+: ""
+
+, "The default task list to create new tasks in."
 : ""
 
 , "Default policy for new devices"
@@ -166,6 +160,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Enter the id of the policy to apply to newly created devices."
 : ""
 
+, "Device Model Agent Deny List"
+: ""
+
+, "Array of regular expressions of Device-Model strings"
+: ""
+
 , "User Agent Deny List"
 : ""
 
@@ -190,6 +190,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "For how long in the past the events should be synchronized."
 : ""
 
+, "%1$s ActiveSync failure"
+: ""
+
+, "Dear user,"
+: ""
+
+, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
+: ""
+
+, "Thank you."
+: ""
+
+, "Your %1$s Team"
+: ""
+
+, "Default Policy"
+: ""
+
+, "Default Policy installed during setup"
+: ""
+
 , "Manage ActiveSync devices"
 : ""
 
