@@ -5,79 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of ActiveSync **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "Default Address book"
-: ""
-
-, "The default address book to create new contacts in."
-: ""
-
-, "Default Calendar"
-: "Agenda par défaut"
-
-, "The default calendar to create new events in."
-: "Calendrier où seront créés par défaut les nouveaux évènements."
-
-, "Default Task List"
-: "Liste des tâches par défaut"
-
-, "The default task list to create new tasks in."
-: "Liste où seront créés par défaut les nouvelles tâches."
-
-, "Sync Devices"
-: ""
-
-, "Device ID"
-: ""
-
-, "Devicetype"
-: ""
-
-, "Owner"
-: ""
-
-, "Policy"
-: ""
-
-, "ActiveSync Version"
-: ""
-
-, "User agent"
-: ""
-
-, "Model"
-: ""
-
-, "IMEI"
-: ""
-
-, "Friendly Name"
-: ""
-
-, "OS"
-: ""
-
-, "OS Language"
-: ""
-
-, "Phonenumber"
-: ""
-
-, "Sync Device, Sync Devices"
-: [
-  ""
- ,""
-
-]
-, "Device, Devices"
-: [
-  "Appareil"
- ,"Appareils"
-
-]
-, "Devices"
-: "Appareils"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Active Sync"
 : "ActiveSync"
@@ -103,15 +31,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Set Sync Filter"
 : "Définir le filtre de synchronisation"
 
+, "Sync Devices"
+: ""
+
 , "ID"
 : ""
 
+, "Device ID"
+: ""
+
 , "Device Type"
 : ""
 
+, "Owner"
+: ""
+
+, "Policy"
+: ""
+
+, "ActiveSync Version"
+: ""
+
+, "User agent"
+: ""
+
+, "Model"
+: ""
+
+, "IMEI"
+: ""
+
+, "Friendly Name"
+: ""
+
 , "Operating System"
 : ""
 
+, "OS Language"
+: ""
+
 , "Phone Number"
 : ""
 
@@ -154,11 +112,47 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Quicksearch"
 : ""
 
-, "Default Policy"
-: "Règle par défaut"
+, "Sync Device, Sync Devices"
+: [
+  ""
+ ,""
 
-, "Default Policy installed during setup"
-: "Politique par défaut configurée durant l'installation"
+]
+, "Device, Devices"
+: [
+  "Appareil"
+ ,"Appareils"
+
+]
+, "Devices"
+: "Appareils"
+
+, "Devicetype"
+: ""
+
+, "OS"
+: ""
+
+, "Phonenumber"
+: ""
+
+, "Default Address book"
+: ""
+
+, "The default address book to create new contacts in."
+: ""
+
+, "Default Calendar"
+: "Agenda par défaut"
+
+, "The default calendar to create new events in."
+: "Calendrier où seront créés par défaut les nouveaux évènements."
+
+, "Default Task List"
+: "Liste des tâches par défaut"
+
+, "The default task list to create new tasks in."
+: "Liste où seront créés par défaut les nouvelles tâches."
 
 , "Default policy for new devices"
 : "Politique par défaut pour les nouveaux appareils"
@@ -166,6 +160,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Enter the id of the policy to apply to newly created devices."
 : "Entrez le numéro de la politique qui s'appliquera aux appareils nouvellement enregistrés"
 
+, "Device Model Agent Deny List"
+: ""
+
+, "Array of regular expressions of Device-Model strings"
+: ""
+
 , "User Agent Deny List"
 : ""
 
@@ -190,6 +190,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "For how long in the past the events should be synchronized."
 : "Période de synchronisation des événements passés"
 
+, "%1$s ActiveSync failure"
+: ""
+
+, "Dear user,"
+: ""
+
+, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
+: ""
+
+, "Thank you."
+: ""
+
+, "Your %1$s Team"
+: ""
+
+, "Default Policy"
+: "Règle par défaut"
+
+, "Default Policy installed during setup"
+: "Politique par défaut configurée durant l'installation"
+
 , "Manage ActiveSync devices"
 : ""
 
