@@ -5,79 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of ActiveSync **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "Default Address book"
-: ""
-
-, "The default address book to create new contacts in."
-: ""
-
-, "Default Calendar"
-: "Standaard agenda"
-
-, "The default calendar to create new events in."
-: "De standaard agenda waar nieuwe gebeurtenissen in komen"
-
-, "Default Task List"
-: "Standaard taaklijst"
-
-, "The default task list to create new tasks in."
-: "De standaard taaklijst waar nieuwe taken in komen"
-
-, "Sync Devices"
-: "Sync Apparaten"
-
-, "Device ID"
-: "Apparaat ID"
-
-, "Devicetype"
-: "Apparaattype"
-
-, "Owner"
-: "Eigenaar"
-
-, "Policy"
-: "Beleid"
-
-, "ActiveSync Version"
-: ""
-
-, "User agent"
-: ""
-
-, "Model"
-: "Model"
-
-, "IMEI"
-: "IMEI"
-
-, "Friendly Name"
-: "Vriendelijke naam"
-
-, "OS"
-: "OS"
-
-, "OS Language"
-: "OS Taal"
-
-, "Phonenumber"
-: "Telefoonnummer"
-
-, "Sync Device, Sync Devices"
-: [
-  ""
- ,""
-
-]
-, "Device, Devices"
-: [
-  "Apparaat"
- ,"Apparaten"
-
-]
-, "Devices"
-: "Apparaten"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Active Sync"
 : "ActiveSync"
@@ -103,15 +31,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Set Sync Filter"
 : "Zet Sync filter"
 
+, "Sync Devices"
+: "Sync Apparaten"
+
 , "ID"
 : "ID"
 
+, "Device ID"
+: "Apparaat ID"
+
 , "Device Type"
 : ""
 
+, "Owner"
+: "Eigenaar"
+
+, "Policy"
+: "Beleid"
+
+, "ActiveSync Version"
+: ""
+
+, "User agent"
+: ""
+
+, "Model"
+: "Model"
+
+, "IMEI"
+: "IMEI"
+
+, "Friendly Name"
+: "Vriendelijke naam"
+
 , "Operating System"
 : ""
 
+, "OS Language"
+: "OS Taal"
+
 , "Phone Number"
 : ""
 
@@ -154,11 +112,47 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Quicksearch"
 : "Snelzoeken"
 
-, "Default Policy"
-: "Standaard gedragslijn"
+, "Sync Device, Sync Devices"
+: [
+  ""
+ ,""
 
-, "Default Policy installed during setup"
-: "Standaard gedragslijn ingesteld tijdens de installatie"
+]
+, "Device, Devices"
+: [
+  "Apparaat"
+ ,"Apparaten"
+
+]
+, "Devices"
+: "Apparaten"
+
+, "Devicetype"
+: "Apparaattype"
+
+, "OS"
+: "OS"
+
+, "Phonenumber"
+: "Telefoonnummer"
+
+, "Default Address book"
+: ""
+
+, "The default address book to create new contacts in."
+: ""
+
+, "Default Calendar"
+: "Standaard agenda"
+
+, "The default calendar to create new events in."
+: "De standaard agenda waar nieuwe gebeurtenissen in komen"
+
+, "Default Task List"
+: "Standaard taaklijst"
+
+, "The default task list to create new tasks in."
+: "De standaard taaklijst waar nieuwe taken in komen"
 
 , "Default policy for new devices"
 : "Standaard gedragslijn voor nieuwe apparaten"
@@ -166,6 +160,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Enter the id of the policy to apply to newly created devices."
 : "Voer het ID van de op nieuwe apparaten van toepassing gedagslijn in"
 
+, "Device Model Agent Deny List"
+: ""
+
+, "Array of regular expressions of Device-Model strings"
+: ""
+
 , "User Agent Deny List"
 : ""
 
@@ -190,6 +190,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "For how long in the past the events should be synchronized."
 : "Hoelang terug moeten afspraken worden gesynchroniseerd."
 
+, "%1$s ActiveSync failure"
+: ""
+
+, "Dear user,"
+: ""
+
+, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
+: ""
+
+, "Thank you."
+: ""
+
+, "Your %1$s Team"
+: ""
+
+, "Default Policy"
+: "Standaard gedragslijn"
+
+, "Default Policy installed during setup"
+: "Standaard gedragslijn ingesteld tijdens de installatie"
+
 , "Manage ActiveSync devices"
 : "Beheer ActiveSync apparaten"
 
