@@ -5,83 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of ActiveSync **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "Default Address book"
-: ""
-
-, "The default address book to create new contacts in."
-: ""
-
-, "Default Calendar"
-: "Domyślny kalendarz"
-
-, "The default calendar to create new events in."
-: "Domyślny kalendarz z nowymi terminami"
-
-, "Default Task List"
-: "Domyślna lista zadań"
-
-, "The default task list to create new tasks in."
-: "Domyślna lista dla nowo tworzonych zadań"
-
-, "Sync Devices"
-: "Połącz urządzenia"
-
-, "Device ID"
-: "Id urządzenia"
-
-, "Devicetype"
-: "Typ urządzenia"
-
-, "Owner"
-: "Właściciel"
-
-, "Policy"
-: "Polityka"
-
-, "ActiveSync Version"
-: ""
-
-, "User agent"
-: ""
-
-, "Model"
-: "Model"
-
-, "IMEI"
-: "IMEI"
-
-, "Friendly Name"
-: "Przyjazna nazwa"
-
-, "OS"
-: "System operacyjny"
-
-, "OS Language"
-: "Język systemu operacyjnego"
-
-, "Phonenumber"
-: "Numer telefonu"
-
-, "Sync Device, Sync Devices"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Device, Devices"
-: [
-  "Urządzenie"
- ,"urządzenia"
- ,"urządzenia"
- ,"urządzenia"
-
-]
-, "Devices"
-: "Urządzenia"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Active Sync"
 : "Zdalna synchronizacja"
@@ -107,15 +31,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Set Sync Filter"
 : "Ustaw filtr synchronizacji"
 
+, "Sync Devices"
+: "Połącz urządzenia"
+
 , "ID"
 : "Id"
 
+, "Device ID"
+: "Id urządzenia"
+
 , "Device Type"
 : ""
 
+, "Owner"
+: "Właściciel"
+
+, "Policy"
+: "Polityka"
+
+, "ActiveSync Version"
+: ""
+
+, "User agent"
+: ""
+
+, "Model"
+: "Model"
+
+, "IMEI"
+: "IMEI"
+
+, "Friendly Name"
+: "Przyjazna nazwa"
+
 , "Operating System"
 : ""
 
+, "OS Language"
+: "Język systemu operacyjnego"
+
 , "Phone Number"
 : ""
 
@@ -158,11 +112,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Quicksearch"
 : "Szybkie wyszukiwanie"
 
-, "Default Policy"
-: "Domyślna polityka"
+, "Sync Device, Sync Devices"
+: [
+  ""
+ ,""
+ ,""
+ ,""
 
-, "Default Policy installed during setup"
-: "Domyślna polityka określona podczas definiowania ustawień"
+]
+, "Device, Devices"
+: [
+  "Urządzenie"
+ ,"urządzenia"
+ ,"urządzenia"
+ ,"urządzenia"
+
+]
+, "Devices"
+: "Urządzenia"
+
+, "Devicetype"
+: "Typ urządzenia"
+
+, "OS"
+: "System operacyjny"
+
+, "Phonenumber"
+: "Numer telefonu"
+
+, "Default Address book"
+: ""
+
+, "The default address book to create new contacts in."
+: ""
+
+, "Default Calendar"
+: "Domyślny kalendarz"
+
+, "The default calendar to create new events in."
+: "Domyślny kalendarz z nowymi terminami"
+
+, "Default Task List"
+: "Domyślna lista zadań"
+
+, "The default task list to create new tasks in."
+: "Domyślna lista dla nowo tworzonych zadań"
 
 , "Default policy for new devices"
 : "Domyślna polityka dla nowych urządzeń"
@@ -170,6 +164,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Enter the id of the policy to apply to newly created devices."
 : "Wpisz id polityki, aby przypisać ją do nowo dodanych urządzeń."
 
+, "Device Model Agent Deny List"
+: ""
+
+, "Array of regular expressions of Device-Model strings"
+: ""
+
 , "User Agent Deny List"
 : ""
 
@@ -194,6 +194,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "For how long in the past the events should be synchronized."
 : "Jak daleko wprzód należy zsynchronizować wydarzenia."
 
+, "%1$s ActiveSync failure"
+: ""
+
+, "Dear user,"
+: ""
+
+, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
+: ""
+
+, "Thank you."
+: ""
+
+, "Your %1$s Team"
+: ""
+
+, "Default Policy"
+: "Domyślna polityka"
+
+, "Default Policy installed during setup"
+: "Domyślna polityka określona podczas definiowania ustawień"
+
 , "Manage ActiveSync devices"
 : "Brak urządzenia połączonego z usługą ActiveSync"
 
