@@ -5,83 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of ActiveSync **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "Default Address book"
-: ""
-
-, "The default address book to create new contacts in."
-: ""
-
-, "Default Calendar"
-: "Календарь по умолчанию"
-
-, "The default calendar to create new events in."
-: "Календарь для создания новых событий по умолчанию"
-
-, "Default Task List"
-: "Список задач по умолчанию"
-
-, "The default task list to create new tasks in."
-: "Список задач для создания новых задач по умолчанию"
-
-, "Sync Devices"
-: "Устройства"
-
-, "Device ID"
-: "ID устройства"
-
-, "Devicetype"
-: "Тип устройства"
-
-, "Owner"
-: "Владелец"
-
-, "Policy"
-: "Политика"
-
-, "ActiveSync Version"
-: ""
-
-, "User agent"
-: ""
-
-, "Model"
-: "Модель"
-
-, "IMEI"
-: "IMEI"
-
-, "Friendly Name"
-: "Простое имя"
-
-, "OS"
-: "ОС"
-
-, "OS Language"
-: "Язык ОС"
-
-, "Phonenumber"
-: "Номер телефона"
-
-, "Sync Device, Sync Devices"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Device, Devices"
-: [
-  "Устройство"
- ,"Устройства"
- ,"Устройства"
- ,"Устройства"
-
-]
-, "Devices"
-: "Устройства"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Active Sync"
 : "Active Sync"
@@ -107,15 +31,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Set Sync Filter"
 : "Установить фильтр синхронизации"
 
+, "Sync Devices"
+: "Устройства"
+
 , "ID"
 : "ID"
 
+, "Device ID"
+: "ID устройства"
+
 , "Device Type"
 : ""
 
+, "Owner"
+: "Владелец"
+
+, "Policy"
+: "Политика"
+
+, "ActiveSync Version"
+: ""
+
+, "User agent"
+: ""
+
+, "Model"
+: "Модель"
+
+, "IMEI"
+: "IMEI"
+
+, "Friendly Name"
+: "Простое имя"
+
 , "Operating System"
 : ""
 
+, "OS Language"
+: "Язык ОС"
+
 , "Phone Number"
 : ""
 
@@ -158,11 +112,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Quicksearch"
 : "Быстрый поиск"
 
-, "Default Policy"
-: "Политика по умолчанию"
+, "Sync Device, Sync Devices"
+: [
+  ""
+ ,""
+ ,""
+ ,""
 
-, "Default Policy installed during setup"
-: "Политика по умолчанию заданная при установке"
+]
+, "Device, Devices"
+: [
+  "Устройство"
+ ,"Устройства"
+ ,"Устройства"
+ ,"Устройства"
+
+]
+, "Devices"
+: "Устройства"
+
+, "Devicetype"
+: "Тип устройства"
+
+, "OS"
+: "ОС"
+
+, "Phonenumber"
+: "Номер телефона"
+
+, "Default Address book"
+: ""
+
+, "The default address book to create new contacts in."
+: ""
+
+, "Default Calendar"
+: "Календарь по умолчанию"
+
+, "The default calendar to create new events in."
+: "Календарь для создания новых событий по умолчанию"
+
+, "Default Task List"
+: "Список задач по умолчанию"
+
+, "The default task list to create new tasks in."
+: "Список задач для создания новых задач по умолчанию"
 
 , "Default policy for new devices"
 : "Политика по умолчанию для новых устройств"
@@ -170,6 +164,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Enter the id of the policy to apply to newly created devices."
 : "Введите ID политики для применения к вновь созданным устройствам."
 
+, "Device Model Agent Deny List"
+: ""
+
+, "Array of regular expressions of Device-Model strings"
+: ""
+
 , "User Agent Deny List"
 : ""
 
@@ -194,6 +194,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "For how long in the past the events should be synchronized."
 : "Насколько давние события должны быть синхронизированы."
 
+, "%1$s ActiveSync failure"
+: ""
+
+, "Dear user,"
+: ""
+
+, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
+: ""
+
+, "Thank you."
+: ""
+
+, "Your %1$s Team"
+: ""
+
+, "Default Policy"
+: "Политика по умолчанию"
+
+, "Default Policy installed during setup"
+: "Политика по умолчанию заданная при установке"
+
 , "Manage ActiveSync devices"
 : "Управление устройствами ActiveSync"
 
