@@ -5,79 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of ActiveSync **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "Default Address book"
-: ""
-
-, "The default address book to create new contacts in."
-: ""
-
-, "Default Calendar"
-: "Kalendari i paracaktuar"
-
-, "The default calendar to create new events in."
-: "Kalendari i paracaktuar ku do "
-
-, "Default Task List"
-: "Lista e paracaktuar detyrave"
-
-, "The default task list to create new tasks in."
-: "Lista e paracaktuar e detyrave ku do të krijohen detyra të reja"
-
-, "Sync Devices"
-: ""
-
-, "Device ID"
-: ""
-
-, "Devicetype"
-: ""
-
-, "Owner"
-: ""
-
-, "Policy"
-: ""
-
-, "ActiveSync Version"
-: ""
-
-, "User agent"
-: ""
-
-, "Model"
-: ""
-
-, "IMEI"
-: ""
-
-, "Friendly Name"
-: ""
-
-, "OS"
-: ""
-
-, "OS Language"
-: ""
-
-, "Phonenumber"
-: ""
-
-, "Sync Device, Sync Devices"
-: [
-  ""
- ,""
-
-]
-, "Device, Devices"
-: [
-  "Pajisja"
- ,"Pajisje"
-
-]
-, "Devices"
-: "Pajisje"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Active Sync"
 : "Sinkornizim aktiv"
@@ -103,15 +31,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Set Sync Filter"
 : "Vendsoni Filtrin e Sinkronizimit"
 
+, "Sync Devices"
+: ""
+
 , "ID"
 : ""
 
+, "Device ID"
+: ""
+
 , "Device Type"
 : ""
 
+, "Owner"
+: ""
+
+, "Policy"
+: ""
+
+, "ActiveSync Version"
+: ""
+
+, "User agent"
+: ""
+
+, "Model"
+: ""
+
+, "IMEI"
+: ""
+
+, "Friendly Name"
+: ""
+
 , "Operating System"
 : ""
 
+, "OS Language"
+: ""
+
 , "Phone Number"
 : ""
 
@@ -154,11 +112,47 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Quicksearch"
 : ""
 
-, "Default Policy"
-: "Politika e paracaktuar e Veprimeve "
+, "Sync Device, Sync Devices"
+: [
+  ""
+ ,""
 
-, "Default Policy installed during setup"
-: "Politika e paracaktuar e veprimeve"
+]
+, "Device, Devices"
+: [
+  "Pajisja"
+ ,"Pajisje"
+
+]
+, "Devices"
+: "Pajisje"
+
+, "Devicetype"
+: ""
+
+, "OS"
+: ""
+
+, "Phonenumber"
+: ""
+
+, "Default Address book"
+: ""
+
+, "The default address book to create new contacts in."
+: ""
+
+, "Default Calendar"
+: "Kalendari i paracaktuar"
+
+, "The default calendar to create new events in."
+: "Kalendari i paracaktuar ku do "
+
+, "Default Task List"
+: "Lista e paracaktuar detyrave"
+
+, "The default task list to create new tasks in."
+: "Lista e paracaktuar e detyrave ku do të krijohen detyra të reja"
 
 , "Default policy for new devices"
 : "Politika e paracaktuar e veprimit për pajisjet e reja"
@@ -166,6 +160,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Enter the id of the policy to apply to newly created devices."
 : "Vendosni ID e Linjës së veprimit që do aplikohet për pajisjet e reja të krijuara "
 
+, "Device Model Agent Deny List"
+: ""
+
+, "Array of regular expressions of Device-Model strings"
+: ""
+
 , "User Agent Deny List"
 : ""
 
@@ -190,6 +190,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "For how long in the past the events should be synchronized."
 : "Për sa kohë përpara duhet të sinkronizohen ngjarjet"
 
+, "%1$s ActiveSync failure"
+: ""
+
+, "Dear user,"
+: ""
+
+, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
+: ""
+
+, "Thank you."
+: ""
+
+, "Your %1$s Team"
+: ""
+
+, "Default Policy"
+: "Politika e paracaktuar e Veprimeve "
+
+, "Default Policy installed during setup"
+: "Politika e paracaktuar e veprimeve"
+
 , "Manage ActiveSync devices"
 : ""
 
