@@ -5,77 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of ActiveSync **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "Default Address book"
-: ""
-
-, "The default address book to create new contacts in."
-: ""
-
-, "Default Calendar"
-: "缺省日历"
-
-, "The default calendar to create new events in."
-: "使用缺省日历创建新的事件"
-
-, "Default Task List"
-: "任务列表"
-
-, "The default task list to create new tasks in."
-: "在默认的任务列表中创建新的任务。"
-
-, "Sync Devices"
-: ""
-
-, "Device ID"
-: ""
-
-, "Devicetype"
-: ""
-
-, "Owner"
-: ""
-
-, "Policy"
-: ""
-
-, "ActiveSync Version"
-: ""
-
-, "User agent"
-: ""
-
-, "Model"
-: ""
-
-, "IMEI"
-: ""
-
-, "Friendly Name"
-: ""
-
-, "OS"
-: ""
-
-, "OS Language"
-: ""
-
-, "Phonenumber"
-: ""
-
-, "Sync Device, Sync Devices"
-: [
-  ""
-
-]
-, "Device, Devices"
-: [
-  "设备"
-
-]
-, "Devices"
-: "设备"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Active Sync"
 : "Active Sync"
@@ -101,15 +31,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Set Sync Filter"
 : "设置同步过滤器"
 
+, "Sync Devices"
+: ""
+
 , "ID"
 : ""
 
+, "Device ID"
+: ""
+
 , "Device Type"
 : ""
 
+, "Owner"
+: ""
+
+, "Policy"
+: ""
+
+, "ActiveSync Version"
+: ""
+
+, "User agent"
+: ""
+
+, "Model"
+: ""
+
+, "IMEI"
+: ""
+
+, "Friendly Name"
+: ""
+
 , "Operating System"
 : ""
 
+, "OS Language"
+: ""
+
 , "Phone Number"
 : ""
 
@@ -152,11 +112,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Quicksearch"
 : ""
 
-, "Default Policy"
-: "默认策略"
+, "Sync Device, Sync Devices"
+: [
+  ""
 
-, "Default Policy installed during setup"
-: "安装过程中使用默认策略"
+]
+, "Device, Devices"
+: [
+  "设备"
+
+]
+, "Devices"
+: "设备"
+
+, "Devicetype"
+: ""
+
+, "OS"
+: ""
+
+, "Phonenumber"
+: ""
+
+, "Default Address book"
+: ""
+
+, "The default address book to create new contacts in."
+: ""
+
+, "Default Calendar"
+: "缺省日历"
+
+, "The default calendar to create new events in."
+: "使用缺省日历创建新的事件"
+
+, "Default Task List"
+: "任务列表"
+
+, "The default task list to create new tasks in."
+: "在默认的任务列表中创建新的任务。"
 
 , "Default policy for new devices"
 : "新设备使用默认策略"
@@ -164,6 +158,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "Enter the id of the policy to apply to newly created devices."
 : "输入ID的策略应用到新创建的设备。"
 
+, "Device Model Agent Deny List"
+: ""
+
+, "Array of regular expressions of Device-Model strings"
+: ""
+
 , "User Agent Deny List"
 : ""
 
@@ -188,6 +188,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
 , "For how long in the past the events should be synchronized."
 : ""
 
+, "%1$s ActiveSync failure"
+: ""
+
+, "Dear user,"
+: ""
+
+, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
+: ""
+
+, "Thank you."
+: ""
+
+, "Your %1$s Team"
+: ""
+
+, "Default Policy"
+: "默认策略"
+
+, "Default Policy installed during setup"
+: "安装过程中使用默认策略"
+
 , "Manage ActiveSync devices"
 : ""
 
