@@ -166,8 +166,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Other Data"
 : "Andere Daten"
 
-, "Birthday"
-: "Geburtstag"
+, "Birthday (private)"
+: "Geburtstag (privat)"
 
 , "Job Title"
 : "Berufs-Bezeichnung"
@@ -468,8 +468,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 
 , "List, Lists"
 : [
-  "Gruppe"
- ,"Gruppen"
+  "Gruppenliste"
+ ,"Gruppenlisten"
 
 ]
 , "Percent"
@@ -487,6 +487,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "List type"
 : "Listen Typ"
 
+, "This is a system group. To edit this group you need the Admin.ManageAccounts right."
+: "Dies ist eine Systemgruppe. Um Änderungen vorzunehmen, benötigen Sie das Recht 'Benutzerkonten verwalten'"
+
 , "All contacts I have read grants for"
 : "Alle Kontakte für die ich Lese-Rechte habe"
 
@@ -878,7 +881,13 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 : "Zu exportierende Adressbücher"
 
 , "Export target"
-: "Exportzielr"
+: "Export Ziel"
+
+, "Language"
+: "Sprache"
+
+, "Select color"
+: "Farbe wählen"
 
 , "Addressbook"
 : "Adressbuch"
@@ -890,7 +899,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 : "Branche"
 
 , "List"
-: "Gruppe"
+: "Gruppenliste"
 
 , "Relation"
 : ""
