@@ -5,388 +5,25 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Addressbook **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 ""
-: "Project-Id-Version: Tine 2.0 - Addressbook\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"
+: "Project-Id-Version: Tine 2.0 - Addressbook\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"
 
-, "Import CSV formated contacts from Google address book"
-: "Import CSV formated contacts from Google address book"
+, "Map"
+: "Map"
 
-, "Contact import from Google address book"
-: "Contact import from Google address book"
+, "Preferred Address"
+: "Preferred Address"
 
-, "LX-Office CSV Contact import"
-: "LX-Office CSV Contact import"
+, "Personal Information"
+: "Personal Information"
 
-, "Import CSV formated contacts from LX-Office"
-: "Import CSV formated contacts from LX-Office"
+, "Salutation"
+: "Salutation"
 
-, "Tine 2.0 contact CSV import"
-: "Tine 2.0 contact CSV import"
+, "Title"
+: "Title"
 
-, "Import CSV formated contacts from Tine 2.0 address book"
-: "Import CSV formated contacts from Tine 2.0 address book"
-
-, "Import list (###CURRENTDATE###)"
-: "Import list (###CURRENTDATE###)"
-
-, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
-: "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
-
-, "Import vCard formated contacts"
-: "Import vCard formated contacts"
-
-, "Contact VCARD import"
-: "Contact VCARD import"
-
-, "Import CSV formated contacts from Exchange / Outlook address book"
-: "Import CSV formated contacts from Exchange / Outlook address book"
-
-, "Contact CSV import from Outlook address book"
-: "Contact CSV import from Outlook address book"
-
-, "Contact CSV import from mac address book"
-: "Contact CSV import from mac address book"
-
-, "Import CSV formated contacts from Outlook 2007 German address book"
-: "Import CSV formated contacts from Outlook 2007 German address book"
-
-, "CSV Outlook 2007 German"
-: "CSV Outlook 2007 German"
-
-, "It is not allowed to delete a contact linked to an user account!"
-: "It is not allowed to delete a contact linked to an user account!"
-
-, "This Short Name already exists. How about {0}?"
-: "This Short Name already exists. How about {0}?"
-
-, "It is not allowed to add non-account contacts to this list"
-: "It is not allowed to add non-account contacts to this list"
-
-, "E-Mail address is already given. Please choose another one."
-: "E-Mail address is already given. Please choose another one."
-
-, "Excel overview"
-: "Excel overview"
-
-, "Word details"
-: "Word details"
-
-, "Excel all data"
-: "Excel all data"
-
-, "CSV all data"
-: "CSV all data"
-
-, "OpenDocument all data"
-: "OpenDocument all data"
-
-, "Relations"
-: "Relations"
-
-, "PDF details"
-: "PDF details"
-
-, "Word letter"
-: "Word letter"
-
-, "Excel phone list"
-: "Excel phone list"
-
-, "Excel phone list grouped by company"
-: "Excel phone list grouped by company"
-
-, "Business Contact Data"
-: "Business Contact Data"
-
-, "Organisation / Unit"
-: "Organisation / Unit"
-
-, "Business Address"
-: "Business Address"
-
-, "Email"
-: "Email"
-
-, "Telephone Work"
-: "Telephone Work"
-
-, "Telephone Cellphone"
-: "Telephone Cellphone"
-
-, "Telephone Car"
-: "Telephone Car"
-
-, "Telephone Fax"
-: "Telephone Fax"
-
-, "Telephone Page"
-: "Telephone Page"
-
-, "URL"
-: "URL"
-
-, "Role"
-: "Role"
-
-, "Room"
-: "Room"
-
-, "Assistant"
-: "Assistant"
-
-, "Assistant Telephone"
-: "Assistant Telephone"
-
-, "Private Contact Data"
-: "Private Contact Data"
-
-, "Private Address"
-: "Private Address"
-
-, "Email Home"
-: "Email Home"
-
-, "Telephone Home"
-: "Telephone Home"
-
-, "Telephone Cellphone Private"
-: "Telephone Cellphone Private"
-
-, "Telephone Fax Home"
-: "Telephone Fax Home"
-
-, "URL Home"
-: "URL Home"
-
-, "Other Data"
-: "Other Data"
-
-, "Birthday"
-: "Birthday"
-
-, "Job Title"
-: "Job Title"
-
-, "Enabled Features"
-: "Enabled Features"
-
-, "Enabled Features in Addressbook Application."
-: "Enabled Features in Addressbook Application."
-
-, "Addressbook Contact Event List"
-: "Addressbook Contact Event List"
-
-, "Shows contact events in edit dialog tab panel"
-: "Shows contact events in edit dialog tab panel"
-
-, "Addressbook List View"
-: "Addressbook List View"
-
-, "Shows an additional view for lists inside the addressbook"
-: "Shows an additional view for lists inside the addressbook"
-
-, "Addressbook Industries"
-: "Addressbook Industries"
-
-, "Add Industry field to Adressbook"
-: "Add Industry field to Adressbook"
-
-, "Mailinglists"
-: "Mailinglists"
-
-, "Make group and lists to mailinglists"
-: "Make group and lists to mailinglists"
-
-, "Addressbook Short Names"
-: "Addressbook Short Names"
-
-, "Add Short Name field to Adressbook"
-: "Add Short Name field to Adressbook"
-
-, "Manage resources in Addressbook"
-: "Manage resources in Addressbook"
-
-, "Show the resources grid also inside the Addressbook"
-: "Show the resources grid also inside the Addressbook"
-
-, "Show Structure Panel in Addressbook"
-: "Show Structure Panel in Addressbook"
-
-, "Visualize relations of records"
-: "Visualize relations of records"
-
-, "Contact duplicate check fields"
-: "Contact duplicate check fields"
-
-, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
-: "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
-
-, "Contact Hidden Criteria"
-: "Contact Hidden Criteria"
-
-, "The contact is hidden if it is ... (one of: disabled, expired or never)"
-: "The contact is hidden if it is ... (one of: disabled, expired or never)"
-
-, "Contact salutations available"
-: "Contact salutations available"
-
-, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
-: "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
-
-, "Mr"
-: "Mr"
-
-, "Ms"
-: "Ms"
-
-, "Company"
-: "Company"
-
-, "Parsing rules for addresses"
-: "Parsing rules for addresses"
-
-, "Path to a XML file with address parsing rules."
-: "Path to a XML file with address parsing rules."
-
-, "List types available"
-: "List types available"
-
-, "List types available."
-: "List types available."
-
-, "Department"
-: "Department"
-
-, "Mailing list"
-: "Mailing list"
-
-, "Use Nominatim during contact import"
-: "Use Nominatim during contact import"
-
-, "Site Filter"
-: "Site Filter"
-
-, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
-: "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
-
-, "Sync Backends"
-: "Sync Backends"
-
-, "Default telephone country code"
-: "Default telephone country code"
-
-, "Addressbook, Addressbooks"
-: [
-  "Addressbook"
- ,"Addressbooks"
-
-]
-, "Contact, Contacts"
-: [
-  "Contact"
- ,"Contacts"
-
-]
-, "Show Disabled"
-: "Show Disabled"
-
-, "Path"
-: "Path"
-
-, "List Member"
-: "List Member"
-
-, "List Role Member"
-: "List Role Member"
-
-, "Telephone"
-: "Telephone"
-
-, "Telephone Normalized"
-: "Telephone Normalized"
-
-, "Country"
-: "Country"
-
-, "City"
-: "City"
-
-, "Postalcode"
-: "Postalcode"
-
-, "Region"
-: "Region"
-
-, "Street"
-: "Street"
-
-, "Street 2"
-: "Street 2"
-
-, "Longitude"
-: "Longitude"
-
-, "Latitude"
-: "Latitude"
-
-, "Country (private)"
-: "Country (private)"
-
-, "City (private)"
-: "City (private)"
-
-, "Postalcode (private)"
-: "Postalcode (private)"
-
-, "Region (private)"
-: "Region (private)"
-
-, "Street (private)"
-: "Street (private)"
-
-, "Street 2 (private)"
-: "Street 2 (private)"
-
-, "Longitude (private)"
-: "Longitude (private)"
-
-, "Latitude (private)"
-: "Latitude (private)"
-
-, "Assistent"
-: "Assistent"
-
-, "Calendar URI"
-: "Calendar URI"
-
-, "Email (private)"
-: "Email (private)"
-
-, "Free/Busy URI"
-: "Free/Busy URI"
-
-, "Geo"
-: "Geo"
-
-, "Groups"
-: "Groups"
-
-, "Industry, Industries"
-: [
-  "Industry"
- ,"Industries"
-
-]
-, "Note"
-: "Note"
-
-, "Last Name"
-: "Last Name"
-
-, "Display Name"
-: "Display Name"
-
-, "Full Name"
-: "Full Name"
+, "Short Name"
+: "Short Name"
 
 , "First Name"
 : "First Name"
@@ -394,240 +31,93 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Middle Name"
 : "Middle Name"
 
-, "Title"
-: "Title"
+, "Last Name"
+: "Last Name"
 
-, "Suffix"
-: "Suffix"
-
-, "Short Name"
-: "Short Name"
+, "Company"
+: "Company"
 
 , "Unit"
 : "Unit"
 
-, "Paths"
-: "Paths"
+, "Display Name"
+: "Display Name"
 
-, "Preferred Address"
-: "Preferred Address"
-
-, "Job Role"
-: "Job Role"
-
-, "Salutation"
-: "Salutation"
-
-, "syncBackendIds"
-: "syncBackendIds"
-
-, "Car phone"
-: "Car phone"
-
-, "Mobile"
-: "Mobile"
-
-, "Mobile (private)"
-: "Mobile (private)"
-
-, "Fax"
-: "Fax"
-
-, "Fax (private)"
-: "Fax (private)"
-
-, "Phone (private)"
-: "Phone (private)"
-
-, "Pager"
-: "Pager"
-
-, "Phone"
-: "Phone"
-
-, "Type"
-: "Type"
-
-, "Timezone"
-: "Timezone"
-
-, "Web"
-: "Web"
-
-, "URL (private)"
-: "URL (private)"
-
-, "Label"
-: "Label"
-
-, "List, Lists"
+, "Industry, Industries"
 : [
-  "List"
- ,"Lists"
+  "Industry"
+ ,"Industries"
 
 ]
-, "Percent"
-: "Percent"
+, "Job Title"
+: "Job Title"
 
-, "Description"
-: "Description"
-
-, "Members"
-: "Members"
-
-, "E-Mail"
-: "E-Mail"
-
-, "List type"
-: "List type"
-
-, "All contacts I have read grants for"
-: "All contacts I have read grants for"
-
-, "My company"
-: "My company"
-
-, "All coworkers in my company"
-: "All coworkers in my company"
-
-, "My contacts"
-: "My contacts"
-
-, "All contacts in my Addressbooks"
-: "All contacts in my Addressbooks"
-
-, "Last modified by me"
-: "Last modified by me"
-
-, "All contacts that I have last modified"
-: "All contacts that I have last modified"
-
-, "Internal Contacts"
-: "Internal Contacts"
-
-, "manage shared addressbooks"
-: "manage shared addressbooks"
-
-, "Create new shared addressbook folders"
-: "Create new shared addressbook folders"
-
-, "manage shared addressbook favorites"
-: "manage shared addressbook favorites"
-
-, "Create or update shared addressbook favorites"
-: "Create or update shared addressbook favorites"
-
-, "Manage lists in CoreData"
-: "Manage lists in CoreData"
-
-, "View, create, delete or update lists in CoreData application"
-: "View, create, delete or update lists in CoreData application"
-
-, "Manage list functions in CoreData"
-: "Manage list functions in CoreData"
-
-, "View, create, delete or update list functions in CoreData application"
-: "View, create, delete or update list functions in CoreData application"
-
-, "Manage list email options"
-: "Manage list email options"
-
-, "Manage list email options like mailing lists"
-: "Manage list email options like mailing lists"
-
-, "Relation, Relations"
-: [
-  "Relation"
- ,"Relations"
-
-]
-, "Search for users ..."
-: "Search for users ..."
-
-, "Search for Contacts ..."
-: "Search for Contacts ..."
-
-, "Tags"
-: "Tags"
-
-, "Name"
-: "Name"
-
-, "Member E-Mails"
-: "Member E-Mails"
-
-, "System Group"
-: "System Group"
-
-, "Group"
-: "Group"
-
-, "Mailing List"
-: "Mailing List"
-
-, "This group is a mailing list"
-: "This group is a mailing list"
-
-, "Grants of a folder also apply recursively for all of its sub folders as long they don't have own grants itself."
-: "Grants of a folder also apply recursively for all of its sub folders as long they don't have own grants itself."
-
-, "Keep copy of group mails"
-: "Keep copy of group mails"
-
-, "Forward external mails"
-: "Forward external mails"
-
-, "Only forward member mails"
-: "Only forward member mails"
-
-, "Only forward to system email accounts"
-: "Only forward to system email accounts"
-
-, "Select record to see its details"
-: "Select record to see its details"
-
-, "This module visualises hierarchically depended relations between records of different types."
-: "This module visualises hierarchically depended relations between records of different types."
-
-, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
-: "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
-
-, "Loading Structure data..."
-: "Loading Structure data..."
-
-, "List Roles"
-: "List Roles"
-
-, "Remove Member"
-: "Remove Member"
-
-, "Search for system groups ..."
-: "Search for system groups ..."
-
-, "Search for groups ..."
-: "Search for groups ..."
-
-, "Map"
-: "Map"
-
-, "Personal Information"
-: "Personal Information"
+, "Birthday (private)"
+: "Birthday (private)"
 
 , "Contact Information"
 : "Contact Information"
 
+, "Phone"
+: "Phone"
+
+, "Mobile"
+: "Mobile"
+
+, "Fax"
+: "Fax"
+
+, "Phone (private)"
+: "Phone (private)"
+
+, "Mobile (private)"
+: "Mobile (private)"
+
+, "Fax (private)"
+: "Fax (private)"
+
+, "E-Mail"
+: "E-Mail"
+
 , "E-Mail (private)"
 : "E-Mail (private)"
 
+, "Web"
+: "Web"
+
 , "Company Address"
 : "Company Address"
 
+, "Street"
+: "Street"
+
+, "Street 2"
+: "Street 2"
+
+, "Region"
+: "Region"
+
 , "Postal Code"
 : "Postal Code"
 
+, "City"
+: "City"
+
+, "Country"
+: "Country"
+
+, "Private Address"
+: "Private Address"
+
+, "Description"
+: "Description"
+
 , "Enter description"
 : "Enter description"
 
+, "Groups"
+: "Groups"
+
 , "Parse address"
 : "Parse address"
 
@@ -649,12 +139,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "End token mode"
 : "End token mode"
 
+, "Customfields"
+: "Customfields"
+
+, "Related to"
+: "Related to"
+
+, "Mailing List"
+: "Mailing List"
+
+, "This group is a mailing list"
+: "This group is a mailing list"
+
+, "Keep copy of group mails"
+: "Keep copy of group mails"
+
+, "Forward external mails"
+: "Forward external mails"
+
+, "Only forward member mails"
+: "Only forward member mails"
+
+, "Only forward to system email accounts"
+: "Only forward to system email accounts"
+
+, "Search for system groups ..."
+: "Search for system groups ..."
+
+, "Search for groups ..."
+: "Search for groups ..."
+
+, "Contact, Contacts"
+: [
+  "Contact"
+ ,"Contacts"
+
+]
+, "Members"
+: "Members"
+
+, "Search for members ..."
+: "Search for members ..."
+
+, "List Roles"
+: "List Roles"
+
+, "Remove Member"
+: "Remove Member"
+
+, "CardDAV URL"
+: "CardDAV URL"
+
 , "New Contact"
 : "New Contact"
 
+, "Addressbook, Addressbooks"
+: [
+  "Addressbook"
+ ,"Addressbooks"
+
+]
 , "ID"
 : "ID"
 
+, "Name"
+: "Name"
+
 , "Structure, Structures"
 : [
   "Structure"
@@ -664,47 +214,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Resources"
 : "Resources"
 
-, "Business"
-: "Business"
-
 , "Private"
 : "Private"
 
-, "Member of List"
-: "Member of List"
+, "The grant to access contacts private information"
+: "The grant to access contacts private information"
 
-, "Related to"
-: "Related to"
+, "Contact Personal Grant, Contact Personal Grants"
+: [
+  "Contact Personal Grant"
+ ,"Contact Personal Grants"
 
-, "Customfields"
-: "Customfields"
+]
+, "List Personal Grant, List Personal Grants"
+: [
+  "List Personal Grant"
+ ,"List Personal Grants"
+
+]
+, "List Information"
+: "List Information"
+
+, "List type"
+: "List type"
+
+, "System accounts only"
+: "System accounts only"
+
+, "{0} must be given"
+: "{0} must be given"
 
 , "List Functions"
 : "List Functions"
 
-, "Lists"
-: "Lists"
+, "Suffix"
+: "Suffix"
 
-, "Select list"
-: "Select list"
+, "Birthday"
+: "Birthday"
 
-, "Import contacts"
-: "Import contacts"
+, "Job Role"
+: "Job Role"
 
-, "Contact of a user account"
-: "Contact of a user account"
-
-, "No name"
-: "No name"
-
-, "Not set"
-: "Not set"
-
-, "Contact Image"
-: "Contact Image"
-
-, "Attachments"
-: "Attachments"
+, "Room"
+: "Room"
 
 , "Street (Company Address)"
 : "Street (Company Address)"
@@ -769,6 +322,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Quick Search"
 : "Quick Search"
 
+, "Type"
+: "Type"
+
 , "Last Modified Time"
 : "Last Modified Time"
 
@@ -781,6 +337,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Created By"
 : "Created By"
 
+, "List, Lists"
+: [
+  "List"
+ ,"Lists"
+
+]
+, "Lists"
+: "Lists"
+
 , "Email Address, Email Addresses"
 : [
   "Email Address"
@@ -799,23 +364,92 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
  ,"List Functions"
 
 ]
+, "GENDER_List Function"
+: "GENDER_List Function"
+
 , "Industries"
 : "Industries"
 
 , "Structures"
 : "Structures"
 
-, "CardDAV URL"
-: "CardDAV URL"
+, "Business"
+: "Business"
 
-, "List Information"
-: "List Information"
+, "Import contacts"
+: "Import contacts"
 
-, "System accounts only"
-: "System accounts only"
+, "Contact of a user account"
+: "Contact of a user account"
 
-, "{0} must be given"
-: "{0} must be given"
+, "No name"
+: "No name"
+
+, "Not set"
+: "Not set"
+
+, "Contact Image"
+: "Contact Image"
+
+, "Attachments"
+: "Attachments"
+
+, "Tags"
+: "Tags"
+
+, "Full Name"
+: "Full Name"
+
+, "Postalcode"
+: "Postalcode"
+
+, "Street (private)"
+: "Street (private)"
+
+, "City (private)"
+: "City (private)"
+
+, "Region (private)"
+: "Region (private)"
+
+, "Postalcode (private)"
+: "Postalcode (private)"
+
+, "Country (private)"
+: "Country (private)"
+
+, "Email"
+: "Email"
+
+, "Car phone"
+: "Car phone"
+
+, "Pager"
+: "Pager"
+
+, "Email (private)"
+: "Email (private)"
+
+, "URL (private)"
+: "URL (private)"
+
+, "Note"
+: "Note"
+
+, "Timezone"
+: "Timezone"
+
+, "Geo"
+: "Geo"
+
+, "Select list"
+: "Select list"
+
+, "Search for users ..."
+: "Search for users ..."
+
+, "Search for Contacts ..."
+: "Search for Contacts ..."
 
 , "Company address"
 : "Company address"
@@ -823,6 +457,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Private address"
 : "Private address"
 
+, "Member E-Mails"
+: "Member E-Mails"
+
+, "System Group"
+: "System Group"
+
+, "Group"
+: "Group"
+
+, "Select record to see its details"
+: "Select record to see its details"
+
+, "This module visualises hierarchically depended relations between records of different types."
+: "This module visualises hierarchically depended relations between records of different types."
+
+, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
+: "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
+
+, "Loading Structure data..."
+: "Loading Structure data..."
+
 , "All contacts"
 : "All contacts"
 
@@ -853,39 +508,483 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "default"
 : "default"
 
+, "Enabled Features"
+: "Enabled Features"
+
+, "Enabled Features in Addressbook Application."
+: "Enabled Features in Addressbook Application."
+
+, "Addressbook Contact Event List"
+: "Addressbook Contact Event List"
+
+, "Shows contact events in edit dialog tab panel"
+: "Shows contact events in edit dialog tab panel"
+
+, "Addressbook List View"
+: "Addressbook List View"
+
+, "Shows an additional view for lists inside the addressbook"
+: "Shows an additional view for lists inside the addressbook"
+
+, "Addressbook Industries"
+: "Addressbook Industries"
+
+, "Add Industry field to Adressbook"
+: "Add Industry field to Adressbook"
+
+, "Mailinglists"
+: "Mailinglists"
+
+, "Make group and lists to mailinglists"
+: "Make group and lists to mailinglists"
+
+, "Addressbook Short Names"
+: "Addressbook Short Names"
+
+, "Add Short Name field to Adressbook"
+: "Add Short Name field to Adressbook"
+
+, "Manage resources in Addressbook"
+: "Manage resources in Addressbook"
+
+, "Show the resources grid also inside the Addressbook"
+: "Show the resources grid also inside the Addressbook"
+
+, "Show Structure Panel in Addressbook"
+: "Show Structure Panel in Addressbook"
+
+, "Visualize relations of records"
+: "Visualize relations of records"
+
+, "Contact (id) representing this installation"
+: "Contact (id) representing this installation"
+
+, "Contact duplicate check fields"
+: "Contact duplicate check fields"
+
+, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
+: "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
+
+, "Contact Hidden Criteria"
+: "Contact Hidden Criteria"
+
+, "The contact is hidden if it is ... (one of: disabled, expired or never)"
+: "The contact is hidden if it is ... (one of: disabled, expired or never)"
+
+, "Contact salutations available"
+: "Contact salutations available"
+
+, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
+: "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
+
+, "Mr"
+: "Mr"
+
+, "Ms"
+: "Ms"
+
+, "Parsing rules for addresses"
+: "Parsing rules for addresses"
+
+, "Path to a XML file with address parsing rules."
+: "Path to a XML file with address parsing rules."
+
+, "List types available"
+: "List types available"
+
+, "List types available."
+: "List types available."
+
+, "Department"
+: "Department"
+
+, "Mailing list"
+: "Mailing list"
+
+, "Use Nominatim during contact import"
+: "Use Nominatim during contact import"
+
+, "Site Filter"
+: "Site Filter"
+
+, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
+: "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
+
+, "Sync Backends"
+: "Sync Backends"
+
+, "Default telephone country code"
+: "Default telephone country code"
+
 , "%s's personal addressbook"
 : "%s's personal addressbook"
 
-, "This contact has been automatically added by the system as an event attender"
-: "This contact has been automatically added by the system as an event attender"
+, "Business Contact Data"
+: "Business Contact Data"
+
+, "Organisation / Unit"
+: "Organisation / Unit"
+
+, "Business Address"
+: "Business Address"
+
+, "Telephone Work"
+: "Telephone Work"
+
+, "Telephone Cellphone"
+: "Telephone Cellphone"
+
+, "Telephone Car"
+: "Telephone Car"
+
+, "Telephone Fax"
+: "Telephone Fax"
+
+, "Telephone Page"
+: "Telephone Page"
+
+, "URL"
+: "URL"
+
+, "Role"
+: "Role"
+
+, "Assistant"
+: "Assistant"
+
+, "Assistant Telephone"
+: "Assistant Telephone"
+
+, "Private Contact Data"
+: "Private Contact Data"
+
+, "Email Home"
+: "Email Home"
+
+, "Telephone Home"
+: "Telephone Home"
+
+, "Telephone Cellphone Private"
+: "Telephone Cellphone Private"
+
+, "Telephone Fax Home"
+: "Telephone Fax Home"
+
+, "URL Home"
+: "URL Home"
+
+, "Other Data"
+: "Other Data"
+
+, "OpenDocument all data"
+: "OpenDocument all data"
+
+, "Excel phone list"
+: "Excel phone list"
+
+, "Excel phone list grouped by company"
+: "Excel phone list grouped by company"
+
+, "Word details"
+: "Word details"
+
+, "Excel overview"
+: "Excel overview"
+
+, "Word letter"
+: "Word letter"
+
+, "PDF details"
+: "PDF details"
+
+, "Excel all data"
+: "Excel all data"
+
+, "VCard Report"
+: "VCard Report"
+
+, "Export multiple addressbooks to vcf files"
+: "Export multiple addressbooks to vcf files"
+
+, "Relations"
+: "Relations"
+
+, "CSV all data"
+: "CSV all data"
+
+, "VCard/VCF"
+: "VCard/VCF"
+
+, "Export contact data into vcf file"
+: "Export contact data into vcf file"
+
+, "Addressbooks to export"
+: "Addressbooks to export"
+
+, "Export target"
+: "Export target"
+
+, "Import CSV formated contacts from Exchange / Outlook address book"
+: "Import CSV formated contacts from Exchange / Outlook address book"
+
+, "Contact CSV import from Outlook address book"
+: "Contact CSV import from Outlook address book"
+
+, "Contact CSV import from mac address book"
+: "Contact CSV import from mac address book"
+
+, "Import CSV formated contacts from Outlook 2007 German address book"
+: "Import CSV formated contacts from Outlook 2007 German address book"
+
+, "CSV Outlook 2007 German"
+: "CSV Outlook 2007 German"
+
+, "Import CSV formated contacts from Outlook 2010 German address book"
+: "Import CSV formated contacts from Outlook 2010 German address book"
+
+, "CSV Outlook 2010 German"
+: "CSV Outlook 2010 German"
+
+, "Import vCard formated contacts"
+: "Import vCard formated contacts"
+
+, "Contact VCARD import"
+: "Contact VCARD import"
+
+, "LX-Office CSV Contact import"
+: "LX-Office CSV Contact import"
+
+, "Import CSV formated contacts from LX-Office"
+: "Import CSV formated contacts from LX-Office"
+
+, "Tine 2.0 contact CSV import"
+: "Tine 2.0 contact CSV import"
+
+, "Import CSV formated contacts from Tine 2.0 address book"
+: "Import CSV formated contacts from Tine 2.0 address book"
+
+, "Import list (###CURRENTDATE###)"
+: "Import list (###CURRENTDATE###)"
+
+, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+
+, "Import CSV formated contacts from Google address book"
+: "Import CSV formated contacts from Google address book"
+
+, "Contact import from Google address book"
+: "Contact import from Google address book"
+
+, "GENDER_List"
+: "GENDER_List"
+
+, "Name/Email"
+: "Name/Email"
+
+, "GENDER_Contact"
+: "GENDER_Contact"
+
+, "Show Disabled"
+: "Show Disabled"
+
+, "Path"
+: "Path"
+
+, "List Member"
+: "List Member"
+
+, "List Role Member"
+: "List Role Member"
+
+, "Telephone"
+: "Telephone"
+
+, "Telephone Normalized"
+: "Telephone Normalized"
+
+, "Longitude"
+: "Longitude"
+
+, "Latitude"
+: "Latitude"
+
+, "Street 2 (private)"
+: "Street 2 (private)"
+
+, "Longitude (private)"
+: "Longitude (private)"
+
+, "Latitude (private)"
+: "Latitude (private)"
+
+, "Assistent"
+: "Assistent"
+
+, "Calendar URI"
+: "Calendar URI"
+
+, "Free/Busy URI"
+: "Free/Busy URI"
+
+, "Paths"
+: "Paths"
+
+, "syncBackendIds"
+: "syncBackendIds"
+
+, "Label"
+: "Label"
+
+, "It is not allowed to add non-account contacts to this list"
+: "It is not allowed to add non-account contacts to this list"
+
+, "E-Mail address is already given. Please choose another one."
+: "E-Mail address is already given. Please choose another one."
+
+, "It is not allowed to delete a contact linked to an user account!"
+: "It is not allowed to delete a contact linked to an user account!"
+
+, "This Short Name already exists. How about {0}?"
+: "This Short Name already exists. How about {0}?"
+
+, "Internal Contacts"
+: "Internal Contacts"
+
+, "All contacts I have read grants for"
+: "All contacts I have read grants for"
+
+, "My company"
+: "My company"
+
+, "All coworkers in my company"
+: "All coworkers in my company"
+
+, "My contacts"
+: "My contacts"
+
+, "All contacts in my Addressbooks"
+: "All contacts in my Addressbooks"
+
+, "Last modified by me"
+: "Last modified by me"
+
+, "All contacts that I have last modified"
+: "All contacts that I have last modified"
 
 , "All Contacts"
 : "All Contacts"
 
-, "Addressbook"
-: "Addressbook"
+, "This contact has been automatically added by the system as an event attender"
+: "This contact has been automatically added by the system as an event attender"
+
+, "manage shared addressbooks"
+: "manage shared addressbooks"
+
+, "Create new shared addressbook folders"
+: "Create new shared addressbook folders"
+
+, "manage shared addressbook favorites"
+: "manage shared addressbook favorites"
+
+, "Create or update shared addressbook favorites"
+: "Create or update shared addressbook favorites"
+
+, "Manage lists in CoreData"
+: "Manage lists in CoreData"
+
+, "View, create, delete or update lists in CoreData application"
+: "View, create, delete or update lists in CoreData application"
+
+, "Manage list functions in CoreData"
+: "Manage list functions in CoreData"
+
+, "View, create, delete or update list functions in CoreData application"
+: "View, create, delete or update list functions in CoreData application"
+
+, "Manage list email options"
+: "Manage list email options"
+
+, "Manage list email options like mailing lists"
+: "Manage list email options like mailing lists"
+
+, "Account"
+: "Account"
+
+, "Exporttime"
+: "Exporttime"
+
+, "28"
+: "28"
+
+, "20"
+: "20"
+
+, "00877546"
+: "00877546"
+
+, "en-GB"
+: "en-GB"
+
+, "00813B4E"
+: "00813B4E"
+
+, "Gruppenrollen"
+: "Gruppenrollen"
+
+, "00DA3FCD"
+: "00DA3FCD"
+
+, "00997199"
+: "00997199"
+
+, "0009326B"
+: "0009326B"
+
+, "008C27A5"
+: "008C27A5"
+
+, "00C96397"
+: "00C96397"
+
+, "00046462"
+: "00046462"
+
+, "Relation, Relations"
+: [
+  "Relation"
+ ,"Relations"
+
+]
+, "Industry"
+: "Industry"
 
 , "Contact"
 : "Contact"
 
-, "Industry"
-: "Industry"
-
-, "List"
-: "List"
-
-, "Relation"
-: "Relation"
+, "Addressbook"
+: "Addressbook"
 
 , "Structure"
 : "Structure"
 
+, "Contact Personal Grant"
+: "Contact Personal Grant"
+
+, "List Personal Grant"
+: "List Personal Grant"
+
+, "List"
+: "List"
+
 , "Email Address"
 : "Email Address"
 
 , "List Function"
 : "List Function"
 
+, "Relation"
+: "Relation"
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
