@@ -5,232 +5,43 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Addressbook **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:12+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ru\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Business Contact Data"
-: "Деловые данные контактов"
+, "Map"
+: "Карта"
 
-, "Organisation / Unit"
-: "Организация / Отделение"
+, "Preferred Address"
+: "Предпочтительный адрес"
 
-, "Business Address"
-: "Рабочий адрес"
+, "Personal Information"
+: "Личная  информация"
 
-, "Email"
-: "Электронная почта"
+, "Salutation"
+: "Приветствие"
 
-, "Telephone Work"
-: "Телефон (рабочий)"
+, "Title"
+: "Название"
 
-, "Telephone Cellphone"
-: "Телефон (мобильный)"
-
-, "Telephone Car"
-: "Телефон (автомобильный)"
-
-, "Telephone Fax"
-: "Телефон (факс)"
-
-, "Telephone Page"
-: "Пейджер"
-
-, "URL"
-: "URL"
-
-, "Role"
-: "Роль"
-
-, "Room"
-: "Помещение"
-
-, "Assistant"
-: "Помощник"
-
-, "Assistant Telephone"
-: "Телефон помощника"
-
-, "Private Contact Data"
-: "Личные данные контактов"
-
-, "Private Address"
-: "Личный адрес"
-
-, "Email Home"
-: "Электронная почта"
-
-, "Telephone Home"
-: "Телефон"
-
-, "Telephone Cellphone Private"
-: "Личный сотовый телефон"
-
-, "Telephone Fax Home"
-: "Факс (домашний)"
-
-, "URL Home"
-: "Домашний URL"
-
-, "Other Data"
-: "Другие данные"
-
-, "Birthday"
-: "Дата рождения"
-
-, "Job Title"
-: "Профессия"
-
-, "Excel all data"
-: "Экспорт данных в Excel"
-
-, "CSV all data"
-: "Экспорт данных в формате CSV"
-
-, "Word details"
-: "Экспорт подробностей в Word"
-
-, "Excel overview"
-: "Экспорт сводки в Excel"
-
-, "OpenDocument all data"
-: "Экспорт всех данных в OpenDocument"
-
-, "PDF details"
-: "Экспорт в PDF"
-
-, "Word letter"
-: "Экспорт письма в Word"
-
-, "Excel phone list"
-: "Экспорт списка телефонов в Excel"
-
-, "Excel phone list grouped by company"
-: "Экспорт в Excel списка телефонов сгруппированного по компаниям"
-
-, "Relations"
+, "Short Name"
 : ""
 
-, "List, Lists"
-: [
-  "Список"
- ,"Списки"
- ,"Списки"
- ,"Списки"
+, "First Name"
+: "Имя"
 
-]
-, "Percent"
-: "Процент"
+, "Middle Name"
+: "Второе имя"
 
-, "Description"
-: "Описание"
+, "Last Name"
+: "Фамилия"
 
-, "Members"
-: "Участники"
+, "Company"
+: "Фирма"
 
-, "Type"
-: "Тип"
+, "Unit"
+: "Отделение"
 
-, "List type"
-: "Список типов"
-
-, "Addressbook, Addressbooks"
-: [
-  "Адресная книга"
- ,"Адресные книги"
- ,"Адресные книги"
- ,"Адресные книги"
-
-]
-, "Contact, Contacts"
-: [
-  "Контакт"
- ,"Контакта"
- ,"Контактов"
- ,"Контактов"
-
-]
-, "Show Disabled"
-: ""
-
-, "Path"
-: ""
-
-, "List Member"
-: ""
-
-, "List Role Member"
-: ""
-
-, "Telephone"
-: ""
-
-, "Telephone Normalized"
-: ""
-
-, "Country"
-: "Страна"
-
-, "City"
-: "Город"
-
-, "Postalcode"
-: "Почтовый индекс"
-
-, "Region"
-: "Область"
-
-, "Street"
-: "Улица"
-
-, "Street 2"
-: "Следующая улица"
-
-, "Longitude"
-: ""
-
-, "Latitude"
-: ""
-
-, "Country (private)"
-: "Страна (личная)"
-
-, "City (private)"
-: "Город (личный)"
-
-, "Postalcode (private)"
-: "Почтовый индекс (личный)"
-
-, "Region (private)"
-: "Область (личная)"
-
-, "Street (private)"
-: "Улица (личная)"
-
-, "Street 2 (private)"
-: ""
-
-, "Longitude (private)"
-: ""
-
-, "Latitude (private)"
-: ""
-
-, "Assistent"
-: ""
-
-, "Calendar URI"
-: ""
-
-, "Email (private)"
-: "Электронная почта (личная)"
-
-, "Free/Busy URI"
-: ""
-
-, "Geo"
-: "Координаты"
-
-, "Groups"
-: "Группы"
+, "Display Name"
+: "Отображать как"
 
 , "Industry, Industries"
 : [
@@ -240,104 +51,95 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
  ,""
 
 ]
-, "Note"
-: "Заметка"
+, "Job Title"
+: "Профессия"
 
-, "Last Name"
-: "Фамилия"
-
-, "Display Name"
-: "Отображать как"
-
-, "Full Name"
-: "Полное имя"
-
-, "First Name"
-: "Имя"
-
-, "Middle Name"
-: "Второе имя"
-
-, "Title"
-: "Название"
-
-, "Suffix"
-: "Дополнение имени"
-
-, "Company"
-: "Фирма"
-
-, "Unit"
-: "Отделение"
-
-, "Paths"
+, "Birthday (private)"
 : ""
 
-, "Preferred Address"
-: "Предпочтительный адрес"
-
-, "Job Role"
-: "Рабочая роль"
-
-, "Salutation"
-: "Приветствие"
-
-, "syncBackendIds"
-: ""
-
-, "Car phone"
-: "Автомобильный телефон"
-
-, "Mobile"
-: "Мобильный телефон"
-
-, "Mobile (private)"
-: "Мобильный (личный)"
-
-, "Fax"
-: "Факс"
-
-, "Fax (private)"
-: "Факс (личный)"
-
-, "Phone (private)"
-: "Телефон (личный)"
-
-, "Pager"
-: "Пейджер"
+, "Contact Information"
+: "Информация контакта"
 
 , "Phone"
 : "Телефон"
 
-, "Timezone"
-: "Часовой пояс"
+, "Mobile"
+: "Мобильный телефон"
+
+, "Fax"
+: "Факс"
+
+, "Phone (private)"
+: "Телефон (личный)"
+
+, "Mobile (private)"
+: "Мобильный (личный)"
+
+, "Fax (private)"
+: "Факс (личный)"
+
+, "E-Mail"
+: "Электронная почта"
+
+, "E-Mail (private)"
+: "Электронная почта (личная)"
 
 , "Web"
 : "Интернет"
 
-, "URL (private)"
-: "Личный веб-сайт"
+, "Company Address"
+: "Адрес фирмы"
 
-, "Label"
-: ""
+, "Street"
+: "Улица"
 
-, "Lists"
-: "Списки"
+, "Street 2"
+: "Следующая улица"
 
-, "Select list"
-: "Выберите список"
+, "Region"
+: "Область"
 
-, "Select record to see its details"
-: ""
+, "Postal Code"
+: "Почтовый индекс"
 
-, "This module visualises hierarchically depended relations between records of different types."
-: ""
+, "City"
+: "Город"
 
-, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
-: ""
+, "Country"
+: "Страна"
 
-, "Loading Structure data..."
-: ""
+, "Private Address"
+: "Личный адрес"
+
+, "Description"
+: "Описание"
+
+, "Enter description"
+: "Введите описание"
+
+, "Groups"
+: "Группы"
+
+, "Parse address"
+: "Синтаксический анализ адреса"
+
+, "Print contact"
+: "Печать контакта"
+
+, "Paste address"
+: "Вставит адрес"
+
+, "Please paste an address or a URI to a vcard that should be parsed:"
+: "Пожалуйста, укажите адрес или URI для vcard, который можно разобрать:"
+
+, "Failed to parse address!"
+: "Невозможно разобрать адрес"
+
+, "The address could not be read."
+: "Адрес нечитаем"
+
+, "End token mode"
+: "Окончание действия символьного отпечатка"
 
 , "Customfields"
 : "Настраиваемые поля"
@@ -345,15 +147,64 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Related to"
 : "Относится к"
 
-, "Contact Information"
-: "Информация контакта"
+, "Mailing List"
+: ""
 
-, "Company Address"
-: "Адрес фирмы"
+, "This group is a mailing list"
+: ""
+
+, "Keep copy of group mails"
+: ""
+
+, "Forward external mails"
+: ""
+
+, "Only forward member mails"
+: ""
+
+, "Only forward to system email accounts"
+: ""
+
+, "Search for system groups ..."
+: "Поиск системных групп..."
+
+, "Search for groups ..."
+: "Поиск групп..."
+
+, "Contact, Contacts"
+: [
+  "Контакт"
+ ,"Контакта"
+ ,"Контактов"
+ ,"Контактов"
+
+]
+, "Members"
+: "Участники"
+
+, "Search for members ..."
+: ""
+
+, "List Roles"
+: "Список ролей"
+
+, "Remove Member"
+: "Удалить члена"
+
+, "CardDAV URL"
+: "CardDAV URL"
 
 , "New Contact"
 : "Новый контакт"
 
+, "Addressbook, Addressbooks"
+: [
+  "Адресная книга"
+ ,"Адресные книги"
+ ,"Адресные книги"
+ ,"Адресные книги"
+
+]
 , "ID"
 : "ID"
 
@@ -371,35 +222,54 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Resources"
 : "Ресурсы"
 
-, "Import contacts"
-: "Импорт контактов"
-
-, "Contact of a user account"
-: "Контакт пользователя"
-
-, "No name"
-: "Без имени"
-
-, "Business"
-: ""
-
 , "Private"
 : "Личное"
 
-, "Not set"
-: "Не установлено"
-
-, "Contact Image"
+, "The grant to access contacts private information"
 : ""
 
-, "Attachments"
+, "Contact Personal Grant, Contact Personal Grants"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "List Personal Grant, List Personal Grants"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "List Information"
+: "Информация о списке"
+
+, "List type"
+: "Список типов"
+
+, "System accounts only"
 : ""
 
-, "Tags"
-: "Тэги"
+, "{0} must be given"
+: "{0} должен быть задан"
 
-, "List Roles"
-: "Список ролей"
+, "List Functions"
+: ""
+
+, "Suffix"
+: "Дополнение имени"
+
+, "Birthday"
+: "Дата рождения"
+
+, "Job Role"
+: "Рабочая роль"
+
+, "Room"
+: "Помещение"
 
 , "Street (Company Address)"
 : "Улица (рабочий адрес)"
@@ -449,12 +319,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Private Communication"
 : "Частное сообщение"
 
-, "E-Mail"
-: "Электронная почта"
-
-, "E-Mail (private)"
-: "Электронная почта (личная)"
-
 , "Web (private)"
 : "Сайт (личный)"
 
@@ -470,8 +334,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Quick Search"
 : "Быстрый поиск"
 
-, "Postal Code"
-: "Почтовый индекс"
+, "Type"
+: "Тип"
 
 , "Last Modified Time"
 : "Время последнего изменения"
@@ -485,6 +349,17 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Created By"
 : "Создано "
 
+, "List, Lists"
+: [
+  "Список"
+ ,"Списки"
+ ,"Списки"
+ ,"Списки"
+
+]
+, "Lists"
+: "Списки"
+
 , "Email Address, Email Addresses"
 : [
   "Адрес электронной почты"
@@ -507,7 +382,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
  ,""
 
 ]
-, "List Functions"
+, "GENDER_List Function"
 : ""
 
 , "Industries"
@@ -516,20 +391,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Structures"
 : ""
 
-, "List Information"
-: "Информация о списке"
+, "Business"
+: ""
 
-, "Enter description"
-: "Введите описание"
+, "Import contacts"
+: "Импорт контактов"
 
-, "{0} must be given"
-: "{0} должен быть задан"
+, "Contact of a user account"
+: "Контакт пользователя"
 
-, "Member of List"
-: "Член Списка"
+, "No name"
+: "Без имени"
 
-, "Map"
-: "Карта"
+, "Not set"
+: "Не установлено"
+
+, "Contact Image"
+: ""
+
+, "Attachments"
+: ""
+
+, "Tags"
+: "Тэги"
+
+, "Full Name"
+: "Полное имя"
+
+, "Postalcode"
+: "Почтовый индекс"
+
+, "Street (private)"
+: "Улица (личная)"
+
+, "City (private)"
+: "Город (личный)"
+
+, "Region (private)"
+: "Область (личная)"
+
+, "Postalcode (private)"
+: "Почтовый индекс (личный)"
+
+, "Country (private)"
+: "Страна (личная)"
+
+, "Email"
+: "Электронная почта"
+
+, "Car phone"
+: "Автомобильный телефон"
+
+, "Pager"
+: "Пейджер"
+
+, "Email (private)"
+: "Электронная почта (личная)"
+
+, "URL (private)"
+: "Личный веб-сайт"
+
+, "Note"
+: "Заметка"
+
+, "Timezone"
+: "Часовой пояс"
+
+, "Geo"
+: "Координаты"
+
+, "Select list"
+: "Выберите список"
+
+, "Search for users ..."
+: "Поиск пользователей..."
+
+, "Search for Contacts ..."
+: "Поиск контактов..."
 
 , "Company address"
 : "Рабочий адрес"
@@ -537,44 +475,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Private address"
 : "Личный адрес"
 
-, "CardDAV URL"
-: "CardDAV URL"
-
-, "Search for system groups ..."
-: "Поиск системных групп..."
-
-, "Search for groups ..."
-: "Поиск групп..."
-
-, "Personal Information"
-: "Личная  информация"
-
-, "Parse address"
-: "Синтаксический анализ адреса"
-
-, "Print contact"
-: "Печать контакта"
-
-, "Paste address"
-: "Вставит адрес"
-
-, "Please paste an address or a URI to a vcard that should be parsed:"
-: "Пожалуйста, укажите адрес или URI для vcard, который можно разобрать:"
-
-, "Failed to parse address!"
-: "Невозможно разобрать адрес"
-
-, "The address could not be read."
-: "Адрес нечитаем"
-
-, "End token mode"
-: "Окончание действия символьного отпечатка"
-
-, "Remove Member"
-: "Удалить члена"
-
-, "Emails"
-: "Почтовые адреса"
+, "Member E-Mails"
+: ""
 
 , "System Group"
 : "Системная группа"
@@ -582,11 +484,17 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Group"
 : "Группа"
 
-, "Search for users ..."
-: "Поиск пользователей..."
+, "Select record to see its details"
+: ""
 
-, "Search for Contacts ..."
-: "Поиск контактов..."
+, "This module visualises hierarchically depended relations between records of different types."
+: ""
+
+, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
+: ""
+
+, "Loading Structure data..."
+: ""
 
 , "All contacts"
 : "Все контакты"
@@ -618,12 +526,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "default"
 : "по умолчанию"
 
-, "All Contacts"
-: "Все контакты"
-
-, "This contact has been automatically added by the system as an event attender"
-: "Этот контакт был автоматически добавлен системой"
-
 , "Enabled Features"
 : "Активные возможности"
 
@@ -648,6 +550,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Add Industry field to Adressbook"
 : "Добавить поле \"Отрасль промышленности\" в Адресную книгу"
 
+, "Mailinglists"
+: ""
+
+, "Make group and lists to mailinglists"
+: ""
+
+, "Addressbook Short Names"
+: ""
+
+, "Add Short Name field to Adressbook"
+: ""
+
 , "Manage resources in Addressbook"
 : "Управление ресурсами в адресной книге"
 
@@ -660,6 +574,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Visualize relations of records"
 : ""
 
+, "Contact (id) representing this installation"
+: ""
+
 , "Contact duplicate check fields"
 : "Поля для проверки дублирования контактов"
 
@@ -705,9 +622,147 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Use Nominatim during contact import"
 : "Использовать Nominatim при импорте контактов"
 
+, "Site Filter"
+: ""
+
+, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
+: ""
+
 , "Sync Backends"
 : "Модули синхронизации"
 
+, "Default telephone country code"
+: ""
+
+, "%s's personal addressbook"
+: "%s личная адресная книга"
+
+, "Business Contact Data"
+: "Деловые данные контактов"
+
+, "Organisation / Unit"
+: "Организация / Отделение"
+
+, "Business Address"
+: "Рабочий адрес"
+
+, "Telephone Work"
+: "Телефон (рабочий)"
+
+, "Telephone Cellphone"
+: "Телефон (мобильный)"
+
+, "Telephone Car"
+: "Телефон (автомобильный)"
+
+, "Telephone Fax"
+: "Телефон (факс)"
+
+, "Telephone Page"
+: "Пейджер"
+
+, "URL"
+: "URL"
+
+, "Role"
+: "Роль"
+
+, "Assistant"
+: "Помощник"
+
+, "Assistant Telephone"
+: "Телефон помощника"
+
+, "Private Contact Data"
+: "Личные данные контактов"
+
+, "Email Home"
+: "Электронная почта"
+
+, "Telephone Home"
+: "Телефон"
+
+, "Telephone Cellphone Private"
+: "Личный сотовый телефон"
+
+, "Telephone Fax Home"
+: "Факс (домашний)"
+
+, "URL Home"
+: "Домашний URL"
+
+, "Other Data"
+: "Другие данные"
+
+, "OpenDocument all data"
+: "Экспорт всех данных в OpenDocument"
+
+, "Excel phone list"
+: "Экспорт списка телефонов в Excel"
+
+, "Excel phone list grouped by company"
+: "Экспорт в Excel списка телефонов сгруппированного по компаниям"
+
+, "Word details"
+: "Экспорт подробностей в Word"
+
+, "Excel overview"
+: "Экспорт сводки в Excel"
+
+, "Word letter"
+: "Экспорт письма в Word"
+
+, "PDF details"
+: "Экспорт в PDF"
+
+, "Excel all data"
+: "Экспорт данных в Excel"
+
+, "VCard Report"
+: ""
+
+, "Export multiple addressbooks to vcf files"
+: ""
+
+, "Relations"
+: ""
+
+, "CSV all data"
+: "Экспорт данных в формате CSV"
+
+, "VCard/VCF"
+: ""
+
+, "Export contact data into vcf file"
+: ""
+
+, "Addressbooks to export"
+: ""
+
+, "Export target"
+: ""
+
+, "Import CSV formated contacts from Exchange / Outlook address book"
+: "Импорт контактов CSV из адресной книги Exchange/Outlook"
+
+, "Contact CSV import from Outlook address book"
+: "Импорт контактов CSV из адресной книги Outlook"
+
+, "Contact CSV import from mac address book"
+: "Импорт контактов CSV из адресной книги mac"
+
+, "Import CSV formated contacts from Outlook 2007 German address book"
+: "Импорт контактов CSV из адресной книги немецкой версии Outlook 2007"
+
+, "CSV Outlook 2007 German"
+: "CSV Outlook 2007 (немецкий)"
+
+, "Import CSV formated contacts from Outlook 2010 German address book"
+: ""
+
+, "CSV Outlook 2010 German"
+: ""
+
 , "Import vCard formated contacts"
 : "Импорт контактов в формате vCard"
 
@@ -732,27 +787,114 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
 : "Контакты импортированы ###CURRENTDATE### в ###CURRENTTIME### ###USERFULLNAME###"
 
-, "Import CSV formated contacts from Outlook 2007 German address book"
-: "Импорт контактов CSV из адресной книги немецкой версии Outlook 2007"
-
-, "CSV Outlook 2007 German"
-: "CSV Outlook 2007 (немецкий)"
-
-, "Import CSV formated contacts from Exchange / Outlook address book"
-: "Импорт контактов CSV из адресной книги Exchange/Outlook"
-
-, "Contact CSV import from Outlook address book"
-: "Импорт контактов CSV из адресной книги Outlook"
-
-, "Contact CSV import from mac address book"
-: "Импорт контактов CSV из адресной книги mac"
-
 , "Import CSV formated contacts from Google address book"
 : "Импорт контактов CSV из адресной книги Google"
 
 , "Contact import from Google address book"
 : "Импорт контактов CSV из адресной книги Google"
 
+, "GENDER_List"
+: ""
+
+, "Name/Email"
+: ""
+
+, "GENDER_Contact"
+: ""
+
+, "Show Disabled"
+: ""
+
+, "Path"
+: ""
+
+, "List Member"
+: ""
+
+, "List Role Member"
+: ""
+
+, "Telephone"
+: ""
+
+, "Telephone Normalized"
+: ""
+
+, "Longitude"
+: ""
+
+, "Latitude"
+: ""
+
+, "Street 2 (private)"
+: ""
+
+, "Longitude (private)"
+: ""
+
+, "Latitude (private)"
+: ""
+
+, "Assistent"
+: ""
+
+, "Calendar URI"
+: ""
+
+, "Free/Busy URI"
+: ""
+
+, "Paths"
+: ""
+
+, "syncBackendIds"
+: ""
+
+, "Label"
+: ""
+
+, "It is not allowed to add non-account contacts to this list"
+: ""
+
+, "E-Mail address is already given. Please choose another one."
+: ""
+
+, "It is not allowed to delete a contact linked to an user account!"
+: ""
+
+, "This Short Name already exists. How about {0}?"
+: ""
+
+, "Internal Contacts"
+: "Внутренние контакты"
+
+, "All contacts I have read grants for"
+: "Все контакты, для которых у меня есть право чтения"
+
+, "My company"
+: "Моя компания"
+
+, "All coworkers in my company"
+: "Все коллеги в моей компании"
+
+, "My contacts"
+: "Мои контакты"
+
+, "All contacts in my Addressbooks"
+: "Все контакты в моих адресных книгах"
+
+, "Last modified by me"
+: "Мои последние изменения"
+
+, "All contacts that I have last modified"
+: "Все контакты, которые последним редактировал я"
+
+, "All Contacts"
+: "Все контакты"
+
+, "This contact has been automatically added by the system as an event attender"
+: "Этот контакт был автоматически добавлен системой"
+
 , "manage shared addressbooks"
 : "управлять общими адресными книгами"
 
@@ -777,6 +919,54 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "View, create, delete or update list functions in CoreData application"
 : "Просмотр, создание, удаление и обновление функций списка в основном приложении"
 
+, "Manage list email options"
+: ""
+
+, "Manage list email options like mailing lists"
+: ""
+
+, "Account"
+: ""
+
+, "Exporttime"
+: ""
+
+, "28"
+: ""
+
+, "20"
+: ""
+
+, "00877546"
+: ""
+
+, "en-GB"
+: ""
+
+, "00813B4E"
+: ""
+
+, "Gruppenrollen"
+: ""
+
+, "00DA3FCD"
+: ""
+
+, "00997199"
+: ""
+
+, "0009326B"
+: ""
+
+, "008C27A5"
+: ""
+
+, "00C96397"
+: ""
+
+, "00046462"
+: ""
+
 , "Relation, Relations"
 : [
   ""
@@ -784,49 +974,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
  ,""
  ,""
 
+
 ]
-, "%s's personal addressbook"
-: "%s личная адресная книга"
-
-, "All contacts I have read grants for"
-: "Все контакты, для которых у меня есть право чтения"
-
-, "My company"
-: "Моя компания"
-
-, "All coworkers in my company"
-: "Все коллеги в моей компании"
-
-, "My contacts"
-: "Мои контакты"
-
-, "All contacts in my Addressbooks"
-: "Все контакты в моих адресных книгах"
-
-, "Last modified by me"
-: "Мои последние изменения"
-
-, "All contacts that I have last modified"
-: "Все контакты, которые последним редактировал я"
-
-, "Internal Contacts"
-: "Внутренние контакты"
-
-, "List"
-: "Список"
-
-, "Addressbook"
-: "Адресная книга"
+, "Industry"
+: ""
 
 , "Contact"
 : "Контакт"
 
-, "Industry"
-: ""
+, "Addressbook"
+: "Адресная книга"
 
 , "Structure"
 : ""
 
+, "Contact Personal Grant"
+: ""
+
+, "List Personal Grant"
+: ""
+
+, "List"
+: "Список"
+
 , "Email Address"
 : "Адрес электронной почты"
 
