@@ -5,252 +5,34 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Addressbook **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: th\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Business Contact Data"
-: "ข้อมูลการติดต่อทางธุรกิจ"
+, "Map"
+: "แผนที่"
 
-, "Organisation / Unit"
-: "องค์กร / หน่วย"
-
-, "Business Address"
-: "ที่อยู่ธุรกิจ"
-
-, "Email"
-: "อีเมล"
-
-, "Telephone Work"
-: "โทรศัพท์ ที่ทำงาน"
-
-, "Telephone Cellphone"
-: "โทรศัพท์ เคลื่อนที่"
-
-, "Telephone Car"
-: "โทรศัพท์ ในรถ"
-
-, "Telephone Fax"
-: "โทรศัพท์ โทรสาร"
-
-, "Telephone Page"
-: "โทรศัพท์ หน้า"
-
-, "URL"
-: "ที่อยู่ของไฟล์หรือเวบไซด์บนอินเตอร์เนต"
-
-, "Role"
-: "หน้าที่"
-
-, "Room"
-: "ห้อง"
-
-, "Assistant"
-: "ผู้ช่วย"
-
-, "Assistant Telephone"
-: "โทรศัพท์ของผู้ช่วย"
-
-, "Private Contact Data"
-: "ข้อมูลการติดต่อส่วนบุคคล"
-
-, "Private Address"
-: "ที่อยู่ส่วนบุคคล"
-
-, "Email Home"
-: "อีเมล ส่วนตัว"
-
-, "Telephone Home"
-: "โทรศัพท์ ที่บ้าน"
-
-, "Telephone Cellphone Private"
-: "โทรศัพท์ เคลื่อนที่ ส่วนบุคคล"
-
-, "Telephone Fax Home"
-: "โทรศัพท์ โทรสารที่บ้าน"
-
-, "URL Home"
-: " URL บ้าน"
-
-, "Other Data"
-: "ข้อมูลอื่น"
-
-, "Birthday"
-: "วันเกิด"
-
-, "Job Title"
-: "ตำแหน่งงาน"
-
-, "Excel all data"
+, "Preferred Address"
 : ""
 
-, "CSV all data"
+, "Personal Information"
+: "ข้อมุลส่วนบุคคล"
+
+, "Salutation"
+: "คำขึ้นต้น"
+
+, "Title"
+: "คำนำหน้าชื่อ"
+
+, "Short Name"
 : ""
 
-, "Word details"
-: ""
-
-, "Excel overview"
-: ""
-
-, "OpenDocument all data"
-: ""
-
-, "PDF details"
-: ""
-
-, "Word letter"
-: ""
-
-, "Excel phone list"
-: ""
-
-, "Excel phone list grouped by company"
-: ""
-
-, "Relations"
-: ""
-
-, "List, Lists"
-: [
-  "รายชื่อ"
-
-]
-, "Percent"
-: ""
-
-, "Description"
-: "การอธิบาย"
-
-, "Members"
-: ""
-
-, "Type"
-: "ประเภท"
-
-, "List type"
-: ""
-
-, "Addressbook, Addressbooks"
-: [
-  "สมุดรายชื่อ"
-
-]
-, "Contact, Contacts"
-: [
-  "การติดต่อ"
-
-]
-, "Show Disabled"
-: ""
-
-, "Path"
-: ""
-
-, "List Member"
-: ""
-
-, "List Role Member"
-: ""
-
-, "Telephone"
-: ""
-
-, "Telephone Normalized"
-: ""
-
-, "Country"
-: "ประเทศ"
-
-, "City"
-: "เมือง"
-
-, "Postalcode"
-: "รหัสไปรษณีย์"
-
-, "Region"
-: "เขต"
-
-, "Street"
-: "ถนน"
-
-, "Street 2"
-: "ถนน 2"
-
-, "Longitude"
-: ""
-
-, "Latitude"
-: ""
-
-, "Country (private)"
-: "ประเทศ (ส่วนตัว)"
-
-, "City (private)"
-: "จังหวัด (ส่วนตัว)"
-
-, "Postalcode (private)"
-: "รหัสไปรษณีย์ (ส่วนตัว)"
-
-, "Region (private)"
-: "เขต (ส่วนตัว)"
-
-, "Street (private)"
-: "ถนน (ส่วนตัว)"
-
-, "Street 2 (private)"
-: ""
-
-, "Longitude (private)"
-: ""
-
-, "Latitude (private)"
-: ""
-
-, "Assistent"
-: ""
-
-, "Calendar URI"
-: ""
-
-, "Email (private)"
-: " อีเมล (ส่วนตัว)"
-
-, "Free/Busy URI"
-: ""
-
-, "Geo"
-: "ภูมิศาสตร์"
-
-, "Groups"
-: ""
-
-, "Industry, Industries"
-: [
-  ""
-
-]
-, "Note"
-: "บันทึก"
-
-, "Last Name"
-: "นามสกุล"
-
-, "Display Name"
-: "ชื่อที่ใช้"
-
-, "Full Name"
-: "ชื่อเต็ม"
-
 , "First Name"
 : "ชื่อตัว"
 
 , "Middle Name"
 : "ชื่อกลาง"
 
-, "Title"
-: "คำนำหน้าชื่อ"
-
-, "Suffix"
-: "คำลงท้ายชื่อ"
+, "Last Name"
+: "นามสกุล"
 
 , "Company"
 : "บริษัท"
@@ -258,74 +40,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Unit"
 : "หน่วย/ แผนก"
 
-, "Paths"
+, "Display Name"
+: "ชื่อที่ใช้"
+
+, "Industry, Industries"
+: [
+  ""
+
+]
+, "Job Title"
+: "ตำแหน่งงาน"
+
+, "Birthday (private)"
 : ""
 
-, "Preferred Address"
-: ""
-
-, "Job Role"
-: "หน้าที่งาน"
-
-, "Salutation"
-: "คำขึ้นต้น"
-
-, "syncBackendIds"
-: ""
-
-, "Car phone"
-: "โทรศัพท์ในรถ"
-
-, "Mobile"
-: "โทรศัพท์เคลื่อนที่"
-
-, "Mobile (private)"
-: "โทรศัพท์เคลื่อนที่ (ส่วนตัว)"
-
-, "Fax"
-: "โทรสาร"
-
-, "Fax (private)"
-: "โทรสาร (ส่วนตัว)"
-
-, "Phone (private)"
-: "โทรศัพท์ (ส่วนตัว)"
-
-, "Pager"
-: "เพจเจอร์"
+, "Contact Information"
+: "ข้อมูลที่ใช้ในการติดต่อ"
 
 , "Phone"
 : "โทรศัพท์"
 
-, "Timezone"
-: "เส้นแบ่งเวลา"
+, "Mobile"
+: "โทรศัพท์เคลื่อนที่"
+
+, "Fax"
+: "โทรสาร"
+
+, "Phone (private)"
+: "โทรศัพท์ (ส่วนตัว)"
+
+, "Mobile (private)"
+: "โทรศัพท์เคลื่อนที่ (ส่วนตัว)"
+
+, "Fax (private)"
+: "โทรสาร (ส่วนตัว)"
+
+, "E-Mail"
+: "อีเมล"
+
+, "E-Mail (private)"
+: " อีเมล (ส่วนตัว)"
 
 , "Web"
 : "เวบไซด์"
 
-, "URL (private)"
-: "รหัสสืบค้นข้อมูลทางอินเตอร์เนต (ส่วนตัว)"
+, "Company Address"
+: "ที่อยู่ของบริษัท"
 
-, "Label"
+, "Street"
+: "ถนน"
+
+, "Street 2"
+: "ถนน 2"
+
+, "Region"
+: "เขต"
+
+, "Postal Code"
+: "รหัสไปรษณีย์"
+
+, "City"
+: "เมือง"
+
+, "Country"
+: "ประเทศ"
+
+, "Private Address"
+: "ที่อยู่ส่วนบุคคล"
+
+, "Description"
+: "การอธิบาย"
+
+, "Enter description"
+: "ใส่ คำอธิบาย"
+
+, "Groups"
 : ""
 
-, "Lists"
-: "รายชื่อ"
+, "Parse address"
+: "วิเคราะห์ ที่อยู่"
 
-, "Select list"
+, "Print contact"
 : ""
 
-, "Select record to see its details"
+, "Paste address"
+: "ใส่ ที่อยู่"
+
+, "Please paste an address or a URI to a vcard that should be parsed:"
 : ""
 
-, "This module visualises hierarchically depended relations between records of different types."
+, "Failed to parse address!"
 : ""
 
-, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
+, "The address could not be read."
 : ""
 
-, "Loading Structure data..."
-: ""
+, "End token mode"
+: "จบโหมดสัญลักษณ์"
 
 , "Customfields"
 : ""
@@ -333,15 +144,58 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Related to"
 : ""
 
-, "Contact Information"
-: "ข้อมูลที่ใช้ในการติดต่อ"
+, "Mailing List"
+: ""
 
-, "Company Address"
-: "ที่อยู่ของบริษัท"
+, "This group is a mailing list"
+: ""
+
+, "Keep copy of group mails"
+: ""
+
+, "Forward external mails"
+: ""
+
+, "Only forward member mails"
+: ""
+
+, "Only forward to system email accounts"
+: ""
+
+, "Search for system groups ..."
+: ""
+
+, "Search for groups ..."
+: ""
+
+, "Contact, Contacts"
+: [
+  "การติดต่อ"
+
+]
+, "Members"
+: ""
+
+, "Search for members ..."
+: ""
+
+, "List Roles"
+: ""
+
+, "Remove Member"
+: ""
+
+, "CardDAV URL"
+: "CalDAV URL"
 
 , "New Contact"
 : "การติดต่อใหม่"
 
+, "Addressbook, Addressbooks"
+: [
+  "สมุดรายชื่อ"
+
+]
 , "ID"
 : ""
 
@@ -356,36 +210,49 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Resources"
 : ""
 
-, "Import contacts"
-: "นำเข้า การติดต่อ"
-
-, "Contact of a user account"
-: "การติดต่อของ บัญชี ผู้ใช้"
-
-, "No name"
-: ""
-
-, "Business"
-: ""
-
 , "Private"
 : "ส่วนตัว"
 
-, "Not set"
+, "The grant to access contacts private information"
 : ""
 
-, "Contact Image"
+, "Contact Personal Grant, Contact Personal Grants"
+: [
+  ""
+
+]
+, "List Personal Grant, List Personal Grants"
+: [
+  ""
+
+]
+, "List Information"
 : ""
 
-, "Attachments"
+, "List type"
 : ""
 
-, "Tags"
-: "ป้ายกำกับ"
-
-, "List Roles"
+, "System accounts only"
 : ""
 
+, "{0} must be given"
+: ""
+
+, "List Functions"
+: ""
+
+, "Suffix"
+: "คำลงท้ายชื่อ"
+
+, "Birthday"
+: "วันเกิด"
+
+, "Job Role"
+: "หน้าที่งาน"
+
+, "Room"
+: "ห้อง"
+
 , "Street (Company Address)"
 : "ถนน (ที่อยู่ของบริษัท)"
 
@@ -434,12 +301,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Private Communication"
 : "การติดต่อสื่อสารส่วนบุคคล"
 
-, "E-Mail"
-: "อีเมล"
-
-, "E-Mail (private)"
-: " อีเมล (ส่วนตัว)"
-
 , "Web (private)"
 : "เวบไซด์  (ส่วนตัว)"
 
@@ -455,8 +316,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Quick Search"
 : "ค้นหาอย่างรวดเร็ว"
 
-, "Postal Code"
-: "รหัสไปรษณีย์"
+, "Type"
+: "ประเภท"
 
 , "Last Modified Time"
 : "เวลาที่ปรับปรุงครั้งล่าสุด"
@@ -470,6 +331,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Created By"
 : "สร้าง โดย"
 
+, "List, Lists"
+: [
+  "รายชื่อ"
+
+]
+, "Lists"
+: "รายชื่อ"
+
 , "Email Address, Email Addresses"
 : [
   ""
@@ -486,7 +355,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
   ""
 
 ]
-, "List Functions"
+, "GENDER_List Function"
 : ""
 
 , "Industries"
@@ -495,20 +364,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Structures"
 : ""
 
-, "List Information"
+, "Business"
 : ""
 
-, "Enter description"
-: "ใส่ คำอธิบาย"
+, "Import contacts"
+: "นำเข้า การติดต่อ"
 
-, "{0} must be given"
+, "Contact of a user account"
+: "การติดต่อของ บัญชี ผู้ใช้"
+
+, "No name"
 : ""
 
-, "Member of List"
-: "สมาชิกของรายชื่อ"
+, "Not set"
+: ""
 
-, "Map"
-: "แผนที่"
+, "Contact Image"
+: ""
+
+, "Attachments"
+: ""
+
+, "Tags"
+: "ป้ายกำกับ"
+
+, "Full Name"
+: "ชื่อเต็ม"
+
+, "Postalcode"
+: "รหัสไปรษณีย์"
+
+, "Street (private)"
+: "ถนน (ส่วนตัว)"
+
+, "City (private)"
+: "จังหวัด (ส่วนตัว)"
+
+, "Region (private)"
+: "เขต (ส่วนตัว)"
+
+, "Postalcode (private)"
+: "รหัสไปรษณีย์ (ส่วนตัว)"
+
+, "Country (private)"
+: "ประเทศ (ส่วนตัว)"
+
+, "Email"
+: "อีเมล"
+
+, "Car phone"
+: "โทรศัพท์ในรถ"
+
+, "Pager"
+: "เพจเจอร์"
+
+, "Email (private)"
+: " อีเมล (ส่วนตัว)"
+
+, "URL (private)"
+: "รหัสสืบค้นข้อมูลทางอินเตอร์เนต (ส่วนตัว)"
+
+, "Note"
+: "บันทึก"
+
+, "Timezone"
+: "เส้นแบ่งเวลา"
+
+, "Geo"
+: "ภูมิศาสตร์"
+
+, "Select list"
+: ""
+
+, "Search for users ..."
+: ""
+
+, "Search for Contacts ..."
+: ""
 
 , "Company address"
 : "ที่อยู่ของบริษัท"
@@ -516,43 +448,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Private address"
 : "ที่อยู่ส่วนบุคคล"
 
-, "CardDAV URL"
-: "CalDAV URL"
-
-, "Search for system groups ..."
-: ""
-
-, "Search for groups ..."
-: ""
-
-, "Personal Information"
-: "ข้อมุลส่วนบุคคล"
-
-, "Parse address"
-: "วิเคราะห์ ที่อยู่"
-
-, "Print contact"
-: ""
-
-, "Paste address"
-: "ใส่ ที่อยู่"
-
-, "Please paste an address or a URI to a vcard that should be parsed:"
-: ""
-
-, "Failed to parse address!"
-: ""
-
-, "The address could not be read."
-: ""
-
-, "End token mode"
-: "จบโหมดสัญลักษณ์"
-
-, "Remove Member"
-: ""
-
-, "Emails"
+, "Member E-Mails"
 : ""
 
 , "System Group"
@@ -561,10 +457,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Group"
 : ""
 
-, "Search for users ..."
+, "Select record to see its details"
 : ""
 
-, "Search for Contacts ..."
+, "This module visualises hierarchically depended relations between records of different types."
+: ""
+
+, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
+: ""
+
+, "Loading Structure data..."
 : ""
 
 , "All contacts"
@@ -597,12 +499,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "default"
 : "ค่าหลัก"
 
-, "All Contacts"
-: "การติดต่อทั้งหมด"
-
-, "This contact has been automatically added by the system as an event attender"
-: ""
-
 , "Enabled Features"
 : ""
 
@@ -627,6 +523,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Add Industry field to Adressbook"
 : ""
 
+, "Mailinglists"
+: ""
+
+, "Make group and lists to mailinglists"
+: ""
+
+, "Addressbook Short Names"
+: ""
+
+, "Add Short Name field to Adressbook"
+: ""
+
 , "Manage resources in Addressbook"
 : ""
 
@@ -639,6 +547,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Visualize relations of records"
 : ""
 
+, "Contact (id) representing this installation"
+: ""
+
 , "Contact duplicate check fields"
 : "การติดต่อซ้ำซ้อน ตรวจสอบที่กล่อง"
 
@@ -684,9 +595,147 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Use Nominatim during contact import"
 : ""
 
+, "Site Filter"
+: ""
+
+, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
+: ""
+
 , "Sync Backends"
 : ""
 
+, "Default telephone country code"
+: ""
+
+, "%s's personal addressbook"
+: "จำนวน %s ของสมุดรายชื่อส่วนบุคคล"
+
+, "Business Contact Data"
+: "ข้อมูลการติดต่อทางธุรกิจ"
+
+, "Organisation / Unit"
+: "องค์กร / หน่วย"
+
+, "Business Address"
+: "ที่อยู่ธุรกิจ"
+
+, "Telephone Work"
+: "โทรศัพท์ ที่ทำงาน"
+
+, "Telephone Cellphone"
+: "โทรศัพท์ เคลื่อนที่"
+
+, "Telephone Car"
+: "โทรศัพท์ ในรถ"
+
+, "Telephone Fax"
+: "โทรศัพท์ โทรสาร"
+
+, "Telephone Page"
+: "โทรศัพท์ หน้า"
+
+, "URL"
+: "ที่อยู่ของไฟล์หรือเวบไซด์บนอินเตอร์เนต"
+
+, "Role"
+: "หน้าที่"
+
+, "Assistant"
+: "ผู้ช่วย"
+
+, "Assistant Telephone"
+: "โทรศัพท์ของผู้ช่วย"
+
+, "Private Contact Data"
+: "ข้อมูลการติดต่อส่วนบุคคล"
+
+, "Email Home"
+: "อีเมล ส่วนตัว"
+
+, "Telephone Home"
+: "โทรศัพท์ ที่บ้าน"
+
+, "Telephone Cellphone Private"
+: "โทรศัพท์ เคลื่อนที่ ส่วนบุคคล"
+
+, "Telephone Fax Home"
+: "โทรศัพท์ โทรสารที่บ้าน"
+
+, "URL Home"
+: " URL บ้าน"
+
+, "Other Data"
+: "ข้อมูลอื่น"
+
+, "OpenDocument all data"
+: ""
+
+, "Excel phone list"
+: ""
+
+, "Excel phone list grouped by company"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel overview"
+: ""
+
+, "Word letter"
+: ""
+
+, "PDF details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "VCard Report"
+: ""
+
+, "Export multiple addressbooks to vcf files"
+: ""
+
+, "Relations"
+: ""
+
+, "CSV all data"
+: ""
+
+, "VCard/VCF"
+: ""
+
+, "Export contact data into vcf file"
+: ""
+
+, "Addressbooks to export"
+: ""
+
+, "Export target"
+: ""
+
+, "Import CSV formated contacts from Exchange / Outlook address book"
+: ""
+
+, "Contact CSV import from Outlook address book"
+: "นำเข้ารายชื่อติดต่อ CSV จากสมุดรายชื่อของโปรแกรม Outlook"
+
+, "Contact CSV import from mac address book"
+: "นำเข้ารายชื่อติดต่อ CSV จากสมุดรายชื่อของแมค"
+
+, "Import CSV formated contacts from Outlook 2007 German address book"
+: ""
+
+, "CSV Outlook 2007 German"
+: "CSV Outlook 2007 ภาษาเยอรมัน"
+
+, "Import CSV formated contacts from Outlook 2010 German address book"
+: ""
+
+, "CSV Outlook 2010 German"
+: ""
+
 , "Import vCard formated contacts"
 : ""
 
@@ -711,27 +760,114 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
 : "รายชื่อติดต่อถูกนำเข้าเมื่อ ###วันปัจจุบัน### ณ ###เวลาปัจจุบัน### โดย ###ชื่อเต็มของผู้ใช้###"
 
-, "Import CSV formated contacts from Outlook 2007 German address book"
-: ""
-
-, "CSV Outlook 2007 German"
-: "CSV Outlook 2007 ภาษาเยอรมัน"
-
-, "Import CSV formated contacts from Exchange / Outlook address book"
-: ""
-
-, "Contact CSV import from Outlook address book"
-: "นำเข้ารายชื่อติดต่อ CSV จากสมุดรายชื่อของโปรแกรม Outlook"
-
-, "Contact CSV import from mac address book"
-: "นำเข้ารายชื่อติดต่อ CSV จากสมุดรายชื่อของแมค"
-
 , "Import CSV formated contacts from Google address book"
 : ""
 
 , "Contact import from Google address book"
 : "รายชื่อติดต่อนำเข้ามาจากสมุดรายชื่อของกูเกิล"
 
+, "GENDER_List"
+: ""
+
+, "Name/Email"
+: ""
+
+, "GENDER_Contact"
+: ""
+
+, "Show Disabled"
+: ""
+
+, "Path"
+: ""
+
+, "List Member"
+: ""
+
+, "List Role Member"
+: ""
+
+, "Telephone"
+: ""
+
+, "Telephone Normalized"
+: ""
+
+, "Longitude"
+: ""
+
+, "Latitude"
+: ""
+
+, "Street 2 (private)"
+: ""
+
+, "Longitude (private)"
+: ""
+
+, "Latitude (private)"
+: ""
+
+, "Assistent"
+: ""
+
+, "Calendar URI"
+: ""
+
+, "Free/Busy URI"
+: ""
+
+, "Paths"
+: ""
+
+, "syncBackendIds"
+: ""
+
+, "Label"
+: ""
+
+, "It is not allowed to add non-account contacts to this list"
+: ""
+
+, "E-Mail address is already given. Please choose another one."
+: ""
+
+, "It is not allowed to delete a contact linked to an user account!"
+: ""
+
+, "This Short Name already exists. How about {0}?"
+: ""
+
+, "Internal Contacts"
+: "การติดต่อภายใน"
+
+, "All contacts I have read grants for"
+: "การติดต่อทั้งหมดที่ฉันได้อ่านแล้วอนุญาตสำหรับ"
+
+, "My company"
+: "บริษัทของฉัน"
+
+, "All coworkers in my company"
+: "ผู้ร่วมงานทั้งหมดในบริษัทของฉัน"
+
+, "My contacts"
+: "ข้อมูลการติดต่อของฉัน"
+
+, "All contacts in my Addressbooks"
+: "ข้อมูลการติดต่อทั้งหมดในสมุดที่อยู่ของฉัน"
+
+, "Last modified by me"
+: "ปรับปรุงครั้งล่าสุด โดยฉัน"
+
+, "All contacts that I have last modified"
+: "การติดต่อทั้งหมดที่ฉันได้ปรับปรุงครั้งล่าสุด"
+
+, "All Contacts"
+: "การติดต่อทั้งหมด"
+
+, "This contact has been automatically added by the system as an event attender"
+: ""
+
 , "manage shared addressbooks"
 : "จัดการ สมุดรายชื่อที่ใช้ในการติดต่อร่วมกัน"
 
@@ -756,53 +892,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "View, create, delete or update list functions in CoreData application"
 : ""
 
+, "Manage list email options"
+: ""
+
+, "Manage list email options like mailing lists"
+: ""
+
+, "Account"
+: ""
+
+, "Exporttime"
+: ""
+
+, "28"
+: ""
+
+, "20"
+: ""
+
+, "00877546"
+: ""
+
+, "en-GB"
+: ""
+
+, "00813B4E"
+: ""
+
+, "Gruppenrollen"
+: ""
+
+, "00DA3FCD"
+: ""
+
+, "00997199"
+: ""
+
+, "0009326B"
+: ""
+
+, "008C27A5"
+: ""
+
+, "00C96397"
+: ""
+
+, "00046462"
+: ""
+
 , "Relation, Relations"
 : [
   ""
 
+
 ]
-, "%s's personal addressbook"
-: "จำนวน %s ของสมุดรายชื่อส่วนบุคคล"
-
-, "All contacts I have read grants for"
-: "การติดต่อทั้งหมดที่ฉันได้อ่านแล้วอนุญาตสำหรับ"
-
-, "My company"
-: "บริษัทของฉัน"
-
-, "All coworkers in my company"
-: "ผู้ร่วมงานทั้งหมดในบริษัทของฉัน"
-
-, "My contacts"
-: "ข้อมูลการติดต่อของฉัน"
-
-, "All contacts in my Addressbooks"
-: "ข้อมูลการติดต่อทั้งหมดในสมุดที่อยู่ของฉัน"
-
-, "Last modified by me"
-: "ปรับปรุงครั้งล่าสุด โดยฉัน"
-
-, "All contacts that I have last modified"
-: "การติดต่อทั้งหมดที่ฉันได้ปรับปรุงครั้งล่าสุด"
-
-, "Internal Contacts"
-: "การติดต่อภายใน"
-
-, "List"
-: "รายชื่อ"
-
-, "Addressbook"
-: "สมุดรายชื่อ"
+, "Industry"
+: ""
 
 , "Contact"
 : "การติดต่อ"
 
-, "Industry"
-: ""
+, "Addressbook"
+: "สมุดรายชื่อ"
 
 , "Structure"
 : ""
 
+, "Contact Personal Grant"
+: ""
+
+, "List Personal Grant"
+: ""
+
+, "List"
+: "รายชื่อ"
+
 , "Email Address"
 : ""
 
