@@ -5,62 +5,260 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Application, Applications"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "User, Users"
+: [
+  "Uživatel"
+ ,"Uživatelé"
+ ,"Uživatelů"
+ ,"Uživatelů"
+
+]
+, "Groups"
+: "Skupiny"
+
+, "Roles"
+: "Role"
+
+, "Applications"
+: "Aplikace"
+
+, "Containers"
 : ""
 
-, "Disable Application"
+, "Shared Tags"
+: "Sdílené štítky"
+
+, "Customfields"
 : ""
 
-, "Settings"
+, "Computers"
+: "Počítače"
+
+, "Access Log, Access Logs"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Log"
 : ""
 
-, "{0} Settings"
-: "Nastavení {0}"
+, "Server Information"
+: "Informace o serveru"
 
-, "Search:"
-: "Hledat:"
+, "ActiveSync Devices"
+: "Zařízení ActiveSync"
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Administrátor"
+
+, "Refresh"
+: ""
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
+, "Default Addressbook for new contacts and groups"
 : ""
 
-, "Displaying application {0} - {1} of {2}"
-: "Zobrazuji aplikace {0} - {1} z {2}"
+, "Computer Name"
+: "Název počítače"
 
-, "No applications to display"
-: "Žádné aplikace ke zobrazení"
+, "Config, Configs"
+: [
+  ""
+ ,""
+ ,""
+ ,""
 
-, "Order"
-: "Pořadí"
+]
+, "Description"
+: "Popis"
 
 , "Name"
 : "Jméno"
 
-, "Status"
-: "Stav"
+, "Label"
+: ""
 
-, "Version"
-: "Verze"
+, "Value"
+: ""
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Název skupiny"
+
+, "Visibility"
+: "Viditelnost"
+
+, "Display in addressbook"
+: "Zobrazit v adresáři"
+
+, "Hide from addressbook"
+: "Nezobrazovat v adresáři"
+
+, "Saved in Addressbook"
+: ""
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Členové skupiny"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: ""
 
 , "Confirm"
 : "Potvrdit"
 
+, "Do you really want to delete the selected tags?"
+: "Opravdu chcete smazat vybrané štítky?"
+
+, "Deleting tag(s)..."
+: "Mažu štítek(ky)..."
+
+, "Add Tag"
+: ""
+
+, "Edit Tag"
+: ""
+
+, "Delete Tag"
+: ""
+
+, "Search:"
+: "Hledat:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Zobrazuji štítky {0} - {1} of {2}"
+
+, "No tags to display"
+: "Žádné štítky ke zobrazení"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Barva"
+
+, "Usage:&#160;"
+: ""
+
+, "Do you really want to delete the selected roles?"
+: "Určitě chcete smazat vybrané role?"
+
+, "Deleting role(s)..."
+: "Mažu roli(e)..."
+
+, "Failed"
+: "Nepodařilo se"
+
+, "Some error occurred while trying to delete the role."
+: "Během mazání role došlo k chybě."
+
+, "Add Role"
+: ""
+
+, "Edit Role"
+: ""
+
+, "Delete Role"
+: ""
+
+, "Displaying roles {0} - {1} of {2}"
+: "Zobrazuji role  {0} - {1} z {2}"
+
+, "No roles to display"
+: "Žádné role ke zobrazení"
+
+, "Container Name"
+: ""
+
+, "Type"
+: ""
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Model"
+: ""
+
+, "personal"
+: ""
+
+, "shared"
+: ""
+
+, "Order"
+: "Pořadí"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: ""
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Opravdu chcete smazat vybrané skupiny?"
 
 , "Deleting group(s)..."
 : "Mažu skupinu(y)..."
 
-, "Failed"
-: "Nepodařilo se"
-
 , "Some error occurred while trying to delete the group."
 : "Během mazání skupiny došlo k chybě."
 
@@ -79,15 +277,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Žádné skupiny ke zobrazení"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Popis"
-
 , "Creation Time"
 : ""
 
@@ -100,13 +292,55 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
-, "Errors"
-: "Chyby"
+, "IP Address"
+: "IP adresa"
 
-, "Please configure store for this field type"
+, "Login Time"
+: "Čas přihlášení"
+
+, "Logout Time"
+: "Čas odhlášení"
+
+, "Client Type"
 : ""
 
-, "Application, Applications"
+, "Session ID"
+: "ID relace"
+
+, "Login Name"
+: "Přihlašovací jméno"
+
+, "Result"
+: "Výsledek"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: ""
+
+, "password expired"
+: ""
+
+, "user disabled"
+: ""
+
+, "invalid password"
+: "neplatné heslo"
+
+, "ambiguous username"
+: "nejednoznačné uživatelské jméno"
+
+, "user not found"
+: "uživatel nebyl nalezen"
+
+, "failure"
+: "chyba"
+
+, "success"
+: "úspěch"
+
+, "Customfield, Customfields"
 : [
   ""
  ,""
@@ -114,6 +348,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,""
 
 ]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
+, "Errors"
+: "Chyby"
+
+, "Please configure store for this field type"
+: ""
+
 , "Record Class"
 : ""
 
@@ -129,9 +375,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : ""
 
-, "Model"
-: ""
-
 , "Custom field definition"
 : ""
 
@@ -168,12 +411,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: ""
-
-, "Label"
-: ""
-
 , "Length"
 : ""
 
@@ -194,189 +431,85 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,""
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : ""
 
-, "Customfield, Customfields"
+, "Enable Account"
+: ""
+
+, "Disable Account"
+: ""
+
+, "Reset Password"
+: ""
+
+, "Status"
+: "Stav"
+
+, "Display name"
+: ""
+
+, "Login name"
+: ""
+
+, "Last name"
+: "Příjmení"
+
+, "First name"
+: "Křestní jméno"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: "Poslední přihlášení"
+
+, "Last login from"
+: "Poslední přihlášení z"
+
+, "Password Must Change"
+: "Musí změnit heslo"
+
+, "Password changed"
+: "Heslo změněno"
+
+, "Expires"
+: "Vyprší"
+
+, "Set new password"
+: "Nastavit nové heslo"
+
+, "Please enter the new password:"
+: "Zadejte prosím nové heslo:"
+
+, "Users"
+: ""
+
+, "Samba User, Samba Users"
 : [
-  ""
- ,""
- ,""
- ,""
+  "Uživatel Samby"
+ ,"Uživatelé Samby"
+ ,"Uživatelů Samby"
+ ,"Uživatelů Samby"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
- ,""
- ,""
- ,""
+  "Uživatel emailu"
+ ,"Uživatelé emailu"
+ ,"Uživatelů emailu"
+ ,"Uživatelů emailu"
 
 ]
-, "Value"
-: ""
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Název počítače"
-
-, "Default Addressbook for new contacts and groups"
-: ""
-
-, "Please wait"
-: "Čekejte prosím"
-
-, "Updating Tag"
-: "Aktualizuji štítek..."
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Opravte prosím vyznačené chyby."
-
-, "Allowed Contexts"
-: "Povolené kontexty"
-
-, "Context"
-: "Kontext"
-
-, "Account Rights"
-: "Práva účtu"
-
-, "View"
-: "Prohlížet"
-
-, "Use"
-: "Používat"
-
-, "Tag Name"
-: "Název štítku"
-
-, "Color"
-: "Barva"
-
-, "Transferring {0}..."
-: ""
-
-, "Tag"
-: "Štítek"
-
-, "Add New Tag"
-: "Přidat nový štítek"
-
-, "Edit Tag \"{0}\""
-: "Editovat štítek \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Opravdu chcete smazat vybrané štítky?"
-
-, "Deleting tag(s)..."
-: "Mažu štítek(ky)..."
-
-, "Add Tag"
-: ""
-
-, "Edit Tag"
-: ""
-
-, "Delete Tag"
-: ""
-
-, "Displaying tags {0} - {1} of {2}"
-: "Zobrazuji štítky {0} - {1} of {2}"
-
-, "No tags to display"
-: "Žádné štítky ke zobrazení"
-
-, "Usage:&#160;"
-: ""
-
-, "Updating Memberships"
-: "Aktualizuji členství"
-
-, "Could not save role."
-: "Nepodařilo se uložit roli."
-
-, "Deleting role..."
-: "Mažu roli..."
-
-, "Some error occurred while trying to delete the role."
-: "Během mazání role došlo k chybě."
-
-, "Rights"
-: "Práva"
-
-, "Members"
-: "Členové"
-
-, "Role Name"
-: "Název role"
-
-, "Role"
-: "Role"
-
-, "Add New Role"
-: "Přidat novou roli"
-
-, "Edit Role \"{0}\""
-: "Editovat roli \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Určitě chcete smazat vybrané role?"
-
-, "Deleting role(s)..."
-: "Mažu roli(e)..."
-
-, "Add Role"
-: ""
-
-, "Edit Role"
-: ""
-
-, "Delete Role"
-: ""
-
-, "Displaying roles {0} - {1} of {2}"
-: "Zobrazuji role  {0} - {1} z {2}"
-
-, "No roles to display"
-: "Žádné role ke zobrazení"
-
-, "Access Log, Access Logs"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Groups"
-: "Skupiny"
-
-, "Applications"
-: "Aplikace"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: ""
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -404,18 +537,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Domovský disk"
 
-, "Login Time"
-: "Čas přihlášení"
-
 , "never logged in"
 : "nikdy nepřihlášen"
 
 , "Home Path"
 : "Domovská cesta"
 
-, "Logout Time"
-: "Čas odhlášení"
-
 , "never logged off"
 : "nikdy neodhlášen"
 
@@ -437,9 +564,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "není nastaveno"
 
-, "Password Must Change"
-: "Musí změnit heslo"
-
 , "Kick Off Time"
 : "Čas automatického odhlášení"
 
@@ -473,11 +597,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Poslední přihlášení"
 
-, "Domain not allowed"
-: ""
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "Jen přesměrovat"
 
 , "E-mail Alias"
 : ""
@@ -488,6 +609,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: ""
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : ""
 
@@ -500,9 +627,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Jen přesměrovat"
-
 , "Password confirmation"
 : "Potvrzení hesla"
 
@@ -515,20 +639,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Účet"
 
-, "First name"
-: "Křestní jméno"
-
-, "Last name"
-: "Příjmení"
-
-, "Login name"
-: ""
-
 , "Password"
 : "Heslo"
 
-, "OpenID"
-: "OpenID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "povoleno"
@@ -548,30 +663,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : ""
 
-, "Expires"
-: "Vyprší"
-
-, "Visibility"
-: "Viditelnost"
-
-, "Display in addressbook"
-: "Zobrazit v adresáři"
-
-, "Hide from addressbook"
-: "Nezobrazovat v adresáři"
-
-, "Saved in Addressbook"
-: ""
-
-, "Last login at"
-: "Poslední přihlášení"
-
 , "don't know"
 : "nevím"
 
-, "Last login from"
-: "Poslední přihlášení z"
-
 , "Password set"
 : "Heslo nastaveno"
 
@@ -593,110 +687,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Uživatel"
- ,"Uživatelé"
- ,"Uživatelů"
- ,"Uživatelů"
-
-]
-, "Users"
-: ""
-
-, "Samba User, Samba Users"
-: [
-  "Uživatel Samby"
- ,"Uživatelé Samby"
- ,"Uživatelů Samby"
- ,"Uživatelů Samby"
-
-]
-, "Email User, Email Users"
-: [
-  "Uživatel emailu"
- ,"Uživatelé emailu"
- ,"Uživatelů emailu"
- ,"Uživatelů emailu"
-
-]
-, "Enable Account"
-: ""
-
-, "Disable Account"
-: ""
-
-, "Reset Password"
-: ""
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: ""
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Heslo změněno"
-
-, "Set new password"
-: "Nastavit nové heslo"
-
-, "Please enter the new password:"
-: "Zadejte prosím nové heslo:"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Název skupiny"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Členové skupiny"
-
-, "personal"
-: ""
-
-, "shared"
-: ""
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: ""
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Container Name"
-: ""
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Počítač"
@@ -705,6 +695,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Počítačů"
 
 ]
+, "Please wait"
+: "Čekejte prosím"
+
+, "Updating Memberships"
+: "Aktualizuji členství"
+
+, "Could not save role."
+: "Nepodařilo se uložit roli."
+
+, "Please fix the errors noted."
+: "Opravte prosím vyznačené chyby."
+
+, "Deleting role..."
+: "Mažu roli..."
+
+, "Rights"
+: "Práva"
+
+, "Members"
+: "Členové"
+
+, "Role Name"
+: "Název role"
+
+, "Transferring {0}..."
+: ""
+
+, "Role"
+: "Role"
+
+, "Add New Role"
+: "Přidat novou roli"
+
+, "Edit Role \"{0}\""
+: "Editovat roli \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -717,78 +746,69 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Role"
+, "Updating Tag"
+: "Aktualizuji štítek..."
 
-, "Containers"
+, "Could not save tag ({0})"
 : ""
 
-, "Shared Tags"
-: "Sdílené štítky"
+, "Allowed Contexts"
+: "Povolené kontexty"
 
-, "Customfields"
+, "Context"
+: "Kontext"
+
+, "Account Rights"
+: "Práva účtu"
+
+, "View"
+: "Prohlížet"
+
+, "Use"
+: "Používat"
+
+, "Tag Name"
+: "Název štítku"
+
+, "Tag"
+: "Štítek"
+
+, "Add New Tag"
+: "Přidat nový štítek"
+
+, "Edit Tag \"{0}\""
+: "Editovat štítek \"{0}\""
+
+, "Enable Application"
 : ""
 
-, "Computers"
-: "Počítače"
-
-, "Server Information"
-: "Informace o serveru"
-
-, "ActiveSync Devices"
-: "Zařízení ActiveSync"
-
-, "E-mail Accounts"
+, "Disable Application"
 : ""
 
-, "Admin"
-: "Administrátor"
-
-, "Refresh"
+, "Settings"
 : ""
 
-, "Feature is disabled by configuration."
+, "{0} Settings"
+: "Nastavení {0}"
+
+, "Enabled"
 : ""
 
-, "IP Address"
-: "IP adresa"
-
-, "Client Type"
+, "Unknown status ({0})"
 : ""
 
-, "Session ID"
-: "ID relace"
+, "Displaying application {0} - {1} of {2}"
+: "Zobrazuji aplikace {0} - {1} z {2}"
 
-, "Login Name"
-: "Přihlašovací jméno"
+, "No applications to display"
+: "Žádné aplikace ke zobrazení"
 
-, "Result"
-: "Výsledek"
+, "Version"
+: "Verze"
 
-, "user blocked"
+, "Default password must change for new user settings"
 : ""
 
-, "password expired"
-: ""
-
-, "user disabled"
-: ""
-
-, "invalid password"
-: "neplatné heslo"
-
-, "ambiguous username"
-: "nejednoznačné uživatelské jméno"
-
-, "user not found"
-: "uživatel nebyl nalezen"
-
-, "failure"
-: "chyba"
-
-, "success"
-: "úspěch"
-
 , "Default IMAP user settings"
 : ""
 
@@ -810,6 +830,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : ""
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -864,6 +890,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -930,6 +962,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -964,25 +998,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : ""
 
-, "Group"
-: ""
+, "User"
+: "Uživatel"
 
-, "Customfield"
+, "Access Log"
 : ""
 
 , "Config"
 : ""
 
-, "Access Log"
+, "Container"
 : ""
 
-, "User"
-: "Uživatel"
+, "Customfield"
+: ""
+
+, "Group"
+: ""
 
 , "Samba User"
 : "Uživatel Samby"
@@ -990,9 +1028,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "Uživatel emailu"
 
-, "Container"
-: ""
-
 , "Computer"
 : "Počítač"
 
