@@ -7,69 +7,246 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
 : "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-01-04 10:23+0100\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.0.5\n"
 
-, "Enable Application"
-: "Anwendung aktivieren"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
 
-, "Disable Application"
-: "Anwendung deaktivieren"
+]
+, "Application, Applications"
+: [
+  "Anwendung"
+ ,"Anwendungen"
 
-, "Settings"
-: "Einstellungen"
+]
+, "User, Users"
+: [
+  "Benutzer"
+ ,"Benutzer"
 
-, "{0} Settings"
-: "{0} Einstellungen"
+]
+, "Groups"
+: "Gruppen"
 
-, "enable application"
-: "Anwendung aktivieren"
+, "Roles"
+: "Rollen"
 
-, "disable application"
-: "Anwendung deaktivieren"
+, "Applications"
+: "Anwendungen"
 
-, "settings"
-: "Einstellungen"
+, "Containers"
+: "Container"
 
-, "Search:"
-: "Suche:"
+, "Shared Tags"
+: "Gemeinsame Tags"
 
-, "disabled"
-: "deaktiviert"
+, "Customfields"
+: "Zusatzfelder"
 
-, "enabled"
-: "aktiviert"
+, "Computers"
+: "Computer"
 
-, "unknown status ({0})"
-: "unbekannter Status ({0})"
+, "Access Log, Access Logs"
+: [
+  "Zugriffslog"
+ ,"Zugriffslogs"
 
-, "Displaying application {0} - {1} of {2}"
-: "Zeige Anwendung {0} - {1} von {2}"
+]
+, "Log"
+: ""
 
-, "No applications to display"
-: "Keine Anwendungen anzuzeigen"
+, "Server Information"
+: "Server Informationen"
 
-, "Order"
-: "Sortierung"
+, "ActiveSync Devices"
+: "ActiveSync Geräte"
+
+, "E-mail Accounts"
+: "E-Mail Konten"
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Admin"
+
+, "Refresh"
+: "Aktualisieren"
+
+, "Disabled"
+: "Deaktiviert"
+
+, "Feature is disabled by configuration."
+: "Funktion ist durch die Konfiguration deaktiviert."
+
+, "Default Addressbook for new contacts and groups"
+: "Standard-Adressbuch für neue Kontakte und Gruppen"
+
+, "Computer Name"
+: "Computername"
+
+, "Config, Configs"
+: [
+  "Konfiguration"
+ ,"Konfigurationen"
+
+]
+, "Description"
+: "Beschreibung"
 
 , "Name"
 : "Name"
 
-, "Status"
-: "Status"
+, "Label"
+: "Bezeichner"
 
-, "Version"
-: "Version"
+, "Value"
+: "Wert"
+
+, "Default ({0})"
+: "Standard ({0})"
+
+, "Yes"
+: "Ja"
+
+, "No"
+: "Nein"
+
+, "Group Name"
+: "Gruppenname"
+
+, "Visibility"
+: "Sichtbarkeit"
+
+, "Display in addressbook"
+: "Zeige im Adressbuch"
+
+, "Hide from addressbook"
+: "Nicht im Adressbuch anzeigen"
+
+, "Saved in Addressbook"
+: "Gespeichert im Adressbuch"
+
+, "E-mail"
+: "E-Mail"
+
+, "Only system accounts can be added to Addressbook group"
+: "Nur Systembenutzer in der zugehörigen Addressbuch-Gruppe erlauben"
+
+, "Group Members"
+: "Gruppenmitglieder"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Domäne ist nicht erlaubt. Bitte prüfen Sie Ihre SMTP-Domänen-Konfiguration."
 
 , "Confirm"
 : "Bestätigen"
 
+, "Do you really want to delete the selected tags?"
+: "Möchten Sie den/die markierten Tag/s wirklich löschen?"
+
+, "Deleting tag(s)..."
+: "Tag(s) löschen..."
+
+, "Add Tag"
+: "Tag hinzufügen"
+
+, "Edit Tag"
+: "Tag bearbeiten"
+
+, "Delete Tag"
+: "Tags löschen"
+
+, "Search:"
+: "Suche:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Zeige Tag {0} - {1} von {2}"
+
+, "No tags to display"
+: "Keine Tags anzuzeigen"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Farbe"
+
+, "Usage:&#160;"
+: "Verwendung:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Möchten Sie die ausgewählten Rollen wirklich löschen?"
+
+, "Deleting role(s)..."
+: "Lösche Rolle(n)..."
+
+, "Failed"
+: "Fehlgeschlagen"
+
+, "Some error occurred while trying to delete the role."
+: "Beim Löschen der Rolle trat ein Fehler auf."
+
+, "Add Role"
+: "Rolle hinzufügen"
+
+, "Edit Role"
+: "Rolle bearbeiten"
+
+, "Delete Role"
+: "Rolle löschen"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Zeige Rollen {0} - {1} von {2}"
+
+, "No roles to display"
+: "Keine Rollen zum Anziegen"
+
+, "Container Name"
+: "Containername"
+
+, "Type"
+: "Typ"
+
+, "Container Order"
+: "Container Reihenfolge"
+
+, "Container, Containers"
+: [
+  "Container"
+ ,"Container"
+
+]
+, "Model"
+: "Modell"
+
+, "personal"
+: "persönlich"
+
+, "shared"
+: "gemeinsam"
+
+, "Order"
+: "Sortierung"
+
+, "Container Hierarchy/Name"
+: "Kalender Hierarchie/Name"
+
+, "Note for Owner"
+: "Notiz für den Besitzer"
+
+, "Info"
+: "Info"
+
+, "Please create Resources in Addressbook or CoreData."
+: "Bitte Ressourcen im Addressbook oder Stammdaten erstellen."
+
 , "Do you really want to delete the selected groups?"
 : "Die ausgewählten Gruppen wirklich löschen?"
 
 , "Deleting group(s)..."
 : "Lösche Gruppe(n)..."
 
-, "Failed"
-: "Fehlgeschlagen"
-
 , "Some error occurred while trying to delete the group."
 : "Beim Löschen der Gruppe trat ein Fehler auf."
 
@@ -88,11 +265,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Keine Gruppen anzuzeigen"
 
-, "ID"
-: "ID"
-
-, "Description"
-: "Beschreibung"
+, "Account only"
+: "Nur Systembenutzer"
 
 , "Creation Time"
 : "Erstellungszeit"
@@ -106,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : "Letzte Änderung von"
 
+, "IP Address"
+: "IP-Adresse"
+
+, "Login Time"
+: "Einlogzeit"
+
+, "Logout Time"
+: "Auslogzeit"
+
+, "Client Type"
+: "Client-Typ"
+
+, "Session ID"
+: "Session-ID"
+
+, "Login Name"
+: "Benutzername"
+
+, "Result"
+: "Ergebnis"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "Benutzer gesperrt"
+
+, "password expired"
+: "Passwort abgelaufen"
+
+, "user disabled"
+: "Benutzer deaktiviert"
+
+, "invalid password"
+: "ungültiges Passwort"
+
+, "ambiguous username"
+: "Benutzername mehrdeutig"
+
+, "user not found"
+: "Benutzer nicht gefunden"
+
+, "failure"
+: "Gescheitert"
+
+, "success"
+: "Erfolg"
+
+, "Customfield, Customfields"
+: [
+  "Zusatzfeld"
+ ,"Zusatzfelder"
+
+]
+, "This custom field is still in use!"
+: "Ein Zusatzfeld ist noch in Benutzung!"
+
+, "Are you sure you want to delete them?"
+: "Sind Sie sicher, dass Sie es löschen möchten?"
+
 , "Errors"
 : "Fehler"
 
 , "Please configure store for this field type"
 : "Bitte konfigurieren Sie einen Datenspeicher für diesen Feldtyp"
 
-, "Application, Applications"
-: [
-  "Anwendung"
- ,"Anwendungen"
-
-]
 , "Record Class"
 : "Datensatz-Klasse"
 
@@ -133,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Datenspeicher konfigurieren"
 
-, "Model"
-: "Modell"
-
 , "Custom field definition"
 : "Zusatzfeld-Definition"
 
@@ -172,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : "Datensatz Liste"
 
-, "Type"
-: "Typ"
-
-, "Label"
-: "Bezeichner"
-
 , "Length"
 : "Länge"
 
@@ -196,185 +415,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Gruppen"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Es gibt bereits ein Zusatzfeld mit diesem Namen. Bitte wählen Sie einen anderen Namen."
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Benutzer aktivieren"
+
+, "Disable Account"
+: "Benutzer deaktivieren"
+
+, "Reset Password"
+: "Passwort zurücksetzen"
+
+, "Status"
+: "Status"
+
+, "Display name"
+: "Bildschirmname"
+
+, "Login name"
+: "Anmeldename"
+
+, "Last name"
+: "Nachname"
+
+, "First name"
+: "Vorname"
+
+, "E-mail usage"
+: "E-Mail-Nutzung"
+
+, "Filesystem usage"
+: "Dateisystem Nutzung"
+
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: "Zuletzt eingeloggt um"
+
+, "Last login from"
+: "Letzter Login von"
+
+, "Password Must Change"
+: "Passwort muss geändert werden"
+
+, "Password changed"
+: "Passwort geändert"
+
+, "Expires"
+: "Verfällt"
+
+, "Set new password"
+: "Passwort zurücksetzen"
+
+, "Please enter the new password:"
+: "Bitte geben Sie das neue Passwort ein:"
+
+, "Users"
+: "Benutzer"
+
+, "Samba User, Samba Users"
 : [
-  "Zusatzfeld"
- ,"Zusatzfelder"
+  "Samba-Benutzer"
+ ,"Samba-Benutzer"
 
 ]
-, "This custom field is still in use!"
-: "Ein Zusatzfeld ist noch in Benutzung!"
-
-, "Are you sure you want to delete them?"
-: "Sind Sie sicher, dass Sie es löschen möchten?"
-
-, "Yes"
-: "Ja"
-
-, "No"
-: "Nein"
-
-, "Default ({0})"
-: "Standard ({0})"
-
-, "Source"
-: "Quelle"
-
-, "Value"
-: "Wert"
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  "Konfiguration"
- ,"Konfigurationen"
+  "E-Mail-Benutzer"
+ ,"E-Mail-Benutzer"
 
 ]
-, "Computer Name"
-: "Computername"
-
-, "Default Addressbook for new contacts and groups"
-: "Standard-Adressbuch für neue Kontakte und Gruppen"
-
-, "Please wait"
-: "Bitte warten"
-
-, "Updating Tag"
-: "Aktualisiere Tag"
-
-, "Could not save tag ({0})"
-: "Konnte Tag ({0}) nicht speichern"
-
-, "Please fix the errors noted."
-: "Bitte beheben Sie die angezeigten Fehler."
-
-, "Allowed Contexts"
-: "Erlaubte Kontexte"
-
-, "Context"
-: "Kontexte"
-
-, "Account Rights"
-: "Benutzerrechte"
-
-, "View"
-: "Zeigen"
-
-, "Use"
-: "Verwenden"
-
-, "Tag Name"
-: "Tag Name"
-
-, "Color"
-: "Farbe"
-
-, "Transferring {0}..."
-: "Übertrage {0} ..."
-
-, "Tag"
-: "Tag"
-
-, "Add New Tag"
-: "Neuen Tag hinzufügen"
-
-, "Edit Tag \"{0}\""
-: "Tag \"{0}\" bearbeiten"
-
-, "Do you really want to delete the selected tags?"
-: "Möchten Sie den/die markierten Tag/s wirklich löschen?"
-
-, "Deleting tag(s)..."
-: "Tag(s) löschen..."
-
-, "Add Tag"
-: "Tag hinzufügen"
-
-, "Edit Tag"
-: "Tag bearbeiten"
-
-, "Delete Tag"
-: "Tags löschen"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Zeige Tag {0} - {1} von {2}"
-
-, "No tags to display"
-: "Keine Tags anzuzeigen"
-
-, "Usage:&#160;"
-: "Verwendung:&#160;"
-
-, "Updating Memberships"
-: "Mitgliedschaft erneuern"
-
-, "Could not save role."
-: "Konnte die Rolle nicht speichern."
-
-, "Deleting role..."
-: "Rolle löschen ..."
-
-, "Some error occurred while trying to delete the role."
-: "Beim Löschen der Rolle trat ein Fehler auf."
-
-, "Rights"
-: "Rechte"
-
-, "Members"
-: "Mitglieder"
-
-, "Role Name"
-: "Rollennname"
-
-, "Role"
-: "Rolle"
-
-, "Add New Role"
-: "Neue Rolle hinzufügen"
-
-, "Edit Role \"{0}\""
-: "Rolle \"{0}\" bearbeiten"
-
-, "Do you really want to delete the selected roles?"
-: "Möchten Sie die ausgewählten Rollen wirklich löschen?"
-
-, "Deleting role(s)..."
-: "Lösche Rolle(n)..."
-
-, "Add Role"
-: "Rolle hinzufügen"
-
-, "Edit Role"
-: "Rolle bearbeiten"
-
-, "Delete Role"
-: "Rolle löschen"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Zeige Rollen {0} - {1} von {2}"
-
-, "No roles to display"
-: "Keine Rollen zum Anziegen"
-
-, "Access Log, Access Logs"
-: [
-  "Zugriffslog"
- ,"Zugriffslogs"
-
-]
-, "Groups"
-: "Gruppen"
-
-, "Applications"
-: "Anwendungen"
-
-, "Configs"
-: "Konfigurationen"
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Domäne ist nicht erlaubt. Bitte prüfen Sie Ihre SMTP-Domänen-Konfiguration."
+, "Special characters are not allowed in login name."
+: "Der Benutzername darf keine Sonderzeichen enthalten."
 
 , "Passwords do not match!"
 : "Passwörter sind ungleich!"
@@ -400,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Home-Festplatte"
 
-, "Logon Time"
-: "Einlogzeit"
-
 , "never logged in"
 : "war noch nie eingeloggt"
 
 , "Home Path"
 : "Home-Pfad"
 
-, "Logoff Time"
-: "Auslogzeit"
-
 , "never logged off"
 : "hat sich niemals ausgeloggt"
 
@@ -433,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "nicht gesetzt"
 
-, "Password Must Change"
-: "Passwort muss geändert werden"
-
 , "Kick Off Time"
 : "Abmeldezeit"
 
@@ -469,33 +577,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Zuletzt eingeloggt um"
 
+, "Forward Only"
+: "Nur Weiterleiten"
+
+, "E-mail Alias"
+: "E-Mail Alias"
+
+, "Add an alias address..."
+: "E-Mail-Adresse hinzufügen..."
+
+, "This alias can be used for sending e-mails."
+: "Dieser Alias kann zum Versenden von E-Mails verwendet werden."
+
 , "Domain not allowed"
 : "Domäne nicht erlaubt"
 
 , "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
 : "Die Domäne {0} des neuen Alias {1} ist nicht als primäre oder sekundäre Domäne im Setup eingetragen. Bitte fügen Sie diese Domain als sekundäre Domain im SMTP setup hinzu oder benutzen Sie eine Domäne welche bereits konfiguriert ist."
 
-, "Email Alias"
-: "E-Mail-Alias"
-
-, "Add an alias address..."
-: "E-Mail-Adresse hinzufügen..."
-
 , "Forwarding to self"
 : "Weiterleitung zu sich selbst"
 
-, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
-: "Sie dürfen keine Weiterleitungsadresse angeben, die identisch mit der E-Mail-Adresse oder eines Alias des Benutzers ist."
+, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
+: "Sie dürfen keine E-Mail-Adresse zur Weiterleitung festlegen, die mit der primären E-Mail-Adresse des Benutzers oder einem seiner Aliase identisch ist."
 
-, "Email Forward"
-: "E-Mail-Weiterleitung"
+, "E-mail Forward"
+: "E-Mail weiterleiten"
 
-, "Add a forward address..."
+, "Add a forwarding address..."
 : "Eine Weiterleitungs-Adresse hinzufügen..."
 
-, "Forward Only"
-: "Nur Weiterleiten"
-
 , "Password confirmation"
 : "Passwortbestätigung"
 
@@ -508,23 +619,17 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Benutzerkonto"
 
-, "First name"
-: "Vorname"
-
-, "Last name"
-: "Nachname"
-
-, "Login name"
-: "Anmeldename"
-
 , "Password"
 : "Passwort"
 
-, "Email"
-: "E-Mail"
+, "Multi Factor Authentication Config"
+: "Multi-Faktor-Authentifizierung"
 
-, "OpenID"
-: "OpenID"
+, "enabled"
+: "aktiviert"
+
+, "disabled"
+: "deaktiviert"
 
 , "expired"
 : "abgelaufen"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "Der \"gesperrt\"-Status erscheint nur, wenn der Benutzer sich zu oft mit falschem Passwort anmelden wollte. Es ist nicht möglich diesen Status zu setzten."
 
-, "Expires"
-: "Verfällt"
-
-, "Visibility"
-: "Sichtbarkeit"
-
-, "Display in addressbook"
-: "Zeige im Adressbuch"
-
-, "Hide from addressbook"
-: "Nicht im Adressbuch anzeigen"
-
-, "Saved in Addressbook"
-: "Gespeichert im Adressbuch"
-
-, "Last login at"
-: "Zuletzt eingeloggt um"
-
 , "don't know"
 : "unbekannt"
 
-, "Last login from"
-: "Letzter Login von"
-
 , "Password set"
 : "Passwort gesetzt"
 
@@ -583,105 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Benutzer"
- ,"Benutzer"
-
-]
-, "Users"
-: "Benutzer"
-
-, "Samba User, Samba Users"
-: [
-  "Samba-Benutzer"
- ,"Samba-Benutzer"
-
-]
-, "Email User, Email Users"
-: [
-  "E-Mail-Benutzer"
- ,"E-Mail-Benutzer"
-
-]
-, "Enable Account"
-: "Benutzer aktivieren"
-
-, "Disable Account"
-: "Benutzer deaktivieren"
-
-, "Reset Password"
-: "Passwort zurücksetzen"
-
-, "Reset Pin"
-: "PIN zurücksetzen"
-
-, "Display name"
-: "Bildschirmname"
-
-, "Email usage"
-: "E-Mail Nutzung"
-
-, "Filesystem usage"
-: "Dateisystem Nutzung"
-
-, "Password changed"
-: "Passwort geändert"
-
-, "Set new password"
-: "Passwort zurücksetzen"
-
-, "Please enter the new password:"
-: "Bitte geben Sie das neue Passwort ein:"
-
-, "Set new pin"
-: "Neuen PIN setzen"
-
-, "Please enter the new pin:"
-: "Bitte geben Sie den neuen PIN ein:"
-
-, "Could not save group."
-: "Konnte Gruppe nicht speichern."
-
-, "Group Name"
-: "Gruppenname"
-
-, "Group Members"
-: "Gruppenmitglieder"
-
-, "Add new group"
-: "Neue Gruppe erstellen"
-
-, "Edit Group \"{0}\""
-: "Gruppe \"{0}\" bearbeiten"
-
-, "personal"
-: "persönlich"
-
-, "shared"
-: "gemeinsam"
-
-, "Note for Owner"
-: "Notiz für den Besitzer"
-
-, "Container, Containers"
-: [
-  "Container"
- ,"Container"
-
-]
-, "Container Name"
-: "Containername"
-
-, "Container Order"
-: "Container Reihenfolge"
-
 , "Computer, Computers"
 : [
   "Computer"
  ,"Computer"
 
 ]
+, "Please wait"
+: "Bitte warten"
+
+, "Updating Memberships"
+: "Mitgliedschaft erneuern"
+
+, "Could not save role."
+: "Konnte die Rolle nicht speichern."
+
+, "Please fix the errors noted."
+: "Bitte beheben Sie die angezeigten Fehler."
+
+, "Deleting role..."
+: "Rolle löschen ..."
+
+, "Rights"
+: "Rechte"
+
+, "Members"
+: "Mitglieder"
+
+, "Role Name"
+: "Rollennname"
+
+, "Transferring {0}..."
+: "Übertrage {0} ..."
+
+, "Role"
+: "Rolle"
+
+, "Add New Role"
+: "Neue Rolle hinzufügen"
+
+, "Edit Role \"{0}\""
+: "Rolle \"{0}\" bearbeiten"
+
+, "Configs"
+: "Konfigurationen"
+
 , "Size"
 : "Größe"
 
@@ -691,224 +721,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Total size of all available revisions"
 : "Gesamtgröße aller verfügbaren Revisionen"
 
-, "Quota Usage"
-: "Kontingents-Nutzung"
+, "Quota Management"
+: "Kontingents-Verwaltung"
 
-, "Roles"
-: "Rollen"
+, "Edit Quota"
+: "Kontingent bearbeiten"
 
-, "Containers"
-: "Container"
+, "Edit {0} Quota"
+: "{0} Kontingent bearbeiten"
 
-, "Shared Tags"
-: "Gemeinsame Tags"
+, "Manage total Filesystem Quota"
+: "Gesamte Dateimanager Quota verwalten"
 
-, "Customfields"
-: "Zusatzfelder"
+, "Total quota"
+: "Gesamte Quota"
 
-, "Computers"
-: "Computer"
+, "Updating Tag"
+: "Aktualisiere Tag"
 
-, "Server Information"
-: "Server Informationen"
+, "Could not save tag ({0})"
+: "Konnte Tag ({0}) nicht speichern"
 
-, "ActiveSync Devices"
-: "ActiveSync Geräte"
+, "Allowed Contexts"
+: "Erlaubte Kontexte"
 
-, "Admin"
-: "Admin"
+, "Context"
+: "Kontexte"
 
-, "Refresh"
-: "Aktualisieren"
+, "Account Rights"
+: "Benutzerrechte"
 
-, "IP Address"
-: "IP-Adresse"
+, "View"
+: "Zeigen"
 
-, "Login Time"
-: "Einlogzeit"
+, "Use"
+: "Verwenden"
 
-, "Logout Time"
-: "Auslogzeit"
+, "Tag Name"
+: "Tag Name"
 
-, "Client Type"
-: "Client-Typ"
+, "Tag"
+: "Tag"
 
-, "Session ID"
-: "Session-ID"
+, "Add New Tag"
+: "Neuen Tag hinzufügen"
 
-, "Login Name"
-: "Benutzername"
+, "Edit Tag \"{0}\""
+: "Tag \"{0}\" bearbeiten"
 
-, "Result"
-: "Ergebnis"
+, "Enable Application"
+: "Anwendung aktivieren"
 
-, "user blocked"
-: "Benutzer gesperrt"
+, "Disable Application"
+: "Anwendung deaktivieren"
 
-, "password expired"
-: "Passwort abgelaufen"
+, "Settings"
+: "Einstellungen"
 
-, "user disabled"
-: "Benutzer deaktiviert"
-
-, "invalid password"
-: "ungültiges Passwort"
-
-, "ambiguous username"
-: "Benutzername mehrdeutig"
-
-, "user not found"
-: "Benutzer nicht gefunden"
-
-, "failure"
-: "Gescheitert"
-
-, "success"
-: "Erfolg"
-
-, "Default IMAP user settings"
-: "Standard IMAP-Benutzer-Einstellungen"
-
-, "Your container has been changed"
-: "Ihr persönlicher Container wurde geändert"
-
-, "Your container has been changed by %1$s %2$sNote: %3$s"
-: "Ihr Container wurde von %1$s geändert %2$sNotiz: %3$s"
-
-, "manage access log"
-: "Zugriffsprotokoll bearbeiten"
-
-, "delete access log entries"
-: "Zugriffsprotokoll-Einträge löschen"
-
-, "manage accounts"
-: "Benutzerkonten verwalten"
-
-, "add and edit users and groups, add group members, change user passwords"
-: "Benutzer und Gruppen anlegen und bearbeiten, Benutzer zu Gruppen zuordnen, Passwörter zurücksetzen"
-
-, "manage applications"
-: "Anwendungen verwalten"
-
-, "enable and disable applications, edit application settings"
-: "Anwendungen bearbeiten, aktivieren und deaktivieren"
-
-, "manage roles"
-: "Rollen verwalten"
-
-, "add and edit roles, add new members to roles, add application rights to roles"
-: "Rollen anlegen und bearbeiten, Benutzerkonten Rollen zuordnen, Rollen Anwendungs-Rechte zuweisen"
-
-, "manage shared tags"
-: "Gemeinsame Tags verwalten"
-
-, "view shared tags"
-: "Gemeinsame Tags ansehen"
-
-, "add, delete and edit shared tags"
-: "Gemeinsame Tags anlegen, bearbeiten und löschen"
-
-, "view shared tags list and details"
-: "Gemeinsame Tags ansehen (Liste und Details)"
-
-, "manage computers"
-: "Computer verwalten"
-
-, "add, delete and edit (samba) computers"
-: "Computer anlegen, bearbeiten und löschen"
-
-, "manage containers"
-: "Container verwalten"
-
-, "add, delete and edit containers and manage container grants"
-: "Container anlegen, löschen und ändern, sowie die Container-Rechte setzen"
-
-, "manage customfields"
-: "Zusatzfelder verwalten"
-
-, "add and edit customfields"
-: "Zusatzfelder anlegen und editieren"
-
-, "view access log"
-: "Zugriffsprotokoll ansehen"
-
-, "view access log list"
-: "Zugriffsprotokoll-Liste ansehen"
-
-, "view accounts"
-: "Benutzerkonten ansehen"
-
-, "view accounts list and details"
-: "Benutzerkonten ansehen (Liste und Details)"
-
-, "view applications"
-: "Anwendungen ansehen"
-
-, "view applications list and details"
-: "Anwendungen ansehen (Liste und Details)"
-
-, "view roles"
-: "Rollen ansehen"
-
-, "view roles list and details"
-: "Rollen ansehen (Liste und Details)"
-
-, "view computers"
-: "Computer ansehen"
-
-, "view computers list and details"
-: "Computerliste und -details ansehen"
-
-, "view containers"
-: "Container ansehen"
-
-, "view personal and shared containers"
-: "Persönlichen und gemeinsame Container ansehen"
-
-, "view customfields"
-: "Zusatzfelder ansehen"
-
-, "view customfields list"
-: "Zusatzfelderliste ansehen"
-
-, "view serverinfo"
-: "Serverinformationen ansehen"
-
-, "view serverinfo list"
-: "Serverinformationen ansehen"
-
-, "view quota usage"
-: "Quota Nutzung ansehen"
-
-, "Special characters are not allowed in login name."
-: "Der Benutzername darf keine Sonderzeichen enthalten."
-
-, "Please create Resources in Addressbook or CoreData."
-: "Bitte Ressourcen im Addressbook oder Stammdaten erstellen."
-
-, "IMAP Quota (MB)"
-: "IMAP Kontingent (MB)"
-
-, "Sieve Quota (MB)"
-: "Sieve Kontingent (MB)"
-
-, "Restart application to apply new customfields?"
-: "Wollen Sie die Anwendung zum Anwenden der neuen Zusatzfelder neu starten?"
-
-, "Default"
-: "Standard"
-
-, "view email accounts"
-: "E-Mail-Konten ansehen"
-
-, "manage email accounts"
-: "E-Mail-Konten verwalten"
-
-, "Only system accounts can be added to Addressbook group"
-: "Nur Systembenutzer in der zugehörigen Addressbuch-Gruppe erlauben"
-
-, "Disabled"
-: "Deaktiviert"
+, "{0} Settings"
+: "{0} Einstellungen"
 
 , "Enabled"
 : "Aktiviert"
@@ -916,38 +787,20 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Unknown status ({0})"
 : "Unbekannter Status ({0})"
 
-, "E-mail"
-: "E-Mail"
+, "Displaying application {0} - {1} of {2}"
+: "Zeige Anwendung {0} - {1} von {2}"
 
-, "E-mail Alias"
-: "E-Mail Alias"
+, "No applications to display"
+: "Keine Anwendungen anzuzeigen"
 
-, "This alias can be used for sending e-mails."
-: "Dieser Alias kann zum Versenden von E-Mails verwendet werden."
+, "Version"
+: "Version"
 
-, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
-: "Sie dürfen keine E-Mail-Adresse zur Weiterleitung festlegen, die mit der primären E-Mail-Adresse des Benutzers oder einem seiner Aliase identisch ist."
+, "Default password must change for new user settings"
+: ""
 
-, "E-mail Forward"
-: "E-Mail weiterleiten"
-
-, "Add a forwarding address..."
-: "Eine Weiterleitungs-Adresse hinzufügen..."
-
-, "E-mail usage"
-: "E-Mail-Nutzung"
-
-, "Container Hierarchy/Name"
-: "Kalender Hierarchie/Name"
-
-, "Info"
-: "Info"
-
-, "E-mail Accounts"
-: "E-Mail Konten"
-
-, "Feature is disabled by configuration."
-: "Funktion ist durch die Konfiguration deaktiviert."
+, "Default IMAP user settings"
+: "Standard IMAP-Benutzer-Einstellungen"
 
 , "Enabled Features"
 : "Aktiviertes Features"
@@ -961,6 +814,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Force retype of new password in user edit dialog"
 : "Erzwinge die erneute Eingabe des neuen Passworts im Benutzer-Bearbeitungsdialog"
 
+, "Your container has been changed"
+: "Ihr persönlicher Container wurde geändert"
+
+, "Your container has been changed by %1$s %2$sNote: %3$s"
+: "Ihr Container wurde von %1$s geändert %2$sNotiz: %3$s"
+
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : "Zugriffsprotokoll bearbeiten"
 
@@ -1015,6 +880,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : "Zusatzfelder anlegen und editieren."
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : "Zugriffsprotokoll ansehen"
 
@@ -1081,35 +952,128 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : "Quota Nutzung ansehen."
 
-, "You are not allowed to set a forward e-mail address that is identical to the users primary e-mail or one of his aliases."
-: "Sie dürfen keine E-Mail-Adresse zur Weiterleitung festlegen, die mit der primären E-Mail-Adresse des Benutzers oder einem seiner Aliase identisch ist."
+, "view ImportExportDefinitions"
+: ""
 
-, "E-Mail"
-: "E-Mail"
+, "Record data needs to be set!"
+: "Datensatz muss gesetzt sein!"
 
-, "E-Mail Accounts"
-: "E-Mail Konten"
+, "Account E-Mail needs to be set!"
+: "Konto E-Mail muss gesetzt sein!"
 
-, "Account only"
-: "Nur Systembenutzer"
+, "E-Mail account not found."
+: "E-Mail-Konto nicht gefunden."
+
+, "It is not allowed to manage total Quota."
+: "Es ist nicht erlaubt, die Gesamte Quota zu verwalten."
+
+, "Delete user will trigger the [V] events, do you still want to execute this action?"
+: "Das Löschen des Benutzers wird die mit [V] markierten Aktionen auslösen, wollen Sie das Löschen durchführen?"
+
+, "Delete personal containers"
+: "Persönliche Ordner löschen"
+
+, "Keep account as contact in the Addressbook"
+: "Als Kontakt im Adressbuch behalten"
+
+, "Keep accounts organizer events as external events in the Calendar"
+: "Organisator-Termine der Benutzer:in als externe Termine im Kalender behalten"
+
+, "Keep accounts Calendar event attendee as external attender"
+: "Termine der Benutzer:in als externe Termine im Kalender behalten"
+
+, "Delete file folders and files"
+: "Dateiordner und Dateien löschen"
+
+, "Delete Email accounts"
+: "E-Mail-Konten löschen"
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Anwendung"
 
-, "Group"
-: "Gruppe"
-
-, "Customfield"
-: "Zusatzfeld"
-
-, "Config"
-: "Konfiguration"
+, "User"
+: "Benutzer"
 
 , "Access Log"
 : "Zugriffslog"
 
-, "User"
-: "Benutzer"
+, "Config"
+: "Konfiguration"
+
+, "Container"
+: "Container"
+
+, "Customfield"
+: "Zusatzfeld"
+
+, "Group"
+: "Gruppe"
 
 , "Samba User"
 : "Samba-Benutzer"
@@ -1117,9 +1081,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "E-Mail-Benutzer"
 
-, "Container"
-: "Container"
-
 , "Computer"
 : "Computer"
 
