@@ -7,69 +7,246 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
 : "Project-Id-Version: Tine 2.0 - Admin\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"
 
-, "Enable Application"
-: "Enable Application"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  "ImportExportDefinition"
+ ,"ImportExportDefinitions"
 
-, "Disable Application"
-: "Disable Application"
+]
+, "Application, Applications"
+: [
+  "Application"
+ ,"Applications"
 
-, "Settings"
-: "Settings"
+]
+, "User, Users"
+: [
+  "User"
+ ,"Users"
 
-, "{0} Settings"
-: "{0} Settings"
+]
+, "Groups"
+: "Groups"
 
-, "enable application"
-: "enable application"
+, "Roles"
+: "Roles"
 
-, "disable application"
-: "disable application"
+, "Applications"
+: "Applications"
 
-, "settings"
-: "settings"
+, "Containers"
+: "Containers"
 
-, "Search:"
-: "Search:"
+, "Shared Tags"
+: "Shared Tags"
 
-, "disabled"
-: "disabled"
+, "Customfields"
+: "Customfields"
 
-, "enabled"
-: "enabled"
+, "Computers"
+: "Computers"
 
-, "unknown status ({0})"
-: "unknown status ({0})"
+, "Access Log, Access Logs"
+: [
+  "Access Log"
+ ,"Access Logs"
 
-, "Displaying application {0} - {1} of {2}"
-: "Displaying application {0} - {1} of {2}"
+]
+, "Log"
+: "Log"
 
-, "No applications to display"
-: "No applications to display"
+, "Server Information"
+: "Server Information"
 
-, "Order"
-: "Order"
+, "ActiveSync Devices"
+: "ActiveSync Devices"
+
+, "E-mail Accounts"
+: "E-mail Accounts"
+
+, "Import Export Definitions"
+: "Import Export Definitions"
+
+, "Admin"
+: "Admin"
+
+, "Refresh"
+: "Refresh"
+
+, "Disabled"
+: "Disabled"
+
+, "Feature is disabled by configuration."
+: "Feature is disabled by configuration."
+
+, "Default Addressbook for new contacts and groups"
+: "Default Addressbook for new contacts and groups"
+
+, "Computer Name"
+: "Computer Name"
+
+, "Config, Configs"
+: [
+  "Config"
+ ,"Configs"
+
+]
+, "Description"
+: "Description"
 
 , "Name"
 : "Name"
 
-, "Status"
-: "Status"
+, "Label"
+: "Label"
 
-, "Version"
-: "Version"
+, "Value"
+: "Value"
+
+, "Default ({0})"
+: "Default ({0})"
+
+, "Yes"
+: "Yes"
+
+, "No"
+: "No"
+
+, "Group Name"
+: "Group Name"
+
+, "Visibility"
+: "Visibility"
+
+, "Display in addressbook"
+: "Display in addressbook"
+
+, "Hide from addressbook"
+: "Hide from addressbook"
+
+, "Saved in Addressbook"
+: "Saved in Addressbook"
+
+, "E-mail"
+: "E-mail"
+
+, "Only system accounts can be added to Addressbook group"
+: "Only system accounts can be added to Addressbook group"
+
+, "Group Members"
+: "Group Members"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Domain is not allowed. Check your SMTP domain configuration."
 
 , "Confirm"
 : "Confirm"
 
+, "Do you really want to delete the selected tags?"
+: "Do you really want to delete the selected tags?"
+
+, "Deleting tag(s)..."
+: "Deleting tag(s)..."
+
+, "Add Tag"
+: "Add Tag"
+
+, "Edit Tag"
+: "Edit Tag"
+
+, "Delete Tag"
+: "Delete Tag"
+
+, "Search:"
+: "Search:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Displaying tags {0} - {1} of {2}"
+
+, "No tags to display"
+: "No tags to display"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Color"
+
+, "Usage:&#160;"
+: "Usage:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Do you really want to delete the selected roles?"
+
+, "Deleting role(s)..."
+: "Deleting role(s)..."
+
+, "Failed"
+: "Failed"
+
+, "Some error occurred while trying to delete the role."
+: "Some error occurred while trying to delete the role."
+
+, "Add Role"
+: "Add Role"
+
+, "Edit Role"
+: "Edit Role"
+
+, "Delete Role"
+: "Delete Role"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Displaying roles {0} - {1} of {2}"
+
+, "No roles to display"
+: "No roles to display"
+
+, "Container Name"
+: "Container Name"
+
+, "Type"
+: "Type"
+
+, "Container Order"
+: "Container Order"
+
+, "Container, Containers"
+: [
+  "Container"
+ ,"Containers"
+
+]
+, "Model"
+: "Model"
+
+, "personal"
+: "personal"
+
+, "shared"
+: "shared"
+
+, "Order"
+: "Order"
+
+, "Container Hierarchy/Name"
+: "Container Hierarchy/Name"
+
+, "Note for Owner"
+: "Note for Owner"
+
+, "Info"
+: "Info"
+
+, "Please create Resources in Addressbook or CoreData."
+: "Please create Resources in Addressbook or CoreData."
+
 , "Do you really want to delete the selected groups?"
 : "Do you really want to delete the selected groups?"
 
 , "Deleting group(s)..."
 : "Deleting group(s)..."
 
-, "Failed"
-: "Failed"
-
 , "Some error occurred while trying to delete the group."
 : "Some error occurred while trying to delete the group."
 
@@ -88,11 +265,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "No groups to display"
 
-, "ID"
-: "ID"
-
-, "Description"
-: "Description"
+, "Account only"
+: "Account only"
 
 , "Creation Time"
 : "Creation Time"
@@ -106,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : "Last Modified By"
 
+, "IP Address"
+: "IP Address"
+
+, "Login Time"
+: "Login Time"
+
+, "Logout Time"
+: "Logout Time"
+
+, "Client Type"
+: "Client Type"
+
+, "Session ID"
+: "Session ID"
+
+, "Login Name"
+: "Login Name"
+
+, "Result"
+: "Result"
+
+, "User Agent"
+: "User Agent"
+
+, "user blocked"
+: "user blocked"
+
+, "password expired"
+: "password expired"
+
+, "user disabled"
+: "user disabled"
+
+, "invalid password"
+: "invalid password"
+
+, "ambiguous username"
+: "ambiguous username"
+
+, "user not found"
+: "user not found"
+
+, "failure"
+: "failure"
+
+, "success"
+: "success"
+
+, "Customfield, Customfields"
+: [
+  "Customfield"
+ ,"Customfields"
+
+]
+, "This custom field is still in use!"
+: "This custom field is still in use!"
+
+, "Are you sure you want to delete them?"
+: "Are you sure you want to delete them?"
+
 , "Errors"
 : "Errors"
 
 , "Please configure store for this field type"
 : "Please configure store for this field type"
 
-, "Application, Applications"
-: [
-  "Application"
- ,"Applications"
-
-]
 , "Record Class"
 : "Record Class"
 
@@ -133,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Configure store"
 
-, "Model"
-: "Model"
-
 , "Custom field definition"
 : "Custom field definition"
 
@@ -172,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : "Record List"
 
-, "Type"
-: "Type"
-
-, "Label"
-: "Label"
-
 , "Length"
 : "Length"
 
@@ -196,185 +415,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Groups"
 
 ]
+, "Key"
+: "Key"
+
 , "Customfield already exists. Please choose another name."
 : "Customfield already exists. Please choose another name."
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Enable Account"
+
+, "Disable Account"
+: "Disable Account"
+
+, "Reset Password"
+: "Reset Password"
+
+, "Status"
+: "Status"
+
+, "Display name"
+: "Display name"
+
+, "Login name"
+: "Login name"
+
+, "Last name"
+: "Last name"
+
+, "First name"
+: "First name"
+
+, "E-mail usage"
+: "E-mail usage"
+
+, "Filesystem usage"
+: "Filesystem usage"
+
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: "Last login at"
+
+, "Last login from"
+: "Last login from"
+
+, "Password Must Change"
+: "Password Must Change"
+
+, "Password changed"
+: "Password changed"
+
+, "Expires"
+: "Expires"
+
+, "Set new password"
+: "Set new password"
+
+, "Please enter the new password:"
+: "Please enter the new password:"
+
+, "Users"
+: "Users"
+
+, "Samba User, Samba Users"
 : [
-  "Customfield"
- ,"Customfields"
+  "Samba User"
+ ,"Samba Users"
 
 ]
-, "This custom field is still in use!"
-: "This custom field is still in use!"
-
-, "Are you sure you want to delete them?"
-: "Are you sure you want to delete them?"
-
-, "Yes"
-: "Yes"
-
-, "No"
-: "No"
-
-, "Default ({0})"
-: "Default ({0})"
-
-, "Source"
-: "Source"
-
-, "Value"
-: "Value"
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  "Config"
- ,"Configs"
+  "Email User"
+ ,"Email Users"
 
 ]
-, "Computer Name"
-: "Computer Name"
-
-, "Default Addressbook for new contacts and groups"
-: "Default Addressbook for new contacts and groups"
-
-, "Please wait"
-: "Please wait"
-
-, "Updating Tag"
-: "Updating Tag"
-
-, "Could not save tag ({0})"
-: "Could not save tag ({0})"
-
-, "Please fix the errors noted."
-: "Please fix the errors noted."
-
-, "Allowed Contexts"
-: "Allowed Contexts"
-
-, "Context"
-: "Context"
-
-, "Account Rights"
-: "Account Rights"
-
-, "View"
-: "View"
-
-, "Use"
-: "Use"
-
-, "Tag Name"
-: "Tag Name"
-
-, "Color"
-: "Color"
-
-, "Transferring {0}..."
-: "Transferring {0}..."
-
-, "Tag"
-: "Tag"
-
-, "Add New Tag"
-: "Add New Tag"
-
-, "Edit Tag \"{0}\""
-: "Edit Tag \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Do you really want to delete the selected tags?"
-
-, "Deleting tag(s)..."
-: "Deleting tag(s)..."
-
-, "Add Tag"
-: "Add Tag"
-
-, "Edit Tag"
-: "Edit Tag"
-
-, "Delete Tag"
-: "Delete Tag"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Displaying tags {0} - {1} of {2}"
-
-, "No tags to display"
-: "No tags to display"
-
-, "Usage:&#160;"
-: "Usage:&#160;"
-
-, "Updating Memberships"
-: "Updating Memberships"
-
-, "Could not save role."
-: "Could not save role."
-
-, "Deleting role..."
-: "Deleting role..."
-
-, "Some error occurred while trying to delete the role."
-: "Some error occurred while trying to delete the role."
-
-, "Rights"
-: "Rights"
-
-, "Members"
-: "Members"
-
-, "Role Name"
-: "Role Name"
-
-, "Role"
-: "Role"
-
-, "Add New Role"
-: "Add New Role"
-
-, "Edit Role \"{0}\""
-: "Edit Role \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Do you really want to delete the selected roles?"
-
-, "Deleting role(s)..."
-: "Deleting role(s)..."
-
-, "Add Role"
-: "Add Role"
-
-, "Edit Role"
-: "Edit Role"
-
-, "Delete Role"
-: "Delete Role"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Displaying roles {0} - {1} of {2}"
-
-, "No roles to display"
-: "No roles to display"
-
-, "Access Log, Access Logs"
-: [
-  "Access Log"
- ,"Access Logs"
-
-]
-, "Groups"
-: "Groups"
-
-, "Applications"
-: "Applications"
-
-, "Configs"
-: "Configs"
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Domain is not allowed. Check your SMTP domain configuration."
+, "Special characters are not allowed in login name."
+: "Special characters are not allowed in login name."
 
 , "Passwords do not match!"
 : "Passwords do not match!"
@@ -400,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Home Drive"
 
-, "Logon Time"
-: "Logon Time"
-
 , "never logged in"
 : "never logged in"
 
 , "Home Path"
 : "Home Path"
 
-, "Logoff Time"
-: "Logoff Time"
-
 , "never logged off"
 : "never logged off"
 
@@ -433,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "not set"
 
-, "Password Must Change"
-: "Password Must Change"
-
 , "Kick Off Time"
 : "Kick Off Time"
 
@@ -469,32 +577,35 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Last Login"
 
+, "Forward Only"
+: "Forward Only"
+
+, "E-mail Alias"
+: "E-mail Alias"
+
+, "Add an alias address..."
+: "Add an alias address..."
+
+, "This alias can be used for sending e-mails."
+: "This alias can be used for sending e-mails."
+
 , "Domain not allowed"
 : "Domain not allowed"
 
 , "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
 : "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
 
-, "Email Alias"
-: "Email Alias"
-
-, "Add an alias address..."
-: "Add an alias address..."
-
 , "Forwarding to self"
 : "Forwarding to self"
 
-, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
-: "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
+, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
+: "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
 
-, "Email Forward"
-: "Email Forward"
+, "E-mail Forward"
+: "E-mail Forward"
 
-, "Add a forward address..."
-: "Add a forward address..."
-
-, "Forward Only"
-: "Forward Only"
+, "Add a forwarding address..."
+: "Add a forwarding address..."
 
 , "Password confirmation"
 : "Password confirmation"
@@ -508,23 +619,17 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Account"
 
-, "First name"
-: "First name"
-
-, "Last name"
-: "Last name"
-
-, "Login name"
-: "Login name"
-
 , "Password"
 : "Password"
 
-, "Email"
-: "Email"
+, "Multi Factor Authentication Config"
+: "Multi Factor Authentication Config"
 
-, "OpenID"
-: "OpenID"
+, "enabled"
+: "enabled"
+
+, "disabled"
+: "disabled"
 
 , "expired"
 : "expired"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 
-, "Expires"
-: "Expires"
-
-, "Visibility"
-: "Visibility"
-
-, "Display in addressbook"
-: "Display in addressbook"
-
-, "Hide from addressbook"
-: "Hide from addressbook"
-
-, "Saved in Addressbook"
-: "Saved in Addressbook"
-
-, "Last login at"
-: "Last login at"
-
 , "don't know"
 : "don't know"
 
-, "Last login from"
-: "Last login from"
-
 , "Password set"
 : "Password set"
 
@@ -583,105 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "User"
- ,"Users"
-
-]
-, "Users"
-: "Users"
-
-, "Samba User, Samba Users"
-: [
-  "Samba User"
- ,"Samba Users"
-
-]
-, "Email User, Email Users"
-: [
-  "Email User"
- ,"Email Users"
-
-]
-, "Enable Account"
-: "Enable Account"
-
-, "Disable Account"
-: "Disable Account"
-
-, "Reset Password"
-: "Reset Password"
-
-, "Reset Pin"
-: "Reset Pin"
-
-, "Display name"
-: "Display name"
-
-, "Email usage"
-: "Email usage"
-
-, "Filesystem usage"
-: "Filesystem usage"
-
-, "Password changed"
-: "Password changed"
-
-, "Set new password"
-: "Set new password"
-
-, "Please enter the new password:"
-: "Please enter the new password:"
-
-, "Set new pin"
-: "Set new pin"
-
-, "Please enter the new pin:"
-: "Please enter the new pin:"
-
-, "Could not save group."
-: "Could not save group."
-
-, "Group Name"
-: "Group Name"
-
-, "Group Members"
-: "Group Members"
-
-, "Add new group"
-: "Add new group"
-
-, "Edit Group \"{0}\""
-: "Edit Group \"{0}\""
-
-, "personal"
-: "personal"
-
-, "shared"
-: "shared"
-
-, "Note for Owner"
-: "Note for Owner"
-
-, "Container, Containers"
-: [
-  "Container"
- ,"Containers"
-
-]
-, "Container Name"
-: "Container Name"
-
-, "Container Order"
-: "Container Order"
-
 , "Computer, Computers"
 : [
   "Computer"
  ,"Computers"
 
 ]
+, "Please wait"
+: "Please wait"
+
+, "Updating Memberships"
+: "Updating Memberships"
+
+, "Could not save role."
+: "Could not save role."
+
+, "Please fix the errors noted."
+: "Please fix the errors noted."
+
+, "Deleting role..."
+: "Deleting role..."
+
+, "Rights"
+: "Rights"
+
+, "Members"
+: "Members"
+
+, "Role Name"
+: "Role Name"
+
+, "Transferring {0}..."
+: "Transferring {0}..."
+
+, "Role"
+: "Role"
+
+, "Add New Role"
+: "Add New Role"
+
+, "Edit Role \"{0}\""
+: "Edit Role \"{0}\""
+
+, "Configs"
+: "Configs"
+
 , "Size"
 : "Size"
 
@@ -694,188 +724,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : "Quota Usage"
 
-, "Roles"
-: "Roles"
+, "Updating Tag"
+: "Updating Tag"
 
-, "Containers"
-: "Containers"
+, "Could not save tag ({0})"
+: "Could not save tag ({0})"
 
-, "Shared Tags"
-: "Shared Tags"
+, "Allowed Contexts"
+: "Allowed Contexts"
 
-, "Customfields"
-: "Customfields"
+, "Context"
+: "Context"
 
-, "Computers"
-: "Computers"
+, "Account Rights"
+: "Account Rights"
 
-, "Server Information"
-: "Server Information"
+, "View"
+: "View"
 
-, "ActiveSync Devices"
-: "ActiveSync Devices"
+, "Use"
+: "Use"
 
-, "Admin"
-: "Admin"
+, "Tag Name"
+: "Tag Name"
 
-, "Refresh"
-: "Refresh"
+, "Tag"
+: "Tag"
 
-, "IP Address"
-: "IP Address"
+, "Add New Tag"
+: "Add New Tag"
 
-, "Login Time"
-: "Login Time"
+, "Edit Tag \"{0}\""
+: "Edit Tag \"{0}\""
 
-, "Logout Time"
-: "Logout Time"
+, "Enable Application"
+: "Enable Application"
 
-, "Client Type"
-: "Client Type"
+, "Disable Application"
+: "Disable Application"
 
-, "Session ID"
-: "Session ID"
+, "Settings"
+: "Settings"
 
-, "Login Name"
-: "Login Name"
-
-, "Result"
-: "Result"
-
-, "user blocked"
-: "user blocked"
-
-, "password expired"
-: "password expired"
-
-, "user disabled"
-: "user disabled"
-
-, "invalid password"
-: "invalid password"
-
-, "ambiguous username"
-: "ambiguous username"
-
-, "user not found"
-: "user not found"
-
-, "failure"
-: "failure"
-
-, "success"
-: "success"
-
-, "Default IMAP user settings"
-: "Default IMAP user settings"
-
-, "Your container has been changed"
-: "Your container has been changed"
-
-, "Your container has been changed by %1$s %2$sNote: %3$s"
-: "Your container has been changed by %1$s %2$sNote: %3$s"
-
-, "manage access log"
-: "manage access log"
-
-, "delete access log entries"
-: "delete access log entries"
-
-, "manage accounts"
-: "manage accounts"
-
-, "add and edit users and groups, add group members, change user passwords"
-: "add and edit users and groups, add group members, change user passwords"
-
-, "manage applications"
-: "manage applications"
-
-, "enable and disable applications, edit application settings"
-: "enable and disable applications, edit application settings"
-
-, "manage roles"
-: "manage roles"
-
-, "add and edit roles, add new members to roles, add application rights to roles"
-: "add and edit roles, add new members to roles, add application rights to roles"
-
-, "manage shared tags"
-: "manage shared tags"
-
-, "add, delete and edit shared tags"
-: "add, delete and edit shared tags"
-
-, "manage computers"
-: "manage computers"
-
-, "add, delete and edit (samba) computers"
-: "add, delete and edit (samba) computers"
-
-, "manage containers"
-: "manage containers"
-
-, "add, delete and edit containers and manage container grants"
-: "add, delete and edit containers and manage container grants"
-
-, "manage customfields"
-: "manage customfields"
-
-, "add and edit customfields"
-: "add and edit customfields"
-
-, "view access log"
-: "view access log"
-
-, "view access log list"
-: "view access log list"
-
-, "view accounts"
-: "view accounts"
-
-, "view accounts list and details"
-: "view accounts list and details"
-
-, "view applications"
-: "view applications"
-
-, "view applications list and details"
-: "view applications list and details"
-
-, "view roles"
-: "view roles"
-
-, "view roles list and details"
-: "view roles list and details"
-
-, "view computers"
-: "view computers"
-
-, "view computers list and details"
-: "view computers list and details"
-
-, "view containers"
-: "view containers"
-
-, "view personal and shared containers"
-: "view personal and shared containers"
-
-, "view customfields"
-: "view customfields"
-
-, "view customfields list"
-: "view customfields list"
-
-, "view serverinfo"
-: "view serverinfo"
-
-, "view serverinfo list"
-: "view serverinfo list"
-
-, "view quota usage"
-: "view quota usage"
-
-, "Disabled"
-: "Disabled"
+, "{0} Settings"
+: "{0} Settings"
 
 , "Enabled"
 : "Enabled"
@@ -883,47 +775,20 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Unknown status ({0})"
 : "Unknown status ({0})"
 
-, "E-mail"
-: "E-mail"
+, "Displaying application {0} - {1} of {2}"
+: "Displaying application {0} - {1} of {2}"
 
-, "Special characters are not allowed in login name."
-: "Special characters are not allowed in login name."
+, "No applications to display"
+: "No applications to display"
 
-, "E-mail Alias"
-: "E-mail Alias"
+, "Version"
+: "Version"
 
-, "This alias can be used for sending e-mails."
-: "This alias can be used for sending e-mails."
+, "Default password must change for new user settings"
+: "Default password must change for new user settings"
 
-, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
-: "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
-
-, "E-mail Forward"
-: "E-mail Forward"
-
-, "Add a forwarding address..."
-: "Add a forwarding address..."
-
-, "E-mail usage"
-: "E-mail usage"
-
-, "Only system accounts can be added to Addressbook group"
-: "Only system accounts can be added to Addressbook group"
-
-, "Container Hierarchy/Name"
-: "Container Hierarchy/Name"
-
-, "Info"
-: "Info"
-
-, "Please create Resources in Addressbook or CoreData."
-: "Please create Resources in Addressbook or CoreData."
-
-, "E-mail Accounts"
-: "E-mail Accounts"
-
-, "Feature is disabled by configuration."
-: "Feature is disabled by configuration."
+, "Default IMAP user settings"
+: "Default IMAP user settings"
 
 , "Enabled Features"
 : "Enabled Features"
@@ -937,6 +802,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Force retype of new password in user edit dialog"
 : "Force retype of new password in user edit dialog"
 
+, "Your container has been changed"
+: "Your container has been changed"
+
+, "Your container has been changed by %1$s %2$sNote: %3$s"
+: "Your container has been changed by %1$s %2$sNote: %3$s"
+
+, "Password is needed for system account creation"
+: "Password is needed for system account creation"
+
+, "Notifications"
+: "Notifications"
+
 , "Manage access log"
 : "Manage access log"
 
@@ -991,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : "Add and edit customfields."
 
+, "Manage import and export definitions"
+: "Manage import and export definitions"
+
+, "Add and edit import and export definitions"
+: "Add and edit import and export definitions"
+
 , "View access log"
 : "View access log"
 
@@ -1057,26 +940,32 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : "View quota usage."
 
-, "Account only"
-: "Account only"
+, "view ImportExportDefinitions"
+: "view ImportExportDefinitions"
+
+, "ImportExportDefinition"
+: "ImportExportDefinition"
 
 , "Application"
 : "Application"
 
-, "Group"
-: "Group"
-
-, "Customfield"
-: "Customfield"
-
-, "Config"
-: "Config"
+, "User"
+: "User"
 
 , "Access Log"
 : "Access Log"
 
-, "User"
-: "User"
+, "Config"
+: "Config"
+
+, "Container"
+: "Container"
+
+, "Customfield"
+: "Customfield"
+
+, "Group"
+: "Group"
 
 , "Samba User"
 : "Samba User"
@@ -1084,9 +973,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "Email User"
 
-, "Container"
-: "Container"
-
 , "Computer"
 : "Computer"
 
