@@ -5,62 +5,248 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nLanguage: en_AU\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nLanguage: en_AU\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
+
+]
+, "Application, Applications"
+: [
+  "Application"
+ ,"Applications"
+
+]
+, "User, Users"
+: [
+  "User"
+ ,"Users"
+
+]
+, "Groups"
+: "Groups"
+
+, "Roles"
+: "Roles"
+
+, "Applications"
+: "Applications"
+
+, "Containers"
+: "Containers"
+
+, "Shared Tags"
+: "Shared Tags"
+
+, "Customfields"
+: "Customfields"
+
+, "Computers"
+: "Computers"
+
+, "Access Log, Access Logs"
+: [
+  "Access Log"
+ ,"Access Logs"
+
+]
+, "Log"
 : ""
 
-, "Disable Application"
+, "Server Information"
 : ""
 
-, "Settings"
+, "ActiveSync Devices"
 : ""
 
-, "{0} Settings"
-: "{0} Settings"
+, "E-mail Accounts"
+: ""
 
-, "Search:"
-: "Search:"
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Admin"
+
+, "Refresh"
+: ""
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Default Addressbook for new contacts and groups"
 
-, "Displaying application {0} - {1} of {2}"
-: "Displaying application {0} - {1} of {2}"
+, "Computer Name"
+: "Computer Name"
 
-, "No applications to display"
-: "No applications to display"
+, "Config, Configs"
+: [
+  ""
+ ,""
 
-, "Order"
-: "Order"
+]
+, "Description"
+: "Description"
 
 , "Name"
 : "Name"
 
-, "Status"
-: "Status"
+, "Label"
+: "Label"
 
-, "Version"
-: "Version"
+, "Value"
+: "Value"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Group Name"
+
+, "Visibility"
+: "Visibility"
+
+, "Display in addressbook"
+: "Display in addressbook"
+
+, "Hide from addressbook"
+: "Hide from addressbook"
+
+, "Saved in Addressbook"
+: "Saved in Addressbook"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Group Members"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Domain is not allowed. Check your SMTP domain configuration."
 
 , "Confirm"
 : "Confirm"
 
+, "Do you really want to delete the selected tags?"
+: "Do you really want to delete the selected tags?"
+
+, "Deleting tag(s)..."
+: "Deleting tag(s)..."
+
+, "Add Tag"
+: ""
+
+, "Edit Tag"
+: ""
+
+, "Delete Tag"
+: ""
+
+, "Search:"
+: "Search:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Displaying tags {0} - {1} of {2}"
+
+, "No tags to display"
+: "No tags to display"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Color"
+
+, "Usage:&#160;"
+: "Usage:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Do you really want to delete the selected roles?"
+
+, "Deleting role(s)..."
+: "Deleting role(s)..."
+
+, "Failed"
+: "Failed"
+
+, "Some error occurred while trying to delete the role."
+: "Some error occurred while trying to delete the role."
+
+, "Add Role"
+: ""
+
+, "Edit Role"
+: ""
+
+, "Delete Role"
+: ""
+
+, "Displaying roles {0} - {1} of {2}"
+: "Displaying roles {0} - {1} of {2}"
+
+, "No roles to display"
+: "No roles to display"
+
+, "Container Name"
+: "Container Name"
+
+, "Type"
+: "Type"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "Container"
+ ,"Containers"
+
+]
+, "Model"
+: "Model"
+
+, "personal"
+: "personal"
+
+, "shared"
+: "shared"
+
+, "Order"
+: "Order"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Note for Owner"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Do you really want to delete the selected groups?"
 
 , "Deleting group(s)..."
 : "Deleting group(s)..."
 
-, "Failed"
-: "Failed"
-
 , "Some error occurred while trying to delete the group."
 : "Some error occurred while trying to delete the group."
 
@@ -79,15 +265,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "No groups to display"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Description"
-
 , "Creation Time"
 : ""
 
@@ -100,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "IP Address"
+
+, "Login Time"
+: "Login Time"
+
+, "Logout Time"
+: "Logout Time"
+
+, "Client Type"
+: "Client Type"
+
+, "Session ID"
+: "Session ID"
+
+, "Login Name"
+: "Login Name"
+
+, "Result"
+: "Result"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "user blocked"
+
+, "password expired"
+: "password expired"
+
+, "user disabled"
+: "user disabled"
+
+, "invalid password"
+: "invalid password"
+
+, "ambiguous username"
+: "ambiguous username"
+
+, "user not found"
+: "user not found"
+
+, "failure"
+: "failure"
+
+, "success"
+: "success"
+
+, "Customfield, Customfields"
+: [
+  "Customfield"
+ ,"Customfields"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Errors"
 
 , "Please configure store for this field type"
 : "Please configure store for this field type"
 
-, "Application, Applications"
-: [
-  "Application"
- ,"Applications"
-
-]
 , "Record Class"
 : "Record Class"
 
@@ -127,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Configure store"
 
-, "Model"
-: "Model"
-
 , "Custom field definition"
 : "Custom field definition"
 
@@ -166,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Type"
-
-, "Label"
-: "Label"
-
 , "Length"
 : "Length"
 
@@ -190,183 +415,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Groups"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Customfield already exists. Please choose another name."
 
-, "Customfield, Customfields"
+, "Enable Account"
+: ""
+
+, "Disable Account"
+: ""
+
+, "Reset Password"
+: ""
+
+, "Status"
+: "Status"
+
+, "Display name"
+: ""
+
+, "Login name"
+: ""
+
+, "Last name"
+: "Last name"
+
+, "First name"
+: "First name"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: "Last login at"
+
+, "Last login from"
+: "Last login from"
+
+, "Password Must Change"
+: "Password Must Change"
+
+, "Password changed"
+: "Password changed"
+
+, "Expires"
+: "Expires"
+
+, "Set new password"
+: "Set new password"
+
+, "Please enter the new password:"
+: "Please enter the new password:"
+
+, "Users"
+: "Users"
+
+, "Samba User, Samba Users"
 : [
-  "Customfield"
- ,"Customfields"
+  "Samba User"
+ ,"Samba Users"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
- ,""
+  "Email User"
+ ,"Email Users"
 
 ]
-, "Value"
-: "Value"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Computer Name"
-
-, "Default Addressbook for new contacts and groups"
-: "Default Addressbook for new contacts and groups"
-
-, "Please wait"
-: "Please wait"
-
-, "Updating Tag"
-: "Updating Tag"
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Please fix the errors noted."
-
-, "Allowed Contexts"
-: "Allowed Contexts"
-
-, "Context"
-: "Context"
-
-, "Account Rights"
-: "Account Rights"
-
-, "View"
-: "View"
-
-, "Use"
-: "Use"
-
-, "Tag Name"
-: "Tag Name"
-
-, "Color"
-: "Color"
-
-, "Transferring {0}..."
-: "Transferring {0}..."
-
-, "Tag"
-: "Tag"
-
-, "Add New Tag"
-: "Add New Tag"
-
-, "Edit Tag \"{0}\""
-: "Edit Tag \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Do you really want to delete the selected tags?"
-
-, "Deleting tag(s)..."
-: "Deleting tag(s)..."
-
-, "Add Tag"
-: ""
-
-, "Edit Tag"
-: ""
-
-, "Delete Tag"
-: ""
-
-, "Displaying tags {0} - {1} of {2}"
-: "Displaying tags {0} - {1} of {2}"
-
-, "No tags to display"
-: "No tags to display"
-
-, "Usage:&#160;"
-: "Usage:&#160;"
-
-, "Updating Memberships"
-: "Updating Memberships"
-
-, "Could not save role."
-: "Could not save role."
-
-, "Deleting role..."
-: "Deleting role..."
-
-, "Some error occurred while trying to delete the role."
-: "Some error occurred while trying to delete the role."
-
-, "Rights"
-: "Rights"
-
-, "Members"
-: "Members"
-
-, "Role Name"
-: "Role Name"
-
-, "Role"
-: "Role"
-
-, "Add New Role"
-: "Add New Role"
-
-, "Edit Role \"{0}\""
-: "Edit Role \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Do you really want to delete the selected roles?"
-
-, "Deleting role(s)..."
-: "Deleting role(s)..."
-
-, "Add Role"
-: ""
-
-, "Edit Role"
-: ""
-
-, "Delete Role"
-: ""
-
-, "Displaying roles {0} - {1} of {2}"
-: "Displaying roles {0} - {1} of {2}"
-
-, "No roles to display"
-: "No roles to display"
-
-, "Access Log, Access Logs"
-: [
-  "Access Log"
- ,"Access Logs"
-
-]
-, "Groups"
-: "Groups"
-
-, "Applications"
-: "Applications"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Domain is not allowed. Check your SMTP domain configuration."
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -394,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Home Drive"
 
-, "Login Time"
-: "Login Time"
-
 , "never logged in"
 : "never logged in"
 
 , "Home Path"
 : "Home Path"
 
-, "Logout Time"
-: "Logout Time"
-
 , "never logged off"
 : "never logged off"
 
@@ -427,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "not set"
 
-, "Password Must Change"
-: "Password Must Change"
-
 , "Kick Off Time"
 : "Kick Off Time"
 
@@ -463,11 +577,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Last Login"
 
-, "Domain not allowed"
-: ""
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "Forward Only"
 
 , "E-mail Alias"
 : ""
@@ -478,6 +589,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: ""
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : ""
 
@@ -490,9 +607,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Forward Only"
-
 , "Password confirmation"
 : "Password confirmation"
 
@@ -505,20 +619,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Account"
 
-, "First name"
-: "First name"
-
-, "Last name"
-: "Last name"
-
-, "Login name"
-: ""
-
 , "Password"
 : "Password"
 
-, "OpenID"
-: "OpenID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "enabled"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : ""
 
-, "Expires"
-: "Expires"
-
-, "Visibility"
-: "Visibility"
-
-, "Display in addressbook"
-: "Display in addressbook"
-
-, "Hide from addressbook"
-: "Hide from addressbook"
-
-, "Saved in Addressbook"
-: "Saved in Addressbook"
-
-, "Last login at"
-: "Last login at"
-
 , "don't know"
 : "don't know"
 
-, "Last login from"
-: "Last login from"
-
 , "Password set"
 : "Password set"
 
@@ -583,108 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "User"
- ,"Users"
-
-]
-, "Users"
-: "Users"
-
-, "Samba User, Samba Users"
-: [
-  "Samba User"
- ,"Samba Users"
-
-]
-, "Email User, Email Users"
-: [
-  "Email User"
- ,"Email Users"
-
-]
-, "Enable Account"
-: ""
-
-, "Disable Account"
-: ""
-
-, "Reset Password"
-: ""
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: ""
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Password changed"
-
-, "Set new password"
-: "Set new password"
-
-, "Please enter the new password:"
-: "Please enter the new password:"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Group Name"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Group Members"
-
-, "personal"
-: "personal"
-
-, "shared"
-: "shared"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Note for Owner"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "Container"
- ,"Containers"
-
-]
-, "Container Name"
-: "Container Name"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Computer"
  ,"Computers"
 
 ]
+, "Please wait"
+: "Please wait"
+
+, "Updating Memberships"
+: "Updating Memberships"
+
+, "Could not save role."
+: "Could not save role."
+
+, "Please fix the errors noted."
+: "Please fix the errors noted."
+
+, "Deleting role..."
+: "Deleting role..."
+
+, "Rights"
+: "Rights"
+
+, "Members"
+: "Members"
+
+, "Role Name"
+: "Role Name"
+
+, "Transferring {0}..."
+: "Transferring {0}..."
+
+, "Role"
+: "Role"
+
+, "Add New Role"
+: "Add New Role"
+
+, "Edit Role \"{0}\""
+: "Edit Role \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -697,77 +724,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Roles"
+, "Updating Tag"
+: "Updating Tag"
 
-, "Containers"
-: "Containers"
-
-, "Shared Tags"
-: "Shared Tags"
-
-, "Customfields"
-: "Customfields"
-
-, "Computers"
-: "Computers"
-
-, "Server Information"
+, "Could not save tag ({0})"
 : ""
 
-, "ActiveSync Devices"
+, "Allowed Contexts"
+: "Allowed Contexts"
+
+, "Context"
+: "Context"
+
+, "Account Rights"
+: "Account Rights"
+
+, "View"
+: "View"
+
+, "Use"
+: "Use"
+
+, "Tag Name"
+: "Tag Name"
+
+, "Tag"
+: "Tag"
+
+, "Add New Tag"
+: "Add New Tag"
+
+, "Edit Tag \"{0}\""
+: "Edit Tag \"{0}\""
+
+, "Enable Application"
 : ""
 
-, "E-mail Accounts"
+, "Disable Application"
 : ""
 
-, "Admin"
-: "Admin"
-
-, "Refresh"
+, "Settings"
 : ""
 
-, "Feature is disabled by configuration."
+, "{0} Settings"
+: "{0} Settings"
+
+, "Enabled"
 : ""
 
-, "IP Address"
-: "IP Address"
+, "Unknown status ({0})"
+: ""
 
-, "Client Type"
-: "Client Type"
+, "Displaying application {0} - {1} of {2}"
+: "Displaying application {0} - {1} of {2}"
 
-, "Session ID"
-: "Session ID"
+, "No applications to display"
+: "No applications to display"
 
-, "Login Name"
-: "Login Name"
+, "Version"
+: "Version"
 
-, "Result"
-: "Result"
-
-, "user blocked"
-: "user blocked"
-
-, "password expired"
-: "password expired"
-
-, "user disabled"
-: "user disabled"
-
-, "invalid password"
-: "invalid password"
-
-, "ambiguous username"
-: "ambiguous username"
-
-, "user not found"
-: "user not found"
-
-, "failure"
-: "failure"
-
-, "success"
-: "success"
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : ""
@@ -790,6 +808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Your container has been changed by %1$s %2$sNote: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -844,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -910,6 +940,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -947,25 +979,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Application"
 
-, "Group"
-: "Group"
-
-, "Customfield"
-: "Customfield"
-
-, "Config"
-: ""
+, "User"
+: "User"
 
 , "Access Log"
 : "Access Log"
 
-, "User"
-: "User"
+, "Config"
+: ""
+
+, "Container"
+: "Container"
+
+, "Customfield"
+: "Customfield"
+
+, "Group"
+: "Group"
 
 , "Samba User"
 : "Samba User"
@@ -973,9 +1009,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "Email User"
 
-, "Container"
-: "Container"
-
 , "Computer"
 : "Computer"
 
