@@ -5,62 +5,248 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (New Zealand) (http://www.transifex.com/tine20/tine20/language/en_NZ/)\nLanguage: en_NZ\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (New Zealand) (http://www.transifex.com/tine20/tine20/language/en_NZ/)\nLanguage: en_NZ\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
+
+]
+, "Application, Applications"
+: [
+  ""
+ ,""
+
+]
+, "User, Users"
+: [
+  ""
+ ,""
+
+]
+, "Groups"
 : ""
 
-, "Disable Application"
+, "Roles"
 : ""
 
-, "Settings"
+, "Applications"
 : ""
 
-, "{0} Settings"
+, "Containers"
 : ""
 
-, "Search:"
+, "Shared Tags"
+: ""
+
+, "Customfields"
+: ""
+
+, "Computers"
+: ""
+
+, "Access Log, Access Logs"
+: [
+  ""
+ ,""
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: ""
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: ""
+
+, "Refresh"
 : ""
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
+, "Default Addressbook for new contacts and groups"
 : ""
 
-, "Displaying application {0} - {1} of {2}"
+, "Computer Name"
 : ""
 
-, "No applications to display"
-: ""
+, "Config, Configs"
+: [
+  ""
+ ,""
 
-, "Order"
+]
+, "Description"
 : ""
 
 , "Name"
 : ""
 
-, "Status"
+, "Label"
 : ""
 
-, "Version"
+, "Value"
+: ""
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: ""
+
+, "Visibility"
+: ""
+
+, "Display in addressbook"
+: ""
+
+, "Hide from addressbook"
+: ""
+
+, "Saved in Addressbook"
+: ""
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: ""
+
+, "Domain is not allowed. Check your SMTP domain configuration."
 : ""
 
 , "Confirm"
 : ""
 
+, "Do you really want to delete the selected tags?"
+: ""
+
+, "Deleting tag(s)..."
+: ""
+
+, "Add Tag"
+: ""
+
+, "Edit Tag"
+: ""
+
+, "Delete Tag"
+: ""
+
+, "Search:"
+: ""
+
+, "Displaying tags {0} - {1} of {2}"
+: ""
+
+, "No tags to display"
+: ""
+
+, "ID"
+: ""
+
+, "Color"
+: ""
+
+, "Usage:&#160;"
+: ""
+
+, "Do you really want to delete the selected roles?"
+: ""
+
+, "Deleting role(s)..."
+: ""
+
+, "Failed"
+: ""
+
+, "Some error occurred while trying to delete the role."
+: ""
+
+, "Add Role"
+: ""
+
+, "Edit Role"
+: ""
+
+, "Delete Role"
+: ""
+
+, "Displaying roles {0} - {1} of {2}"
+: ""
+
+, "No roles to display"
+: ""
+
+, "Container Name"
+: ""
+
+, "Type"
+: ""
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  ""
+ ,""
+
+]
+, "Model"
+: ""
+
+, "personal"
+: ""
+
+, "shared"
+: ""
+
+, "Order"
+: ""
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: ""
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : ""
 
 , "Deleting group(s)..."
 : ""
 
-, "Failed"
-: ""
-
 , "Some error occurred while trying to delete the group."
 : ""
 
@@ -79,13 +265,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : ""
 
-, "ID"
-: ""
-
-, "E-mail"
-: ""
-
-, "Description"
+, "Account only"
 : ""
 
 , "Creation Time"
@@ -100,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: ""
+
+, "Login Time"
+: ""
+
+, "Logout Time"
+: ""
+
+, "Client Type"
+: ""
+
+, "Session ID"
+: ""
+
+, "Login Name"
+: ""
+
+, "Result"
+: ""
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: ""
+
+, "password expired"
+: ""
+
+, "user disabled"
+: ""
+
+, "invalid password"
+: ""
+
+, "ambiguous username"
+: ""
+
+, "user not found"
+: ""
+
+, "failure"
+: ""
+
+, "success"
+: ""
+
+, "Customfield, Customfields"
+: [
+  ""
+ ,""
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : ""
 
 , "Please configure store for this field type"
 : ""
 
-, "Application, Applications"
-: [
-  ""
- ,""
-
-]
 , "Record Class"
 : ""
 
@@ -127,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : ""
 
-, "Model"
-: ""
-
 , "Custom field definition"
 : ""
 
@@ -166,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: ""
-
-, "Label"
-: ""
-
 , "Length"
 : ""
 
@@ -190,183 +415,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,""
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : ""
 
-, "Customfield, Customfields"
+, "Enable Account"
+: ""
+
+, "Disable Account"
+: ""
+
+, "Reset Password"
+: ""
+
+, "Status"
+: ""
+
+, "Display name"
+: ""
+
+, "Login name"
+: ""
+
+, "Last name"
+: ""
+
+, "First name"
+: ""
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: ""
+
+, "Last login at"
+: ""
+
+, "Last login from"
+: ""
+
+, "Password Must Change"
+: ""
+
+, "Password changed"
+: ""
+
+, "Expires"
+: ""
+
+, "Set new password"
+: ""
+
+, "Please enter the new password:"
+: ""
+
+, "Users"
+: ""
+
+, "Samba User, Samba Users"
 : [
   ""
  ,""
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
   ""
  ,""
 
 ]
-, "Value"
-: ""
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: ""
-
-, "Default Addressbook for new contacts and groups"
-: ""
-
-, "Please wait"
-: ""
-
-, "Updating Tag"
-: ""
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: ""
-
-, "Allowed Contexts"
-: ""
-
-, "Context"
-: ""
-
-, "Account Rights"
-: ""
-
-, "View"
-: ""
-
-, "Use"
-: ""
-
-, "Tag Name"
-: ""
-
-, "Color"
-: ""
-
-, "Transferring {0}..."
-: ""
-
-, "Tag"
-: ""
-
-, "Add New Tag"
-: ""
-
-, "Edit Tag \"{0}\""
-: ""
-
-, "Do you really want to delete the selected tags?"
-: ""
-
-, "Deleting tag(s)..."
-: ""
-
-, "Add Tag"
-: ""
-
-, "Edit Tag"
-: ""
-
-, "Delete Tag"
-: ""
-
-, "Displaying tags {0} - {1} of {2}"
-: ""
-
-, "No tags to display"
-: ""
-
-, "Usage:&#160;"
-: ""
-
-, "Updating Memberships"
-: ""
-
-, "Could not save role."
-: ""
-
-, "Deleting role..."
-: ""
-
-, "Some error occurred while trying to delete the role."
-: ""
-
-, "Rights"
-: ""
-
-, "Members"
-: ""
-
-, "Role Name"
-: ""
-
-, "Role"
-: ""
-
-, "Add New Role"
-: ""
-
-, "Edit Role \"{0}\""
-: ""
-
-, "Do you really want to delete the selected roles?"
-: ""
-
-, "Deleting role(s)..."
-: ""
-
-, "Add Role"
-: ""
-
-, "Edit Role"
-: ""
-
-, "Delete Role"
-: ""
-
-, "Displaying roles {0} - {1} of {2}"
-: ""
-
-, "No roles to display"
-: ""
-
-, "Access Log, Access Logs"
-: [
-  ""
- ,""
-
-]
-, "Groups"
-: ""
-
-, "Applications"
-: ""
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: ""
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -394,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : ""
 
-, "Login Time"
-: ""
-
 , "never logged in"
 : ""
 
 , "Home Path"
 : ""
 
-, "Logout Time"
-: ""
-
 , "never logged off"
 : ""
 
@@ -427,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : ""
 
-, "Password Must Change"
-: ""
-
 , "Kick Off Time"
 : ""
 
@@ -463,10 +577,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : ""
 
-, "Domain not allowed"
-: ""
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+, "Forward Only"
 : ""
 
 , "E-mail Alias"
@@ -478,6 +589,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: ""
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : ""
 
@@ -490,9 +607,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: ""
-
 , "Password confirmation"
 : ""
 
@@ -505,19 +619,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : ""
 
-, "First name"
-: ""
-
-, "Last name"
-: ""
-
-, "Login name"
-: ""
-
 , "Password"
 : ""
 
-, "OpenID"
+, "Multi Factor Authentication Config"
 : ""
 
 , "enabled"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : ""
 
-, "Expires"
-: ""
-
-, "Visibility"
-: ""
-
-, "Display in addressbook"
-: ""
-
-, "Hide from addressbook"
-: ""
-
-, "Saved in Addressbook"
-: ""
-
-, "Last login at"
-: ""
-
 , "don't know"
 : ""
 
-, "Last login from"
-: ""
-
 , "Password set"
 : ""
 
@@ -583,108 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : ""
 
-, "User, Users"
-: [
-  ""
- ,""
-
-]
-, "Users"
-: ""
-
-, "Samba User, Samba Users"
-: [
-  ""
- ,""
-
-]
-, "Email User, Email Users"
-: [
-  ""
- ,""
-
-]
-, "Enable Account"
-: ""
-
-, "Disable Account"
-: ""
-
-, "Reset Password"
-: ""
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: ""
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: ""
-
-, "Set new password"
-: ""
-
-, "Please enter the new password:"
-: ""
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: ""
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: ""
-
-, "personal"
-: ""
-
-, "shared"
-: ""
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: ""
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  ""
- ,""
-
-]
-, "Container Name"
-: ""
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   ""
  ,""
 
 ]
+, "Please wait"
+: ""
+
+, "Updating Memberships"
+: ""
+
+, "Could not save role."
+: ""
+
+, "Please fix the errors noted."
+: ""
+
+, "Deleting role..."
+: ""
+
+, "Rights"
+: ""
+
+, "Members"
+: ""
+
+, "Role Name"
+: ""
+
+, "Transferring {0}..."
+: ""
+
+, "Role"
+: ""
+
+, "Add New Role"
+: ""
+
+, "Edit Role \"{0}\""
+: ""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -697,76 +724,67 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
+, "Updating Tag"
 : ""
 
-, "Containers"
+, "Could not save tag ({0})"
 : ""
 
-, "Shared Tags"
+, "Allowed Contexts"
 : ""
 
-, "Customfields"
+, "Context"
 : ""
 
-, "Computers"
+, "Account Rights"
 : ""
 
-, "Server Information"
+, "View"
 : ""
 
-, "ActiveSync Devices"
+, "Use"
 : ""
 
-, "E-mail Accounts"
+, "Tag Name"
 : ""
 
-, "Admin"
+, "Tag"
 : ""
 
-, "Refresh"
+, "Add New Tag"
 : ""
 
-, "Feature is disabled by configuration."
+, "Edit Tag \"{0}\""
 : ""
 
-, "IP Address"
+, "Enable Application"
 : ""
 
-, "Client Type"
+, "Disable Application"
 : ""
 
-, "Session ID"
+, "Settings"
 : ""
 
-, "Login Name"
+, "{0} Settings"
 : ""
 
-, "Result"
+, "Enabled"
 : ""
 
-, "user blocked"
+, "Unknown status ({0})"
 : ""
 
-, "password expired"
+, "Displaying application {0} - {1} of {2}"
 : ""
 
-, "user disabled"
+, "No applications to display"
 : ""
 
-, "invalid password"
+, "Version"
 : ""
 
-, "ambiguous username"
-: ""
-
-, "user not found"
-: ""
-
-, "failure"
-: ""
-
-, "success"
+, "Default password must change for new user settings"
 : ""
 
 , "Default IMAP user settings"
@@ -790,6 +808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : ""
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -844,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -910,22 +940,31 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
+
+, "ImportExportDefinition"
+: ""
+
 , "Application"
 : ""
 
-, "Group"
-: ""
-
-, "Customfield"
-: ""
-
-, "Config"
+, "User"
 : ""
 
 , "Access Log"
 : ""
 
-, "User"
+, "Config"
+: ""
+
+, "Container"
+: ""
+
+, "Customfield"
+: ""
+
+, "Group"
 : ""
 
 , "Samba User"
@@ -934,9 +973,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : ""
 
-, "Container"
-: ""
-
 , "Computer"
 : ""
 
