@@ -5,62 +5,248 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Habilitar aplicación"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
 
-, "Disable Application"
-: "Deshabilitar aplicación"
+]
+, "Application, Applications"
+: [
+  "Aplicación"
+ ,"Aplicaciones"
 
-, "Settings"
-: "Configuraciones"
+]
+, "User, Users"
+: [
+  "Usuario"
+ ,"Usuarios"
 
-, "{0} Settings"
-: "{0} Configuraciones"
+]
+, "Groups"
+: "Grupos"
 
-, "Search:"
-: "Buscar:"
+, "Roles"
+: "Cargos"
+
+, "Applications"
+: "Aplicaciones"
+
+, "Containers"
+: "Contenidos"
+
+, "Shared Tags"
+: "Etiquetas Compartidas"
+
+, "Customfields"
+: "campos persolaizados"
+
+, "Computers"
+: "Computadores"
+
+, "Access Log, Access Logs"
+: [
+  "Log de acceso"
+ ,"Logs de accesos"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "Información del servidor"
+
+, "ActiveSync Devices"
+: "Dispositivos ActiveSync"
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Admin"
+
+, "Refresh"
+: "Actualizar"
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Libreta de direcciones por defecto para nuevos usuarios y grupos"
 
-, "Displaying application {0} - {1} of {2}"
-: "Mostrando aplicación {0} - {1} of {2}"
+, "Computer Name"
+: "Nombre del Computador"
 
-, "No applications to display"
-: "No hay aplicaciones para mostrar"
+, "Config, Configs"
+: [
+  ""
+ ,""
 
-, "Order"
-: "Ordenar"
+]
+, "Description"
+: "Descripción"
 
 , "Name"
 : "Nombre"
 
-, "Status"
-: "Estado"
+, "Label"
+: "Etiqueta"
 
-, "Version"
-: "Versión"
+, "Value"
+: "Valor"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: "Si"
+
+, "No"
+: "No"
+
+, "Group Name"
+: "Nombre del Grupo"
+
+, "Visibility"
+: "Visibilidad"
+
+, "Display in addressbook"
+: "Mostrar en libreta de direcciones"
+
+, "Hide from addressbook"
+: "Esconder de la libreta de direcciones"
+
+, "Saved in Addressbook"
+: "Guardar en Libreta de Direcciones"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Miembros del Grupo"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "El dominio no está permitido. Compruebe su configuración de dominios SMTP."
 
 , "Confirm"
 : "Confirmar"
 
+, "Do you really want to delete the selected tags?"
+: "¿Realmente quiere eliminar las etiquetas seleccionadas?"
+
+, "Deleting tag(s)..."
+: "Eliminando etiqueta(s)..."
+
+, "Add Tag"
+: "Agregar Etiqueta"
+
+, "Edit Tag"
+: "Editar Etiqueta"
+
+, "Delete Tag"
+: "Eliminar Etiqueta"
+
+, "Search:"
+: "Buscar:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Mostrando etiquetas {0} - {1} de {2}"
+
+, "No tags to display"
+: "No hay etiquetas que mostrar"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Color"
+
+, "Usage:&#160;"
+: "Uso:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "¿Realmente desea borrar los cargos seleccionados?"
+
+, "Deleting role(s)..."
+: "Borrando cargo(s)..."
+
+, "Failed"
+: "Falló"
+
+, "Some error occurred while trying to delete the role."
+: "Ocurrió un error al intentar borrar el cargo."
+
+, "Add Role"
+: "Agregar Rol"
+
+, "Edit Role"
+: "Editar Rol"
+
+, "Delete Role"
+: "Eliminar Rol"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Mostrando cargos {0} - {1} of {2}"
+
+, "No roles to display"
+: "Sin cargos para mostrar"
+
+, "Container Name"
+: "Nombre del contenedor"
+
+, "Type"
+: "Tipo"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "Contenido"
+ ,"Contenidos"
+
+]
+, "Model"
+: "Modelo"
+
+, "personal"
+: "personal"
+
+, "shared"
+: "compartido"
+
+, "Order"
+: "Ordenar"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Nota para el autor"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "¿Realmente desea borrar los grupos seleccionados?"
 
 , "Deleting group(s)..."
 : "Borrando grupo(s)..."
 
-, "Failed"
-: "Falló"
-
 , "Some error occurred while trying to delete the group."
 : "Ocurrió un error al intentar borrar este grupo."
 
@@ -79,15 +265,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "No hay grupos para mostrar"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Descripción"
-
 , "Creation Time"
 : ""
 
@@ -100,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "Dirección IP"
+
+, "Login Time"
+: "Hora de Ingreso"
+
+, "Logout Time"
+: "Hora de Salida"
+
+, "Client Type"
+: "Tipo de cliente"
+
+, "Session ID"
+: "ID de Sesión"
+
+, "Login Name"
+: "Nombre de Usuario"
+
+, "Result"
+: "Resultado"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "Usuario bloqueado"
+
+, "password expired"
+: "Contraseña expirada"
+
+, "user disabled"
+: "Usuario deshabilitado"
+
+, "invalid password"
+: "Contraseña incorrecta"
+
+, "ambiguous username"
+: "nombre de usuario ambiguo"
+
+, "user not found"
+: "usuario no encontrado"
+
+, "failure"
+: "Error"
+
+, "success"
+: "Exitoso"
+
+, "Customfield, Customfields"
+: [
+  "Campo personalizado"
+ ,"Campos personalizados"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Errores"
 
 , "Please configure store for this field type"
 : "Favor de configurar panel para este tipo de campo"
 
-, "Application, Applications"
-: [
-  "Aplicación"
- ,"Aplicaciones"
-
-]
 , "Record Class"
 : "Clase de Registro"
 
@@ -127,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Panel de Configuración"
 
-, "Model"
-: "Modelo"
-
 , "Custom field definition"
 : "Definir campo personalizado"
 
@@ -166,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Tipo"
-
-, "Label"
-: "Etiqueta"
-
 , "Length"
 : "Largo"
 
@@ -190,183 +415,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Grupos"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Campo personalizado ya existe. Favor de cambiar el nombre"
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Habilitar Cuenta"
+
+, "Disable Account"
+: "Deshabilitar Cuenta"
+
+, "Reset Password"
+: "Restablecer contraseña"
+
+, "Status"
+: "Estado"
+
+, "Display name"
+: "Nombre a mostrar"
+
+, "Login name"
+: "Nombre de Usuario"
+
+, "Last name"
+: "Apellidos"
+
+, "First name"
+: "Nombres"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: "Último ingreso el"
+
+, "Last login from"
+: "Último ingreso desde"
+
+, "Password Must Change"
+: "La Contraseña Debe Cambiar"
+
+, "Password changed"
+: "Contraseña cambiada"
+
+, "Expires"
+: "Expira"
+
+, "Set new password"
+: "Establecer nueva contraseña"
+
+, "Please enter the new password:"
+: "Porfavor escriba la nueva contraseña:"
+
+, "Users"
+: "Usuarios"
+
+, "Samba User, Samba Users"
 : [
-  "Campo personalizado"
- ,"Campos personalizados"
+  "Usuario de Samba"
+ ,"Usuarios de Samba"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: "Si"
-
-, "No"
-: "No"
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
- ,""
+  "Usuario de Correo"
+ ,"Usuarios de Correo"
 
 ]
-, "Value"
-: "Valor"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Nombre del Computador"
-
-, "Default Addressbook for new contacts and groups"
-: "Libreta de direcciones por defecto para nuevos usuarios y grupos"
-
-, "Please wait"
-: "Por favor espere"
-
-, "Updating Tag"
-: "Actualizando Etiqueta"
-
-, "Could not save tag ({0})"
-: "No se pudo guardar la etiqueta ({0})"
-
-, "Please fix the errors noted."
-: "Por favor corrija los errores indicados."
-
-, "Allowed Contexts"
-: "Contextos Permitidos"
-
-, "Context"
-: "Contexto"
-
-, "Account Rights"
-: "Derechos de Cuentas"
-
-, "View"
-: "Ver"
-
-, "Use"
-: "Usar"
-
-, "Tag Name"
-: "Nombre de la etiqueta"
-
-, "Color"
-: "Color"
-
-, "Transferring {0}..."
-: "Transfiriendo {0}..."
-
-, "Tag"
-: "Etiqueta"
-
-, "Add New Tag"
-: "Añadir etiqueta nueva"
-
-, "Edit Tag \"{0}\""
-: "Editar etiqueta «{0}»"
-
-, "Do you really want to delete the selected tags?"
-: "¿Realmente quiere eliminar las etiquetas seleccionadas?"
-
-, "Deleting tag(s)..."
-: "Eliminando etiqueta(s)..."
-
-, "Add Tag"
-: "Agregar Etiqueta"
-
-, "Edit Tag"
-: "Editar Etiqueta"
-
-, "Delete Tag"
-: "Eliminar Etiqueta"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Mostrando etiquetas {0} - {1} de {2}"
-
-, "No tags to display"
-: "No hay etiquetas que mostrar"
-
-, "Usage:&#160;"
-: "Uso:&#160;"
-
-, "Updating Memberships"
-: "Actualizando Cuentas de Usuario"
-
-, "Could not save role."
-: "No se pudo guardar cargo."
-
-, "Deleting role..."
-: "Borrando cargo..."
-
-, "Some error occurred while trying to delete the role."
-: "Ocurrió un error al intentar borrar el cargo."
-
-, "Rights"
-: "Derechos"
-
-, "Members"
-: "Miembros"
-
-, "Role Name"
-: "Nombre del Cargo"
-
-, "Role"
-: "Rol"
-
-, "Add New Role"
-: "Agregar Nuevo Cargo"
-
-, "Edit Role \"{0}\""
-: "Editar Cargo \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "¿Realmente desea borrar los cargos seleccionados?"
-
-, "Deleting role(s)..."
-: "Borrando cargo(s)..."
-
-, "Add Role"
-: "Agregar Rol"
-
-, "Edit Role"
-: "Editar Rol"
-
-, "Delete Role"
-: "Eliminar Rol"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Mostrando cargos {0} - {1} of {2}"
-
-, "No roles to display"
-: "Sin cargos para mostrar"
-
-, "Access Log, Access Logs"
-: [
-  "Log de acceso"
- ,"Logs de accesos"
-
-]
-, "Groups"
-: "Grupos"
-
-, "Applications"
-: "Aplicaciones"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "El dominio no está permitido. Compruebe su configuración de dominios SMTP."
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -394,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Unidad Home"
 
-, "Login Time"
-: "Hora de Ingreso"
-
 , "never logged in"
 : "nunca ha ingresado"
 
 , "Home Path"
 : "Ubicación Home"
 
-, "Logout Time"
-: "Hora de Salida"
-
 , "never logged off"
 : "nunca ha salido"
 
@@ -427,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "sin guardar"
 
-, "Password Must Change"
-: "La Contraseña Debe Cambiar"
-
 , "Kick Off Time"
 : "Tiempo de Expulsión"
 
@@ -463,11 +577,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Último Ingreso"
 
-, "Domain not allowed"
-: "Dominio denegado"
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: "El dominio {0} del alias {1} que trata de agregar no esta configurado como dominio primario o secundario en la configuracion. Por favor agregar este dominio como secundario en la configuracion SMTP o utilice otro dominio que ya este configurado."
+, "Forward Only"
+: "Sólo Reenviar"
 
 , "E-mail Alias"
 : ""
@@ -478,6 +589,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: "Dominio denegado"
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: "El dominio {0} del alias {1} que trata de agregar no esta configurado como dominio primario o secundario en la configuracion. Por favor agregar este dominio como secundario en la configuracion SMTP o utilice otro dominio que ya este configurado."
+
 , "Forwarding to self"
 : "Reenviar a remitente"
 
@@ -490,9 +607,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Sólo Reenviar"
-
 , "Password confirmation"
 : "Confirmación de Contraseña"
 
@@ -505,20 +619,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Cuenta"
 
-, "First name"
-: "Nombres"
-
-, "Last name"
-: "Apellidos"
-
-, "Login name"
-: "Nombre de Usuario"
-
 , "Password"
 : "Contraseña"
 
-, "OpenID"
-: "OpenID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "habilitado"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "Estado Bloqueado. Sólo es válido si el usuario intentó iniciar sesión con una contraseña incorrecta repetidamente. No es posible fijar este estado."
 
-, "Expires"
-: "Expira"
-
-, "Visibility"
-: "Visibilidad"
-
-, "Display in addressbook"
-: "Mostrar en libreta de direcciones"
-
-, "Hide from addressbook"
-: "Esconder de la libreta de direcciones"
-
-, "Saved in Addressbook"
-: "Guardar en Libreta de Direcciones"
-
-, "Last login at"
-: "Último ingreso el"
-
 , "don't know"
 : "desconocido"
 
-, "Last login from"
-: "Último ingreso desde"
-
 , "Password set"
 : "Contraseña guardada"
 
@@ -583,108 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Usuario"
- ,"Usuarios"
-
-]
-, "Users"
-: "Usuarios"
-
-, "Samba User, Samba Users"
-: [
-  "Usuario de Samba"
- ,"Usuarios de Samba"
-
-]
-, "Email User, Email Users"
-: [
-  "Usuario de Correo"
- ,"Usuarios de Correo"
-
-]
-, "Enable Account"
-: "Habilitar Cuenta"
-
-, "Disable Account"
-: "Deshabilitar Cuenta"
-
-, "Reset Password"
-: "Restablecer contraseña"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Nombre a mostrar"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Contraseña cambiada"
-
-, "Set new password"
-: "Establecer nueva contraseña"
-
-, "Please enter the new password:"
-: "Porfavor escriba la nueva contraseña:"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Nombre del Grupo"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Miembros del Grupo"
-
-, "personal"
-: "personal"
-
-, "shared"
-: "compartido"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Nota para el autor"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "Contenido"
- ,"Contenidos"
-
-]
-, "Container Name"
-: "Nombre del contenedor"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Computador"
  ,"Computadores"
 
 ]
+, "Please wait"
+: "Por favor espere"
+
+, "Updating Memberships"
+: "Actualizando Cuentas de Usuario"
+
+, "Could not save role."
+: "No se pudo guardar cargo."
+
+, "Please fix the errors noted."
+: "Por favor corrija los errores indicados."
+
+, "Deleting role..."
+: "Borrando cargo..."
+
+, "Rights"
+: "Derechos"
+
+, "Members"
+: "Miembros"
+
+, "Role Name"
+: "Nombre del Cargo"
+
+, "Transferring {0}..."
+: "Transfiriendo {0}..."
+
+, "Role"
+: "Rol"
+
+, "Add New Role"
+: "Agregar Nuevo Cargo"
+
+, "Edit Role \"{0}\""
+: "Editar Cargo \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : "Tamaño"
 
@@ -697,77 +724,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Cargos"
+, "Updating Tag"
+: "Actualizando Etiqueta"
 
-, "Containers"
-: "Contenidos"
+, "Could not save tag ({0})"
+: "No se pudo guardar la etiqueta ({0})"
 
-, "Shared Tags"
-: "Etiquetas Compartidas"
+, "Allowed Contexts"
+: "Contextos Permitidos"
 
-, "Customfields"
-: "campos persolaizados"
+, "Context"
+: "Contexto"
 
-, "Computers"
-: "Computadores"
+, "Account Rights"
+: "Derechos de Cuentas"
 
-, "Server Information"
-: "Información del servidor"
+, "View"
+: "Ver"
 
-, "ActiveSync Devices"
-: "Dispositivos ActiveSync"
+, "Use"
+: "Usar"
 
-, "E-mail Accounts"
+, "Tag Name"
+: "Nombre de la etiqueta"
+
+, "Tag"
+: "Etiqueta"
+
+, "Add New Tag"
+: "Añadir etiqueta nueva"
+
+, "Edit Tag \"{0}\""
+: "Editar etiqueta «{0}»"
+
+, "Enable Application"
+: "Habilitar aplicación"
+
+, "Disable Application"
+: "Deshabilitar aplicación"
+
+, "Settings"
+: "Configuraciones"
+
+, "{0} Settings"
+: "{0} Configuraciones"
+
+, "Enabled"
 : ""
 
-, "Admin"
-: "Admin"
-
-, "Refresh"
-: "Actualizar"
-
-, "Feature is disabled by configuration."
+, "Unknown status ({0})"
 : ""
 
-, "IP Address"
-: "Dirección IP"
+, "Displaying application {0} - {1} of {2}"
+: "Mostrando aplicación {0} - {1} of {2}"
 
-, "Client Type"
-: "Tipo de cliente"
+, "No applications to display"
+: "No hay aplicaciones para mostrar"
 
-, "Session ID"
-: "ID de Sesión"
+, "Version"
+: "Versión"
 
-, "Login Name"
-: "Nombre de Usuario"
-
-, "Result"
-: "Resultado"
-
-, "user blocked"
-: "Usuario bloqueado"
-
-, "password expired"
-: "Contraseña expirada"
-
-, "user disabled"
-: "Usuario deshabilitado"
-
-, "invalid password"
-: "Contraseña incorrecta"
-
-, "ambiguous username"
-: "nombre de usuario ambiguo"
-
-, "user not found"
-: "usuario no encontrado"
-
-, "failure"
-: "Error"
-
-, "success"
-: "Exitoso"
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : "Configuraciones por defecto de IMAP del usuario"
@@ -790,6 +808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Su contenido se modificó por %1$s %2$s Nota: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -844,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -910,6 +940,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -954,25 +986,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Aplicación"
 
-, "Group"
-: "Grupo"
-
-, "Customfield"
-: "Campo personalizado"
-
-, "Config"
-: ""
+, "User"
+: "Usuario"
 
 , "Access Log"
 : "Log de acceso"
 
-, "User"
-: "Usuario"
+, "Config"
+: ""
+
+, "Container"
+: "Contenido"
+
+, "Customfield"
+: "Campo personalizado"
+
+, "Group"
+: "Grupo"
 
 , "Samba User"
 : "Usuario de Samba"
@@ -980,9 +1016,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "Usuario de Correo"
 
-, "Container"
-: "Contenido"
-
 , "Computer"
 : "Computador"
 
