@@ -5,62 +5,248 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Aktivoi ohjelma"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
 
-, "Disable Application"
-: "Poista ohjelma käytöstä"
+]
+, "Application, Applications"
+: [
+  "Ohjelma"
+ ,"Ohjelmat"
 
-, "Settings"
-: "Asetukset"
+]
+, "User, Users"
+: [
+  "Käyttäjä"
+ ,"Käyttäjät"
 
-, "{0} Settings"
-: "{0} Asetukset"
+]
+, "Groups"
+: "Ryhmät"
 
-, "Search:"
-: "Hae:"
+, "Roles"
+: "Roolit"
+
+, "Applications"
+: "Ohjelmat"
+
+, "Containers"
+: ""
+
+, "Shared Tags"
+: ""
+
+, "Customfields"
+: ""
+
+, "Computers"
+: "Tietokoneet"
+
+, "Access Log, Access Logs"
+: [
+  "Kirjautumisloki"
+ ,"Kirjautumislokit"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "Palvelimen tiedot"
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Ylläpitäjä"
+
+, "Refresh"
+: "Päivitä"
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Oletus osoitekirja uusille yhteystiedoille ja ryhmille"
 
-, "Displaying application {0} - {1} of {2}"
-: "Näytetään ohjelmat {0} - {1} - {2}"
+, "Computer Name"
+: "Tietokoneen nimi"
 
-, "No applications to display"
-: "Ei ohjelmia näytettäväksi"
+, "Config, Configs"
+: [
+  ""
+ ,""
 
-, "Order"
-: "Järjestys"
+]
+, "Description"
+: "Kuvaus"
 
 , "Name"
 : "Nimi"
 
-, "Status"
-: "Tila"
+, "Label"
+: ""
 
-, "Version"
-: "Versio"
+, "Value"
+: "Arvo"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Ryhmän nimi"
+
+, "Visibility"
+: "Näkyvyys"
+
+, "Display in addressbook"
+: "Näytä osoitekirjassa"
+
+, "Hide from addressbook"
+: "Älä näytä osoitekirjassa"
+
+, "Saved in Addressbook"
+: "Tallennettu osoitekirjaan"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Ryhmän jäsenet"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: ""
 
 , "Confirm"
 : "Vahvista"
 
+, "Do you really want to delete the selected tags?"
+: ""
+
+, "Deleting tag(s)..."
+: ""
+
+, "Add Tag"
+: ""
+
+, "Edit Tag"
+: ""
+
+, "Delete Tag"
+: ""
+
+, "Search:"
+: "Hae:"
+
+, "Displaying tags {0} - {1} of {2}"
+: ""
+
+, "No tags to display"
+: ""
+
+, "ID"
+: "Tunnus"
+
+, "Color"
+: "Väri"
+
+, "Usage:&#160;"
+: ""
+
+, "Do you really want to delete the selected roles?"
+: ""
+
+, "Deleting role(s)..."
+: ""
+
+, "Failed"
+: "Epäonnistui"
+
+, "Some error occurred while trying to delete the role."
+: ""
+
+, "Add Role"
+: "Lisää rooli"
+
+, "Edit Role"
+: "Muokkaa roolia"
+
+, "Delete Role"
+: "Poista rooli"
+
+, "Displaying roles {0} - {1} of {2}"
+: ""
+
+, "No roles to display"
+: ""
+
+, "Container Name"
+: ""
+
+, "Type"
+: "Tyyppi"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  ""
+ ,""
+
+]
+, "Model"
+: "Malli"
+
+, "personal"
+: "henkilökohtainen"
+
+, "shared"
+: "jaettu"
+
+, "Order"
+: "Järjestys"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Huomautus käytäjälle"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Haluatko poistaa valitut ryhmät?"
 
 , "Deleting group(s)..."
 : "Poistetaan ryhmiä..."
 
-, "Failed"
-: "Epäonnistui"
-
 , "Some error occurred while trying to delete the group."
 : "Ryhmien poistossa havaittu virheitä."
 
@@ -79,15 +265,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Ei ryhmiä"
 
-, "ID"
-: "Tunnus"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Kuvaus"
-
 , "Creation Time"
 : ""
 
@@ -100,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "IP Osoite"
+
+, "Login Time"
+: "Kirjautumisaika"
+
+, "Logout Time"
+: "Ulos kirjautumisaika"
+
+, "Client Type"
+: "Asiakas tyyppi"
+
+, "Session ID"
+: "Yhteyden tunnus"
+
+, "Login Name"
+: "Kirjautumis nimi"
+
+, "Result"
+: "Tulokset"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "käyttäjä estetty"
+
+, "password expired"
+: "salasana umpeutunut"
+
+, "user disabled"
+: "käyttäjä poistettu"
+
+, "invalid password"
+: "virheellinen salasana"
+
+, "ambiguous username"
+: ""
+
+, "user not found"
+: "käyttäjää ei löydy"
+
+, "failure"
+: "virhe"
+
+, "success"
+: "onnistui"
+
+, "Customfield, Customfields"
+: [
+  "Muokattava kenttä"
+ ,"Muokattavat kentät"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Virheet"
 
 , "Please configure store for this field type"
 : ""
 
-, "Application, Applications"
-: [
-  "Ohjelma"
- ,"Ohjelmat"
-
-]
 , "Record Class"
 : ""
 
@@ -127,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : ""
 
-, "Model"
-: "Malli"
-
 , "Custom field definition"
 : "Muokattavan kentän kuvaus"
 
@@ -166,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Tyyppi"
-
-, "Label"
-: ""
-
 , "Length"
 : "Pituus"
 
@@ -190,183 +415,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Ryhmät"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : ""
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Aktivoi käyttäjätili"
+
+, "Disable Account"
+: "Poista käyttäjätili käytöstä"
+
+, "Reset Password"
+: "Nollaa salasana"
+
+, "Status"
+: "Tila"
+
+, "Display name"
+: "Näyttönimi"
+
+, "Login name"
+: "Kirjautumisnimi"
+
+, "Last name"
+: "Sukunimi"
+
+, "First name"
+: "Etunimi"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: ""
+
+, "Last login at"
+: "Viimeksi kirjautunut"
+
+, "Last login from"
+: "Viimeksi kirjautunut "
+
+, "Password Must Change"
+: "Salasana on vaihdettava"
+
+, "Password changed"
+: "Salasanan muuttaminen"
+
+, "Expires"
+: "Päättynyt"
+
+, "Set new password"
+: "Aseta uusi salasana"
+
+, "Please enter the new password:"
+: "Kirjoita uusi salasana: "
+
+, "Users"
+: "Käyttäjät"
+
+, "Samba User, Samba Users"
 : [
-  "Muokattava kenttä"
- ,"Muokattavat kentät"
+  "Samba käyttäjä"
+ ,"Samba käyttäjät"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
- ,""
+  "Sähköposti käyttäjä"
+ ,"Sähköposti käyttäjät"
 
 ]
-, "Value"
-: "Arvo"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Tietokoneen nimi"
-
-, "Default Addressbook for new contacts and groups"
-: "Oletus osoitekirja uusille yhteystiedoille ja ryhmille"
-
-, "Please wait"
-: "Odota hetki"
-
-, "Updating Tag"
-: ""
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Korjaa löytyneet virheet."
-
-, "Allowed Contexts"
-: ""
-
-, "Context"
-: ""
-
-, "Account Rights"
-: ""
-
-, "View"
-: ""
-
-, "Use"
-: ""
-
-, "Tag Name"
-: ""
-
-, "Color"
-: "Väri"
-
-, "Transferring {0}..."
-: "Siirretään {0}..."
-
-, "Tag"
-: ""
-
-, "Add New Tag"
-: ""
-
-, "Edit Tag \"{0}\""
-: ""
-
-, "Do you really want to delete the selected tags?"
-: ""
-
-, "Deleting tag(s)..."
-: ""
-
-, "Add Tag"
-: ""
-
-, "Edit Tag"
-: ""
-
-, "Delete Tag"
-: ""
-
-, "Displaying tags {0} - {1} of {2}"
-: ""
-
-, "No tags to display"
-: ""
-
-, "Usage:&#160;"
-: ""
-
-, "Updating Memberships"
-: ""
-
-, "Could not save role."
-: "Roolin tallennus ei onnistunut."
-
-, "Deleting role..."
-: "Poistetaan rooli..."
-
-, "Some error occurred while trying to delete the role."
-: ""
-
-, "Rights"
-: "Oikeudet"
-
-, "Members"
-: "Jäsenet"
-
-, "Role Name"
-: "Roolin nimi"
-
-, "Role"
-: "Rooli"
-
-, "Add New Role"
-: "Lisää uusi rooli"
-
-, "Edit Role \"{0}\""
-: ""
-
-, "Do you really want to delete the selected roles?"
-: ""
-
-, "Deleting role(s)..."
-: ""
-
-, "Add Role"
-: "Lisää rooli"
-
-, "Edit Role"
-: "Muokkaa roolia"
-
-, "Delete Role"
-: "Poista rooli"
-
-, "Displaying roles {0} - {1} of {2}"
-: ""
-
-, "No roles to display"
-: ""
-
-, "Access Log, Access Logs"
-: [
-  "Kirjautumisloki"
- ,"Kirjautumislokit"
-
-]
-, "Groups"
-: "Ryhmät"
-
-, "Applications"
-: "Ohjelmat"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: ""
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -394,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : ""
 
-, "Login Time"
-: "Kirjautumisaika"
-
 , "never logged in"
 : "ei koskaan kirjautunut sisään"
 
 , "Home Path"
 : "Kotipolku"
 
-, "Logout Time"
-: "Ulos kirjautumisaika"
-
 , "never logged off"
 : "ei koskaan kirjautunut ulos"
 
@@ -427,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "ei asetettu"
 
-, "Password Must Change"
-: "Salasana on vaihdettava"
-
 , "Kick Off Time"
 : ""
 
@@ -463,11 +577,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Edellinen kirjautuminen"
 
-, "Domain not allowed"
-: ""
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "Uudelleen ohjaus ainoastaan"
 
 , "E-mail Alias"
 : ""
@@ -478,6 +589,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: ""
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : ""
 
@@ -490,9 +607,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Uudelleen ohjaus ainoastaan"
-
 , "Password confirmation"
 : "Salasanan vahvistaminen"
 
@@ -505,19 +619,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Käyttäjätili"
 
-, "First name"
-: "Etunimi"
-
-, "Last name"
-: "Sukunimi"
-
-, "Login name"
-: "Kirjautumisnimi"
-
 , "Password"
 : "Salasana"
 
-, "OpenID"
+, "Multi Factor Authentication Config"
 : ""
 
 , "enabled"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : ""
 
-, "Expires"
-: "Päättynyt"
-
-, "Visibility"
-: "Näkyvyys"
-
-, "Display in addressbook"
-: "Näytä osoitekirjassa"
-
-, "Hide from addressbook"
-: "Älä näytä osoitekirjassa"
-
-, "Saved in Addressbook"
-: "Tallennettu osoitekirjaan"
-
-, "Last login at"
-: "Viimeksi kirjautunut"
-
 , "don't know"
 : "ei tiedossa"
 
-, "Last login from"
-: "Viimeksi kirjautunut "
-
 , "Password set"
 : ""
 
@@ -583,108 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Käyttäjä"
- ,"Käyttäjät"
-
-]
-, "Users"
-: "Käyttäjät"
-
-, "Samba User, Samba Users"
-: [
-  "Samba käyttäjä"
- ,"Samba käyttäjät"
-
-]
-, "Email User, Email Users"
-: [
-  "Sähköposti käyttäjä"
- ,"Sähköposti käyttäjät"
-
-]
-, "Enable Account"
-: "Aktivoi käyttäjätili"
-
-, "Disable Account"
-: "Poista käyttäjätili käytöstä"
-
-, "Reset Password"
-: "Nollaa salasana"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Näyttönimi"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Salasanan muuttaminen"
-
-, "Set new password"
-: "Aseta uusi salasana"
-
-, "Please enter the new password:"
-: "Kirjoita uusi salasana: "
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Ryhmän nimi"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Ryhmän jäsenet"
-
-, "personal"
-: "henkilökohtainen"
-
-, "shared"
-: "jaettu"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Huomautus käytäjälle"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  ""
- ,""
-
-]
-, "Container Name"
-: ""
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Tietokone"
  ,"Tietokoneet"
 
 ]
+, "Please wait"
+: "Odota hetki"
+
+, "Updating Memberships"
+: ""
+
+, "Could not save role."
+: "Roolin tallennus ei onnistunut."
+
+, "Please fix the errors noted."
+: "Korjaa löytyneet virheet."
+
+, "Deleting role..."
+: "Poistetaan rooli..."
+
+, "Rights"
+: "Oikeudet"
+
+, "Members"
+: "Jäsenet"
+
+, "Role Name"
+: "Roolin nimi"
+
+, "Transferring {0}..."
+: "Siirretään {0}..."
+
+, "Role"
+: "Rooli"
+
+, "Add New Role"
+: "Lisää uusi rooli"
+
+, "Edit Role \"{0}\""
+: ""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -697,77 +724,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Roolit"
-
-, "Containers"
+, "Updating Tag"
 : ""
 
-, "Shared Tags"
+, "Could not save tag ({0})"
 : ""
 
-, "Customfields"
+, "Allowed Contexts"
 : ""
 
-, "Computers"
-: "Tietokoneet"
-
-, "Server Information"
-: "Palvelimen tiedot"
-
-, "ActiveSync Devices"
+, "Context"
 : ""
 
-, "E-mail Accounts"
+, "Account Rights"
 : ""
 
-, "Admin"
-: "Ylläpitäjä"
-
-, "Refresh"
-: "Päivitä"
-
-, "Feature is disabled by configuration."
+, "View"
 : ""
 
-, "IP Address"
-: "IP Osoite"
-
-, "Client Type"
-: "Asiakas tyyppi"
-
-, "Session ID"
-: "Yhteyden tunnus"
-
-, "Login Name"
-: "Kirjautumis nimi"
-
-, "Result"
-: "Tulokset"
-
-, "user blocked"
-: "käyttäjä estetty"
-
-, "password expired"
-: "salasana umpeutunut"
-
-, "user disabled"
-: "käyttäjä poistettu"
-
-, "invalid password"
-: "virheellinen salasana"
-
-, "ambiguous username"
+, "Use"
 : ""
 
-, "user not found"
-: "käyttäjää ei löydy"
+, "Tag Name"
+: ""
 
-, "failure"
-: "virhe"
+, "Tag"
+: ""
 
-, "success"
-: "onnistui"
+, "Add New Tag"
+: ""
+
+, "Edit Tag \"{0}\""
+: ""
+
+, "Enable Application"
+: "Aktivoi ohjelma"
+
+, "Disable Application"
+: "Poista ohjelma käytöstä"
+
+, "Settings"
+: "Asetukset"
+
+, "{0} Settings"
+: "{0} Asetukset"
+
+, "Enabled"
+: ""
+
+, "Unknown status ({0})"
+: ""
+
+, "Displaying application {0} - {1} of {2}"
+: "Näytetään ohjelmat {0} - {1} - {2}"
+
+, "No applications to display"
+: "Ei ohjelmia näytettäväksi"
+
+, "Version"
+: "Versio"
+
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : "Oletus IMAP käyttäjä asetukset"
@@ -790,6 +808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Tallennustilaasi on muutettu %1$s %2$sHuom: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -844,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -910,6 +940,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -944,24 +976,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Ohjelma"
 
-, "Group"
-: "Ryhmä"
-
-, "Customfield"
-: "Muokattava kenttä"
-
-, "Config"
-: ""
+, "User"
+: "Käyttäjä"
 
 , "Access Log"
 : "Kirjautumisloki"
 
-, "User"
-: "Käyttäjä"
+, "Config"
+: ""
+
+, "Container"
+: ""
+
+, "Customfield"
+: "Muokattava kenttä"
+
+, "Group"
+: "Ryhmä"
 
 , "Samba User"
 : "Samba käyttäjä"
@@ -969,9 +1006,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "Sähköposti käyttäjä"
 
-, "Container"
-: ""
-
 , "Computer"
 : "Tietokone"
 
