@@ -5,62 +5,248 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Activer l'application"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
 
-, "Disable Application"
-: "Désactiver l'application"
+]
+, "Application, Applications"
+: [
+  "Application"
+ ,"Applications"
 
-, "Settings"
-: "Paramètres"
+]
+, "User, Users"
+: [
+  "Utilisateur"
+ ,"Utilisateurs"
 
-, "{0} Settings"
-: "{0} paramètres"
+]
+, "Groups"
+: "Groupes"
 
-, "Search:"
-: "Chercher:"
+, "Roles"
+: "Rôles"
+
+, "Applications"
+: "Applications"
+
+, "Containers"
+: "Composants"
+
+, "Shared Tags"
+: "Marqueurs partagés"
+
+, "Customfields"
+: "Champs personnalisés"
+
+, "Computers"
+: "Ordinateurs"
+
+, "Access Log, Access Logs"
+: [
+  "Journal d'accès"
+ ,"Journaux d'accès"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "Informations du serveur"
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Administration"
+
+, "Refresh"
+: "Actualiser"
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Carnet d'adresse par défaut pour un nouveau contact ou groupe"
 
-, "Displaying application {0} - {1} of {2}"
-: "Affichage des applications {0} - {1} de {2}"
+, "Computer Name"
+: "Nom d'ordinateur"
 
-, "No applications to display"
-: "Pas d'application à afficher"
+, "Config, Configs"
+: [
+  ""
+ ,""
 
-, "Order"
-: "Ordre"
+]
+, "Description"
+: "Description"
 
 , "Name"
 : "Nom"
 
-, "Status"
-: "Statut"
+, "Label"
+: "Libellé"
 
-, "Version"
-: "Version"
+, "Value"
+: "Valeur"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Nom du groupe"
+
+, "Visibility"
+: "Visibilité"
+
+, "Display in addressbook"
+: "Afficher dans le carnet d'adresses"
+
+, "Hide from addressbook"
+: "Masquer dans le carnet d'adresses"
+
+, "Saved in Addressbook"
+: "Sauvegarder dans le carnet d'adresses"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Membres du groupe"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Domaine non autorisé. Vérifierla configuration SMTP"
 
 , "Confirm"
 : "Confirmer"
 
+, "Do you really want to delete the selected tags?"
+: "Confirmez la suppression des marqueurs sélectionnés ?"
+
+, "Deleting tag(s)..."
+: "Suppression des marqueurs..."
+
+, "Add Tag"
+: "Ajouter un tag"
+
+, "Edit Tag"
+: "Modifier un tag"
+
+, "Delete Tag"
+: "Supprimer un tag"
+
+, "Search:"
+: "Chercher:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Affichage des marqueurs {0} - {1} de {2}"
+
+, "No tags to display"
+: "Pas de marqueur à afficher"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Couleur"
+
+, "Usage:&#160;"
+: "Usage:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Confirmez vous la suppression des rôles sélectionnés ?"
+
+, "Deleting role(s)..."
+: "Suppression de(s) rôle(s)..."
+
+, "Failed"
+: "Échec"
+
+, "Some error occurred while trying to delete the role."
+: "Une erreur est survenue lors de la suppression du rôle."
+
+, "Add Role"
+: "Ajouter un rôle"
+
+, "Edit Role"
+: "Modifier le rôle"
+
+, "Delete Role"
+: "Supprimer le rôle"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Affichage des rôles {0} - {1} de {2}"
+
+, "No roles to display"
+: "Pas de rôle à afficher"
+
+, "Container Name"
+: "Nom du composant"
+
+, "Type"
+: "Type"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "Composant"
+ ,"Composants"
+
+]
+, "Model"
+: "Modèle"
+
+, "personal"
+: "Personnel"
+
+, "shared"
+: "Partagé"
+
+, "Order"
+: "Ordre"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Note au propriétaire"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Confirmez-vous la suppression des groupes sélectionnés?"
 
 , "Deleting group(s)..."
 : "Suppression de(s) groupe(s)..."
 
-, "Failed"
-: "Échec"
-
 , "Some error occurred while trying to delete the group."
 : "Une erreur est survenue lors de la suppression du groupe."
 
@@ -79,15 +265,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Pas de groupe à afficher"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Description"
-
 , "Creation Time"
 : ""
 
@@ -100,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "Adresse IP"
+
+, "Login Time"
+: "Heure de connexion"
+
+, "Logout Time"
+: "Heure de déconnexion"
+
+, "Client Type"
+: "Type du client"
+
+, "Session ID"
+: "ID de session"
+
+, "Login Name"
+: "Identifiant"
+
+, "Result"
+: "Résultat"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "utilisateur bloqué"
+
+, "password expired"
+: "Mot de passe obsolète"
+
+, "user disabled"
+: "utilisateur désactivé"
+
+, "invalid password"
+: "mot de passe invalide"
+
+, "ambiguous username"
+: "nom d'utilisateur ambigu"
+
+, "user not found"
+: "utilisateur inconnu"
+
+, "failure"
+: "échec"
+
+, "success"
+: "réussi"
+
+, "Customfield, Customfields"
+: [
+  "Champ personnalisé"
+ ,"Champs personnalisés"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Erreurs"
 
 , "Please configure store for this field type"
 : "Merci de configurer le stockage pour ce champ"
 
-, "Application, Applications"
-: [
-  "Application"
- ,"Applications"
-
-]
 , "Record Class"
 : "Type d'enregistrement"
 
@@ -127,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Configurer le stockage"
 
-, "Model"
-: "Modèle"
-
 , "Custom field definition"
 : "Définition du champ personnalisé"
 
@@ -166,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Type"
-
-, "Label"
-: "Libellé"
-
 , "Length"
 : "Longueur"
 
@@ -190,183 +415,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Groupes"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Ce champ personnalisé existe déjà. Choisissez un autre nom."
 
-, "Customfield, Customfields"
-: [
-  "Champ personnalisé"
- ,"Champs personnalisés"
+, "Enable Account"
+: "Activer un compte"
 
-]
-, "This custom field is still in use!"
-: ""
+, "Disable Account"
+: "Désactiver un compte"
 
-, "Are you sure you want to delete them?"
-: ""
+, "Reset Password"
+: "Réinitialiser le mot de passe"
 
-, "Yes"
-: ""
+, "Status"
+: "Statut"
 
-, "No"
-: ""
+, "Display name"
+: "Nom donné"
 
-, "Config, Configs"
-: [
-  ""
- ,""
+, "Login name"
+: "Login"
 
-]
-, "Value"
-: "Valeur"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Nom d'ordinateur"
-
-, "Default Addressbook for new contacts and groups"
-: "Carnet d'adresse par défaut pour un nouveau contact ou groupe"
-
-, "Please wait"
-: "Veuillez patienter"
-
-, "Updating Tag"
-: "Mise à jour du marqueur"
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Veuillez corriger les erreurs indiquées."
-
-, "Allowed Contexts"
-: "Contextes autorisés"
-
-, "Context"
-: "Contexte"
-
-, "Account Rights"
-: "Droits"
-
-, "View"
-: "Visualiser"
-
-, "Use"
-: "Utiliser"
-
-, "Tag Name"
+, "Last name"
 : "Nom"
 
-, "Color"
-: "Couleur"
+, "First name"
+: "Prénom"
 
-, "Transferring {0}..."
-: "Transfert de {0} en cours..."
-
-, "Tag"
-: "Marqueur"
-
-, "Add New Tag"
-: "Ajouter"
-
-, "Edit Tag \"{0}\""
-: "Éditer le marqueur \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Confirmez la suppression des marqueurs sélectionnés ?"
-
-, "Deleting tag(s)..."
-: "Suppression des marqueurs..."
-
-, "Add Tag"
-: "Ajouter un tag"
-
-, "Edit Tag"
-: "Modifier un tag"
-
-, "Delete Tag"
-: "Supprimer un tag"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Affichage des marqueurs {0} - {1} de {2}"
-
-, "No tags to display"
-: "Pas de marqueur à afficher"
-
-, "Usage:&#160;"
-: "Usage:&#160;"
-
-, "Updating Memberships"
-: "Mise à jour des appartenances"
-
-, "Could not save role."
-: "Le rôle n'a pas pu être sauvegardé."
-
-, "Deleting role..."
-: "Suppression du rôle..."
-
-, "Some error occurred while trying to delete the role."
-: "Une erreur est survenue lors de la suppression du rôle."
-
-, "Rights"
-: "Droits"
-
-, "Members"
-: "Membres"
-
-, "Role Name"
-: "Nom du rôle"
-
-, "Role"
-: "Rôle"
-
-, "Add New Role"
-: "Ajouter un nouveau rôle"
-
-, "Edit Role \"{0}\""
-: "Éditer le rôle \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Confirmez vous la suppression des rôles sélectionnés ?"
-
-, "Deleting role(s)..."
-: "Suppression de(s) rôle(s)..."
-
-, "Add Role"
-: "Ajouter un rôle"
-
-, "Edit Role"
-: "Modifier le rôle"
-
-, "Delete Role"
-: "Supprimer le rôle"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Affichage des rôles {0} - {1} de {2}"
-
-, "No roles to display"
-: "Pas de rôle à afficher"
-
-, "Access Log, Access Logs"
-: [
-  "Journal d'accès"
- ,"Journaux d'accès"
-
-]
-, "Groups"
-: "Groupes"
-
-, "Applications"
-: "Applications"
-
-, "Configs"
+, "E-mail usage"
 : ""
 
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Domaine non autorisé. Vérifierla configuration SMTP"
+, "Filesystem usage"
+: ""
 
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: "Dernier login à"
+
+, "Last login from"
+: "Dernier login depuis"
+
+, "Password Must Change"
+: "le mot de passe doit être mis à jour"
+
+, "Password changed"
+: "Mot de passe mis à jour."
+
+, "Expires"
+: "Expiration"
+
+, "Set new password"
+: "Changer de mot de passe"
+
+, "Please enter the new password:"
+: "Veuillez saisir le nouveau mot de passe :"
+
+, "Users"
+: "Utilisateurs"
+
+, "Samba User, Samba Users"
+: [
+  "Utilisateur Samba"
+ ,"Utilisateurs Samba"
+
+]
+, "Email User, Email Users"
+: [
+  "Envoyer un courriel à l'utilisateur"
+ ,"Envoyer un courriel aux utilisateurs"
+
+]
 , "Special characters are not allowed in login name."
 : ""
 
@@ -394,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Lecteur personnel"
 
-, "Login Time"
-: "Heure de connexion"
-
 , "never logged in"
 : "jamais connecté"
 
 , "Home Path"
 : "Chemin du Home"
 
-, "Logout Time"
-: "Heure de déconnexion"
-
 , "never logged off"
 : "jamais déconnecté"
 
@@ -427,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "non défini"
 
-, "Password Must Change"
-: "le mot de passe doit être mis à jour"
-
 , "Kick Off Time"
 : "Durée de bannissement"
 
@@ -463,11 +577,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Dernier login à"
 
-, "Domain not allowed"
-: "Domaine non autorisé"
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "Transfert seulement"
 
 , "E-mail Alias"
 : ""
@@ -478,6 +589,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: "Domaine non autorisé"
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : "Me transférer"
 
@@ -490,9 +607,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Transfert seulement"
-
 , "Password confirmation"
 : "Confirmation du mot de passe"
 
@@ -505,20 +619,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Compte"
 
-, "First name"
-: "Prénom"
-
-, "Last name"
-: "Nom"
-
-, "Login name"
-: "Login"
-
 , "Password"
 : "Mot de passe"
 
-, "OpenID"
-: "OpenID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "activé"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "Le statut bloqué n'est possible que lorsqu'un utilisateur utilise un mauvais mot de passe. Il est impossible de l'utiliser ici."
 
-, "Expires"
-: "Expiration"
-
-, "Visibility"
-: "Visibilité"
-
-, "Display in addressbook"
-: "Afficher dans le carnet d'adresses"
-
-, "Hide from addressbook"
-: "Masquer dans le carnet d'adresses"
-
-, "Saved in Addressbook"
-: "Sauvegarder dans le carnet d'adresses"
-
-, "Last login at"
-: "Dernier login à"
-
 , "don't know"
 : "je ne sais pas"
 
-, "Last login from"
-: "Dernier login depuis"
-
 , "Password set"
 : "Mot de passe défini"
 
@@ -583,108 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Utilisateur"
- ,"Utilisateurs"
-
-]
-, "Users"
-: "Utilisateurs"
-
-, "Samba User, Samba Users"
-: [
-  "Utilisateur Samba"
- ,"Utilisateurs Samba"
-
-]
-, "Email User, Email Users"
-: [
-  "Envoyer un courriel à l'utilisateur"
- ,"Envoyer un courriel aux utilisateurs"
-
-]
-, "Enable Account"
-: "Activer un compte"
-
-, "Disable Account"
-: "Désactiver un compte"
-
-, "Reset Password"
-: "Réinitialiser le mot de passe"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Nom donné"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Mot de passe mis à jour."
-
-, "Set new password"
-: "Changer de mot de passe"
-
-, "Please enter the new password:"
-: "Veuillez saisir le nouveau mot de passe :"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Nom du groupe"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Membres du groupe"
-
-, "personal"
-: "Personnel"
-
-, "shared"
-: "Partagé"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Note au propriétaire"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "Composant"
- ,"Composants"
-
-]
-, "Container Name"
-: "Nom du composant"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Ordinateur"
  ,"Ordinateurs"
 
 ]
+, "Please wait"
+: "Veuillez patienter"
+
+, "Updating Memberships"
+: "Mise à jour des appartenances"
+
+, "Could not save role."
+: "Le rôle n'a pas pu être sauvegardé."
+
+, "Please fix the errors noted."
+: "Veuillez corriger les erreurs indiquées."
+
+, "Deleting role..."
+: "Suppression du rôle..."
+
+, "Rights"
+: "Droits"
+
+, "Members"
+: "Membres"
+
+, "Role Name"
+: "Nom du rôle"
+
+, "Transferring {0}..."
+: "Transfert de {0} en cours..."
+
+, "Role"
+: "Rôle"
+
+, "Add New Role"
+: "Ajouter un nouveau rôle"
+
+, "Edit Role \"{0}\""
+: "Éditer le rôle \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -697,77 +724,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Rôles"
+, "Updating Tag"
+: "Mise à jour du marqueur"
 
-, "Containers"
-: "Composants"
-
-, "Shared Tags"
-: "Marqueurs partagés"
-
-, "Customfields"
-: "Champs personnalisés"
-
-, "Computers"
-: "Ordinateurs"
-
-, "Server Information"
-: "Informations du serveur"
-
-, "ActiveSync Devices"
+, "Could not save tag ({0})"
 : ""
 
-, "E-mail Accounts"
+, "Allowed Contexts"
+: "Contextes autorisés"
+
+, "Context"
+: "Contexte"
+
+, "Account Rights"
+: "Droits"
+
+, "View"
+: "Visualiser"
+
+, "Use"
+: "Utiliser"
+
+, "Tag Name"
+: "Nom"
+
+, "Tag"
+: "Marqueur"
+
+, "Add New Tag"
+: "Ajouter"
+
+, "Edit Tag \"{0}\""
+: "Éditer le marqueur \"{0}\""
+
+, "Enable Application"
+: "Activer l'application"
+
+, "Disable Application"
+: "Désactiver l'application"
+
+, "Settings"
+: "Paramètres"
+
+, "{0} Settings"
+: "{0} paramètres"
+
+, "Enabled"
 : ""
 
-, "Admin"
-: "Administration"
-
-, "Refresh"
-: "Actualiser"
-
-, "Feature is disabled by configuration."
+, "Unknown status ({0})"
 : ""
 
-, "IP Address"
-: "Adresse IP"
+, "Displaying application {0} - {1} of {2}"
+: "Affichage des applications {0} - {1} de {2}"
 
-, "Client Type"
-: "Type du client"
+, "No applications to display"
+: "Pas d'application à afficher"
 
-, "Session ID"
-: "ID de session"
+, "Version"
+: "Version"
 
-, "Login Name"
-: "Identifiant"
-
-, "Result"
-: "Résultat"
-
-, "user blocked"
-: "utilisateur bloqué"
-
-, "password expired"
-: "Mot de passe obsolète"
-
-, "user disabled"
-: "utilisateur désactivé"
-
-, "invalid password"
-: "mot de passe invalide"
-
-, "ambiguous username"
-: "nom d'utilisateur ambigu"
-
-, "user not found"
-: "utilisateur inconnu"
-
-, "failure"
-: "échec"
-
-, "success"
-: "réussi"
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : "Configuration IMAP par défaut"
@@ -790,6 +808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Votre composant a été modifié par %1$s %2$s Note: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -844,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -910,6 +940,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -954,25 +986,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Application"
 
-, "Group"
-: "Groupe"
-
-, "Customfield"
-: "Champ personnalisé"
-
-, "Config"
-: ""
+, "User"
+: "Utilisateur"
 
 , "Access Log"
 : "Journal d'accès"
 
-, "User"
-: "Utilisateur"
+, "Config"
+: ""
+
+, "Container"
+: "Composant"
+
+, "Customfield"
+: "Champ personnalisé"
+
+, "Group"
+: "Groupe"
 
 , "Samba User"
 : "Utilisateur Samba"
@@ -980,9 +1016,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "Envoyer un courriel à l'utilisateur"
 
-, "Container"
-: "Composant"
-
 , "Computer"
 : "Ordinateur"
 
