@@ -5,62 +5,254 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Omogući Modul"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
+ ,""
 
-, "Disable Application"
-: "Onemogući Modul"
+]
+, "Application, Applications"
+: [
+  "Modul"
+ ,"Moduli"
+ ,"Modula"
 
-, "Settings"
-: "Postavke"
+]
+, "User, Users"
+: [
+  "Korisnika"
+ ,"Korisnika"
+ ,"Korisnika"
 
-, "{0} Settings"
-: "{0} Postavke"
+]
+, "Groups"
+: "Grupe"
 
-, "Search:"
-: "Pretraži:"
+, "Roles"
+: "Uloge"
+
+, "Applications"
+: "Moduli"
+
+, "Containers"
+: "Spremnici"
+
+, "Shared Tags"
+: "Zajedničke oznake"
+
+, "Customfields"
+: "Dodatna polja"
+
+, "Computers"
+: "Računala"
+
+, "Access Log, Access Logs"
+: [
+  "Pristupni logovi"
+ ,"Pristupna loga"
+ ,"Pristupnih logova"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "Informacije o poslužitelju"
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Admin"
+
+, "Refresh"
+: "Osvježiti"
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Početni adresar za nove kontakte i grupe"
 
-, "Displaying application {0} - {1} of {2}"
-: "Prikaz modula {0} - {1} od {2}"
+, "Computer Name"
+: "Naziv računala"
 
-, "No applications to display"
-: "Nema modula za prikaz"
+, "Config, Configs"
+: [
+  ""
+ ,""
+ ,""
 
-, "Order"
-: "Redoslijed"
+]
+, "Description"
+: "Opis"
 
 , "Name"
 : "Naziv"
 
-, "Status"
-: "Status"
+, "Label"
+: "Labela"
 
-, "Version"
-: "Verzija"
+, "Value"
+: "Vrijednost"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Naziv grupe"
+
+, "Visibility"
+: "Vidljivost"
+
+, "Display in addressbook"
+: "Prikaži u imeniku"
+
+, "Hide from addressbook"
+: "Sakrij u imeniku"
+
+, "Saved in Addressbook"
+: "Spremljeno u adresar"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Članovi grupe"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Domena nije dopuštena. Provjerite konfiguraciju Vašeg SMTP servera."
 
 , "Confirm"
 : "Potvrdi"
 
+, "Do you really want to delete the selected tags?"
+: "Želite li izbrisati označene oznake?"
+
+, "Deleting tag(s)..."
+: "Brisanje oznake(a)..."
+
+, "Add Tag"
+: "Dodaj Oznaku"
+
+, "Edit Tag"
+: "Uredi Oznaku"
+
+, "Delete Tag"
+: "Obriši Oznaku"
+
+, "Search:"
+: "Pretraži:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Prikaz oznaka {0} - {1} od {2}"
+
+, "No tags to display"
+: "Nema oznaka za prikaz"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Boja"
+
+, "Usage:&#160;"
+: "Iskorišteno:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Želite li izbrisati označene uloge?"
+
+, "Deleting role(s)..."
+: "Brisanje uloge(a)..."
+
+, "Failed"
+: "Neuspjelo"
+
+, "Some error occurred while trying to delete the role."
+: "Pojavila se greška tijekom brisanja uloge."
+
+, "Add Role"
+: "Dodaj Rolu"
+
+, "Edit Role"
+: "Uredi Rolu"
+
+, "Delete Role"
+: "Obriši Rolu"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Prikaz uloga {0} - {1} od {2}"
+
+, "No roles to display"
+: "Nema uloga za prikaz"
+
+, "Container Name"
+: "Naziv spremnika"
+
+, "Type"
+: "Tip"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "Spremnik"
+ ,"Spremnika"
+ ,"Spremnika"
+
+]
+, "Model"
+: "Model"
+
+, "personal"
+: "osobni"
+
+, "shared"
+: "dijeljeni"
+
+, "Order"
+: "Redoslijed"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Biljaška za vlasnika"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Želite li izbrisati označene grupe?"
 
 , "Deleting group(s)..."
 : "Brisanje grupe(a)..."
 
-, "Failed"
-: "Neuspjelo"
-
 , "Some error occurred while trying to delete the group."
 : "Pojavila se greška tijekom brisanja grupe."
 
@@ -79,15 +271,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Nema grupa za prikaz"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Opis"
-
 , "Creation Time"
 : ""
 
@@ -100,19 +286,73 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "IP Adresa"
+
+, "Login Time"
+: "Vrijeme prijave"
+
+, "Logout Time"
+: "Vrijeme odjave"
+
+, "Client Type"
+: "Tip klijenta"
+
+, "Session ID"
+: "ID sesije"
+
+, "Login Name"
+: "Korisničko ime"
+
+, "Result"
+: "Rezultat"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "korisnik blokiran"
+
+, "password expired"
+: "lozinka istekla"
+
+, "user disabled"
+: "korisnik onemogućen"
+
+, "invalid password"
+: "Neispravna zaporka"
+
+, "ambiguous username"
+: "nejasno korisničko ime"
+
+, "user not found"
+: "korisnik nije pronađen"
+
+, "failure"
+: "neuspješno"
+
+, "success"
+: "uspješno"
+
+, "Customfield, Customfields"
+: [
+  "Dodatno polje"
+ ,"Dodatna polja"
+ ,"Dodatnih polja"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Greške"
 
 , "Please configure store for this field type"
 : "Molimo Vas postavite spremanje za ovo polje"
 
-, "Application, Applications"
-: [
-  "Modul"
- ,"Moduli"
- ,"Modula"
-
-]
 , "Record Class"
 : "Zapisnik klase"
 
@@ -128,9 +368,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Postavite spremanje"
 
-, "Model"
-: "Model"
-
 , "Custom field definition"
 : "Definicija Dodatnog polja"
 
@@ -167,12 +404,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Tip"
-
-, "Label"
-: "Labela"
-
 , "Length"
 : "Dužina"
 
@@ -192,186 +423,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Grupa"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Dodatno polje već postoji. Molimo odaberite drugo ime."
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Omogući račun"
+
+, "Disable Account"
+: "Onemogući račun"
+
+, "Reset Password"
+: "Resetiraj lozinku"
+
+, "Status"
+: "Status"
+
+, "Display name"
+: "Prikaz imena"
+
+, "Login name"
+: "Korisničko ime"
+
+, "Last name"
+: "Prezime"
+
+, "First name"
+: "Ime"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: "Zadnja prijava"
+
+, "Last login from"
+: "Zadnja prijava od"
+
+, "Password Must Change"
+: "Potrebna promjena zaporke"
+
+, "Password changed"
+: "Zaporka je promijenjena"
+
+, "Expires"
+: "Ističe"
+
+, "Set new password"
+: "Postavi novu zaporku"
+
+, "Please enter the new password:"
+: "Molimo Vas da unesete novu zaporku:"
+
+, "Users"
+: "Korisnici"
+
+, "Samba User, Samba Users"
 : [
-  "Dodatno polje"
- ,"Dodatna polja"
- ,"Dodatnih polja"
+  "Samba korisnik"
+ ,"Samba korisnika"
+ ,"Samba korisnika"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
- ,""
- ,""
+  "E-mail korisnik"
+ ,"E-mail korisnika"
+ ,"E-mail korisnika"
 
 ]
-, "Value"
-: "Vrijednost"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Naziv računala"
-
-, "Default Addressbook for new contacts and groups"
-: "Početni adresar za nove kontakte i grupe"
-
-, "Please wait"
-: "Molimo pričekajte"
-
-, "Updating Tag"
-: "Ažuriranje oznake"
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Molimo Vas da ispravite zabilježene greške."
-
-, "Allowed Contexts"
-: "Dozvoljena značenja"
-
-, "Context"
-: "Značenje"
-
-, "Account Rights"
-: "Prava korisničkog računa"
-
-, "View"
-: "Pregled"
-
-, "Use"
-: "Korištenje"
-
-, "Tag Name"
-: "Naziv oznake"
-
-, "Color"
-: "Boja"
-
-, "Transferring {0}..."
-: "Prijenos {0}..."
-
-, "Tag"
-: "Oznaka"
-
-, "Add New Tag"
-: "Dodaj novu oznaku"
-
-, "Edit Tag \"{0}\""
-: "Uredi Oznaku \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Želite li izbrisati označene oznake?"
-
-, "Deleting tag(s)..."
-: "Brisanje oznake(a)..."
-
-, "Add Tag"
-: "Dodaj Oznaku"
-
-, "Edit Tag"
-: "Uredi Oznaku"
-
-, "Delete Tag"
-: "Obriši Oznaku"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Prikaz oznaka {0} - {1} od {2}"
-
-, "No tags to display"
-: "Nema oznaka za prikaz"
-
-, "Usage:&#160;"
-: "Iskorišteno:&#160;"
-
-, "Updating Memberships"
-: "Ažuriranje članova"
-
-, "Could not save role."
-: "Nije moguće spremiti ulogu."
-
-, "Deleting role..."
-: "Brisanje uloge..."
-
-, "Some error occurred while trying to delete the role."
-: "Pojavila se greška tijekom brisanja uloge."
-
-, "Rights"
-: "Prava"
-
-, "Members"
-: "Članovi"
-
-, "Role Name"
-: "Naziv uloge"
-
-, "Role"
-: "Uloga"
-
-, "Add New Role"
-: "Dodaj novu ulogu"
-
-, "Edit Role \"{0}\""
-: "Uredi Ulogu \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Želite li izbrisati označene uloge?"
-
-, "Deleting role(s)..."
-: "Brisanje uloge(a)..."
-
-, "Add Role"
-: "Dodaj Rolu"
-
-, "Edit Role"
-: "Uredi Rolu"
-
-, "Delete Role"
-: "Obriši Rolu"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Prikaz uloga {0} - {1} od {2}"
-
-, "No roles to display"
-: "Nema uloga za prikaz"
-
-, "Access Log, Access Logs"
-: [
-  "Pristupni logovi"
- ,"Pristupna loga"
- ,"Pristupnih logova"
-
-]
-, "Groups"
-: "Grupe"
-
-, "Applications"
-: "Moduli"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Domena nije dopuštena. Provjerite konfiguraciju Vašeg SMTP servera."
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -399,18 +527,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Početni disk"
 
-, "Login Time"
-: "Vrijeme prijave"
-
 , "never logged in"
 : "Nikada prijavljen"
 
 , "Home Path"
 : "Početna lokacija"
 
-, "Logout Time"
-: "Vrijeme odjave"
-
 , "never logged off"
 : "Nikada odjavljen"
 
@@ -432,9 +554,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "nije postavljeno"
 
-, "Password Must Change"
-: "Potrebna promjena zaporke"
-
 , "Kick Off Time"
 : "Vrijeme početka"
 
@@ -468,11 +587,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Zadnja prijava"
 
-, "Domain not allowed"
-: "Domena nije dozvoljena"
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "Samo proslijedi"
 
 , "E-mail Alias"
 : ""
@@ -483,6 +599,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: "Domena nije dozvoljena"
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : "Prosjediti na sebe"
 
@@ -495,9 +617,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Samo proslijedi"
-
 , "Password confirmation"
 : "Potvrda zaporke"
 
@@ -510,20 +629,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Račun"
 
-, "First name"
-: "Ime"
-
-, "Last name"
-: "Prezime"
-
-, "Login name"
-: "Korisničko ime"
-
 , "Password"
 : "Zaporka"
 
-, "OpenID"
-: "OpenID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "Omogućeno"
@@ -543,30 +653,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "Status Blokiran je moguć samo ukoliko se korisnik pokuša prijaviti sa krivom lozinkom prevelik broj puta. Taj status nije moguće ovdje postaviti."
 
-, "Expires"
-: "Ističe"
-
-, "Visibility"
-: "Vidljivost"
-
-, "Display in addressbook"
-: "Prikaži u imeniku"
-
-, "Hide from addressbook"
-: "Sakrij u imeniku"
-
-, "Saved in Addressbook"
-: "Spremljeno u adresar"
-
-, "Last login at"
-: "Zadnja prijava"
-
 , "don't know"
 : "ne zna"
 
-, "Last login from"
-: "Zadnja prijava od"
-
 , "Password set"
 : "Zaporka postavljena"
 
@@ -588,106 +677,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Korisnika"
- ,"Korisnika"
- ,"Korisnika"
-
-]
-, "Users"
-: "Korisnici"
-
-, "Samba User, Samba Users"
-: [
-  "Samba korisnik"
- ,"Samba korisnika"
- ,"Samba korisnika"
-
-]
-, "Email User, Email Users"
-: [
-  "E-mail korisnik"
- ,"E-mail korisnika"
- ,"E-mail korisnika"
-
-]
-, "Enable Account"
-: "Omogući račun"
-
-, "Disable Account"
-: "Onemogući račun"
-
-, "Reset Password"
-: "Resetiraj lozinku"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Prikaz imena"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Zaporka je promijenjena"
-
-, "Set new password"
-: "Postavi novu zaporku"
-
-, "Please enter the new password:"
-: "Molimo Vas da unesete novu zaporku:"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Naziv grupe"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Članovi grupe"
-
-, "personal"
-: "osobni"
-
-, "shared"
-: "dijeljeni"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Biljaška za vlasnika"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "Spremnik"
- ,"Spremnika"
- ,"Spremnika"
-
-]
-, "Container Name"
-: "Naziv spremnika"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Računalo"
@@ -695,6 +684,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Računala"
 
 ]
+, "Please wait"
+: "Molimo pričekajte"
+
+, "Updating Memberships"
+: "Ažuriranje članova"
+
+, "Could not save role."
+: "Nije moguće spremiti ulogu."
+
+, "Please fix the errors noted."
+: "Molimo Vas da ispravite zabilježene greške."
+
+, "Deleting role..."
+: "Brisanje uloge..."
+
+, "Rights"
+: "Prava"
+
+, "Members"
+: "Članovi"
+
+, "Role Name"
+: "Naziv uloge"
+
+, "Transferring {0}..."
+: "Prijenos {0}..."
+
+, "Role"
+: "Uloga"
+
+, "Add New Role"
+: "Dodaj novu ulogu"
+
+, "Edit Role \"{0}\""
+: "Uredi Ulogu \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -707,77 +735,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Uloge"
+, "Updating Tag"
+: "Ažuriranje oznake"
 
-, "Containers"
-: "Spremnici"
-
-, "Shared Tags"
-: "Zajedničke oznake"
-
-, "Customfields"
-: "Dodatna polja"
-
-, "Computers"
-: "Računala"
-
-, "Server Information"
-: "Informacije o poslužitelju"
-
-, "ActiveSync Devices"
+, "Could not save tag ({0})"
 : ""
 
-, "E-mail Accounts"
+, "Allowed Contexts"
+: "Dozvoljena značenja"
+
+, "Context"
+: "Značenje"
+
+, "Account Rights"
+: "Prava korisničkog računa"
+
+, "View"
+: "Pregled"
+
+, "Use"
+: "Korištenje"
+
+, "Tag Name"
+: "Naziv oznake"
+
+, "Tag"
+: "Oznaka"
+
+, "Add New Tag"
+: "Dodaj novu oznaku"
+
+, "Edit Tag \"{0}\""
+: "Uredi Oznaku \"{0}\""
+
+, "Enable Application"
+: "Omogući Modul"
+
+, "Disable Application"
+: "Onemogući Modul"
+
+, "Settings"
+: "Postavke"
+
+, "{0} Settings"
+: "{0} Postavke"
+
+, "Enabled"
 : ""
 
-, "Admin"
-: "Admin"
-
-, "Refresh"
-: "Osvježiti"
-
-, "Feature is disabled by configuration."
+, "Unknown status ({0})"
 : ""
 
-, "IP Address"
-: "IP Adresa"
+, "Displaying application {0} - {1} of {2}"
+: "Prikaz modula {0} - {1} od {2}"
 
-, "Client Type"
-: "Tip klijenta"
+, "No applications to display"
+: "Nema modula za prikaz"
 
-, "Session ID"
-: "ID sesije"
+, "Version"
+: "Verzija"
 
-, "Login Name"
-: "Korisničko ime"
-
-, "Result"
-: "Rezultat"
-
-, "user blocked"
-: "korisnik blokiran"
-
-, "password expired"
-: "lozinka istekla"
-
-, "user disabled"
-: "korisnik onemogućen"
-
-, "invalid password"
-: "Neispravna zaporka"
-
-, "ambiguous username"
-: "nejasno korisničko ime"
-
-, "user not found"
-: "korisnik nije pronađen"
-
-, "failure"
-: "neuspješno"
-
-, "success"
-: "uspješno"
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : "Glavne IMAP korisničke postavke"
@@ -800,6 +819,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Vaš spremnik je izmijenje id %1$s %2$s. Bilješka: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -854,6 +879,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -920,6 +951,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -958,25 +991,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Modul"
 
-, "Group"
-: "Grupa"
-
-, "Customfield"
-: "Dodatno polje"
-
-, "Config"
-: ""
+, "User"
+: "Korisnika"
 
 , "Access Log"
 : "Pristupni logovi"
 
-, "User"
-: "Korisnika"
+, "Config"
+: ""
+
+, "Container"
+: "Spremnik"
+
+, "Customfield"
+: "Dodatno polje"
+
+, "Group"
+: "Grupa"
 
 , "Samba User"
 : "Samba korisnik"
@@ -984,9 +1021,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "E-mail korisnik"
 
-, "Container"
-: "Spremnik"
-
 , "Computer"
 : "Računalo"
 
