@@ -5,62 +5,248 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Alkalmazás engedélyezése"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
 
-, "Disable Application"
-: "Alkalmazás letiltása"
+]
+, "Application, Applications"
+: [
+  "Alkalmazás"
+ ,"Alkalmazások"
 
-, "Settings"
-: "Beállítása"
+]
+, "User, Users"
+: [
+  "Felhasználó"
+ ,"Felhasználók"
 
-, "{0} Settings"
-: "{0} Beállítások"
+]
+, "Groups"
+: "Csoportok"
 
-, "Search:"
-: "Keresés:"
+, "Roles"
+: "Szerepek"
+
+, "Applications"
+: "Alkalmazások"
+
+, "Containers"
+: "Konténerek"
+
+, "Shared Tags"
+: "Megosztott címkék"
+
+, "Customfields"
+: "Egyedi mezők"
+
+, "Computers"
+: "Számítógépek"
+
+, "Access Log, Access Logs"
+: [
+  "Hozzáférési Napló"
+ ,"Hozzáférési Napló"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "Szerver információ"
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Admin"
+
+, "Refresh"
+: "Frissítés"
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Alapértelmezett Címjegyzék új kapcsolatokhoz és csoportokhoz"
 
-, "Displaying application {0} - {1} of {2}"
-: "Alkalmazások megjelenítése {0} - {1} / {2}"
+, "Computer Name"
+: "Számítógép Név"
 
-, "No applications to display"
-: "Nincs megjeleníthető alkalamazás"
+, "Config, Configs"
+: [
+  ""
+ ,""
 
-, "Order"
-: "Sorrend"
+]
+, "Description"
+: "Leírás"
 
 , "Name"
 : "Név"
 
-, "Status"
-: "Állapot"
+, "Label"
+: "Osztályozás"
 
-, "Version"
-: "Verzió"
+, "Value"
+: "Érték"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Csoport neve"
+
+, "Visibility"
+: "Láthatóság"
+
+, "Display in addressbook"
+: "Megjelenítés a címjegyzékben"
+
+, "Hide from addressbook"
+: "Elrejtés a címjegyzékben"
+
+, "Saved in Addressbook"
+: "Címjegyzékben mentve"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Csoport tagok"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Domain nem engedélyezett. Nézd meg az SMTP domain konfigurációt."
 
 , "Confirm"
 : "Megerősít"
 
+, "Do you really want to delete the selected tags?"
+: "Biztos törölni akarja a kiválaszott címkéket?"
+
+, "Deleting tag(s)..."
+: "Címke(ék) törlése..."
+
+, "Add Tag"
+: "Címke hozzáadása"
+
+, "Edit Tag"
+: "Címke szerkesztése"
+
+, "Delete Tag"
+: "Címke törlése"
+
+, "Search:"
+: "Keresés:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Címkék megjelenítése {0} - {1} / {2}"
+
+, "No tags to display"
+: "Nincs megjeleníthető címke"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Szín"
+
+, "Usage:&#160;"
+: "Használat:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Biztos törölni akarod a kiválasztott szerepeket?"
+
+, "Deleting role(s)..."
+: "Szerep(ek) törlése..."
+
+, "Failed"
+: "Nem sikerült"
+
+, "Some error occurred while trying to delete the role."
+: "Valamilyen hiba történt a szerep mentése közben."
+
+, "Add Role"
+: "Szabály hozzáadása"
+
+, "Edit Role"
+: "Szabály szerkesztése"
+
+, "Delete Role"
+: "Szabály törlése"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Szerepek megjelenítése{0} - {1} / {2}"
+
+, "No roles to display"
+: "Nincs megjelenthető szerep"
+
+, "Container Name"
+: "Konténer Név"
+
+, "Type"
+: "Típus"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "Konténer"
+ ,"Konténerek"
+
+]
+, "Model"
+: "Modell"
+
+, "personal"
+: "személyes"
+
+, "shared"
+: "megosztott"
+
+, "Order"
+: "Sorrend"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Feljegyzés a tulajdonosnak"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Valóban törölni akarja a kiválasztott csoportokat?"
 
 , "Deleting group(s)..."
 : "Csoport(ok) törlése..."
 
-, "Failed"
-: "Nem sikerült"
-
 , "Some error occurred while trying to delete the group."
 : "Valamilyen hiba történt a csoport törlése közben."
 
@@ -79,15 +265,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Nincs megjeleníthető csoport"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Leírás"
-
 , "Creation Time"
 : ""
 
@@ -100,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "IP Cím"
+
+, "Login Time"
+: "Bejelentkezés ideje"
+
+, "Logout Time"
+: "Kijelentkezés ideje"
+
+, "Client Type"
+: "Kliens típus"
+
+, "Session ID"
+: "Hozzáférés ID"
+
+, "Login Name"
+: "Bejelentkezési név"
+
+, "Result"
+: "Eredmény"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "felhasználó blokkolva"
+
+, "password expired"
+: "jelszó lejárt"
+
+, "user disabled"
+: "felhasználó letiltva"
+
+, "invalid password"
+: "érvénytelen jelszó"
+
+, "ambiguous username"
+: "kétértelmű felhasználó név"
+
+, "user not found"
+: "felhasználó nem található"
+
+, "failure"
+: "hiba"
+
+, "success"
+: "siker"
+
+, "Customfield, Customfields"
+: [
+  "Egyedi mező"
+ ,"Egyedi mezők"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Hibák"
 
 , "Please configure store for this field type"
 : "Kérlek állítsd be ennek a mező típusnak a tárolását"
 
-, "Application, Applications"
-: [
-  "Alkalmazás"
- ,"Alkalmazások"
-
-]
 , "Record Class"
 : "Adat osztály"
 
@@ -127,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Tárolás beállítása"
 
-, "Model"
-: "Modell"
-
 , "Custom field definition"
 : "Egyedi mező leírás"
 
@@ -166,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Típus"
-
-, "Label"
-: "Osztályozás"
-
 , "Length"
 : "Hossz"
 
@@ -190,183 +415,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Csoport"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Egyedi mező már létezik. Kérlek válassz egy másik nevet."
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Fiók engedélyezése"
+
+, "Disable Account"
+: "Fiók törlése"
+
+, "Reset Password"
+: "Jelszó visszaállítása"
+
+, "Status"
+: "Állapot"
+
+, "Display name"
+: "Megjelenítési név"
+
+, "Login name"
+: "Bejelentkezési név"
+
+, "Last name"
+: "Vezetéknév"
+
+, "First name"
+: "Keresztnév"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: "Utolsó bejelentkezés"
+
+, "Last login from"
+: "Utolsó bejelentkezés helye"
+
+, "Password Must Change"
+: "A jelszót meg kell változtatni"
+
+, "Password changed"
+: "Jelszó megváltoztatása"
+
+, "Expires"
+: "Lejár"
+
+, "Set new password"
+: "Új jelszó beállítása"
+
+, "Please enter the new password:"
+: "Kérjük adja meg az új jelszavat:"
+
+, "Users"
+: "Felhasználók"
+
+, "Samba User, Samba Users"
 : [
-  "Egyedi mező"
- ,"Egyedi mezők"
+  "Samba User"
+ ,"Samba Users"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
- ,""
+  "Email User"
+ ,"Email Users"
 
 ]
-, "Value"
-: "Érték"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Számítógép Név"
-
-, "Default Addressbook for new contacts and groups"
-: "Alapértelmezett Címjegyzék új kapcsolatokhoz és csoportokhoz"
-
-, "Please wait"
-: "Kérlek várj"
-
-, "Updating Tag"
-: "Címke frissítése"
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Kérjük javítsa kis a jelölt hibákat."
-
-, "Allowed Contexts"
-: "Megengedett kontextus"
-
-, "Context"
-: "Kontextus"
-
-, "Account Rights"
-: "Fiók jogok"
-
-, "View"
-: "Megtekintés"
-
-, "Use"
-: "Használ"
-
-, "Tag Name"
-: "Címke név"
-
-, "Color"
-: "Szín"
-
-, "Transferring {0}..."
-: "{0} átvitele..."
-
-, "Tag"
-: "Címke"
-
-, "Add New Tag"
-: "Új címke hozzáadása"
-
-, "Edit Tag \"{0}\""
-: "Címke szerkesztése  \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Biztos törölni akarja a kiválaszott címkéket?"
-
-, "Deleting tag(s)..."
-: "Címke(ék) törlése..."
-
-, "Add Tag"
-: "Címke hozzáadása"
-
-, "Edit Tag"
-: "Címke szerkesztése"
-
-, "Delete Tag"
-: "Címke törlése"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Címkék megjelenítése {0} - {1} / {2}"
-
-, "No tags to display"
-: "Nincs megjeleníthető címke"
-
-, "Usage:&#160;"
-: "Használat:&#160;"
-
-, "Updating Memberships"
-: "Tagságok frissítése"
-
-, "Could not save role."
-: "Szerep mentése nem sikerült."
-
-, "Deleting role..."
-: "Szerep törlése..."
-
-, "Some error occurred while trying to delete the role."
-: "Valamilyen hiba történt a szerep mentése közben."
-
-, "Rights"
-: "Jogok"
-
-, "Members"
-: "Tagok"
-
-, "Role Name"
-: "Szerep neve"
-
-, "Role"
-: "Szerep"
-
-, "Add New Role"
-: "Új szerep hozzáadása"
-
-, "Edit Role \"{0}\""
-: "Szerep szerkesztése \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Biztos törölni akarod a kiválasztott szerepeket?"
-
-, "Deleting role(s)..."
-: "Szerep(ek) törlése..."
-
-, "Add Role"
-: "Szabály hozzáadása"
-
-, "Edit Role"
-: "Szabály szerkesztése"
-
-, "Delete Role"
-: "Szabály törlése"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Szerepek megjelenítése{0} - {1} / {2}"
-
-, "No roles to display"
-: "Nincs megjelenthető szerep"
-
-, "Access Log, Access Logs"
-: [
-  "Hozzáférési Napló"
- ,"Hozzáférési Napló"
-
-]
-, "Groups"
-: "Csoportok"
-
-, "Applications"
-: "Alkalmazások"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Domain nem engedélyezett. Nézd meg az SMTP domain konfigurációt."
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -394,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Home meghajtó"
 
-, "Login Time"
-: "Bejelentkezés ideje"
-
 , "never logged in"
 : "sosem jelentkezett be"
 
 , "Home Path"
 : "Home útvonal"
 
-, "Logout Time"
-: "Kijelentkezés ideje"
-
 , "never logged off"
 : "sosem jelentkezett ki"
 
@@ -427,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "nincs beállítva"
 
-, "Password Must Change"
-: "A jelszót meg kell változtatni"
-
 , "Kick Off Time"
 : "Kirúgás ideje"
 
@@ -463,11 +577,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Utolsó bejelentkezés"
 
-, "Domain not allowed"
-: "Domain nem engedélyezett"
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "Csak továbbítás"
 
 , "E-mail Alias"
 : ""
@@ -478,6 +589,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: "Domain nem engedélyezett"
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : "Továbbítás magamnak"
 
@@ -490,9 +607,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Csak továbbítás"
-
 , "Password confirmation"
 : "Jelszó megerősítés"
 
@@ -505,20 +619,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Fiók"
 
-, "First name"
-: "Keresztnév"
-
-, "Last name"
-: "Vezetéknév"
-
-, "Login name"
-: "Bejelentkezési név"
-
 , "Password"
 : "Jelszó"
 
-, "OpenID"
-: "OpenID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "engedélyezve"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "A blokkolt állapot csak akkor él, ha egy felhasználó túl gyakran próbált meg rossz jelszóval bejelentkezni. Itt nem lehetséges ezt az állapotot beállítani."
 
-, "Expires"
-: "Lejár"
-
-, "Visibility"
-: "Láthatóság"
-
-, "Display in addressbook"
-: "Megjelenítés a címjegyzékben"
-
-, "Hide from addressbook"
-: "Elrejtés a címjegyzékben"
-
-, "Saved in Addressbook"
-: "Címjegyzékben mentve"
-
-, "Last login at"
-: "Utolsó bejelentkezés"
-
 , "don't know"
 : "nem tudom"
 
-, "Last login from"
-: "Utolsó bejelentkezés helye"
-
 , "Password set"
 : "Beállított jelszó"
 
@@ -583,108 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Felhasználó"
- ,"Felhasználók"
-
-]
-, "Users"
-: "Felhasználók"
-
-, "Samba User, Samba Users"
-: [
-  "Samba User"
- ,"Samba Users"
-
-]
-, "Email User, Email Users"
-: [
-  "Email User"
- ,"Email Users"
-
-]
-, "Enable Account"
-: "Fiók engedélyezése"
-
-, "Disable Account"
-: "Fiók törlése"
-
-, "Reset Password"
-: "Jelszó visszaállítása"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Megjelenítési név"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Jelszó megváltoztatása"
-
-, "Set new password"
-: "Új jelszó beállítása"
-
-, "Please enter the new password:"
-: "Kérjük adja meg az új jelszavat:"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Csoport neve"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Csoport tagok"
-
-, "personal"
-: "személyes"
-
-, "shared"
-: "megosztott"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Feljegyzés a tulajdonosnak"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "Konténer"
- ,"Konténerek"
-
-]
-, "Container Name"
-: "Konténer Név"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Számítógép"
  ,"Számítógépek"
 
 ]
+, "Please wait"
+: "Kérlek várj"
+
+, "Updating Memberships"
+: "Tagságok frissítése"
+
+, "Could not save role."
+: "Szerep mentése nem sikerült."
+
+, "Please fix the errors noted."
+: "Kérjük javítsa kis a jelölt hibákat."
+
+, "Deleting role..."
+: "Szerep törlése..."
+
+, "Rights"
+: "Jogok"
+
+, "Members"
+: "Tagok"
+
+, "Role Name"
+: "Szerep neve"
+
+, "Transferring {0}..."
+: "{0} átvitele..."
+
+, "Role"
+: "Szerep"
+
+, "Add New Role"
+: "Új szerep hozzáadása"
+
+, "Edit Role \"{0}\""
+: "Szerep szerkesztése \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -697,77 +724,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Szerepek"
+, "Updating Tag"
+: "Címke frissítése"
 
-, "Containers"
-: "Konténerek"
-
-, "Shared Tags"
-: "Megosztott címkék"
-
-, "Customfields"
-: "Egyedi mezők"
-
-, "Computers"
-: "Számítógépek"
-
-, "Server Information"
-: "Szerver információ"
-
-, "ActiveSync Devices"
+, "Could not save tag ({0})"
 : ""
 
-, "E-mail Accounts"
+, "Allowed Contexts"
+: "Megengedett kontextus"
+
+, "Context"
+: "Kontextus"
+
+, "Account Rights"
+: "Fiók jogok"
+
+, "View"
+: "Megtekintés"
+
+, "Use"
+: "Használ"
+
+, "Tag Name"
+: "Címke név"
+
+, "Tag"
+: "Címke"
+
+, "Add New Tag"
+: "Új címke hozzáadása"
+
+, "Edit Tag \"{0}\""
+: "Címke szerkesztése  \"{0}\""
+
+, "Enable Application"
+: "Alkalmazás engedélyezése"
+
+, "Disable Application"
+: "Alkalmazás letiltása"
+
+, "Settings"
+: "Beállítása"
+
+, "{0} Settings"
+: "{0} Beállítások"
+
+, "Enabled"
 : ""
 
-, "Admin"
-: "Admin"
-
-, "Refresh"
-: "Frissítés"
-
-, "Feature is disabled by configuration."
+, "Unknown status ({0})"
 : ""
 
-, "IP Address"
-: "IP Cím"
+, "Displaying application {0} - {1} of {2}"
+: "Alkalmazások megjelenítése {0} - {1} / {2}"
 
-, "Client Type"
-: "Kliens típus"
+, "No applications to display"
+: "Nincs megjeleníthető alkalamazás"
 
-, "Session ID"
-: "Hozzáférés ID"
+, "Version"
+: "Verzió"
 
-, "Login Name"
-: "Bejelentkezési név"
-
-, "Result"
-: "Eredmény"
-
-, "user blocked"
-: "felhasználó blokkolva"
-
-, "password expired"
-: "jelszó lejárt"
-
-, "user disabled"
-: "felhasználó letiltva"
-
-, "invalid password"
-: "érvénytelen jelszó"
-
-, "ambiguous username"
-: "kétértelmű felhasználó név"
-
-, "user not found"
-: "felhasználó nem található"
-
-, "failure"
-: "hiba"
-
-, "success"
-: "siker"
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : "Alapértelmezett IMAP felhasználó beállítások"
@@ -790,6 +808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Konténeredet megváltozotta %1$s %2$sFeljegyzés: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -844,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -910,6 +940,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -948,25 +980,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Alkalmazás"
 
-, "Group"
-: "Csoport"
-
-, "Customfield"
-: "Egyedi mező"
-
-, "Config"
-: ""
+, "User"
+: "Felhasználó"
 
 , "Access Log"
 : "Hozzáférési Napló"
 
-, "User"
-: "Felhasználó"
+, "Config"
+: ""
+
+, "Container"
+: "Konténer"
+
+, "Customfield"
+: "Egyedi mező"
+
+, "Group"
+: "Csoport"
 
 , "Samba User"
 : "Samba User"
@@ -974,9 +1010,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "Email User"
 
-, "Container"
-: "Konténer"
-
 , "Computer"
 : "Számítógép"
 
