@@ -5,62 +5,242 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Japanese (http://www.transifex.com/tine20/tine20/language/ja/)\nLanguage: ja\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Japanese (http://www.transifex.com/tine20/tine20/language/ja/)\nLanguage: ja\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "アプリケーションを有効にする"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
 
-, "Disable Application"
-: "アプリケーションを無効にする"
+]
+, "Application, Applications"
+: [
+  ""
 
-, "Settings"
-: "設定"
+]
+, "User, Users"
+: [
+  "ユーザー"
 
-, "{0} Settings"
-: "{0}の設定"
+]
+, "Groups"
+: "グループ"
 
-, "Search:"
-: "検索："
+, "Roles"
+: "役割"
+
+, "Applications"
+: "アプリケーション"
+
+, "Containers"
+: ""
+
+, "Shared Tags"
+: "共有タグ"
+
+, "Customfields"
+: ""
+
+, "Computers"
+: ""
+
+, "Access Log, Access Logs"
+: [
+  "アクセスログ"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: ""
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "管理者"
+
+, "Refresh"
+: ""
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
+, "Default Addressbook for new contacts and groups"
 : ""
 
-, "Displaying application {0} - {1} of {2}"
-: "アプリケーションの表示 {0} - {1} 件中 {2}"
+, "Computer Name"
+: "コンピューター名"
 
-, "No applications to display"
-: "表示するアプリケーションがありません"
+, "Config, Configs"
+: [
+  ""
 
-, "Order"
-: "並び順"
+]
+, "Description"
+: "説明"
 
 , "Name"
 : "名前"
 
-, "Status"
-: "ステータス"
+, "Label"
+: ""
 
-, "Version"
-: "バージョン"
+, "Value"
+: "値"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "グループ名"
+
+, "Visibility"
+: ""
+
+, "Display in addressbook"
+: "アドレス帳に表示する"
+
+, "Hide from addressbook"
+: "アドレス帳に表示しない"
+
+, "Saved in Addressbook"
+: "アドレス帳に保存"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "グループメンバー"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: ""
 
 , "Confirm"
 : "確認"
 
+, "Do you really want to delete the selected tags?"
+: "選択されたタグを本当に削除しますか？"
+
+, "Deleting tag(s)..."
+: "タグを削除しています..."
+
+, "Add Tag"
+: "タグの追加"
+
+, "Edit Tag"
+: "タグの編集"
+
+, "Delete Tag"
+: "タグの削除"
+
+, "Search:"
+: "検索："
+
+, "Displaying tags {0} - {1} of {2}"
+: "タグの表示 {0} - {1} 件中 {2}"
+
+, "No tags to display"
+: "表示するタグがありません"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "色"
+
+, "Usage:&#160;"
+: ""
+
+, "Do you really want to delete the selected roles?"
+: "選択されたロールを本当に削除しますか？"
+
+, "Deleting role(s)..."
+: "ロールを削除しています..."
+
+, "Failed"
+: "失敗"
+
+, "Some error occurred while trying to delete the role."
+: "ロールの削除中にエラーが発生しました"
+
+, "Add Role"
+: ""
+
+, "Edit Role"
+: ""
+
+, "Delete Role"
+: ""
+
+, "Displaying roles {0} - {1} of {2}"
+: "ロールの表示 {0} - {1} 件中 {2}"
+
+, "No roles to display"
+: "表示するロールがありません"
+
+, "Container Name"
+: "コンテナ名"
+
+, "Type"
+: ""
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "コンテナ"
+
+]
+, "Model"
+: ""
+
+, "personal"
+: "個人用"
+
+, "shared"
+: "共有"
+
+, "Order"
+: "並び順"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: ""
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "本当に選択したグループを削除しますか？"
 
 , "Deleting group(s)..."
 : "グループを削除しています..."
 
-, "Failed"
-: "失敗"
-
 , "Some error occurred while trying to delete the group."
 : "グループの削除中にエラーが発生しました"
 
@@ -79,15 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "表示するグループがありません"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "説明"
-
 , "Creation Time"
 : ""
 
@@ -100,17 +274,71 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "ＩＰアドレス"
+
+, "Login Time"
+: "ログイン時間"
+
+, "Logout Time"
+: "ログアウト時間"
+
+, "Client Type"
+: ""
+
+, "Session ID"
+: "セッションＩＤ"
+
+, "Login Name"
+: "ログイン名"
+
+, "Result"
+: "結果"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "ユーザーはブロックされています"
+
+, "password expired"
+: "パスワードの有効期限が切れました"
+
+, "user disabled"
+: "ユーザーは無効になっています"
+
+, "invalid password"
+: "パスワードが違います"
+
+, "ambiguous username"
+: "あいまいなユーザ名"
+
+, "user not found"
+: "ユーザが見つかりません"
+
+, "failure"
+: "失敗"
+
+, "success"
+: "成功"
+
+, "Customfield, Customfields"
+: [
+  ""
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "エラー"
 
 , "Please configure store for this field type"
 : ""
 
-, "Application, Applications"
-: [
-  ""
-
-]
 , "Record Class"
 : ""
 
@@ -126,9 +354,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "ストアの設定"
 
-, "Model"
-: ""
-
 , "Custom field definition"
 : "カスタムフィールドの定義"
 
@@ -165,12 +390,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: ""
-
-, "Label"
-: ""
-
 , "Length"
 : "長さ"
 
@@ -188,180 +407,79 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
   "グループ"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "カスタムフィールドは既に登録されています。別の名前を使用してください。"
 
-, "Customfield, Customfields"
+, "Enable Account"
+: ""
+
+, "Disable Account"
+: ""
+
+, "Reset Password"
+: ""
+
+, "Status"
+: "ステータス"
+
+, "Display name"
+: ""
+
+, "Login name"
+: ""
+
+, "Last name"
+: "姓"
+
+, "First name"
+: "名"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: ""
+
+, "Last login at"
+: "前回のログイン"
+
+, "Last login from"
+: "前回のログイン（From)"
+
+, "Password Must Change"
+: ""
+
+, "Password changed"
+: "パスワード変更"
+
+, "Expires"
+: "期間"
+
+, "Set new password"
+: "新しいパスワードの設定"
+
+, "Please enter the new password:"
+: "新しいパスワードを入力してください"
+
+, "Users"
+: ""
+
+, "Samba User, Samba Users"
 : [
   ""
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
   ""
 
 ]
-, "Value"
-: "値"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "コンピューター名"
-
-, "Default Addressbook for new contacts and groups"
-: ""
-
-, "Please wait"
-: "お待ちください"
-
-, "Updating Tag"
-: ""
-
-, "Could not save tag ({0})"
-: "タグ({0})は保存できませんでした"
-
-, "Please fix the errors noted."
-: "表示されているエラーを修正してください"
-
-, "Allowed Contexts"
-: "許可されたコンテキスト"
-
-, "Context"
-: "コンテキスト"
-
-, "Account Rights"
-: "アカウントの権限"
-
-, "View"
-: "表示"
-
-, "Use"
-: "使用"
-
-, "Tag Name"
-: "タグ名"
-
-, "Color"
-: "色"
-
-, "Transferring {0}..."
-: "{0}の転送中..."
-
-, "Tag"
-: "タグ"
-
-, "Add New Tag"
-: "タグの新規追加"
-
-, "Edit Tag \"{0}\""
-: "タグの編集 \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "選択されたタグを本当に削除しますか？"
-
-, "Deleting tag(s)..."
-: "タグを削除しています..."
-
-, "Add Tag"
-: "タグの追加"
-
-, "Edit Tag"
-: "タグの編集"
-
-, "Delete Tag"
-: "タグの削除"
-
-, "Displaying tags {0} - {1} of {2}"
-: "タグの表示 {0} - {1} 件中 {2}"
-
-, "No tags to display"
-: "表示するタグがありません"
-
-, "Usage:&#160;"
-: ""
-
-, "Updating Memberships"
-: "メンバーシップをアップデートしています"
-
-, "Could not save role."
-: "ロールを保存できませんでした"
-
-, "Deleting role..."
-: "ロールを削除しています..."
-
-, "Some error occurred while trying to delete the role."
-: "ロールの削除中にエラーが発生しました"
-
-, "Rights"
-: "権限"
-
-, "Members"
-: "メンバー"
-
-, "Role Name"
-: "役割名"
-
-, "Role"
-: ""
-
-, "Add New Role"
-: "役割の追加"
-
-, "Edit Role \"{0}\""
-: "役割の編集 \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "選択されたロールを本当に削除しますか？"
-
-, "Deleting role(s)..."
-: "ロールを削除しています..."
-
-, "Add Role"
-: ""
-
-, "Edit Role"
-: ""
-
-, "Delete Role"
-: ""
-
-, "Displaying roles {0} - {1} of {2}"
-: "ロールの表示 {0} - {1} 件中 {2}"
-
-, "No roles to display"
-: "表示するロールがありません"
-
-, "Access Log, Access Logs"
-: [
-  "アクセスログ"
-
-]
-, "Groups"
-: "グループ"
-
-, "Applications"
-: "アプリケーション"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: ""
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -389,18 +507,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : ""
 
-, "Login Time"
-: "ログイン時間"
-
 , "never logged in"
 : "ログインしていません"
 
 , "Home Path"
 : ""
 
-, "Logout Time"
-: "ログアウト時間"
-
 , "never logged off"
 : ""
 
@@ -422,9 +534,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : ""
 
-, "Password Must Change"
-: ""
-
 , "Kick Off Time"
 : ""
 
@@ -458,10 +567,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : ""
 
-, "Domain not allowed"
-: ""
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+, "Forward Only"
 : ""
 
 , "E-mail Alias"
@@ -473,6 +579,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: ""
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : ""
 
@@ -485,9 +597,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: ""
-
 , "Password confirmation"
 : ""
 
@@ -500,19 +609,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : ""
 
-, "First name"
-: "名"
-
-, "Last name"
-: "姓"
-
-, "Login name"
-: ""
-
 , "Password"
 : "パスワード"
 
-, "OpenID"
+, "Multi Factor Authentication Config"
 : ""
 
 , "enabled"
@@ -533,30 +633,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : ""
 
-, "Expires"
-: "期間"
-
-, "Visibility"
-: ""
-
-, "Display in addressbook"
-: "アドレス帳に表示する"
-
-, "Hide from addressbook"
-: "アドレス帳に表示しない"
-
-, "Saved in Addressbook"
-: "アドレス帳に保存"
-
-, "Last login at"
-: "前回のログイン"
-
 , "don't know"
 : ""
 
-, "Last login from"
-: "前回のログイン（From)"
-
 , "Password set"
 : "パスワード設定"
 
@@ -578,103 +657,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : ""
 
-, "User, Users"
-: [
-  "ユーザー"
-
-]
-, "Users"
-: ""
-
-, "Samba User, Samba Users"
-: [
-  ""
-
-]
-, "Email User, Email Users"
-: [
-  ""
-
-]
-, "Enable Account"
-: ""
-
-, "Disable Account"
-: ""
-
-, "Reset Password"
-: ""
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: ""
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "パスワード変更"
-
-, "Set new password"
-: "新しいパスワードの設定"
-
-, "Please enter the new password:"
-: "新しいパスワードを入力してください"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "グループ名"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "グループメンバー"
-
-, "personal"
-: "個人用"
-
-, "shared"
-: "共有"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: ""
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "コンテナ"
-
-]
-, "Container Name"
-: "コンテナ名"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   ""
 
 ]
+, "Please wait"
+: "お待ちください"
+
+, "Updating Memberships"
+: "メンバーシップをアップデートしています"
+
+, "Could not save role."
+: "ロールを保存できませんでした"
+
+, "Please fix the errors noted."
+: "表示されているエラーを修正してください"
+
+, "Deleting role..."
+: "ロールを削除しています..."
+
+, "Rights"
+: "権限"
+
+, "Members"
+: "メンバー"
+
+, "Role Name"
+: "役割名"
+
+, "Transferring {0}..."
+: "{0}の転送中..."
+
+, "Role"
+: ""
+
+, "Add New Role"
+: "役割の追加"
+
+, "Edit Role \"{0}\""
+: "役割の編集 \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -687,78 +713,69 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "役割"
-
-, "Containers"
+, "Updating Tag"
 : ""
 
-, "Shared Tags"
-: "共有タグ"
+, "Could not save tag ({0})"
+: "タグ({0})は保存できませんでした"
 
-, "Customfields"
+, "Allowed Contexts"
+: "許可されたコンテキスト"
+
+, "Context"
+: "コンテキスト"
+
+, "Account Rights"
+: "アカウントの権限"
+
+, "View"
+: "表示"
+
+, "Use"
+: "使用"
+
+, "Tag Name"
+: "タグ名"
+
+, "Tag"
+: "タグ"
+
+, "Add New Tag"
+: "タグの新規追加"
+
+, "Edit Tag \"{0}\""
+: "タグの編集 \"{0}\""
+
+, "Enable Application"
+: "アプリケーションを有効にする"
+
+, "Disable Application"
+: "アプリケーションを無効にする"
+
+, "Settings"
+: "設定"
+
+, "{0} Settings"
+: "{0}の設定"
+
+, "Enabled"
 : ""
 
-, "Computers"
+, "Unknown status ({0})"
 : ""
 
-, "Server Information"
+, "Displaying application {0} - {1} of {2}"
+: "アプリケーションの表示 {0} - {1} 件中 {2}"
+
+, "No applications to display"
+: "表示するアプリケーションがありません"
+
+, "Version"
+: "バージョン"
+
+, "Default password must change for new user settings"
 : ""
 
-, "ActiveSync Devices"
-: ""
-
-, "E-mail Accounts"
-: ""
-
-, "Admin"
-: "管理者"
-
-, "Refresh"
-: ""
-
-, "Feature is disabled by configuration."
-: ""
-
-, "IP Address"
-: "ＩＰアドレス"
-
-, "Client Type"
-: ""
-
-, "Session ID"
-: "セッションＩＤ"
-
-, "Login Name"
-: "ログイン名"
-
-, "Result"
-: "結果"
-
-, "user blocked"
-: "ユーザーはブロックされています"
-
-, "password expired"
-: "パスワードの有効期限が切れました"
-
-, "user disabled"
-: "ユーザーは無効になっています"
-
-, "invalid password"
-: "パスワードが違います"
-
-, "ambiguous username"
-: "あいまいなユーザ名"
-
-, "user not found"
-: "ユーザが見つかりません"
-
-, "failure"
-: "失敗"
-
-, "success"
-: "成功"
-
 , "Default IMAP user settings"
 : ""
 
@@ -780,6 +797,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : ""
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -834,6 +857,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -900,6 +929,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -937,25 +968,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : ""
 
-, "Group"
-: "グループ"
-
-, "Customfield"
-: ""
-
-, "Config"
-: ""
+, "User"
+: "ユーザー"
 
 , "Access Log"
 : "アクセスログ"
 
-, "User"
-: "ユーザー"
+, "Config"
+: ""
+
+, "Container"
+: "コンテナ"
+
+, "Customfield"
+: ""
+
+, "Group"
+: "グループ"
 
 , "Samba User"
 : ""
@@ -963,9 +998,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : ""
 
-, "Container"
-: "コンテナ"
-
 , "Computer"
 : ""
 
