@@ -5,62 +5,248 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
+
+]
+, "Application, Applications"
+: [
+  "Toepassing"
+ ,"Toepassingen"
+
+]
+, "User, Users"
+: [
+  "Gebruiker"
+ ,"Gebruikers"
+
+]
+, "Groups"
+: "Groepen"
+
+, "Roles"
+: "Rollen"
+
+, "Applications"
+: "Toepassingen"
+
+, "Containers"
+: "Containers"
+
+, "Shared Tags"
+: "Gedeelde tags"
+
+, "Customfields"
 : ""
 
-, "Disable Application"
+, "Computers"
 : ""
 
-, "Settings"
+, "Access Log, Access Logs"
+: [
+  ""
+ ,""
+
+]
+, "Log"
 : ""
 
-, "{0} Settings"
-: "{0} Instellingen"
+, "Server Information"
+: ""
 
-, "Search:"
-: "Zoeken:"
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Beheer"
+
+, "Refresh"
+: ""
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
+, "Default Addressbook for new contacts and groups"
 : ""
 
-, "Displaying application {0} - {1} of {2}"
-: "Tonen van toepassing {0} - {1} van {2}"
-
-, "No applications to display"
-: "Geen toepassingen te tonen"
-
-, "Order"
+, "Computer Name"
 : ""
 
+, "Config, Configs"
+: [
+  ""
+ ,""
+
+]
+, "Description"
+: "Omschrijving"
+
 , "Name"
 : ""
 
-, "Status"
-: "Status"
+, "Label"
+: ""
 
-, "Version"
-: "Versie"
+, "Value"
+: "Waarde"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Groep naam"
+
+, "Visibility"
+: ""
+
+, "Display in addressbook"
+: ""
+
+, "Hide from addressbook"
+: ""
+
+, "Saved in Addressbook"
+: ""
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: ""
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: ""
 
 , "Confirm"
 : "Bevestig"
 
+, "Do you really want to delete the selected tags?"
+: ""
+
+, "Deleting tag(s)..."
+: ""
+
+, "Add Tag"
+: ""
+
+, "Edit Tag"
+: ""
+
+, "Delete Tag"
+: ""
+
+, "Search:"
+: "Zoeken:"
+
+, "Displaying tags {0} - {1} of {2}"
+: ""
+
+, "No tags to display"
+: ""
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Kleur"
+
+, "Usage:&#160;"
+: ""
+
+, "Do you really want to delete the selected roles?"
+: ""
+
+, "Deleting role(s)..."
+: ""
+
+, "Failed"
+: "Mislukt"
+
+, "Some error occurred while trying to delete the role."
+: ""
+
+, "Add Role"
+: ""
+
+, "Edit Role"
+: ""
+
+, "Delete Role"
+: ""
+
+, "Displaying roles {0} - {1} of {2}"
+: ""
+
+, "No roles to display"
+: ""
+
+, "Container Name"
+: "Container naam"
+
+, "Type"
+: "Type"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "Container"
+ ,"Containers"
+
+]
+, "Model"
+: ""
+
+, "personal"
+: "persoonlijk"
+
+, "shared"
+: "gedeeld"
+
+, "Order"
+: ""
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Notitie voor eigenaar"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : ""
 
 , "Deleting group(s)..."
 : ""
 
-, "Failed"
-: "Mislukt"
-
 , "Some error occurred while trying to delete the group."
 : ""
 
@@ -79,15 +265,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : ""
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Omschrijving"
-
 , "Creation Time"
 : ""
 
@@ -100,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "IP adres"
+
+, "Login Time"
+: ""
+
+, "Logout Time"
+: ""
+
+, "Client Type"
+: ""
+
+, "Session ID"
+: ""
+
+, "Login Name"
+: ""
+
+, "Result"
+: ""
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: ""
+
+, "password expired"
+: "wachtwoord verlopen"
+
+, "user disabled"
+: ""
+
+, "invalid password"
+: ""
+
+, "ambiguous username"
+: "gebruikersnaam niet eenduidig"
+
+, "user not found"
+: "gebruiker niet gevonden"
+
+, "failure"
+: ""
+
+, "success"
+: ""
+
+, "Customfield, Customfields"
+: [
+  ""
+ ,""
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Fouten"
 
 , "Please configure store for this field type"
 : ""
 
-, "Application, Applications"
-: [
-  "Toepassing"
- ,"Toepassingen"
-
-]
 , "Record Class"
 : ""
 
@@ -127,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : ""
 
-, "Model"
-: ""
-
 , "Custom field definition"
 : ""
 
@@ -166,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Type"
-
-, "Label"
-: ""
-
 , "Length"
 : ""
 
@@ -190,183 +415,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Groepen"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : ""
 
-, "Customfield, Customfields"
+, "Enable Account"
+: ""
+
+, "Disable Account"
+: ""
+
+, "Reset Password"
+: ""
+
+, "Status"
+: "Status"
+
+, "Display name"
+: ""
+
+, "Login name"
+: ""
+
+, "Last name"
+: "Achternaam"
+
+, "First name"
+: "Voornaam"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: ""
+
+, "Last login at"
+: ""
+
+, "Last login from"
+: ""
+
+, "Password Must Change"
+: ""
+
+, "Password changed"
+: "Wachtwoord gewijzigd"
+
+, "Expires"
+: ""
+
+, "Set new password"
+: ""
+
+, "Please enter the new password:"
+: ""
+
+, "Users"
+: ""
+
+, "Samba User, Samba Users"
 : [
   ""
  ,""
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
   ""
  ,""
 
 ]
-, "Value"
-: "Waarde"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: ""
-
-, "Default Addressbook for new contacts and groups"
-: ""
-
-, "Please wait"
-: "Moment..."
-
-, "Updating Tag"
-: ""
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Verhelp de genoemde fouten."
-
-, "Allowed Contexts"
-: ""
-
-, "Context"
-: ""
-
-, "Account Rights"
-: ""
-
-, "View"
-: ""
-
-, "Use"
-: ""
-
-, "Tag Name"
-: ""
-
-, "Color"
-: "Kleur"
-
-, "Transferring {0}..."
-: ""
-
-, "Tag"
-: ""
-
-, "Add New Tag"
-: ""
-
-, "Edit Tag \"{0}\""
-: ""
-
-, "Do you really want to delete the selected tags?"
-: ""
-
-, "Deleting tag(s)..."
-: ""
-
-, "Add Tag"
-: ""
-
-, "Edit Tag"
-: ""
-
-, "Delete Tag"
-: ""
-
-, "Displaying tags {0} - {1} of {2}"
-: ""
-
-, "No tags to display"
-: ""
-
-, "Usage:&#160;"
-: ""
-
-, "Updating Memberships"
-: ""
-
-, "Could not save role."
-: ""
-
-, "Deleting role..."
-: ""
-
-, "Some error occurred while trying to delete the role."
-: ""
-
-, "Rights"
-: ""
-
-, "Members"
-: ""
-
-, "Role Name"
-: ""
-
-, "Role"
-: ""
-
-, "Add New Role"
-: ""
-
-, "Edit Role \"{0}\""
-: ""
-
-, "Do you really want to delete the selected roles?"
-: ""
-
-, "Deleting role(s)..."
-: ""
-
-, "Add Role"
-: ""
-
-, "Edit Role"
-: ""
-
-, "Delete Role"
-: ""
-
-, "Displaying roles {0} - {1} of {2}"
-: ""
-
-, "No roles to display"
-: ""
-
-, "Access Log, Access Logs"
-: [
-  ""
- ,""
-
-]
-, "Groups"
-: "Groepen"
-
-, "Applications"
-: "Toepassingen"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: ""
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -394,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : ""
 
-, "Login Time"
-: ""
-
 , "never logged in"
 : ""
 
 , "Home Path"
 : ""
 
-, "Logout Time"
-: ""
-
 , "never logged off"
 : ""
 
@@ -427,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : ""
 
-, "Password Must Change"
-: ""
-
 , "Kick Off Time"
 : ""
 
@@ -463,10 +577,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : ""
 
-, "Domain not allowed"
-: ""
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+, "Forward Only"
 : ""
 
 , "E-mail Alias"
@@ -478,6 +589,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: ""
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : ""
 
@@ -490,9 +607,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: ""
-
 , "Password confirmation"
 : ""
 
@@ -505,19 +619,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : ""
 
-, "First name"
-: "Voornaam"
-
-, "Last name"
-: "Achternaam"
-
-, "Login name"
-: ""
-
 , "Password"
 : ""
 
-, "OpenID"
+, "Multi Factor Authentication Config"
 : ""
 
 , "enabled"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : ""
 
-, "Expires"
-: ""
-
-, "Visibility"
-: ""
-
-, "Display in addressbook"
-: ""
-
-, "Hide from addressbook"
-: ""
-
-, "Saved in Addressbook"
-: ""
-
-, "Last login at"
-: ""
-
 , "don't know"
 : ""
 
-, "Last login from"
-: ""
-
 , "Password set"
 : ""
 
@@ -583,108 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : ""
 
-, "User, Users"
-: [
-  "Gebruiker"
- ,"Gebruikers"
-
-]
-, "Users"
-: ""
-
-, "Samba User, Samba Users"
-: [
-  ""
- ,""
-
-]
-, "Email User, Email Users"
-: [
-  ""
- ,""
-
-]
-, "Enable Account"
-: ""
-
-, "Disable Account"
-: ""
-
-, "Reset Password"
-: ""
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: ""
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Wachtwoord gewijzigd"
-
-, "Set new password"
-: ""
-
-, "Please enter the new password:"
-: ""
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Groep naam"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: ""
-
-, "personal"
-: "persoonlijk"
-
-, "shared"
-: "gedeeld"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Notitie voor eigenaar"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "Container"
- ,"Containers"
-
-]
-, "Container Name"
-: "Container naam"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   ""
  ,""
 
 ]
+, "Please wait"
+: "Moment..."
+
+, "Updating Memberships"
+: ""
+
+, "Could not save role."
+: ""
+
+, "Please fix the errors noted."
+: "Verhelp de genoemde fouten."
+
+, "Deleting role..."
+: ""
+
+, "Rights"
+: ""
+
+, "Members"
+: ""
+
+, "Role Name"
+: ""
+
+, "Transferring {0}..."
+: ""
+
+, "Role"
+: ""
+
+, "Add New Role"
+: ""
+
+, "Edit Role \"{0}\""
+: ""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -697,76 +724,67 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Rollen"
-
-, "Containers"
-: "Containers"
-
-, "Shared Tags"
-: "Gedeelde tags"
-
-, "Customfields"
+, "Updating Tag"
 : ""
 
-, "Computers"
+, "Could not save tag ({0})"
 : ""
 
-, "Server Information"
+, "Allowed Contexts"
 : ""
 
-, "ActiveSync Devices"
+, "Context"
 : ""
 
-, "E-mail Accounts"
+, "Account Rights"
 : ""
 
-, "Admin"
-: "Beheer"
-
-, "Refresh"
+, "View"
 : ""
 
-, "Feature is disabled by configuration."
+, "Use"
 : ""
 
-, "IP Address"
-: "IP adres"
-
-, "Client Type"
+, "Tag Name"
 : ""
 
-, "Session ID"
+, "Tag"
 : ""
 
-, "Login Name"
+, "Add New Tag"
 : ""
 
-, "Result"
+, "Edit Tag \"{0}\""
 : ""
 
-, "user blocked"
+, "Enable Application"
 : ""
 
-, "password expired"
-: "wachtwoord verlopen"
-
-, "user disabled"
+, "Disable Application"
 : ""
 
-, "invalid password"
+, "Settings"
 : ""
 
-, "ambiguous username"
-: "gebruikersnaam niet eenduidig"
+, "{0} Settings"
+: "{0} Instellingen"
 
-, "user not found"
-: "gebruiker niet gevonden"
-
-, "failure"
+, "Enabled"
 : ""
 
-, "success"
+, "Unknown status ({0})"
+: ""
+
+, "Displaying application {0} - {1} of {2}"
+: "Tonen van toepassing {0} - {1} van {2}"
+
+, "No applications to display"
+: "Geen toepassingen te tonen"
+
+, "Version"
+: "Versie"
+
+, "Default password must change for new user settings"
 : ""
 
 , "Default IMAP user settings"
@@ -790,6 +808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : ""
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -844,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -910,6 +940,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -935,24 +967,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
+
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Toepassing"
 
-, "Group"
-: "Groep"
+, "User"
+: "Gebruiker"
 
-, "Customfield"
+, "Access Log"
 : ""
 
 , "Config"
 : ""
 
-, "Access Log"
+, "Container"
+: "Container"
+
+, "Customfield"
 : ""
 
-, "User"
-: "Gebruiker"
+, "Group"
+: "Groep"
 
 , "Samba User"
 : ""
@@ -960,9 +998,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : ""
 
-, "Container"
-: "Container"
-
 , "Computer"
 : ""
 
