@@ -5,62 +5,248 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Permitir Aplicação"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
 
-, "Disable Application"
-: "Aplicação Bloqueada"
+]
+, "Application, Applications"
+: [
+  "Aplicação"
+ ,"Aplicações"
 
-, "Settings"
-: "Parâmetros"
+]
+, "User, Users"
+: [
+  "Usuário"
+ ,"Usuários"
 
-, "{0} Settings"
-: "{0} Parâmetros"
+]
+, "Groups"
+: "Grupos"
 
-, "Search:"
-: "Pesquisa:"
+, "Roles"
+: "Funções"
+
+, "Applications"
+: "Aplicações"
+
+, "Containers"
+: "Repositórios"
+
+, "Shared Tags"
+: "Identificações Compartilhadas"
+
+, "Customfields"
+: "Campos personalizados"
+
+, "Computers"
+: "Computadores"
+
+, "Access Log, Access Logs"
+: [
+  "Relação de Acesso"
+ ,"Relação de Acessos"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "Informações do Servidor"
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Administrador"
+
+, "Refresh"
+: "Atualizar"
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Catálogo de Endereços padrão para novos contatos e grupos"
 
-, "Displaying application {0} - {1} of {2}"
-: "Exibindo aplicação {0} - {1} de {2}"
+, "Computer Name"
+: "Nome do Computador"
 
-, "No applications to display"
-: "Nenhuma aplicação a exibir"
+, "Config, Configs"
+: [
+  ""
+ ,""
 
-, "Order"
-: "Ordenar"
+]
+, "Description"
+: "Descrição"
 
 , "Name"
 : "Nome"
 
-, "Status"
-: "Situação"
+, "Label"
+: "Legenda"
 
-, "Version"
-: "Versão"
+, "Value"
+: "Valor"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Nome do Grupo"
+
+, "Visibility"
+: "Visibilidade"
+
+, "Display in addressbook"
+: "Exibir no catálogo de endereços"
+
+, "Hide from addressbook"
+: "Ocultar do catálogo de endereços"
+
+, "Saved in Addressbook"
+: "Salvar no Catálogo de Endereços"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Membros do Grupo"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Domínio não permitido. Verificar a configação do seu domínio SMTP."
 
 , "Confirm"
 : "Confirmar"
 
+, "Do you really want to delete the selected tags?"
+: "Você quer realmente apagar as identificações selecionadas?"
+
+, "Deleting tag(s)..."
+: "Apagando identificação(ões)..."
+
+, "Add Tag"
+: "Adicionar Identificação"
+
+, "Edit Tag"
+: "Editar Identificação"
+
+, "Delete Tag"
+: "Apagar Identificação"
+
+, "Search:"
+: "Pesquisa:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Exibindo identificações {0} - {1} of {2}"
+
+, "No tags to display"
+: "Nenhuma identificação a exibir"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Cor"
+
+, "Usage:&#160;"
+: "Tratamento:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Você quer realmente apagar as funções selecionadas?"
+
+, "Deleting role(s)..."
+: "Apagando função(ões)..."
+
+, "Failed"
+: "Falhou"
+
+, "Some error occurred while trying to delete the role."
+: "Ocorreu algum erro enquanto a função era apagada."
+
+, "Add Role"
+: "Adicionar Função"
+
+, "Edit Role"
+: "Editar Função"
+
+, "Delete Role"
+: "Apagar Função"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Exibindo funções {0} - {1} of {2}"
+
+, "No roles to display"
+: "Nenhuma função a exibir"
+
+, "Container Name"
+: "Nome do Repositório"
+
+, "Type"
+: "Tipo"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "Repositório"
+ ,"Repositórios"
+
+]
+, "Model"
+: "Modelo"
+
+, "personal"
+: "pessoal"
+
+, "shared"
+: "compartilhado"
+
+, "Order"
+: "Ordenar"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Nota para o Proprietário"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Você quer realmente apagar os grupos selecionados?"
 
 , "Deleting group(s)..."
 : "Apagando grupo(s)..."
 
-, "Failed"
-: "Falhou"
-
 , "Some error occurred while trying to delete the group."
 : "Ocorreram alguns erros enquanto tentava apagar o grupo."
 
@@ -79,15 +265,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Nenhum grupo a exibir"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Descrição"
-
 , "Creation Time"
 : ""
 
@@ -100,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "Endereço IP"
+
+, "Login Time"
+: "Hora da Entrada"
+
+, "Logout Time"
+: "Hora de Saída"
+
+, "Client Type"
+: "Tipo de Cliente"
+
+, "Session ID"
+: "ID da Sessão"
+
+, "Login Name"
+: "Nome de Entrada"
+
+, "Result"
+: "Resultado"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "usuário bloqueado"
+
+, "password expired"
+: "senha expirada"
+
+, "user disabled"
+: "usuário inválido"
+
+, "invalid password"
+: "senha inválida"
+
+, "ambiguous username"
+: "nome de usuário ambíguo"
+
+, "user not found"
+: "usuário não encontrado"
+
+, "failure"
+: "falha"
+
+, "success"
+: "sucesso"
+
+, "Customfield, Customfields"
+: [
+  "Campo personalizado"
+ ,"Campos personalizados"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Erros"
 
 , "Please configure store for this field type"
 : "Favor configurar o depósito para este tipo de campo"
 
-, "Application, Applications"
-: [
-  "Aplicação"
- ,"Aplicações"
-
-]
 , "Record Class"
 : "Classe de Registro"
 
@@ -127,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Configurar armazenamento"
 
-, "Model"
-: "Modelo"
-
 , "Custom field definition"
 : "Definição de campo personalizado"
 
@@ -166,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Tipo"
-
-, "Label"
-: "Legenda"
-
 , "Length"
 : "Comprimento"
 
@@ -190,183 +415,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Grupos"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Campo personalizado já existe. Favor escolher outro nome."
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Habilitar Conta"
+
+, "Disable Account"
+: "Desabilitar Conta"
+
+, "Reset Password"
+: "Redefinir Senha"
+
+, "Status"
+: "Situação"
+
+, "Display name"
+: "Exibir nome"
+
+, "Login name"
+: "Nome de entrada"
+
+, "Last name"
+: "Sobrenome"
+
+, "First name"
+: "Prenome"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "ID de Abertura"
+
+, "Last login at"
+: "Último acesso às"
+
+, "Last login from"
+: "Último acesso de"
+
+, "Password Must Change"
+: "Senha deve mudar"
+
+, "Password changed"
+: "Senha modificada"
+
+, "Expires"
+: "Expira"
+
+, "Set new password"
+: "Definir nova senha"
+
+, "Please enter the new password:"
+: "Favor informar nova senha:"
+
+, "Users"
+: "Usuários"
+
+, "Samba User, Samba Users"
 : [
-  "Campo personalizado"
- ,"Campos personalizados"
+  "Usuário Samba"
+ ,"Usuários Samba"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
- ,""
+  "Usuário de Email"
+ ,"Usuários de Email"
 
 ]
-, "Value"
-: "Valor"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Nome do Computador"
-
-, "Default Addressbook for new contacts and groups"
-: "Catálogo de Endereços padrão para novos contatos e grupos"
-
-, "Please wait"
-: "Favor aguardar"
-
-, "Updating Tag"
-: "Atualizando Identificação"
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Favor fixar os erros anotados."
-
-, "Allowed Contexts"
-: "Contextos Permitidos"
-
-, "Context"
-: "Contexto"
-
-, "Account Rights"
-: "Direitos de Conta"
-
-, "View"
-: "Visões"
-
-, "Use"
-: "Usar"
-
-, "Tag Name"
-: "Nome da Identificação"
-
-, "Color"
-: "Cor"
-
-, "Transferring {0}..."
-: "Transferindo {0}..."
-
-, "Tag"
-: "Identificação"
-
-, "Add New Tag"
-: "Adicionar Nova Identificação"
-
-, "Edit Tag \"{0}\""
-: "Editar Identificação  \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Você quer realmente apagar as identificações selecionadas?"
-
-, "Deleting tag(s)..."
-: "Apagando identificação(ões)..."
-
-, "Add Tag"
-: "Adicionar Identificação"
-
-, "Edit Tag"
-: "Editar Identificação"
-
-, "Delete Tag"
-: "Apagar Identificação"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Exibindo identificações {0} - {1} of {2}"
-
-, "No tags to display"
-: "Nenhuma identificação a exibir"
-
-, "Usage:&#160;"
-: "Tratamento:&#160;"
-
-, "Updating Memberships"
-: "Atualizando Sócios"
-
-, "Could not save role."
-: "Não foi possível salvar a função."
-
-, "Deleting role..."
-: "Apagando a função..."
-
-, "Some error occurred while trying to delete the role."
-: "Ocorreu algum erro enquanto a função era apagada."
-
-, "Rights"
-: "Direitos"
-
-, "Members"
-: "Membros"
-
-, "Role Name"
-: "Nome da Função"
-
-, "Role"
-: "Função"
-
-, "Add New Role"
-: "Adicionar Nova Função"
-
-, "Edit Role \"{0}\""
-: "Editar Função \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Você quer realmente apagar as funções selecionadas?"
-
-, "Deleting role(s)..."
-: "Apagando função(ões)..."
-
-, "Add Role"
-: "Adicionar Função"
-
-, "Edit Role"
-: "Editar Função"
-
-, "Delete Role"
-: "Apagar Função"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Exibindo funções {0} - {1} of {2}"
-
-, "No roles to display"
-: "Nenhuma função a exibir"
-
-, "Access Log, Access Logs"
-: [
-  "Relação de Acesso"
- ,"Relação de Acessos"
-
-]
-, "Groups"
-: "Grupos"
-
-, "Applications"
-: "Aplicações"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Domínio não permitido. Verificar a configação do seu domínio SMTP."
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -394,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Drive Inicial"
 
-, "Login Time"
-: "Hora da Entrada"
-
 , "never logged in"
 : "nunca acessado em"
 
 , "Home Path"
 : "Nome do Caminho"
 
-, "Logout Time"
-: "Hora de Saída"
-
 , "never logged off"
 : "nunca desligado"
 
@@ -427,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "não definido"
 
-, "Password Must Change"
-: "Senha deve mudar"
-
 , "Kick Off Time"
 : "Hora de início"
 
@@ -463,11 +577,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Último Acesso"
 
-, "Domain not allowed"
-: "Domínio não permitido"
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "Somente encaminhar "
 
 , "E-mail Alias"
 : ""
@@ -478,6 +589,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: "Domínio não permitido"
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : "Auto encaminhamento"
 
@@ -490,9 +607,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Somente encaminhar "
-
 , "Password confirmation"
 : "Confirmação de senha"
 
@@ -505,20 +619,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Conta"
 
-, "First name"
-: "Prenome"
-
-, "Last name"
-: "Sobrenome"
-
-, "Login name"
-: "Nome de entrada"
-
 , "Password"
 : "Senha"
 
-, "OpenID"
-: "ID de Abertura"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "permitido"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "Situação bloqueada só é válida se o usuário tentou entrar com um senha errada frequentemente. Não é possível atribuir esta situação aqui."
 
-, "Expires"
-: "Expira"
-
-, "Visibility"
-: "Visibilidade"
-
-, "Display in addressbook"
-: "Exibir no catálogo de endereços"
-
-, "Hide from addressbook"
-: "Ocultar do catálogo de endereços"
-
-, "Saved in Addressbook"
-: "Salvar no Catálogo de Endereços"
-
-, "Last login at"
-: "Último acesso às"
-
 , "don't know"
 : "não sei"
 
-, "Last login from"
-: "Último acesso de"
-
 , "Password set"
 : "Definir senha"
 
@@ -583,108 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Usuário"
- ,"Usuários"
-
-]
-, "Users"
-: "Usuários"
-
-, "Samba User, Samba Users"
-: [
-  "Usuário Samba"
- ,"Usuários Samba"
-
-]
-, "Email User, Email Users"
-: [
-  "Usuário de Email"
- ,"Usuários de Email"
-
-]
-, "Enable Account"
-: "Habilitar Conta"
-
-, "Disable Account"
-: "Desabilitar Conta"
-
-, "Reset Password"
-: "Redefinir Senha"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Exibir nome"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Senha modificada"
-
-, "Set new password"
-: "Definir nova senha"
-
-, "Please enter the new password:"
-: "Favor informar nova senha:"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Nome do Grupo"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Membros do Grupo"
-
-, "personal"
-: "pessoal"
-
-, "shared"
-: "compartilhado"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Nota para o Proprietário"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "Repositório"
- ,"Repositórios"
-
-]
-, "Container Name"
-: "Nome do Repositório"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Computador"
  ,"Computadores"
 
 ]
+, "Please wait"
+: "Favor aguardar"
+
+, "Updating Memberships"
+: "Atualizando Sócios"
+
+, "Could not save role."
+: "Não foi possível salvar a função."
+
+, "Please fix the errors noted."
+: "Favor fixar os erros anotados."
+
+, "Deleting role..."
+: "Apagando a função..."
+
+, "Rights"
+: "Direitos"
+
+, "Members"
+: "Membros"
+
+, "Role Name"
+: "Nome da Função"
+
+, "Transferring {0}..."
+: "Transferindo {0}..."
+
+, "Role"
+: "Função"
+
+, "Add New Role"
+: "Adicionar Nova Função"
+
+, "Edit Role \"{0}\""
+: "Editar Função \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -697,77 +724,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Funções"
+, "Updating Tag"
+: "Atualizando Identificação"
 
-, "Containers"
-: "Repositórios"
-
-, "Shared Tags"
-: "Identificações Compartilhadas"
-
-, "Customfields"
-: "Campos personalizados"
-
-, "Computers"
-: "Computadores"
-
-, "Server Information"
-: "Informações do Servidor"
-
-, "ActiveSync Devices"
+, "Could not save tag ({0})"
 : ""
 
-, "E-mail Accounts"
+, "Allowed Contexts"
+: "Contextos Permitidos"
+
+, "Context"
+: "Contexto"
+
+, "Account Rights"
+: "Direitos de Conta"
+
+, "View"
+: "Visões"
+
+, "Use"
+: "Usar"
+
+, "Tag Name"
+: "Nome da Identificação"
+
+, "Tag"
+: "Identificação"
+
+, "Add New Tag"
+: "Adicionar Nova Identificação"
+
+, "Edit Tag \"{0}\""
+: "Editar Identificação  \"{0}\""
+
+, "Enable Application"
+: "Permitir Aplicação"
+
+, "Disable Application"
+: "Aplicação Bloqueada"
+
+, "Settings"
+: "Parâmetros"
+
+, "{0} Settings"
+: "{0} Parâmetros"
+
+, "Enabled"
 : ""
 
-, "Admin"
-: "Administrador"
-
-, "Refresh"
-: "Atualizar"
-
-, "Feature is disabled by configuration."
+, "Unknown status ({0})"
 : ""
 
-, "IP Address"
-: "Endereço IP"
+, "Displaying application {0} - {1} of {2}"
+: "Exibindo aplicação {0} - {1} de {2}"
 
-, "Client Type"
-: "Tipo de Cliente"
+, "No applications to display"
+: "Nenhuma aplicação a exibir"
 
-, "Session ID"
-: "ID da Sessão"
+, "Version"
+: "Versão"
 
-, "Login Name"
-: "Nome de Entrada"
-
-, "Result"
-: "Resultado"
-
-, "user blocked"
-: "usuário bloqueado"
-
-, "password expired"
-: "senha expirada"
-
-, "user disabled"
-: "usuário inválido"
-
-, "invalid password"
-: "senha inválida"
-
-, "ambiguous username"
-: "nome de usuário ambíguo"
-
-, "user not found"
-: "usuário não encontrado"
-
-, "failure"
-: "falha"
-
-, "success"
-: "sucesso"
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : "Parâmetros padrão de usuário IMAP"
@@ -790,6 +808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Seu repositório foi modificado por %1$s %2$sNota: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -844,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -910,6 +940,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -948,25 +980,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Aplicação"
 
-, "Group"
-: "Grupo"
-
-, "Customfield"
-: "Campo personalizado"
-
-, "Config"
-: ""
+, "User"
+: "Usuário"
 
 , "Access Log"
 : "Relação de Acesso"
 
-, "User"
-: "Usuário"
+, "Config"
+: ""
+
+, "Container"
+: "Repositório"
+
+, "Customfield"
+: "Campo personalizado"
+
+, "Group"
+: "Grupo"
 
 , "Samba User"
 : "Usuário Samba"
@@ -974,9 +1010,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "Usuário de Email"
 
-, "Container"
-: "Repositório"
-
 , "Computer"
 : "Computador"
 
