@@ -5,52 +5,247 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nLanguage: ro_RO\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nLanguage: ro_RO\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Activare Aplicaţie"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
+ ,""
 
-, "Disable Application"
-: "Dezctivare Aplicaţie"
+]
+, "Application, Applications"
+: [
+  "Aplicaţie"
+ ,"Aplicaţii"
+ ,"Aplicaţii"
 
-, "Settings"
-: "Setări"
+]
+, "User, Users"
+: [
+  "Utilizator"
+ ,"Utilizatori"
+ ,"Utilizatori"
 
-, "{0} Settings"
-: "{0} Setări"
+]
+, "Groups"
+: "Grupuri"
 
-, "Search:"
+, "Roles"
+: "Roluri"
+
+, "Applications"
+: "Aplicaţii"
+
+, "Containers"
+: "Containere"
+
+, "Shared Tags"
+: ""
+
+, "Customfields"
+: ""
+
+, "Computers"
+: "Calculatoare"
+
+, "Access Log, Access Logs"
+: [
+  ""
+ ,""
+ ,""
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: ""
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Admin"
+
+, "Refresh"
 : ""
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
+, "Default Addressbook for new contacts and groups"
 : ""
 
-, "Displaying application {0} - {1} of {2}"
+, "Computer Name"
 : ""
 
-, "No applications to display"
+, "Config, Configs"
+: [
+  ""
+ ,""
+ ,""
+
+]
+, "Description"
+: "Descriere"
+
+, "Name"
+: "Nume"
+
+, "Label"
+: "Etichetă"
+
+, "Value"
+: "Valoare"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Nume Grup"
+
+, "Visibility"
+: ""
+
+, "Display in addressbook"
+: ""
+
+, "Hide from addressbook"
+: ""
+
+, "Saved in Addressbook"
+: ""
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: ""
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: ""
+
+, "Confirm"
+: "Confirm"
+
+, "Do you really want to delete the selected tags?"
+: ""
+
+, "Deleting tag(s)..."
+: ""
+
+, "Add Tag"
+: "Adaugă Tag"
+
+, "Edit Tag"
+: "Editează Tag"
+
+, "Delete Tag"
+: "Şterge  Tag"
+
+, "Search:"
+: ""
+
+, "Displaying tags {0} - {1} of {2}"
+: ""
+
+, "No tags to display"
+: ""
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Culoare"
+
+, "Usage:&#160;"
+: ""
+
+, "Do you really want to delete the selected roles?"
+: ""
+
+, "Deleting role(s)..."
+: ""
+
+, "Failed"
+: ""
+
+, "Some error occurred while trying to delete the role."
+: ""
+
+, "Add Role"
+: "Adaugă Rol"
+
+, "Edit Role"
+: "Editează Rol"
+
+, "Delete Role"
+: "Şterge Rol"
+
+, "Displaying roles {0} - {1} of {2}"
+: ""
+
+, "No roles to display"
+: ""
+
+, "Container Name"
+: ""
+
+, "Type"
+: "Tip"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  ""
+ ,""
+ ,""
+
+]
+, "Model"
+: "Model"
+
+, "personal"
+: "personal"
+
+, "shared"
 : ""
 
 , "Order"
 : ""
 
-, "Name"
-: "Nume"
+, "Container Hierarchy/Name"
+: ""
 
-, "Status"
-: "Status"
+, "Note for Owner"
+: ""
 
-, "Version"
-: "Versiune"
+, "Info"
+: ""
 
-, "Confirm"
-: "Confirm"
+, "Please create Resources in Addressbook or CoreData."
+: ""
 
 , "Do you really want to delete the selected groups?"
 : ""
@@ -58,9 +253,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Deleting group(s)..."
 : ""
 
-, "Failed"
-: ""
-
 , "Some error occurred while trying to delete the group."
 : ""
 
@@ -79,15 +271,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : ""
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Descriere"
-
 , "Creation Time"
 : ""
 
@@ -100,19 +286,73 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: ""
+
+, "Login Time"
+: ""
+
+, "Logout Time"
+: ""
+
+, "Client Type"
+: "Tip Client "
+
+, "Session ID"
+: "ID Sesiune"
+
+, "Login Name"
+: "Nume Login"
+
+, "Result"
+: "Resultat"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "utilizator blocat"
+
+, "password expired"
+: "parolă expirată"
+
+, "user disabled"
+: "utilizator dezactivat"
+
+, "invalid password"
+: "parolă invalidă"
+
+, "ambiguous username"
+: "nume utilizator ambigu"
+
+, "user not found"
+: "utilizator negăsit"
+
+, "failure"
+: "eşec"
+
+, "success"
+: "succes"
+
+, "Customfield, Customfields"
+: [
+  ""
+ ,""
+ ,""
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Erori"
 
 , "Please configure store for this field type"
 : ""
 
-, "Application, Applications"
-: [
-  "Aplicaţie"
- ,"Aplicaţii"
- ,"Aplicaţii"
-
-]
 , "Record Class"
 : "Clasă înregistrată"
 
@@ -128,9 +368,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : ""
 
-, "Model"
-: "Model"
-
 , "Custom field definition"
 : ""
 
@@ -167,12 +404,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Tip"
-
-, "Label"
-: "Etichetă"
-
 , "Length"
 : "Lungime"
 
@@ -192,186 +423,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Grupuri"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : ""
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Activează Cont"
+
+, "Disable Account"
+: "Dezactivează Cont"
+
+, "Reset Password"
+: ""
+
+, "Status"
+: "Status"
+
+, "Display name"
+: "Nume afişat"
+
+, "Login name"
+: ""
+
+, "Last name"
+: "Nume"
+
+, "First name"
+: "Prenume"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: ""
+
+, "Last login from"
+: ""
+
+, "Password Must Change"
+: ""
+
+, "Password changed"
+: ""
+
+, "Expires"
+: ""
+
+, "Set new password"
+: ""
+
+, "Please enter the new password:"
+: ""
+
+, "Users"
+: "Utilizatori"
+
+, "Samba User, Samba Users"
 : [
   ""
  ,""
  ,""
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
   ""
  ,""
  ,""
 
 ]
-, "Value"
-: "Valoare"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: ""
-
-, "Default Addressbook for new contacts and groups"
-: ""
-
-, "Please wait"
-: ""
-
-, "Updating Tag"
-: ""
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: ""
-
-, "Allowed Contexts"
-: ""
-
-, "Context"
-: ""
-
-, "Account Rights"
-: ""
-
-, "View"
-: ""
-
-, "Use"
-: ""
-
-, "Tag Name"
-: ""
-
-, "Color"
-: "Culoare"
-
-, "Transferring {0}..."
-: ""
-
-, "Tag"
-: "Tag"
-
-, "Add New Tag"
-: ""
-
-, "Edit Tag \"{0}\""
-: ""
-
-, "Do you really want to delete the selected tags?"
-: ""
-
-, "Deleting tag(s)..."
-: ""
-
-, "Add Tag"
-: "Adaugă Tag"
-
-, "Edit Tag"
-: "Editează Tag"
-
-, "Delete Tag"
-: "Şterge  Tag"
-
-, "Displaying tags {0} - {1} of {2}"
-: ""
-
-, "No tags to display"
-: ""
-
-, "Usage:&#160;"
-: ""
-
-, "Updating Memberships"
-: ""
-
-, "Could not save role."
-: ""
-
-, "Deleting role..."
-: ""
-
-, "Some error occurred while trying to delete the role."
-: ""
-
-, "Rights"
-: ""
-
-, "Members"
-: "Membri"
-
-, "Role Name"
-: "Nume Rol"
-
-, "Role"
-: "Rol"
-
-, "Add New Role"
-: "Adaugă Rol Nou"
-
-, "Edit Role \"{0}\""
-: ""
-
-, "Do you really want to delete the selected roles?"
-: ""
-
-, "Deleting role(s)..."
-: ""
-
-, "Add Role"
-: "Adaugă Rol"
-
-, "Edit Role"
-: "Editează Rol"
-
-, "Delete Role"
-: "Şterge Rol"
-
-, "Displaying roles {0} - {1} of {2}"
-: ""
-
-, "No roles to display"
-: ""
-
-, "Access Log, Access Logs"
-: [
-  ""
- ,""
- ,""
-
-]
-, "Groups"
-: "Grupuri"
-
-, "Applications"
-: "Aplicaţii"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: ""
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -399,18 +527,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : ""
 
-, "Login Time"
-: ""
-
 , "never logged in"
 : ""
 
 , "Home Path"
 : ""
 
-, "Logout Time"
-: ""
-
 , "never logged off"
 : ""
 
@@ -432,9 +554,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : ""
 
-, "Password Must Change"
-: ""
-
 , "Kick Off Time"
 : ""
 
@@ -468,10 +587,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : ""
 
-, "Domain not allowed"
-: ""
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+, "Forward Only"
 : ""
 
 , "E-mail Alias"
@@ -483,6 +599,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: ""
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : ""
 
@@ -495,9 +617,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: ""
-
 , "Password confirmation"
 : "Confirmare parolă"
 
@@ -510,20 +629,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Cont"
 
-, "First name"
-: "Prenume"
-
-, "Last name"
-: "Nume"
-
-, "Login name"
-: ""
-
 , "Password"
 : "Parola"
 
-, "OpenID"
-: "OpenID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : ""
@@ -543,30 +653,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : ""
 
-, "Expires"
-: ""
-
-, "Visibility"
-: ""
-
-, "Display in addressbook"
-: ""
-
-, "Hide from addressbook"
-: ""
-
-, "Saved in Addressbook"
-: ""
-
-, "Last login at"
-: ""
-
 , "don't know"
 : ""
 
-, "Last login from"
-: ""
-
 , "Password set"
 : ""
 
@@ -588,106 +677,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Utilizator"
- ,"Utilizatori"
- ,"Utilizatori"
-
-]
-, "Users"
-: "Utilizatori"
-
-, "Samba User, Samba Users"
-: [
-  ""
- ,""
- ,""
-
-]
-, "Email User, Email Users"
-: [
-  ""
- ,""
- ,""
-
-]
-, "Enable Account"
-: "Activează Cont"
-
-, "Disable Account"
-: "Dezactivează Cont"
-
-, "Reset Password"
-: ""
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Nume afişat"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: ""
-
-, "Set new password"
-: ""
-
-, "Please enter the new password:"
-: ""
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Nume Grup"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: ""
-
-, "personal"
-: "personal"
-
-, "shared"
-: ""
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: ""
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  ""
- ,""
- ,""
-
-]
-, "Container Name"
-: ""
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Calculator"
@@ -695,6 +684,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Calculatoare"
 
 ]
+, "Please wait"
+: ""
+
+, "Updating Memberships"
+: ""
+
+, "Could not save role."
+: ""
+
+, "Please fix the errors noted."
+: ""
+
+, "Deleting role..."
+: ""
+
+, "Rights"
+: ""
+
+, "Members"
+: "Membri"
+
+, "Role Name"
+: "Nume Rol"
+
+, "Transferring {0}..."
+: ""
+
+, "Role"
+: "Rol"
+
+, "Add New Role"
+: "Adaugă Rol Nou"
+
+, "Edit Role \"{0}\""
+: ""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -707,77 +735,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Roluri"
-
-, "Containers"
-: "Containere"
-
-, "Shared Tags"
+, "Updating Tag"
 : ""
 
-, "Customfields"
+, "Could not save tag ({0})"
 : ""
 
-, "Computers"
-: "Calculatoare"
-
-, "Server Information"
+, "Allowed Contexts"
 : ""
 
-, "ActiveSync Devices"
+, "Context"
 : ""
 
-, "E-mail Accounts"
+, "Account Rights"
 : ""
 
-, "Admin"
-: "Admin"
-
-, "Refresh"
+, "View"
 : ""
 
-, "Feature is disabled by configuration."
+, "Use"
 : ""
 
-, "IP Address"
+, "Tag Name"
 : ""
 
-, "Client Type"
-: "Tip Client "
+, "Tag"
+: "Tag"
 
-, "Session ID"
-: "ID Sesiune"
+, "Add New Tag"
+: ""
 
-, "Login Name"
-: "Nume Login"
+, "Edit Tag \"{0}\""
+: ""
 
-, "Result"
-: "Resultat"
+, "Enable Application"
+: "Activare Aplicaţie"
 
-, "user blocked"
-: "utilizator blocat"
+, "Disable Application"
+: "Dezctivare Aplicaţie"
 
-, "password expired"
-: "parolă expirată"
+, "Settings"
+: "Setări"
 
-, "user disabled"
-: "utilizator dezactivat"
+, "{0} Settings"
+: "{0} Setări"
 
-, "invalid password"
-: "parolă invalidă"
+, "Enabled"
+: ""
 
-, "ambiguous username"
-: "nume utilizator ambigu"
+, "Unknown status ({0})"
+: ""
 
-, "user not found"
-: "utilizator negăsit"
+, "Displaying application {0} - {1} of {2}"
+: ""
 
-, "failure"
-: "eşec"
+, "No applications to display"
+: ""
 
-, "success"
-: "succes"
+, "Version"
+: "Versiune"
+
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : ""
@@ -800,6 +819,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : ""
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -854,6 +879,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -920,6 +951,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -935,23 +968,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
+
+, "ImportExportDefinition"
+: ""
+
 , "Application"
 : "Aplicaţie"
 
-, "Group"
-: "Grup"
+, "User"
+: "Utilizator"
 
-, "Customfield"
+, "Access Log"
 : ""
 
 , "Config"
 : ""
 
-, "Access Log"
+, "Container"
 : ""
 
-, "User"
-: "Utilizator"
+, "Customfield"
+: ""
+
+, "Group"
+: "Grup"
 
 , "Samba User"
 : ""
@@ -959,9 +999,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : ""
 
-, "Container"
-: ""
-
 , "Computer"
 : "Calculator"
 
