@@ -5,62 +5,260 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Включить приложение"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
+ ,""
+ ,""
 
-, "Disable Application"
-: "Отключить приложение"
+]
+, "Application, Applications"
+: [
+  "Приложение"
+ ,"Приложения"
+ ,"Приложения"
+ ,"Приложения"
 
-, "Settings"
-: "Настройки"
+]
+, "User, Users"
+: [
+  "Пользователь"
+ ,"Пользователя"
+ ,"Пользователей"
+ ,"Пользователей"
 
-, "{0} Settings"
-: "{0} Настройки"
+]
+, "Groups"
+: "Группы"
 
-, "Search:"
-: "Поиск:"
+, "Roles"
+: "Роли"
+
+, "Applications"
+: "Приложения"
+
+, "Containers"
+: "Контейнеры"
+
+, "Shared Tags"
+: "Общие тэги"
+
+, "Customfields"
+: "Настраиваемые поля"
+
+, "Computers"
+: "Компьютеры"
+
+, "Access Log, Access Logs"
+: [
+  "Журнал доступа"
+ ,"Журналы доступа"
+ ,"Журналы доступа"
+ ,"Журналы доступа"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "Информация о сервере"
+
+, "ActiveSync Devices"
+: "Устройства с поддержкой Active Sync"
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Администратор"
+
+, "Refresh"
+: "Обновить"
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Адресная книга по умолчанию для новых контактов и групп"
 
-, "Displaying application {0} - {1} of {2}"
-: "Показаны приложения {0} - {1} из {2}"
+, "Computer Name"
+: "Имя компьютера"
 
-, "No applications to display"
-: "Нет приложений"
+, "Config, Configs"
+: [
+  "Настройка"
+ ,"Настройки"
+ ,"Настройки"
+ ,"Настройки"
 
-, "Order"
-: "Порядок"
+]
+, "Description"
+: "Описание"
 
 , "Name"
 : "Имя"
 
-, "Status"
-: "Статус"
+, "Label"
+: "Метка"
 
-, "Version"
-: "Версия"
+, "Value"
+: "Значение"
+
+, "Default ({0})"
+: "По умолчанию ({0})"
+
+, "Yes"
+: "Да"
+
+, "No"
+: "Нет"
+
+, "Group Name"
+: "Название группы"
+
+, "Visibility"
+: "Видимость"
+
+, "Display in addressbook"
+: "Отображать в адресной книге"
+
+, "Hide from addressbook"
+: "Скрыть в адресной книги"
+
+, "Saved in Addressbook"
+: "Сохранено в адресную книгу"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Члены группы"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Домен недопустим. Пожалуйста, проверьте настройки домена в конфигурации SMTP"
 
 , "Confirm"
 : "Подтвердить"
 
+, "Do you really want to delete the selected tags?"
+: "Вы действительно хотите удалить выбранные тэги?"
+
+, "Deleting tag(s)..."
+: "Удаление тэга(ов)..."
+
+, "Add Tag"
+: "Добавить тег"
+
+, "Edit Tag"
+: "Изменить тег"
+
+, "Delete Tag"
+: "Удалить тег"
+
+, "Search:"
+: "Поиск:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Показаны тэги {0} - {1} из {2}"
+
+, "No tags to display"
+: "Нет тэгов"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Цвет"
+
+, "Usage:&#160;"
+: "Использование:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Вы действительно хотите удалить выбранные роли?"
+
+, "Deleting role(s)..."
+: "Удаление роли(ей)..."
+
+, "Failed"
+: "Неудача"
+
+, "Some error occurred while trying to delete the role."
+: "При удаление роли произошла ошибка."
+
+, "Add Role"
+: "Добавить роль"
+
+, "Edit Role"
+: "Изменить роль"
+
+, "Delete Role"
+: "Удалить роль"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Показаны роли {0} - {1} из {2}"
+
+, "No roles to display"
+: "Нет ролей"
+
+, "Container Name"
+: "Имя контейнера"
+
+, "Type"
+: "Тип"
+
+, "Container Order"
+: "Порядок контейнеров"
+
+, "Container, Containers"
+: [
+  "Контейнер"
+ ,"Контейнеры"
+ ,"Контейнеры"
+ ,"Контейнеры"
+
+]
+, "Model"
+: "Модель"
+
+, "personal"
+: "личный"
+
+, "shared"
+: "общий"
+
+, "Order"
+: "Порядок"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Примечание владельца"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Вы уверены что хотите удалить выбранные группы?"
 
 , "Deleting group(s)..."
 : "Удаление групп(ы)..."
 
-, "Failed"
-: "Неудача"
-
 , "Some error occurred while trying to delete the group."
 : "При удаление группы произошла ошибка."
 
@@ -79,15 +277,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Нет групп"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Описание"
-
 , "Creation Time"
 : ""
 
@@ -100,20 +292,74 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "IP адрес"
+
+, "Login Time"
+: "Время регистрации"
+
+, "Logout Time"
+: "Время выхода из системы"
+
+, "Client Type"
+: "Тип клиента"
+
+, "Session ID"
+: "ID сессии"
+
+, "Login Name"
+: "Имя для регистрации"
+
+, "Result"
+: "Результат"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "пользователь заблокирован"
+
+, "password expired"
+: "истек срок пароля"
+
+, "user disabled"
+: "пользователь отключен"
+
+, "invalid password"
+: "неверный пароль"
+
+, "ambiguous username"
+: "Имя пользователя многозначно"
+
+, "user not found"
+: "пользователь не найден"
+
+, "failure"
+: "неудачно"
+
+, "success"
+: "успешно"
+
+, "Customfield, Customfields"
+: [
+  "Настраиваемые поля"
+ ,"Настраиваемые поля"
+ ,"Настраиваемые поля"
+ ,"Настраиваемые поля"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Ошибки"
 
 , "Please configure store for this field type"
 : "Пожалуйста, настройте хранилище для этого типа поля"
 
-, "Application, Applications"
-: [
-  "Приложение"
- ,"Приложения"
- ,"Приложения"
- ,"Приложения"
-
-]
 , "Record Class"
 : "Класс записей"
 
@@ -129,9 +375,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Настроить хранилище"
 
-, "Model"
-: "Модель"
-
 , "Custom field definition"
 : "Пользовательское поле определений"
 
@@ -168,12 +411,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Тип"
-
-, "Label"
-: "Метка"
-
 , "Length"
 : "Длина"
 
@@ -194,189 +431,85 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Группы"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Это настраиваемое поле уже существует. Пожалуйста, используйте другое имя."
 
-, "Customfield, Customfields"
-: [
-  "Настраиваемые поля"
- ,"Настраиваемые поля"
- ,"Настраиваемые поля"
- ,"Настраиваемые поля"
+, "Enable Account"
+: "включить учётную запись"
 
-]
-, "This custom field is still in use!"
+, "Disable Account"
+: "отключить учётную запись"
+
+, "Reset Password"
+: "Сбросить пароль"
+
+, "Status"
+: "Статус"
+
+, "Display name"
+: "Отображать как"
+
+, "Login name"
+: "Имя пользователя"
+
+, "Last name"
+: "Фамилия"
+
+, "First name"
+: "Имя"
+
+, "E-mail usage"
 : ""
 
-, "Are you sure you want to delete them?"
+, "Filesystem usage"
 : ""
 
-, "Yes"
-: "Да"
+, "OpenID"
+: "OpenID"
 
-, "No"
-: "Нет"
+, "Last login at"
+: "Последний регистрировался в"
 
-, "Config, Configs"
+, "Last login from"
+: "Последняя регистрация от"
+
+, "Password Must Change"
+: "Пароль должен быть изменен"
+
+, "Password changed"
+: "Пароль изменен"
+
+, "Expires"
+: "Истекает"
+
+, "Set new password"
+: "Задать новый пароль"
+
+, "Please enter the new password:"
+: "Пожалуйста, введите новый пароль:"
+
+, "Users"
+: "Пользователи"
+
+, "Samba User, Samba Users"
 : [
-  "Настройка"
- ,"Настройки"
- ,"Настройки"
- ,"Настройки"
+  "Пользователь Samba"
+ ,"Пользователя Samba"
+ ,"Пользователей Samba"
+ ,"Пользователей Samba"
 
 ]
-, "Value"
-: "Значение"
-
-, "Default ({0})"
-: "По умолчанию ({0})"
-
-, "Computer Name"
-: "Имя компьютера"
-
-, "Default Addressbook for new contacts and groups"
-: "Адресная книга по умолчанию для новых контактов и групп"
-
-, "Please wait"
-: "Пожалуйста, подождите"
-
-, "Updating Tag"
-: "Обновление тега"
-
-, "Could not save tag ({0})"
-: "Тег ({0}) не сохранён"
-
-, "Please fix the errors noted."
-: "Пожалуйста, устраните отмеченные ошибки."
-
-, "Allowed Contexts"
-: "Разрешённый контекст"
-
-, "Context"
-: "Контекст"
-
-, "Account Rights"
-: "Права учётной записи"
-
-, "View"
-: "Представление"
-
-, "Use"
-: "Использовать"
-
-, "Tag Name"
-: "Название тэга"
-
-, "Color"
-: "Цвет"
-
-, "Transferring {0}..."
-: "Передано {0}..."
-
-, "Tag"
-: "Тег"
-
-, "Add New Tag"
-: "Добавить новый тэг"
-
-, "Edit Tag \"{0}\""
-: "Изменить тэг \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Вы действительно хотите удалить выбранные тэги?"
-
-, "Deleting tag(s)..."
-: "Удаление тэга(ов)..."
-
-, "Add Tag"
-: "Добавить тег"
-
-, "Edit Tag"
-: "Изменить тег"
-
-, "Delete Tag"
-: "Удалить тег"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Показаны тэги {0} - {1} из {2}"
-
-, "No tags to display"
-: "Нет тэгов"
-
-, "Usage:&#160;"
-: "Использование:&#160;"
-
-, "Updating Memberships"
-: "Обновить членство"
-
-, "Could not save role."
-: "Не удалось сохранить роль."
-
-, "Deleting role..."
-: "Удаление роли..."
-
-, "Some error occurred while trying to delete the role."
-: "При удаление роли произошла ошибка."
-
-, "Rights"
-: "Права"
-
-, "Members"
-: "Участники"
-
-, "Role Name"
-: "Название роли"
-
-, "Role"
-: "Роль"
-
-, "Add New Role"
-: "Добавьте новую роль"
-
-, "Edit Role \"{0}\""
-: "Изменить роль \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Вы действительно хотите удалить выбранные роли?"
-
-, "Deleting role(s)..."
-: "Удаление роли(ей)..."
-
-, "Add Role"
-: "Добавить роль"
-
-, "Edit Role"
-: "Изменить роль"
-
-, "Delete Role"
-: "Удалить роль"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Показаны роли {0} - {1} из {2}"
-
-, "No roles to display"
-: "Нет ролей"
-
-, "Access Log, Access Logs"
+, "Email User, Email Users"
 : [
-  "Журнал доступа"
- ,"Журналы доступа"
- ,"Журналы доступа"
- ,"Журналы доступа"
+  "Электронные адреса пользователей"
+ ,"Электронные адреса пользователей"
+ ,"Электронные адреса пользователей"
+ ,"Электронные адреса пользователей"
 
 ]
-, "Groups"
-: "Группы"
-
-, "Applications"
-: "Приложения"
-
-, "Configs"
-: "Настройки"
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Домен недопустим. Пожалуйста, проверьте настройки домена в конфигурации SMTP"
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -404,18 +537,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Домашний диск"
 
-, "Login Time"
-: "Время регистрации"
-
 , "never logged in"
 : "никогда не регистрировался"
 
 , "Home Path"
 : "Домашний путь"
 
-, "Logout Time"
-: "Время выхода из системы"
-
 , "never logged off"
 : "никогда не регистрировался"
 
@@ -437,9 +564,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "не задан"
 
-, "Password Must Change"
-: "Пароль должен быть изменен"
-
 , "Kick Off Time"
 : "Время начала"
 
@@ -473,11 +597,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Последний вход"
 
-, "Domain not allowed"
-: "Домен недопустим"
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: "Домен {0} псевдонима {1}, который вы пытаетесь добавить, не является ни основным, ни дополнительным. Пожалуйста добавьте этот домен во второстепенные домены в настройках SMTP или используйте другой домен."
+, "Forward Only"
+: "Только пересылка"
 
 , "E-mail Alias"
 : ""
@@ -488,6 +609,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: "Домен недопустим"
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: "Домен {0} псевдонима {1}, который вы пытаетесь добавить, не является ни основным, ни дополнительным. Пожалуйста добавьте этот домен во второстепенные домены в настройках SMTP или используйте другой домен."
+
 , "Forwarding to self"
 : "Пересылка себе"
 
@@ -500,9 +627,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Только пересылка"
-
 , "Password confirmation"
 : "Подтверждение пароля"
 
@@ -515,20 +639,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Учётная запись"
 
-, "First name"
-: "Имя"
-
-, "Last name"
-: "Фамилия"
-
-, "Login name"
-: "Имя пользователя"
-
 , "Password"
 : "Пароль"
 
-, "OpenID"
-: "OpenID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "включено"
@@ -548,30 +663,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "Статус \"заблокировано\" будет стоять только в том случае, если пользователь часто ошибался с вводом пароля. Выставить этот статус здесь невозможно."
 
-, "Expires"
-: "Истекает"
-
-, "Visibility"
-: "Видимость"
-
-, "Display in addressbook"
-: "Отображать в адресной книге"
-
-, "Hide from addressbook"
-: "Скрыть в адресной книги"
-
-, "Saved in Addressbook"
-: "Сохранено в адресную книгу"
-
-, "Last login at"
-: "Последний регистрировался в"
-
 , "don't know"
 : "неизвестно"
 
-, "Last login from"
-: "Последняя регистрация от"
-
 , "Password set"
 : "Пароль установлен"
 
@@ -593,110 +687,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Пользователь"
- ,"Пользователя"
- ,"Пользователей"
- ,"Пользователей"
-
-]
-, "Users"
-: "Пользователи"
-
-, "Samba User, Samba Users"
-: [
-  "Пользователь Samba"
- ,"Пользователя Samba"
- ,"Пользователей Samba"
- ,"Пользователей Samba"
-
-]
-, "Email User, Email Users"
-: [
-  "Электронные адреса пользователей"
- ,"Электронные адреса пользователей"
- ,"Электронные адреса пользователей"
- ,"Электронные адреса пользователей"
-
-]
-, "Enable Account"
-: "включить учётную запись"
-
-, "Disable Account"
-: "отключить учётную запись"
-
-, "Reset Password"
-: "Сбросить пароль"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Отображать как"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Пароль изменен"
-
-, "Set new password"
-: "Задать новый пароль"
-
-, "Please enter the new password:"
-: "Пожалуйста, введите новый пароль:"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Название группы"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Члены группы"
-
-, "personal"
-: "личный"
-
-, "shared"
-: "общий"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Примечание владельца"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "Контейнер"
- ,"Контейнеры"
- ,"Контейнеры"
- ,"Контейнеры"
-
-]
-, "Container Name"
-: "Имя контейнера"
-
-, "Container Order"
-: "Порядок контейнеров"
-
 , "Computer, Computers"
 : [
   "Компьютер"
@@ -705,6 +695,45 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Компьютеров"
 
 ]
+, "Please wait"
+: "Пожалуйста, подождите"
+
+, "Updating Memberships"
+: "Обновить членство"
+
+, "Could not save role."
+: "Не удалось сохранить роль."
+
+, "Please fix the errors noted."
+: "Пожалуйста, устраните отмеченные ошибки."
+
+, "Deleting role..."
+: "Удаление роли..."
+
+, "Rights"
+: "Права"
+
+, "Members"
+: "Участники"
+
+, "Role Name"
+: "Название роли"
+
+, "Transferring {0}..."
+: "Передано {0}..."
+
+, "Role"
+: "Роль"
+
+, "Add New Role"
+: "Добавьте новую роль"
+
+, "Edit Role \"{0}\""
+: "Изменить роль \"{0}\""
+
+, "Configs"
+: "Настройки"
+
 , "Size"
 : ""
 
@@ -717,77 +746,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Роли"
+, "Updating Tag"
+: "Обновление тега"
 
-, "Containers"
-: "Контейнеры"
+, "Could not save tag ({0})"
+: "Тег ({0}) не сохранён"
 
-, "Shared Tags"
-: "Общие тэги"
+, "Allowed Contexts"
+: "Разрешённый контекст"
 
-, "Customfields"
-: "Настраиваемые поля"
+, "Context"
+: "Контекст"
 
-, "Computers"
-: "Компьютеры"
+, "Account Rights"
+: "Права учётной записи"
 
-, "Server Information"
-: "Информация о сервере"
+, "View"
+: "Представление"
 
-, "ActiveSync Devices"
-: "Устройства с поддержкой Active Sync"
+, "Use"
+: "Использовать"
 
-, "E-mail Accounts"
+, "Tag Name"
+: "Название тэга"
+
+, "Tag"
+: "Тег"
+
+, "Add New Tag"
+: "Добавить новый тэг"
+
+, "Edit Tag \"{0}\""
+: "Изменить тэг \"{0}\""
+
+, "Enable Application"
+: "Включить приложение"
+
+, "Disable Application"
+: "Отключить приложение"
+
+, "Settings"
+: "Настройки"
+
+, "{0} Settings"
+: "{0} Настройки"
+
+, "Enabled"
 : ""
 
-, "Admin"
-: "Администратор"
-
-, "Refresh"
-: "Обновить"
-
-, "Feature is disabled by configuration."
+, "Unknown status ({0})"
 : ""
 
-, "IP Address"
-: "IP адрес"
+, "Displaying application {0} - {1} of {2}"
+: "Показаны приложения {0} - {1} из {2}"
 
-, "Client Type"
-: "Тип клиента"
+, "No applications to display"
+: "Нет приложений"
 
-, "Session ID"
-: "ID сессии"
+, "Version"
+: "Версия"
 
-, "Login Name"
-: "Имя для регистрации"
-
-, "Result"
-: "Результат"
-
-, "user blocked"
-: "пользователь заблокирован"
-
-, "password expired"
-: "истек срок пароля"
-
-, "user disabled"
-: "пользователь отключен"
-
-, "invalid password"
-: "неверный пароль"
-
-, "ambiguous username"
-: "Имя пользователя многозначно"
-
-, "user not found"
-: "пользователь не найден"
-
-, "failure"
-: "неудачно"
-
-, "success"
-: "успешно"
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : "Пользовательские настройки IMAP по-умолчанию."
@@ -810,6 +830,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Ваш контейнер изменён %1$s %2$sПримечание: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -864,6 +890,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -930,6 +962,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -974,25 +1008,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Приложение"
 
-, "Group"
-: "Группа"
-
-, "Customfield"
-: "Настраиваемые поля"
-
-, "Config"
-: "Настройка"
+, "User"
+: "Пользователь"
 
 , "Access Log"
 : "Журнал доступа"
 
-, "User"
-: "Пользователь"
+, "Config"
+: "Настройка"
+
+, "Container"
+: "Контейнер"
+
+, "Customfield"
+: "Настраиваемые поля"
+
+, "Group"
+: "Группа"
 
 , "Samba User"
 : "Пользователь Samba"
@@ -1000,9 +1038,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "Электронные адреса пользователей"
 
-, "Container"
-: "Контейнер"
-
 , "Computer"
 : "Компьютер"
 
