@@ -5,62 +5,248 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Aktivizo Aplikacionin"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
 
-, "Disable Application"
-: "Ç'aktivizo Aplikacionin"
+]
+, "Application, Applications"
+: [
+  "Aplikacion"
+ ,"Apliakcione"
 
-, "Settings"
-: "Konfigurime"
+]
+, "User, Users"
+: [
+  "Përdorues"
+ ,"Përdoruesa"
 
-, "{0} Settings"
-: "{0} Konfigurime"
+]
+, "Groups"
+: "Grupe"
 
-, "Search:"
-: "Kërko:"
+, "Roles"
+: "Role"
+
+, "Applications"
+: "Aplikacione"
+
+, "Containers"
+: "Konteinerë"
+
+, "Shared Tags"
+: "Etiketa të ndara"
+
+, "Customfields"
+: "Fusha‎ të personifikuara"
+
+, "Computers"
+: "Kompjutera"
+
+, "Access Log, Access Logs"
+: [
+  "Ditari i hyrjeve"
+ ,"Ditarët e hyrjeve"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "Informacion i serverit"
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Admin"
+
+, "Refresh"
+: "Rifresko"
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Blloku i paracaktuar i adresave për kontakte dhe grupe te rinj"
 
-, "Displaying application {0} - {1} of {2}"
-: "Duke shfaqur aplikacionin  {0} - {1} nga {2}"
+, "Computer Name"
+: "Emri i Kompjuterit"
 
-, "No applications to display"
-: "Nuk ka aplikacione për tu shfaqur"
+, "Config, Configs"
+: [
+  ""
+ ,""
 
-, "Order"
-: "Renditje"
+]
+, "Description"
+: "Përshkrimi"
 
 , "Name"
 : "Emri"
 
-, "Status"
-: "Status"
+, "Label"
+: "EtiketV"
 
-, "Version"
-: "Versioni"
+, "Value"
+: "Vlera"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Emër Grupi"
+
+, "Visibility"
+: "Dukshmëria"
+
+, "Display in addressbook"
+: "Shfaqni në bllokun e adresave"
+
+, "Hide from addressbook"
+: "Fshihni nga blloku i adresave"
+
+, "Saved in Addressbook"
+: "U ruajt në bllokun e adresave"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Pjesëtarë  Grupi"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Domain nuk lejohet, Kontrolloni konfigurimet e domain-it SMTP"
 
 , "Confirm"
 : "Konfirmo"
 
+, "Do you really want to delete the selected tags?"
+: "Doni vërtet të fshini etiketat e zgjedhura"
+
+, "Deleting tag(s)..."
+: "Duke fshirë etiketën(at)"
+
+, "Add Tag"
+: "Shto Etiketë"
+
+, "Edit Tag"
+: "Modifiko Etiketën"
+
+, "Delete Tag"
+: "Fshij Etiketën"
+
+, "Search:"
+: "Kërko:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Duke shfaqur etiketat {0} - {1} nga {2}"
+
+, "No tags to display"
+: "Nuk ka etiketa për tu shfaqur"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Ngjyrë"
+
+, "Usage:&#160;"
+: "Përdorimi:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Doni vërtetë të fshini rolet e zgjedhur?"
+
+, "Deleting role(s)..."
+: "Duke fshirë rolin(et)"
+
+, "Failed"
+: "Dështoi"
+
+, "Some error occurred while trying to delete the role."
+: "Ndodhën disa gabime ndërkohe që po fshihej roli"
+
+, "Add Role"
+: "Shto Rol"
+
+, "Edit Role"
+: "Modifiko Rolin"
+
+, "Delete Role"
+: "Fshij Rolin"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Duke shfaqur rolin {0} - {1} nga {2}"
+
+, "No roles to display"
+: "Nuk ka role për tu shfaqur"
+
+, "Container Name"
+: "Emri i Konteinerit"
+
+, "Type"
+: "Tipi"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "Konteiner"
+ ,"Konteinerë"
+
+]
+, "Model"
+: "Modeli"
+
+, "personal"
+: "personal"
+
+, "shared"
+: "ndarë"
+
+, "Order"
+: "Renditje"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Shënim për zoteruesin"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Doni vërtet të fshini grupet e zgjedhur?"
 
 , "Deleting group(s)..."
 : "Duke fshirë grup(et)..."
 
-, "Failed"
-: "Dështoi"
-
 , "Some error occurred while trying to delete the group."
 : "Ndodhën disa gabime ndërkohe që po fshihej grupi"
 
@@ -79,15 +265,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Nuk ka grupe për tu shfaqur"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Përshkrimi"
-
 , "Creation Time"
 : ""
 
@@ -100,18 +280,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "Adresa IP"
+
+, "Login Time"
+: "Koha e hyrjes"
+
+, "Logout Time"
+: "Koha e daljes"
+
+, "Client Type"
+: "Tipi i Klientit"
+
+, "Session ID"
+: "ID e seances"
+
+, "Login Name"
+: "Emri i Hyrjes"
+
+, "Result"
+: "Reziltati"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "përdoruesi i bllokuar"
+
+, "password expired"
+: "fjalëkalimi ka skaduar"
+
+, "user disabled"
+: "përdoruesi i ç'aktivizuar"
+
+, "invalid password"
+: "fjalëkalim jo i saktë"
+
+, "ambiguous username"
+: "Emër përdoruesi jo i qartë"
+
+, "user not found"
+: "përdouresi nuk u gjend"
+
+, "failure"
+: "dështim"
+
+, "success"
+: "sukses"
+
+, "Customfield, Customfields"
+: [
+  "Fushë e personalizuar"
+ ,"Fusha të personalizuara"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Gabime"
 
 , "Please configure store for this field type"
 : "Ju lutem konfiguroni vend-ruajtien për këtë tip fushe"
 
-, "Application, Applications"
-: [
-  "Aplikacion"
- ,"Apliakcione"
-
-]
 , "Record Class"
 : "Klasa regjistrimit"
 
@@ -127,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Konfiguro vend-ruajtien"
 
-, "Model"
-: "Modeli"
-
 , "Custom field definition"
 : "Përcaktimi i fushës së personalizuar"
 
@@ -166,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Tipi"
-
-, "Label"
-: "EtiketV"
-
 , "Length"
 : "Gjatësi"
 
@@ -190,183 +415,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Grupe"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Fusha e personalizuar ekziston. Ju lutem zgjidhni një emër tjetër"
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Aktivizoni Llogarinë"
+
+, "Disable Account"
+: "Ç'aktivizoni Llogarinë"
+
+, "Reset Password"
+: "Rivendosni Fjalëkalimin"
+
+, "Status"
+: "Status"
+
+, "Display name"
+: "Emri i Shfaqur"
+
+, "Login name"
+: "Emrii Hyrjes"
+
+, "Last name"
+: "Mbiemri"
+
+, "First name"
+: "Emri"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: "Hyrja e fundit më"
+
+, "Last login from"
+: "Hyrja e fundit nga"
+
+, "Password Must Change"
+: "Fjalëkalimi Duhet ndryshuar"
+
+, "Password changed"
+: "Fjalëkalimi ndryshoi"
+
+, "Expires"
+: "Skadon"
+
+, "Set new password"
+: "Vendosni Fjalëkalimin e ri"
+
+, "Please enter the new password:"
+: "Ju lutem fusni fjalëkalimin e ri"
+
+, "Users"
+: "Përdorues"
+
+, "Samba User, Samba Users"
 : [
-  "Fushë e personalizuar"
- ,"Fusha të personalizuara"
+  "Perdorues Samba"
+ ,"Perdorues Samba"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
- ,""
+  "Përdorues E-Poste"
+ ,"Perdorues E-Poste"
 
 ]
-, "Value"
-: "Vlera"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Emri i Kompjuterit"
-
-, "Default Addressbook for new contacts and groups"
-: "Blloku i paracaktuar i adresave për kontakte dhe grupe te rinj"
-
-, "Please wait"
-: "Ju lutem prisni"
-
-, "Updating Tag"
-: "Duke përditesuar etiketën"
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Ju lutem riparoni gabimet e shënuara"
-
-, "Allowed Contexts"
-: "Kontekst i lejuar"
-
-, "Context"
-: "Kontekst"
-
-, "Account Rights"
-: "Të drejtat e llogarisë"
-
-, "View"
-: "Shiko"
-
-, "Use"
-: "Përdor"
-
-, "Tag Name"
-: "Emri i Etiketës"
-
-, "Color"
-: "Ngjyrë"
-
-, "Transferring {0}..."
-: "Duke transferuar {0}... "
-
-, "Tag"
-: "Etiketë"
-
-, "Add New Tag"
-: "Shto një etiketë të re"
-
-, "Edit Tag \"{0}\""
-: "Modifiko Etiketen \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Doni vërtet të fshini etiketat e zgjedhura"
-
-, "Deleting tag(s)..."
-: "Duke fshirë etiketën(at)"
-
-, "Add Tag"
-: "Shto Etiketë"
-
-, "Edit Tag"
-: "Modifiko Etiketën"
-
-, "Delete Tag"
-: "Fshij Etiketën"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Duke shfaqur etiketat {0} - {1} nga {2}"
-
-, "No tags to display"
-: "Nuk ka etiketa për tu shfaqur"
-
-, "Usage:&#160;"
-: "Përdorimi:&#160;"
-
-, "Updating Memberships"
-: "Duke përditësuar Anëtarësimet"
-
-, "Could not save role."
-: "Roli nuk u ruajt dot"
-
-, "Deleting role..."
-: "Duke fshir rolin..."
-
-, "Some error occurred while trying to delete the role."
-: "Ndodhën disa gabime ndërkohe që po fshihej roli"
-
-, "Rights"
-: "Të drejta"
-
-, "Members"
-: "Pjesëtarë"
-
-, "Role Name"
-: "Emri i Rolit"
-
-, "Role"
-: "Roli"
-
-, "Add New Role"
-: "Shto një rol të ri"
-
-, "Edit Role \"{0}\""
-: "Modifiko Rolin \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Doni vërtetë të fshini rolet e zgjedhur?"
-
-, "Deleting role(s)..."
-: "Duke fshirë rolin(et)"
-
-, "Add Role"
-: "Shto Rol"
-
-, "Edit Role"
-: "Modifiko Rolin"
-
-, "Delete Role"
-: "Fshij Rolin"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Duke shfaqur rolin {0} - {1} nga {2}"
-
-, "No roles to display"
-: "Nuk ka role për tu shfaqur"
-
-, "Access Log, Access Logs"
-: [
-  "Ditari i hyrjeve"
- ,"Ditarët e hyrjeve"
-
-]
-, "Groups"
-: "Grupe"
-
-, "Applications"
-: "Aplikacione"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Domain nuk lejohet, Kontrolloni konfigurimet e domain-it SMTP"
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -394,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Arkiva Kryesore"
 
-, "Login Time"
-: "Koha e hyrjes"
-
 , "never logged in"
 : "Nuk ka hyrë asnjëhere"
 
 , "Home Path"
 : "Rruga kryesore"
 
-, "Logout Time"
-: "Koha e daljes"
-
 , "never logged off"
 : "Nuk ka dalë asnjëhere"
 
@@ -427,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "nuk është vendosur"
 
-, "Password Must Change"
-: "Fjalëkalimi Duhet ndryshuar"
-
 , "Kick Off Time"
 : "Koha e përjashtimit"
 
@@ -463,11 +577,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Hyrja e Fundit"
 
-, "Domain not allowed"
-: "Domain nuk lejohet"
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "Vetëm Ridrejtim"
 
 , "E-mail Alias"
 : ""
@@ -478,6 +589,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: "Domain nuk lejohet"
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : "Ridrejtuar tek vetja"
 
@@ -490,9 +607,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Vetëm Ridrejtim"
-
 , "Password confirmation"
 : "Konfirmim Fjalëkalimi"
 
@@ -505,20 +619,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Llogari"
 
-, "First name"
-: "Emri"
-
-, "Last name"
-: "Mbiemri"
-
-, "Login name"
-: "Emrii Hyrjes"
-
 , "Password"
 : "Fjalëkalimi"
 
-, "OpenID"
-: "OpenID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "aktivizuar"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "Statusi i bllokuar është i vlefshëm vetëm nëse përdoruesi provoi të hynte shumë shpeshme fjalëkalim të gabuar. Nuk është e mundur të vendoset ky status këtu"
 
-, "Expires"
-: "Skadon"
-
-, "Visibility"
-: "Dukshmëria"
-
-, "Display in addressbook"
-: "Shfaqni në bllokun e adresave"
-
-, "Hide from addressbook"
-: "Fshihni nga blloku i adresave"
-
-, "Saved in Addressbook"
-: "U ruajt në bllokun e adresave"
-
-, "Last login at"
-: "Hyrja e fundit më"
-
 , "don't know"
 : "nuk e di"
 
-, "Last login from"
-: "Hyrja e fundit nga"
-
 , "Password set"
 : "Fjalëkalimi u vendos"
 
@@ -583,108 +667,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Përdorues"
- ,"Përdoruesa"
-
-]
-, "Users"
-: "Përdorues"
-
-, "Samba User, Samba Users"
-: [
-  "Perdorues Samba"
- ,"Perdorues Samba"
-
-]
-, "Email User, Email Users"
-: [
-  "Përdorues E-Poste"
- ,"Perdorues E-Poste"
-
-]
-, "Enable Account"
-: "Aktivizoni Llogarinë"
-
-, "Disable Account"
-: "Ç'aktivizoni Llogarinë"
-
-, "Reset Password"
-: "Rivendosni Fjalëkalimin"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Emri i Shfaqur"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Fjalëkalimi ndryshoi"
-
-, "Set new password"
-: "Vendosni Fjalëkalimin e ri"
-
-, "Please enter the new password:"
-: "Ju lutem fusni fjalëkalimin e ri"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Emër Grupi"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Pjesëtarë  Grupi"
-
-, "personal"
-: "personal"
-
-, "shared"
-: "ndarë"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Shënim për zoteruesin"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "Konteiner"
- ,"Konteinerë"
-
-]
-, "Container Name"
-: "Emri i Konteinerit"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Kompjuter"
  ,"Kompjutera"
 
 ]
+, "Please wait"
+: "Ju lutem prisni"
+
+, "Updating Memberships"
+: "Duke përditësuar Anëtarësimet"
+
+, "Could not save role."
+: "Roli nuk u ruajt dot"
+
+, "Please fix the errors noted."
+: "Ju lutem riparoni gabimet e shënuara"
+
+, "Deleting role..."
+: "Duke fshir rolin..."
+
+, "Rights"
+: "Të drejta"
+
+, "Members"
+: "Pjesëtarë"
+
+, "Role Name"
+: "Emri i Rolit"
+
+, "Transferring {0}..."
+: "Duke transferuar {0}... "
+
+, "Role"
+: "Roli"
+
+, "Add New Role"
+: "Shto një rol të ri"
+
+, "Edit Role \"{0}\""
+: "Modifiko Rolin \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -697,77 +724,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Role"
+, "Updating Tag"
+: "Duke përditesuar etiketën"
 
-, "Containers"
-: "Konteinerë"
-
-, "Shared Tags"
-: "Etiketa të ndara"
-
-, "Customfields"
-: "Fusha‎ të personifikuara"
-
-, "Computers"
-: "Kompjutera"
-
-, "Server Information"
-: "Informacion i serverit"
-
-, "ActiveSync Devices"
+, "Could not save tag ({0})"
 : ""
 
-, "E-mail Accounts"
+, "Allowed Contexts"
+: "Kontekst i lejuar"
+
+, "Context"
+: "Kontekst"
+
+, "Account Rights"
+: "Të drejtat e llogarisë"
+
+, "View"
+: "Shiko"
+
+, "Use"
+: "Përdor"
+
+, "Tag Name"
+: "Emri i Etiketës"
+
+, "Tag"
+: "Etiketë"
+
+, "Add New Tag"
+: "Shto një etiketë të re"
+
+, "Edit Tag \"{0}\""
+: "Modifiko Etiketen \"{0}\""
+
+, "Enable Application"
+: "Aktivizo Aplikacionin"
+
+, "Disable Application"
+: "Ç'aktivizo Aplikacionin"
+
+, "Settings"
+: "Konfigurime"
+
+, "{0} Settings"
+: "{0} Konfigurime"
+
+, "Enabled"
 : ""
 
-, "Admin"
-: "Admin"
-
-, "Refresh"
-: "Rifresko"
-
-, "Feature is disabled by configuration."
+, "Unknown status ({0})"
 : ""
 
-, "IP Address"
-: "Adresa IP"
+, "Displaying application {0} - {1} of {2}"
+: "Duke shfaqur aplikacionin  {0} - {1} nga {2}"
 
-, "Client Type"
-: "Tipi i Klientit"
+, "No applications to display"
+: "Nuk ka aplikacione për tu shfaqur"
 
-, "Session ID"
-: "ID e seances"
+, "Version"
+: "Versioni"
 
-, "Login Name"
-: "Emri i Hyrjes"
-
-, "Result"
-: "Reziltati"
-
-, "user blocked"
-: "përdoruesi i bllokuar"
-
-, "password expired"
-: "fjalëkalimi ka skaduar"
-
-, "user disabled"
-: "përdoruesi i ç'aktivizuar"
-
-, "invalid password"
-: "fjalëkalim jo i saktë"
-
-, "ambiguous username"
-: "Emër përdoruesi jo i qartë"
-
-, "user not found"
-: "përdouresi nuk u gjend"
-
-, "failure"
-: "dështim"
-
-, "success"
-: "sukses"
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : "Konfigurimet e Paracaktuara IMAP të përdoruesit"
@@ -790,6 +808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Konteineri juaj është ndryshuar nga %1$s %2$sShenim: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -844,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -910,6 +940,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -954,25 +986,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Aplikacion"
 
-, "Group"
-: "Grup"
-
-, "Customfield"
-: "Fushë e personalizuar"
-
-, "Config"
-: ""
+, "User"
+: "Përdorues"
 
 , "Access Log"
 : "Ditari i hyrjeve"
 
-, "User"
-: "Përdorues"
+, "Config"
+: ""
+
+, "Container"
+: "Konteiner"
+
+, "Customfield"
+: "Fushë e personalizuar"
+
+, "Group"
+: "Grup"
 
 , "Samba User"
 : "Perdorues Samba"
@@ -980,9 +1016,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "Përdorues E-Poste"
 
-, "Container"
-: "Konteiner"
-
 , "Computer"
 : "Kompjuter"
 
