@@ -5,62 +5,248 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:13+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Aktivera applikation"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+ ,""
 
-, "Disable Application"
-: "Avaktivera applikation"
+]
+, "Application, Applications"
+: [
+  "Tillämpning"
+ ,"Tillämpningar"
 
-, "Settings"
-: "Inställningar"
+]
+, "User, Users"
+: [
+  "Användare"
+ ,"Användare"
 
-, "{0} Settings"
-: "{0} Inställningar"
+]
+, "Groups"
+: "Grupper"
 
-, "Search:"
-: "Sök:"
+, "Roles"
+: "Roller"
+
+, "Applications"
+: "Tillämpningar"
+
+, "Containers"
+: "Behållare"
+
+, "Shared Tags"
+: "Delade Taggar"
+
+, "Customfields"
+: "Egna fält"
+
+, "Computers"
+: "Datorer"
+
+, "Access Log, Access Logs"
+: [
+  "Åtkomst Logg"
+ ,"Åtkomsts Loggar"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "Serverinformation"
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Administratör"
+
+, "Refresh"
+: "Uppdatera"
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Standard Adressbok för nya kontakter och grupper"
 
-, "Displaying application {0} - {1} of {2}"
-: "Visar tillämpning {0} - {1} av {2}"
+, "Computer Name"
+: "Dator Namn"
 
-, "No applications to display"
-: "Inga tillämpningar att visa"
+, "Config, Configs"
+: [
+  ""
+ ,""
 
-, "Order"
-: "Beställ"
+]
+, "Description"
+: "Beskrivning"
 
 , "Name"
 : "Namn"
 
-, "Status"
-: "Status"
+, "Label"
+: "Märke"
 
-, "Version"
-: "Version"
+, "Value"
+: "Värde"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: "Ja"
+
+, "No"
+: "Nej"
+
+, "Group Name"
+: "Grupp Namn"
+
+, "Visibility"
+: "Synlighet"
+
+, "Display in addressbook"
+: "Visa i adressbok"
+
+, "Hide from addressbook"
+: "Dölj från adressbok"
+
+, "Saved in Addressbook"
+: "Spara i Adressbok"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Grupp Medlemmar"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Domän ej tillåten. Kontrollera konfigurationen för SMTP-domänen."
 
 , "Confirm"
 : "Bekräfta"
 
+, "Do you really want to delete the selected tags?"
+: "Vill du verkligen ta bort valda taggar?"
+
+, "Deleting tag(s)..."
+: "Tar bort tagg(ar)..."
+
+, "Add Tag"
+: "Lägg till tagg"
+
+, "Edit Tag"
+: "Editera tagg"
+
+, "Delete Tag"
+: "Radera tagg"
+
+, "Search:"
+: "Sök:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Visar taggar {0} - {1} av {2}"
+
+, "No tags to display"
+: "Inga taggar att visa"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Färg"
+
+, "Usage:&#160;"
+: "Användande:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Vill du verkligen ta bort dom valda rollerna?"
+
+, "Deleting role(s)..."
+: "tar bort roll(er)..."
+
+, "Failed"
+: "Misslyckades"
+
+, "Some error occurred while trying to delete the role."
+: "Några fel uppstod vid försök att ta bort gruppen."
+
+, "Add Role"
+: "Lägg till roll"
+
+, "Edit Role"
+: "Editera roll"
+
+, "Delete Role"
+: "Radera roll"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Visar roller {0} - {1} av {2}"
+
+, "No roles to display"
+: "Inga roller att visa"
+
+, "Container Name"
+: "Behållare Namn"
+
+, "Type"
+: "Typ"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "Behållare"
+ ,"Behållare"
+
+]
+, "Model"
+: "Modell"
+
+, "personal"
+: "personlig"
+
+, "shared"
+: "Delad"
+
+, "Order"
+: "Beställ"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Notering för Ägare"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Vill du verkligen ta bort valda grupper?"
 
 , "Deleting group(s)..."
 : "Ta bort grupp(er)..."
 
-, "Failed"
-: "Misslyckades"
-
 , "Some error occurred while trying to delete the group."
 : "Några fel uppstod vid försök att ta bort gruppen."
 
@@ -79,25 +265,79 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Inga grupper att visa"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Beskrivning"
-
 , "Creation Time"
-: ""
+: "Skapad tid"
 
 , "Created By"
-: ""
+: "Skapad av"
 
 , "Last Modified Time"
-: ""
+: "Senast ändrad tid"
 
 , "Last Modified By"
+: "Senast ändrad av"
+
+, "IP Address"
+: "IP Adress"
+
+, "Login Time"
+: "Inloggningstid Tid"
+
+, "Logout Time"
+: "Utloggningstid Tid"
+
+, "Client Type"
+: "Klient Typ"
+
+, "Session ID"
+: "Sessions ID"
+
+, "Login Name"
+: "Inloggnings Namn"
+
+, "Result"
+: "Resultat"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "Användare blockad"
+
+, "password expired"
+: "lösenord utgått"
+
+, "user disabled"
+: "användare inatkiverad"
+
+, "invalid password"
+: "ogiltligt lösenord"
+
+, "ambiguous username"
+: "tvetydligt användarnamn"
+
+, "user not found"
+: "användare inte hittad"
+
+, "failure"
+: "misslyckande"
+
+, "success"
+: "framsteg"
+
+, "Customfield, Customfields"
+: [
+  "Eget fält"
+ ,"Egna fält"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
 : ""
 
 , "Errors"
@@ -106,12 +346,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Please configure store for this field type"
 : "Konfigurera butiken för denna filtyp"
 
-, "Application, Applications"
-: [
-  "Tillämpning"
- ,"Tillämpningar"
-
-]
 , "Record Class"
 : "Post Klass"
 
@@ -127,9 +361,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Konfigurations butik"
 
-, "Model"
-: "Modell"
-
 , "Custom field definition"
 : "Eget fält betydelse"
 
@@ -166,12 +397,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Typ"
-
-, "Label"
-: "Märke"
-
 , "Length"
 : "Längd"
 
@@ -190,185 +415,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
  ,"Grupper"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Anpassade fältet existerar redan. Vänligen välj ett annat namn."
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Aktivera konto"
+
+, "Disable Account"
+: "Avaktivera konto"
+
+, "Reset Password"
+: "Återställ lösenord"
+
+, "Status"
+: "Status"
+
+, "Display name"
+: "Visningsnamn"
+
+, "Login name"
+: "Inloggningsnamn"
+
+, "Last name"
+: "Efternamn"
+
+, "First name"
+: "Förnamn"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "ÖppnaID"
+
+, "Last login at"
+: "Senaste Inloggning"
+
+, "Last login from"
+: "Senaste Inloggning från"
+
+, "Password Must Change"
+: "Lösenord måste ändras"
+
+, "Password changed"
+: "Lösenord ändrat"
+
+, "Expires"
+: "Utgår"
+
+, "Set new password"
+: "Välj nytt lösenord"
+
+, "Please enter the new password:"
+: "Ange nytt lösenord"
+
+, "Users"
+: "Användare"
+
+, "Samba User, Samba Users"
 : [
-  "Eget fält"
- ,"Egna fält"
+  "Samba Användare"
+ ,"Samba Användare"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
- ,""
+  "E-post Användare"
+ ,"E-post Användare"
 
 ]
-, "Value"
-: "Värde"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Dator Namn"
-
-, "Default Addressbook for new contacts and groups"
-: "Standard Adressbok för nya kontakter och grupper"
-
-, "Please wait"
-: "Vänligen vänta"
-
-, "Updating Tag"
-: "Updaterings Tagg"
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Åtgärda felen som noterats."
-
-, "Allowed Contexts"
-: "Tillåtna Sammanhang"
-
-, "Context"
-: "Sammanhang"
-
-, "Account Rights"
-: "Konto Rättigheter"
-
-, "View"
-: "Visa "
-
-, "Use"
-: "Använda"
-
-, "Tag Name"
-: "Tagg Namn"
-
-, "Color"
-: "Färg"
-
-, "Transferring {0}..."
-: "Överför {0}..."
-
-, "Tag"
-: "Tagg"
-
-, "Add New Tag"
-: "Lägg till ny tagg"
-
-, "Edit Tag \"{0}\""
-: "Ändra Tagg \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Vill du verkligen ta bort valda taggar?"
-
-, "Deleting tag(s)..."
-: "Tar bort tagg(ar)..."
-
-, "Add Tag"
-: "Lägg till tagg"
-
-, "Edit Tag"
-: "Editera tagg"
-
-, "Delete Tag"
-: "Radera tagg"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Visar taggar {0} - {1} av {2}"
-
-, "No tags to display"
-: "Inga taggar att visa"
-
-, "Usage:&#160;"
-: "Användande:&#160;"
-
-, "Updating Memberships"
-: "Uppdatera medlemsskap"
-
-, "Could not save role."
-: "Kunde inte spara roll."
-
-, "Deleting role..."
-: "Tar bort roll..."
-
-, "Some error occurred while trying to delete the role."
-: "Några fel uppstod vid försök att ta bort gruppen."
-
-, "Rights"
-: "Rättigheter"
-
-, "Members"
-: "Medlemmar"
-
-, "Role Name"
-: "Roll Namn"
-
-, "Role"
-: "Roll"
-
-, "Add New Role"
-: "Lägg Till Ny Roll"
-
-, "Edit Role \"{0}\""
-: "Ändra Roll \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Vill du verkligen ta bort dom valda rollerna?"
-
-, "Deleting role(s)..."
-: "tar bort roll(er)..."
-
-, "Add Role"
-: "Lägg till roll"
-
-, "Edit Role"
-: "Editera roll"
-
-, "Delete Role"
-: "Radera roll"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Visar roller {0} - {1} av {2}"
-
-, "No roles to display"
-: "Inga roller att visa"
-
-, "Access Log, Access Logs"
-: [
-  "Åtkomst Logg"
- ,"Åtkomsts Loggar"
-
-]
-, "Groups"
-: "Grupper"
-
-, "Applications"
-: "Tillämpningar"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Domän ej tillåten. Kontrollera konfigurationen för SMTP-domänen."
-
 , "Special characters are not allowed in login name."
-: ""
+: "Specialtecken är inte tillåtna i inloggningsnamn."
 
 , "Passwords do not match!"
 : "Lösenorden matchar inte!"
@@ -394,18 +517,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Hemmadisk"
 
-, "Login Time"
-: "Inloggningstid Tid"
-
 , "never logged in"
 : "loggade inte in"
 
 , "Home Path"
 : "Sökväg för hem"
 
-, "Logout Time"
-: "Utloggningstid Tid"
-
 , "never logged off"
 : "loggade inte av"
 
@@ -427,9 +544,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "inte inställt"
 
-, "Password Must Change"
-: "Lösenord måste ändras"
-
 , "Kick Off Time"
 : "Tid för avspark"
 
@@ -463,11 +577,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Senast inloggad"
 
-, "Domain not allowed"
-: "Domän inte tillåten"
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "Vidarebefordra endast"
 
 , "E-mail Alias"
 : ""
@@ -478,6 +589,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: "Domän inte tillåten"
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : "Vidarebefodran till sig själv"
 
@@ -490,9 +607,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Vidarebefordra endast"
-
 , "Password confirmation"
 : "Lösenordskonfirmation"
 
@@ -505,20 +619,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Konto"
 
-, "First name"
-: "Förnamn"
-
-, "Last name"
-: "Efternamn"
-
-, "Login name"
-: "Inloggningsnamn"
-
 , "Password"
 : "Lösenord"
 
-, "OpenID"
-: "ÖppnaID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "aktiverad"
@@ -538,30 +643,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "Blockerade status är endast giltigt om användaren försökte logga in med fel lösenord för ofta. Det är inte möjligt att ställa in denna status här."
 
-, "Expires"
-: "Utgår"
-
-, "Visibility"
-: "Synlighet"
-
-, "Display in addressbook"
-: "Visa i adressbok"
-
-, "Hide from addressbook"
-: "Dölj från adressbok"
-
-, "Saved in Addressbook"
-: "Spara i Adressbok"
-
-, "Last login at"
-: "Senaste Inloggning"
-
 , "don't know"
 : "vet inte"
 
-, "Last login from"
-: "Senaste Inloggning från"
-
 , "Password set"
 : "Lösenord Satt"
 
@@ -575,7 +659,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 : "Filserver"
 
 , "Filesystem"
-: ""
+: "Filsystem"
 
 , "IMAP"
 : "IMAP"
@@ -583,111 +667,54 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "Användare"
- ,"Användare"
-
-]
-, "Users"
-: "Användare"
-
-, "Samba User, Samba Users"
-: [
-  "Samba Användare"
- ,"Samba Användare"
-
-]
-, "Email User, Email Users"
-: [
-  "E-post Användare"
- ,"E-post Användare"
-
-]
-, "Enable Account"
-: "Aktivera konto"
-
-, "Disable Account"
-: "Avaktivera konto"
-
-, "Reset Password"
-: "Återställ lösenord"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Visningsnamn"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Lösenord ändrat"
-
-, "Set new password"
-: "Välj nytt lösenord"
-
-, "Please enter the new password:"
-: "Ange nytt lösenord"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Grupp Namn"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Grupp Medlemmar"
-
-, "personal"
-: "personlig"
-
-, "shared"
-: "Delad"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Notering för Ägare"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "Behållare"
- ,"Behållare"
-
-]
-, "Container Name"
-: "Behållare Namn"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "Dator"
  ,"Datorer"
 
 ]
-, "Size"
+, "Please wait"
+: "Vänligen vänta"
+
+, "Updating Memberships"
+: "Uppdatera medlemsskap"
+
+, "Could not save role."
+: "Kunde inte spara roll."
+
+, "Please fix the errors noted."
+: "Åtgärda felen som noterats."
+
+, "Deleting role..."
+: "Tar bort roll..."
+
+, "Rights"
+: "Rättigheter"
+
+, "Members"
+: "Medlemmar"
+
+, "Role Name"
+: "Roll Namn"
+
+, "Transferring {0}..."
+: "Överför {0}..."
+
+, "Role"
+: "Roll"
+
+, "Add New Role"
+: "Lägg Till Ny Roll"
+
+, "Edit Role \"{0}\""
+: "Ändra Roll \"{0}\""
+
+, "Configs"
 : ""
 
+, "Size"
+: "Storlek"
+
 , "Revision Size"
 : ""
 
@@ -697,77 +724,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Roller"
+, "Updating Tag"
+: "Updaterings Tagg"
 
-, "Containers"
-: "Behållare"
-
-, "Shared Tags"
-: "Delade Taggar"
-
-, "Customfields"
-: "Egna fält"
-
-, "Computers"
-: "Datorer"
-
-, "Server Information"
-: "Serverinformation"
-
-, "ActiveSync Devices"
+, "Could not save tag ({0})"
 : ""
 
-, "E-mail Accounts"
+, "Allowed Contexts"
+: "Tillåtna Sammanhang"
+
+, "Context"
+: "Sammanhang"
+
+, "Account Rights"
+: "Konto Rättigheter"
+
+, "View"
+: "Visa "
+
+, "Use"
+: "Använda"
+
+, "Tag Name"
+: "Tagg Namn"
+
+, "Tag"
+: "Tagg"
+
+, "Add New Tag"
+: "Lägg till ny tagg"
+
+, "Edit Tag \"{0}\""
+: "Ändra Tagg \"{0}\""
+
+, "Enable Application"
+: "Aktivera applikation"
+
+, "Disable Application"
+: "Avaktivera applikation"
+
+, "Settings"
+: "Inställningar"
+
+, "{0} Settings"
+: "{0} Inställningar"
+
+, "Enabled"
 : ""
 
-, "Admin"
-: "Administratör"
-
-, "Refresh"
-: "Uppdatera"
-
-, "Feature is disabled by configuration."
+, "Unknown status ({0})"
 : ""
 
-, "IP Address"
-: "IP Adress"
+, "Displaying application {0} - {1} of {2}"
+: "Visar tillämpning {0} - {1} av {2}"
 
-, "Client Type"
-: "Klient Typ"
+, "No applications to display"
+: "Inga tillämpningar att visa"
 
-, "Session ID"
-: "Sessions ID"
+, "Version"
+: "Version"
 
-, "Login Name"
-: "Inloggnings Namn"
-
-, "Result"
-: "Resultat"
-
-, "user blocked"
-: "Användare blockad"
-
-, "password expired"
-: "lösenord utgått"
-
-, "user disabled"
-: "användare inatkiverad"
-
-, "invalid password"
-: "ogiltligt lösenord"
-
-, "ambiguous username"
-: "tvetydligt användarnamn"
-
-, "user not found"
-: "användare inte hittad"
-
-, "failure"
-: "misslyckande"
-
-, "success"
-: "framsteg"
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : "Standard IMAP-inställningar för användare"
@@ -790,6 +808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Din behållare har blivit ändrad av %1$s %2$sNotering: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -844,6 +868,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -910,6 +940,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -949,24 +981,32 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
+
+
+
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "Tillämpning"
 
-, "Group"
-: "Grupp"
-
-, "Customfield"
-: "Eget fält"
-
-, "Config"
-: ""
+, "User"
+: "Användare"
 
 , "Access Log"
 : "Åtkomst Logg"
 
-, "User"
-: "Användare"
+, "Config"
+: ""
+
+, "Container"
+: "Behållare"
+
+, "Customfield"
+: "Eget fält"
+
+, "Group"
+: "Grupp"
 
 , "Samba User"
 : "Samba Användare"
@@ -974,9 +1014,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "E-post Användare"
 
-, "Container"
-: "Behållare"
-
 , "Computer"
 : "Dator"
 
