@@ -5,62 +5,242 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "อนุญาตให้ใช้แอพลิเคชั่น"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
 
-, "Disable Application"
-: "ยกเลิกการใช้แอพลิเคชั่น"
+]
+, "Application, Applications"
+: [
+  "การประยุกต์ใช้"
 
-, "Settings"
-: "ค่าติดตั้ง"
+]
+, "User, Users"
+: [
+  "ผู้ใช้"
 
-, "{0} Settings"
-: "ค่าติดตั้ง {0}"
+]
+, "Groups"
+: "กลุ่ม"
 
-, "Search:"
-: "ค้นหา:"
+, "Roles"
+: "หน้าที่"
+
+, "Applications"
+: "การประยุกต์ใช้"
+
+, "Containers"
+: "ที่จัดเก็บ"
+
+, "Shared Tags"
+: "ป้ายกำกับที่ใช้ร่วมกัน"
+
+, "Customfields"
+: ""
+
+, "Computers"
+: "คอมพิวเตอร์"
+
+, "Access Log, Access Logs"
+: [
+  "บันทึกการใช้งาน"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "ข้อมูลระบบ"
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "ผู้ดูแลระบบ"
+
+, "Refresh"
+: ""
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "สมุดรายชื่อหลักสำหรับการติดต่อและกลุ่มใหม่"
 
-, "Displaying application {0} - {1} of {2}"
-: "แสดงการใช้ {0} - {1} จาก {2}"
+, "Computer Name"
+: "ชื่อของคอมพิวเตอร์"
 
-, "No applications to display"
-: "ไม่มีการใช้ใด ๆ ให้แสดง"
+, "Config, Configs"
+: [
+  ""
 
-, "Order"
-: "คำสั่ง"
+]
+, "Description"
+: "การอธิบาย"
 
 , "Name"
 : "ชื่อ"
 
-, "Status"
-: "สถานะ"
+, "Label"
+: "ป้าย"
 
-, "Version"
-: "ภาค"
+, "Value"
+: "ค่า"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "ชื่อกลุ่ม"
+
+, "Visibility"
+: "การมองเห็นได้"
+
+, "Display in addressbook"
+: "แสดงในสมุดรายชื่อ"
+
+, "Hide from addressbook"
+: "ซ่อนจากสมุดรายชื่อ"
+
+, "Saved in Addressbook"
+: "บันทึกแล้วในสมุดรายชื่อ"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "สมาชิกของกลุ่ม"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: ""
 
 , "Confirm"
 : "ยืนยัน"
 
+, "Do you really want to delete the selected tags?"
+: "คุณแน่ใจว่าคุณต้องการลบป้ายกำกับที่เลือก?"
+
+, "Deleting tag(s)..."
+: "กำลังลบ ป้ายกำกับ(s)..."
+
+, "Add Tag"
+: "เพิ่มป้ายกำกับ"
+
+, "Edit Tag"
+: "แก้ไขป้ายกำกับ"
+
+, "Delete Tag"
+: "ลบป้ายกำกับ"
+
+, "Search:"
+: "ค้นหา:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "กำกังแสดงป้ายกำกับ {0} - {1} จาก {2}"
+
+, "No tags to display"
+: "ไม่มีป้ายกำกับใด ๆ ให้แสดง"
+
+, "ID"
+: "รหัส"
+
+, "Color"
+: "สี"
+
+, "Usage:&#160;"
+: "การใช้:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "คุณแน่ใจว่าต้องการลบหน้าที่ที่เลือกไว้นี้?"
+
+, "Deleting role(s)..."
+: "กำลังลบ หน้าที่(s)..."
+
+, "Failed"
+: "ได้ล้มเหลว"
+
+, "Some error occurred while trying to delete the role."
+: "มีข้อผิดพลาดบางอย่างเกิดขึ้น ขณะที่พยายามลบหน้าที่"
+
+, "Add Role"
+: "เพิ่มหน้าที่"
+
+, "Edit Role"
+: "แก้ไขหน้าที่"
+
+, "Delete Role"
+: "ลบหน้าที่"
+
+, "Displaying roles {0} - {1} of {2}"
+: "กำลังแสดงหน้าที่ {0} - {1} จาก {2}"
+
+, "No roles to display"
+: "ไม่มีหน้าที่ใด ๆ ให้แสดง"
+
+, "Container Name"
+: "ชื่อที่จัดเก็บ"
+
+, "Type"
+: "ประเภท"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "ที่จัดเก็บ"
+
+]
+, "Model"
+: "รุ่น"
+
+, "personal"
+: "ส่วนตัว"
+
+, "shared"
+: "ใช้ร่วมกัน"
+
+, "Order"
+: "คำสั่ง"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "บันทึกสำหรับเจ้าของ"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "คุณแน่ใจว่าต้องการลบกลุ่มที่เลือกไว้นี้?"
 
 , "Deleting group(s)..."
 : "กำลังลบ กลุ่ม"
 
-, "Failed"
-: "ได้ล้มเหลว"
-
 , "Some error occurred while trying to delete the group."
 : "มีข้อผิดพลาดบางอย่างเกิดขึ้น ขณะที่พยายามลบกลุ่ม"
 
@@ -79,15 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "ไม่มีกลุ่มใด ๆ ให้แสดง"
 
-, "ID"
-: "รหัส"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "การอธิบาย"
-
 , "Creation Time"
 : ""
 
@@ -100,17 +274,71 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "หมายเลขไอพี"
+
+, "Login Time"
+: "เวลาเข้าใช้"
+
+, "Logout Time"
+: "เวลาเลิกใช้"
+
+, "Client Type"
+: "ประเภทลูกค้า"
+
+, "Session ID"
+: "รหัสเซสชัน"
+
+, "Login Name"
+: "ชื่อที่เข้าใช้"
+
+, "Result"
+: "ผลลัพธ์"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "ผู้ใช้ถูกล็อก"
+
+, "password expired"
+: "รหัสผ่านหมดอายุแล้ว"
+
+, "user disabled"
+: "ผู้ใช้ปิดใช้งานแล้ว"
+
+, "invalid password"
+: "รหัสผ่านไม่ถูกต้อง"
+
+, "ambiguous username"
+: "ชื่อผู้ใช้คลุมเครือ"
+
+, "user not found"
+: "ผู้ใช้ไม่พบ"
+
+, "failure"
+: "ความล้มเหลว"
+
+, "success"
+: "ความสำเร็จ"
+
+, "Customfield, Customfields"
+: [
+  ""
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "ข้อผิดพลาด"
 
 , "Please configure store for this field type"
 : ""
 
-, "Application, Applications"
-: [
-  "การประยุกต์ใช้"
-
-]
 , "Record Class"
 : "บันทึก ชั้น"
 
@@ -126,9 +354,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : ""
 
-, "Model"
-: "รุ่น"
-
 , "Custom field definition"
 : ""
 
@@ -165,12 +390,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "ประเภท"
-
-, "Label"
-: "ป้าย"
-
 , "Length"
 : "ความยาว"
 
@@ -188,180 +407,79 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
   "กลุ่ม"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : ""
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "อนุญาตใช้บัญชี"
+
+, "Disable Account"
+: "เลิกบัญชี"
+
+, "Reset Password"
+: "ตั้งรหัสผ่านใหม่"
+
+, "Status"
+: "สถานะ"
+
+, "Display name"
+: "ชื่อที่ใช้"
+
+, "Login name"
+: "ชื่อที่เข้าใช้"
+
+, "Last name"
+: "นามสกุล"
+
+, "First name"
+: "ชื่อตัว"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "รหัสเปิด"
+
+, "Last login at"
+: "ลงชื่อเข้าใช้ครั้งล่าสุด เมื่อ"
+
+, "Last login from"
+: "ลงชื่อเข้าใช้ครั้งล่าสุด จาก"
+
+, "Password Must Change"
+: "รหัสผ่านต้องเปลี่ยน"
+
+, "Password changed"
+: "รหัสผ่านได้เปลี่ยนแล้ว"
+
+, "Expires"
+: "หมดอายุ"
+
+, "Set new password"
+: "ตั้งรหัสผ่านใหม่"
+
+, "Please enter the new password:"
+: "กรุณาใส่รหัสผ่านใหม่:"
+
+, "Users"
+: "ผู้ใช้"
+
+, "Samba User, Samba Users"
 : [
-  ""
+  "ผู้ใช้ Samba"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
+  "ผู้ใช้อีเมล"
 
 ]
-, "Value"
-: "ค่า"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "ชื่อของคอมพิวเตอร์"
-
-, "Default Addressbook for new contacts and groups"
-: "สมุดรายชื่อหลักสำหรับการติดต่อและกลุ่มใหม่"
-
-, "Please wait"
-: "กรุณารอ"
-
-, "Updating Tag"
-: "กำลังปรับปรุงป้ายกำกับ"
-
-, "Could not save tag ({0})"
-: "ไม่สามารถจัดเก็บป้ายกำกับ ({0}) ได้"
-
-, "Please fix the errors noted."
-: "กรุณาแก้ไขข้อผิดพลาดที่ได้บันทึกไว้"
-
-, "Allowed Contexts"
-: "เนื้อหาที่อนุญาต"
-
-, "Context"
-: "เนื้อหา"
-
-, "Account Rights"
-: "สิทธิ์เกี่ยวกับบัญชี"
-
-, "View"
-: "ดู"
-
-, "Use"
-: "ใช้"
-
-, "Tag Name"
-: "ชื่อป้ายกำกับ"
-
-, "Color"
-: "สี"
-
-, "Transferring {0}..."
-: "กำลังโอนย้าย {0}..."
-
-, "Tag"
-: "ป้ายกำกับ"
-
-, "Add New Tag"
-: "เพิ่มป้ายกำกับใหม่"
-
-, "Edit Tag \"{0}\""
-: "แก้ไขป้ายกำกับ \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "คุณแน่ใจว่าคุณต้องการลบป้ายกำกับที่เลือก?"
-
-, "Deleting tag(s)..."
-: "กำลังลบ ป้ายกำกับ(s)..."
-
-, "Add Tag"
-: "เพิ่มป้ายกำกับ"
-
-, "Edit Tag"
-: "แก้ไขป้ายกำกับ"
-
-, "Delete Tag"
-: "ลบป้ายกำกับ"
-
-, "Displaying tags {0} - {1} of {2}"
-: "กำกังแสดงป้ายกำกับ {0} - {1} จาก {2}"
-
-, "No tags to display"
-: "ไม่มีป้ายกำกับใด ๆ ให้แสดง"
-
-, "Usage:&#160;"
-: "การใช้:&#160;"
-
-, "Updating Memberships"
-: "กำลังปรับปรุงการเป็นสมาชิก"
-
-, "Could not save role."
-: "ไม่สามารถจัดเก็บหน้าที่ได้"
-
-, "Deleting role..."
-: "กำลังลบ หน้าที่..."
-
-, "Some error occurred while trying to delete the role."
-: "มีข้อผิดพลาดบางอย่างเกิดขึ้น ขณะที่พยายามลบหน้าที่"
-
-, "Rights"
-: "สิทธิ์"
-
-, "Members"
-: "สมาชิก"
-
-, "Role Name"
-: "ชื่อหน้าที่"
-
-, "Role"
-: "หน้าที่"
-
-, "Add New Role"
-: "เพิ่มหน้าที่ใหม่"
-
-, "Edit Role \"{0}\""
-: "แก้ไขหน้าที่ \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "คุณแน่ใจว่าต้องการลบหน้าที่ที่เลือกไว้นี้?"
-
-, "Deleting role(s)..."
-: "กำลังลบ หน้าที่(s)..."
-
-, "Add Role"
-: "เพิ่มหน้าที่"
-
-, "Edit Role"
-: "แก้ไขหน้าที่"
-
-, "Delete Role"
-: "ลบหน้าที่"
-
-, "Displaying roles {0} - {1} of {2}"
-: "กำลังแสดงหน้าที่ {0} - {1} จาก {2}"
-
-, "No roles to display"
-: "ไม่มีหน้าที่ใด ๆ ให้แสดง"
-
-, "Access Log, Access Logs"
-: [
-  "บันทึกการใช้งาน"
-
-]
-, "Groups"
-: "กลุ่ม"
-
-, "Applications"
-: "การประยุกต์ใช้"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: ""
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -389,18 +507,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : ""
 
-, "Login Time"
-: "เวลาเข้าใช้"
-
 , "never logged in"
 : "ไม่เคยได้เข้าใช้"
 
 , "Home Path"
 : ""
 
-, "Logout Time"
-: "เวลาเลิกใช้"
-
 , "never logged off"
 : "ไม่เคยเลิกใช้"
 
@@ -422,9 +534,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "ยังไม่ได้กำหนด"
 
-, "Password Must Change"
-: "รหัสผ่านต้องเปลี่ยน"
-
 , "Kick Off Time"
 : ""
 
@@ -458,11 +567,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "ลงบันทึกเข้าครั้งล่าสุด"
 
-, "Domain not allowed"
-: "โดเมนไม่ได้รับอนุญาต"
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "ส่งต่อเท่านั้น"
 
 , "E-mail Alias"
 : ""
@@ -473,6 +579,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: "โดเมนไม่ได้รับอนุญาต"
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : "ส่งต่อให้ตัวเอง"
 
@@ -485,9 +597,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "ส่งต่อเท่านั้น"
-
 , "Password confirmation"
 : "การยืนยันรหัสผ่าน"
 
@@ -500,20 +609,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "บัญชี"
 
-, "First name"
-: "ชื่อตัว"
-
-, "Last name"
-: "นามสกุล"
-
-, "Login name"
-: "ชื่อที่เข้าใช้"
-
 , "Password"
 : "รหัสผ่าน"
 
-, "OpenID"
-: "รหัสเปิด"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "เปิดใช้งานแล้ว"
@@ -533,30 +633,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "สถานะ ถูกล็อก จะใช้ต่อเมื่อผู้ใช้พยายามลงชื่อเข้าใช้ด้วยรหัสผ่านที่ผิดบ่อย ๆ ณ ที่นี่ไม่สามารถตั้งค่าสถานะนี้ได้"
 
-, "Expires"
-: "หมดอายุ"
-
-, "Visibility"
-: "การมองเห็นได้"
-
-, "Display in addressbook"
-: "แสดงในสมุดรายชื่อ"
-
-, "Hide from addressbook"
-: "ซ่อนจากสมุดรายชื่อ"
-
-, "Saved in Addressbook"
-: "บันทึกแล้วในสมุดรายชื่อ"
-
-, "Last login at"
-: "ลงชื่อเข้าใช้ครั้งล่าสุด เมื่อ"
-
 , "don't know"
 : "ไม่ทราบ"
 
-, "Last login from"
-: "ลงชื่อเข้าใช้ครั้งล่าสุด จาก"
-
 , "Password set"
 : "ตั้งรหัสผ่าน"
 
@@ -578,103 +657,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "ผู้ใช้"
-
-]
-, "Users"
-: "ผู้ใช้"
-
-, "Samba User, Samba Users"
-: [
-  "ผู้ใช้ Samba"
-
-]
-, "Email User, Email Users"
-: [
-  "ผู้ใช้อีเมล"
-
-]
-, "Enable Account"
-: "อนุญาตใช้บัญชี"
-
-, "Disable Account"
-: "เลิกบัญชี"
-
-, "Reset Password"
-: "ตั้งรหัสผ่านใหม่"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "ชื่อที่ใช้"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "รหัสผ่านได้เปลี่ยนแล้ว"
-
-, "Set new password"
-: "ตั้งรหัสผ่านใหม่"
-
-, "Please enter the new password:"
-: "กรุณาใส่รหัสผ่านใหม่:"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "ชื่อกลุ่ม"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "สมาชิกของกลุ่ม"
-
-, "personal"
-: "ส่วนตัว"
-
-, "shared"
-: "ใช้ร่วมกัน"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "บันทึกสำหรับเจ้าของ"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "ที่จัดเก็บ"
-
-]
-, "Container Name"
-: "ชื่อที่จัดเก็บ"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "คอมพิวเตอร์"
 
 ]
+, "Please wait"
+: "กรุณารอ"
+
+, "Updating Memberships"
+: "กำลังปรับปรุงการเป็นสมาชิก"
+
+, "Could not save role."
+: "ไม่สามารถจัดเก็บหน้าที่ได้"
+
+, "Please fix the errors noted."
+: "กรุณาแก้ไขข้อผิดพลาดที่ได้บันทึกไว้"
+
+, "Deleting role..."
+: "กำลังลบ หน้าที่..."
+
+, "Rights"
+: "สิทธิ์"
+
+, "Members"
+: "สมาชิก"
+
+, "Role Name"
+: "ชื่อหน้าที่"
+
+, "Transferring {0}..."
+: "กำลังโอนย้าย {0}..."
+
+, "Role"
+: "หน้าที่"
+
+, "Add New Role"
+: "เพิ่มหน้าที่ใหม่"
+
+, "Edit Role \"{0}\""
+: "แก้ไขหน้าที่ \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -687,78 +713,69 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "หน้าที่"
+, "Updating Tag"
+: "กำลังปรับปรุงป้ายกำกับ"
 
-, "Containers"
-: "ที่จัดเก็บ"
+, "Could not save tag ({0})"
+: "ไม่สามารถจัดเก็บป้ายกำกับ ({0}) ได้"
 
-, "Shared Tags"
-: "ป้ายกำกับที่ใช้ร่วมกัน"
+, "Allowed Contexts"
+: "เนื้อหาที่อนุญาต"
 
-, "Customfields"
+, "Context"
+: "เนื้อหา"
+
+, "Account Rights"
+: "สิทธิ์เกี่ยวกับบัญชี"
+
+, "View"
+: "ดู"
+
+, "Use"
+: "ใช้"
+
+, "Tag Name"
+: "ชื่อป้ายกำกับ"
+
+, "Tag"
+: "ป้ายกำกับ"
+
+, "Add New Tag"
+: "เพิ่มป้ายกำกับใหม่"
+
+, "Edit Tag \"{0}\""
+: "แก้ไขป้ายกำกับ \"{0}\""
+
+, "Enable Application"
+: "อนุญาตให้ใช้แอพลิเคชั่น"
+
+, "Disable Application"
+: "ยกเลิกการใช้แอพลิเคชั่น"
+
+, "Settings"
+: "ค่าติดตั้ง"
+
+, "{0} Settings"
+: "ค่าติดตั้ง {0}"
+
+, "Enabled"
 : ""
 
-, "Computers"
-: "คอมพิวเตอร์"
-
-, "Server Information"
-: "ข้อมูลระบบ"
-
-, "ActiveSync Devices"
+, "Unknown status ({0})"
 : ""
 
-, "E-mail Accounts"
+, "Displaying application {0} - {1} of {2}"
+: "แสดงการใช้ {0} - {1} จาก {2}"
+
+, "No applications to display"
+: "ไม่มีการใช้ใด ๆ ให้แสดง"
+
+, "Version"
+: "ภาค"
+
+, "Default password must change for new user settings"
 : ""
 
-, "Admin"
-: "ผู้ดูแลระบบ"
-
-, "Refresh"
-: ""
-
-, "Feature is disabled by configuration."
-: ""
-
-, "IP Address"
-: "หมายเลขไอพี"
-
-, "Client Type"
-: "ประเภทลูกค้า"
-
-, "Session ID"
-: "รหัสเซสชัน"
-
-, "Login Name"
-: "ชื่อที่เข้าใช้"
-
-, "Result"
-: "ผลลัพธ์"
-
-, "user blocked"
-: "ผู้ใช้ถูกล็อก"
-
-, "password expired"
-: "รหัสผ่านหมดอายุแล้ว"
-
-, "user disabled"
-: "ผู้ใช้ปิดใช้งานแล้ว"
-
-, "invalid password"
-: "รหัสผ่านไม่ถูกต้อง"
-
-, "ambiguous username"
-: "ชื่อผู้ใช้คลุมเครือ"
-
-, "user not found"
-: "ผู้ใช้ไม่พบ"
-
-, "failure"
-: "ความล้มเหลว"
-
-, "success"
-: "ความสำเร็จ"
-
 , "Default IMAP user settings"
 : "ค่าตั้งตั้งของผู้ใช้ IMAP หลัก "
 
@@ -780,6 +797,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "มีการเปลี่ยนแปลงตู้ใส่ของของคุณ โดย %1$s %2$sหมายเหตุ: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -834,6 +857,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -900,6 +929,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -939,25 +970,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "การประยุกต์ใช้"
 
-, "Group"
-: "กลุ่ม"
-
-, "Customfield"
-: ""
-
-, "Config"
-: ""
+, "User"
+: "ผู้ใช้"
 
 , "Access Log"
 : "บันทึกการใช้งาน"
 
-, "User"
-: "ผู้ใช้"
+, "Config"
+: ""
+
+, "Container"
+: "ที่จัดเก็บ"
+
+, "Customfield"
+: ""
+
+, "Group"
+: "กลุ่ม"
 
 , "Samba User"
 : "ผู้ใช้ Samba"
@@ -965,9 +1000,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "ผู้ใช้อีเมล"
 
-, "Container"
-: "ที่จัดเก็บ"
-
 , "Computer"
 : "คอมพิวเตอร์"
 
