@@ -5,62 +5,242 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
-: "Mở ứng dụng"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
 
-, "Disable Application"
-: "Cấm ứng dụng"
+]
+, "Application, Applications"
+: [
+  "one: Ứng dụng\nother: Ứng dụng"
 
-, "Settings"
-: "Thiết lập"
+]
+, "User, Users"
+: [
+  "one: Người dùng\nother: Người dùng"
 
-, "{0} Settings"
-: "{0} Thiết lập"
+]
+, "Groups"
+: "Nhóm"
 
-, "Search:"
-: "Tìm kiếm:"
+, "Roles"
+: "Vai trò"
+
+, "Applications"
+: "Ứng dụng"
+
+, "Containers"
+: "Bộ chứa"
+
+, "Shared Tags"
+: "Từ khóa chia sẻ"
+
+, "Customfields"
+: "Trường tùy biến"
+
+, "Computers"
+: "Máy tính"
+
+, "Access Log, Access Logs"
+: [
+  "one: Nhật ký truy cập\nother: Nhật ký truy cập"
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: "Thông tin máy chủ"
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "Admin"
+
+, "Refresh"
+: "Nạp lại"
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
-: ""
+, "Default Addressbook for new contacts and groups"
+: "Danh bạ mặc định cho nhóm và liên lạc mới"
 
-, "Displaying application {0} - {1} of {2}"
-: "Hiển thị ứng dụng {0} - {1} của {2}"
+, "Computer Name"
+: "Tên máy tính"
 
-, "No applications to display"
-: "Không có ứng dụng nào"
+, "Config, Configs"
+: [
+  ""
 
-, "Order"
-: "Xắp xếp"
+]
+, "Description"
+: "Mô tả"
 
 , "Name"
 : "Tên"
 
-, "Status"
-: "Trạng thái"
+, "Label"
+: "Nhãn"
 
-, "Version"
-: "Phiên bản"
+, "Value"
+: "Giá trị"
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "Tên nhóm"
+
+, "Visibility"
+: "Có thể nhìn thấy"
+
+, "Display in addressbook"
+: "Hiển thị trong sổ địa chỉ"
+
+, "Hide from addressbook"
+: "Ẩn từ sổ địa chỉ"
+
+, "Saved in Addressbook"
+: "Đã lưu trong Sổ địa chỉ"
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "Nhóm thành viên"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: "Tên miền không được phép. Kiểm tra cấu hình tên miền SMTP"
 
 , "Confirm"
 : "Xác nhận"
 
+, "Do you really want to delete the selected tags?"
+: "Bạn có muốn xóa các từ khóa đa chọn?"
+
+, "Deleting tag(s)..."
+: "Đang xóa từ khóa ..."
+
+, "Add Tag"
+: "Thêm từ khóa"
+
+, "Edit Tag"
+: "Sửa từ khóa"
+
+, "Delete Tag"
+: "Xóa từ khóa"
+
+, "Search:"
+: "Tìm kiếm:"
+
+, "Displaying tags {0} - {1} of {2}"
+: "Hiển thị từ khóa {0} - {1} của {2}"
+
+, "No tags to display"
+: "Không có từ khóa nào"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "Màu"
+
+, "Usage:&#160;"
+: "Sử dụng:&#160;"
+
+, "Do you really want to delete the selected roles?"
+: "Bạn có muốn xóa vai trò đã chọn"
+
+, "Deleting role(s)..."
+: "Đang xóa vai trò..."
+
+, "Failed"
+: "Hỏng"
+
+, "Some error occurred while trying to delete the role."
+: "Có lỗi khi xóa vai trò"
+
+, "Add Role"
+: "Thêm vai trò"
+
+, "Edit Role"
+: "Sửa vai trò"
+
+, "Delete Role"
+: "Xóa vai trò"
+
+, "Displaying roles {0} - {1} of {2}"
+: "Hiển thị vai trò {0} - {1} của {2}"
+
+, "No roles to display"
+: "Không có vai trò nào"
+
+, "Container Name"
+: "Tên bộ chứa"
+
+, "Type"
+: "Loại"
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  "one: Bộ chứa\nother: Bộ chứa"
+
+]
+, "Model"
+: "Model"
+
+, "personal"
+: "cá nhân"
+
+, "shared"
+: "dùng chung"
+
+, "Order"
+: "Xắp xếp"
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: "Ghi chép cho chủ sở huwuxu"
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "Bạn có muốn xóa nhóm được chọn"
 
 , "Deleting group(s)..."
 : "Đang xóa nhóm ..."
 
-, "Failed"
-: "Hỏng"
-
 , "Some error occurred while trying to delete the group."
 : "Có lỗi xảy ra khi xóa nhóm"
 
@@ -79,15 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "Không có nhóm bài được hiển thị"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "Mô tả"
-
 , "Creation Time"
 : ""
 
@@ -100,17 +274,71 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "Địa chỉ IP"
+
+, "Login Time"
+: "Thời gian đăng nhập"
+
+, "Logout Time"
+: "Thời gian thoát"
+
+, "Client Type"
+: "Loại người dùng"
+
+, "Session ID"
+: "Session ID"
+
+, "Login Name"
+: "Tên đăng nhập"
+
+, "Result"
+: "Kết quả"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: "người dùng đã bị phong tỏa"
+
+, "password expired"
+: "mật khẩu đã hết hạn"
+
+, "user disabled"
+: "người dùng đã bị cấm"
+
+, "invalid password"
+: "sai mật khẩu"
+
+, "ambiguous username"
+: "Tên truy cập không rõ"
+
+, "user not found"
+: "không tìm thấy người dùng"
+
+, "failure"
+: "hỏng"
+
+, "success"
+: "thành công"
+
+, "Customfield, Customfields"
+: [
+  "one: Trường tùy biến\nother: Trường tùy biến"
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "Lỗi"
 
 , "Please configure store for this field type"
 : "Xin cấu hình store cho loại trường này"
 
-, "Application, Applications"
-: [
-  "one: Ứng dụng\nother: Ứng dụng"
-
-]
 , "Record Class"
 : "Record Class"
 
@@ -126,9 +354,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : "Cấu hình store"
 
-, "Model"
-: "Model"
-
 , "Custom field definition"
 : "Định nghĩa trường tùy biến"
 
@@ -165,12 +390,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: "Loại"
-
-, "Label"
-: "Nhãn"
-
 , "Length"
 : "Độ dài"
 
@@ -188,180 +407,79 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
   "one: Nhóm\nother: Nhóm"
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : "Trường tùy biến đã tồn tại. Xin chọn tên khác."
 
-, "Customfield, Customfields"
+, "Enable Account"
+: "Mở tài khoản"
+
+, "Disable Account"
+: "Tắt tài khoản"
+
+, "Reset Password"
+: "Nhập lại mật khẩu"
+
+, "Status"
+: "Trạng thái"
+
+, "Display name"
+: "Tên hiển thị"
+
+, "Login name"
+: "Tên đăng nhập"
+
+, "Last name"
+: "Tên"
+
+, "First name"
+: "Tên họ"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "OpenID"
+
+, "Last login at"
+: "Đăng nhập lần cuối lúc"
+
+, "Last login from"
+: "Đawng nhập lần cuối từ"
+
+, "Password Must Change"
+: "Mật khẩu phải được thay đổi"
+
+, "Password changed"
+: "Đã đổi mật khẩu"
+
+, "Expires"
+: "Hết hạn"
+
+, "Set new password"
+: "Đặt mật khẩu mới"
+
+, "Please enter the new password:"
+: "Xin hãy nhập mật khẩu mới"
+
+, "Users"
+: "Người dùng"
+
+, "Samba User, Samba Users"
 : [
-  "one: Trường tùy biến\nother: Trường tùy biến"
+  "one: Người dùng Samba\nother: Người dùng Samba"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
+  "one: Người sử dụng email\nother: Người sử dụng email"
 
 ]
-, "Value"
-: "Giá trị"
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "Tên máy tính"
-
-, "Default Addressbook for new contacts and groups"
-: "Danh bạ mặc định cho nhóm và liên lạc mới"
-
-, "Please wait"
-: "Xin hãy đợi"
-
-, "Updating Tag"
-: "Đang cập nhật từ khóa"
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "Xin hãy sửa các lỗi được ghi chú."
-
-, "Allowed Contexts"
-: "Ngữ cảnh được phép"
-
-, "Context"
-: "Ngữ cảnh"
-
-, "Account Rights"
-: "Quyền tài khoản"
-
-, "View"
-: "Xem"
-
-, "Use"
-: "Sử dụng"
-
-, "Tag Name"
-: "Tên từ khóa"
-
-, "Color"
-: "Màu"
-
-, "Transferring {0}..."
-: "Đang chuyển {0} ..."
-
-, "Tag"
-: "Từ khóa"
-
-, "Add New Tag"
-: "Thêm từ khóa"
-
-, "Edit Tag \"{0}\""
-: "Sửa từ khóa \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "Bạn có muốn xóa các từ khóa đa chọn?"
-
-, "Deleting tag(s)..."
-: "Đang xóa từ khóa ..."
-
-, "Add Tag"
-: "Thêm từ khóa"
-
-, "Edit Tag"
-: "Sửa từ khóa"
-
-, "Delete Tag"
-: "Xóa từ khóa"
-
-, "Displaying tags {0} - {1} of {2}"
-: "Hiển thị từ khóa {0} - {1} của {2}"
-
-, "No tags to display"
-: "Không có từ khóa nào"
-
-, "Usage:&#160;"
-: "Sử dụng:&#160;"
-
-, "Updating Memberships"
-: "Đang cập nhật thành viên"
-
-, "Could not save role."
-: "Không thể lưu vai trò"
-
-, "Deleting role..."
-: "Đang xóa vai trò ..."
-
-, "Some error occurred while trying to delete the role."
-: "Có lỗi khi xóa vai trò"
-
-, "Rights"
-: "Quyền"
-
-, "Members"
-: "Thành viên"
-
-, "Role Name"
-: "Tên vai trò"
-
-, "Role"
-: "Vai trò"
-
-, "Add New Role"
-: "Thêm vai trò"
-
-, "Edit Role \"{0}\""
-: "Sửa vai trò \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "Bạn có muốn xóa vai trò đã chọn"
-
-, "Deleting role(s)..."
-: "Đang xóa vai trò..."
-
-, "Add Role"
-: "Thêm vai trò"
-
-, "Edit Role"
-: "Sửa vai trò"
-
-, "Delete Role"
-: "Xóa vai trò"
-
-, "Displaying roles {0} - {1} of {2}"
-: "Hiển thị vai trò {0} - {1} của {2}"
-
-, "No roles to display"
-: "Không có vai trò nào"
-
-, "Access Log, Access Logs"
-: [
-  "one: Nhật ký truy cập\nother: Nhật ký truy cập"
-
-]
-, "Groups"
-: "Nhóm"
-
-, "Applications"
-: "Ứng dụng"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: "Tên miền không được phép. Kiểm tra cấu hình tên miền SMTP"
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -389,18 +507,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Home Drive"
 
-, "Login Time"
-: "Thời gian đăng nhập"
-
 , "never logged in"
 : "chưa bao giờ đăng nhập"
 
 , "Home Path"
 : "Đường dẫn trang chủ"
 
-, "Logout Time"
-: "Thời gian thoát"
-
 , "never logged off"
 : "chưa bao giờ thoát"
 
@@ -422,9 +534,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "chưa đặt"
 
-, "Password Must Change"
-: "Mật khẩu phải được thay đổi"
-
 , "Kick Off Time"
 : "Thời gian bắt đầu"
 
@@ -458,11 +567,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "Đăng nhập lần cuối"
 
-, "Domain not allowed"
-: "Tên miền không được phép sử dụng"
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "Chỉ chuyển tiếp"
 
 , "E-mail Alias"
 : ""
@@ -473,6 +579,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: "Tên miền không được phép sử dụng"
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : "Chuyển tiếp tới chính tôi"
 
@@ -485,9 +597,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "Chỉ chuyển tiếp"
-
 , "Password confirmation"
 : "Xác nhận mật khẩu"
 
@@ -500,20 +609,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "Tài khoản"
 
-, "First name"
-: "Tên họ"
-
-, "Last name"
-: "Tên"
-
-, "Login name"
-: "Tên đăng nhập"
-
 , "Password"
 : "Mật khẩu"
 
-, "OpenID"
-: "OpenID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "đang mở"
@@ -533,30 +633,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : "Trạng thái bị phong tỏa chỉ hợp lệ khi người dùng cố đăng nhập với một mật khẩu sai một cách thường xuyên. Nó không thể được đặt trạng thái này ở đây."
 
-, "Expires"
-: "Hết hạn"
-
-, "Visibility"
-: "Có thể nhìn thấy"
-
-, "Display in addressbook"
-: "Hiển thị trong sổ địa chỉ"
-
-, "Hide from addressbook"
-: "Ẩn từ sổ địa chỉ"
-
-, "Saved in Addressbook"
-: "Đã lưu trong Sổ địa chỉ"
-
-, "Last login at"
-: "Đăng nhập lần cuối lúc"
-
 , "don't know"
 : "không biết"
 
-, "Last login from"
-: "Đawng nhập lần cuối từ"
-
 , "Password set"
 : "Mật khẩu được đặt"
 
@@ -578,103 +657,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  "one: Người dùng\nother: Người dùng"
-
-]
-, "Users"
-: "Người dùng"
-
-, "Samba User, Samba Users"
-: [
-  "one: Người dùng Samba\nother: Người dùng Samba"
-
-]
-, "Email User, Email Users"
-: [
-  "one: Người sử dụng email\nother: Người sử dụng email"
-
-]
-, "Enable Account"
-: "Mở tài khoản"
-
-, "Disable Account"
-: "Tắt tài khoản"
-
-, "Reset Password"
-: "Nhập lại mật khẩu"
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: "Tên hiển thị"
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "Đã đổi mật khẩu"
-
-, "Set new password"
-: "Đặt mật khẩu mới"
-
-, "Please enter the new password:"
-: "Xin hãy nhập mật khẩu mới"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "Tên nhóm"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "Nhóm thành viên"
-
-, "personal"
-: "cá nhân"
-
-, "shared"
-: "dùng chung"
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: "Ghi chép cho chủ sở huwuxu"
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  "one: Bộ chứa\nother: Bộ chứa"
-
-]
-, "Container Name"
-: "Tên bộ chứa"
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "one: Máy tính\nother: Máy tính"
 
 ]
+, "Please wait"
+: "Xin hãy đợi"
+
+, "Updating Memberships"
+: "Đang cập nhật thành viên"
+
+, "Could not save role."
+: "Không thể lưu vai trò"
+
+, "Please fix the errors noted."
+: "Xin hãy sửa các lỗi được ghi chú."
+
+, "Deleting role..."
+: "Đang xóa vai trò ..."
+
+, "Rights"
+: "Quyền"
+
+, "Members"
+: "Thành viên"
+
+, "Role Name"
+: "Tên vai trò"
+
+, "Transferring {0}..."
+: "Đang chuyển {0} ..."
+
+, "Role"
+: "Vai trò"
+
+, "Add New Role"
+: "Thêm vai trò"
+
+, "Edit Role \"{0}\""
+: "Sửa vai trò \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -687,77 +713,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "Vai trò"
+, "Updating Tag"
+: "Đang cập nhật từ khóa"
 
-, "Containers"
-: "Bộ chứa"
-
-, "Shared Tags"
-: "Từ khóa chia sẻ"
-
-, "Customfields"
-: "Trường tùy biến"
-
-, "Computers"
-: "Máy tính"
-
-, "Server Information"
-: "Thông tin máy chủ"
-
-, "ActiveSync Devices"
+, "Could not save tag ({0})"
 : ""
 
-, "E-mail Accounts"
+, "Allowed Contexts"
+: "Ngữ cảnh được phép"
+
+, "Context"
+: "Ngữ cảnh"
+
+, "Account Rights"
+: "Quyền tài khoản"
+
+, "View"
+: "Xem"
+
+, "Use"
+: "Sử dụng"
+
+, "Tag Name"
+: "Tên từ khóa"
+
+, "Tag"
+: "Từ khóa"
+
+, "Add New Tag"
+: "Thêm từ khóa"
+
+, "Edit Tag \"{0}\""
+: "Sửa từ khóa \"{0}\""
+
+, "Enable Application"
+: "Mở ứng dụng"
+
+, "Disable Application"
+: "Cấm ứng dụng"
+
+, "Settings"
+: "Thiết lập"
+
+, "{0} Settings"
+: "{0} Thiết lập"
+
+, "Enabled"
 : ""
 
-, "Admin"
-: "Admin"
-
-, "Refresh"
-: "Nạp lại"
-
-, "Feature is disabled by configuration."
+, "Unknown status ({0})"
 : ""
 
-, "IP Address"
-: "Địa chỉ IP"
+, "Displaying application {0} - {1} of {2}"
+: "Hiển thị ứng dụng {0} - {1} của {2}"
 
-, "Client Type"
-: "Loại người dùng"
+, "No applications to display"
+: "Không có ứng dụng nào"
 
-, "Session ID"
-: "Session ID"
+, "Version"
+: "Phiên bản"
 
-, "Login Name"
-: "Tên đăng nhập"
-
-, "Result"
-: "Kết quả"
-
-, "user blocked"
-: "người dùng đã bị phong tỏa"
-
-, "password expired"
-: "mật khẩu đã hết hạn"
-
-, "user disabled"
-: "người dùng đã bị cấm"
-
-, "invalid password"
-: "sai mật khẩu"
-
-, "ambiguous username"
-: "Tên truy cập không rõ"
-
-, "user not found"
-: "không tìm thấy người dùng"
-
-, "failure"
-: "hỏng"
-
-, "success"
-: "thành công"
+, "Default password must change for new user settings"
+: ""
 
 , "Default IMAP user settings"
 : "Default IMAP user settings"
@@ -780,6 +797,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : "Bộ chứa của bạn đã được đổi từ %1$s %2$s. Ghi chú: %3$s"
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -834,6 +857,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -900,6 +929,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -944,25 +975,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : "one: Ứng dụng\nother: Ứng dụng"
 
-, "Group"
-: "one: Nhóm\nother: Nhóm"
-
-, "Customfield"
-: "one: Trường tùy biến\nother: Trường tùy biến"
-
-, "Config"
-: ""
+, "User"
+: "one: Người dùng\nother: Người dùng"
 
 , "Access Log"
 : "one: Nhật ký truy cập\nother: Nhật ký truy cập"
 
-, "User"
-: "one: Người dùng\nother: Người dùng"
+, "Config"
+: ""
+
+, "Container"
+: "one: Bộ chứa\nother: Bộ chứa"
+
+, "Customfield"
+: "one: Trường tùy biến\nother: Trường tùy biến"
+
+, "Group"
+: "one: Nhóm\nother: Nhóm"
 
 , "Samba User"
 : "one: Người dùng Samba\nother: Người dùng Samba"
@@ -970,9 +1005,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "one: Người sử dụng email\nother: Người sử dụng email"
 
-, "Container"
-: "one: Bộ chứa\nother: Bộ chứa"
-
 , "Computer"
 : "one: Máy tính\nother: Máy tính"
 
