@@ -5,62 +5,242 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+
+]
+, "Application, Applications"
+: [
+  ""
+
+]
+, "User, Users"
+: [
+  ""
+
+]
+, "Groups"
+: "组"
+
+, "Roles"
+: "角色"
+
+, "Applications"
+: "应用程序"
+
+, "Containers"
 : ""
 
-, "Disable Application"
+, "Shared Tags"
+: "共享的标签"
+
+, "Customfields"
 : ""
 
-, "Settings"
+, "Computers"
+: "电脑"
+
+, "Access Log, Access Logs"
+: [
+  ""
+
+]
+, "Log"
 : ""
 
-, "{0} Settings"
-: "{0}设置"
+, "Server Information"
+: ""
 
-, "Search:"
-: "搜索："
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "管理"
+
+, "Refresh"
+: ""
 
 , "Disabled"
 : ""
 
-, "Enabled"
+, "Feature is disabled by configuration."
 : ""
 
-, "Unknown status ({0})"
+, "Default Addressbook for new contacts and groups"
 : ""
 
-, "Displaying application {0} - {1} of {2}"
-: "显示程序 {0} - {1} of {2}"
+, "Computer Name"
+: "电脑名"
 
-, "No applications to display"
-: "没有程序要显示"
+, "Config, Configs"
+: [
+  ""
 
-, "Order"
-: ""
+]
+, "Description"
+: "描述"
 
 , "Name"
 : "名字"
 
-, "Status"
-: "状态"
+, "Label"
+: ""
 
-, "Version"
+, "Value"
+: ""
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "组名"
+
+, "Visibility"
+: "可见度"
+
+, "Display in addressbook"
+: "在地址本中显示"
+
+, "Hide from addressbook"
+: "从地址本中隐藏"
+
+, "Saved in Addressbook"
+: ""
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "组成员"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
 : ""
 
 , "Confirm"
 : "确认"
 
+, "Do you really want to delete the selected tags?"
+: "真的想删除选中的标签？"
+
+, "Deleting tag(s)..."
+: "删除标签"
+
+, "Add Tag"
+: ""
+
+, "Edit Tag"
+: ""
+
+, "Delete Tag"
+: ""
+
+, "Search:"
+: "搜索："
+
+, "Displaying tags {0} - {1} of {2}"
+: "显示标签{0} - {1} of {2}"
+
+, "No tags to display"
+: "没有标签要显示"
+
+, "ID"
+: "ID"
+
+, "Color"
+: "颜色"
+
+, "Usage:&#160;"
+: ""
+
+, "Do you really want to delete the selected roles?"
+: "真的想删除选中的角色？"
+
+, "Deleting role(s)..."
+: "删除角色 ..."
+
+, "Failed"
+: "失败"
+
+, "Some error occurred while trying to delete the role."
+: "当试图删除角色是发生错误"
+
+, "Add Role"
+: ""
+
+, "Edit Role"
+: ""
+
+, "Delete Role"
+: ""
+
+, "Displaying roles {0} - {1} of {2}"
+: "显示角色{0} - {1} of {2}"
+
+, "No roles to display"
+: "没有角色要显示"
+
+, "Container Name"
+: ""
+
+, "Type"
+: ""
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  ""
+
+]
+, "Model"
+: ""
+
+, "personal"
+: ""
+
+, "shared"
+: ""
+
+, "Order"
+: ""
+
+, "Container Hierarchy/Name"
+: ""
+
+, "Note for Owner"
+: ""
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
+
 , "Do you really want to delete the selected groups?"
 : "真的要删除选中的组？"
 
 , "Deleting group(s)..."
 : "删除组..."
 
-, "Failed"
-: "失败"
-
 , "Some error occurred while trying to delete the group."
 : "当试图删除组时发生错误"
 
@@ -79,15 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "没有组要显示"
 
-, "ID"
-: "ID"
-
-, "E-mail"
+, "Account only"
 : ""
 
-, "Description"
-: "描述"
-
 , "Creation Time"
 : ""
 
@@ -100,17 +274,71 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "IP 地址"
+
+, "Login Time"
+: "登录时间"
+
+, "Logout Time"
+: "登出时间"
+
+, "Client Type"
+: ""
+
+, "Session ID"
+: "会话 ID"
+
+, "Login Name"
+: "登录名"
+
+, "Result"
+: "结果"
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: ""
+
+, "password expired"
+: ""
+
+, "user disabled"
+: ""
+
+, "invalid password"
+: "无效的密码"
+
+, "ambiguous username"
+: "不清楚的用户名"
+
+, "user not found"
+: "没有发现用户"
+
+, "failure"
+: "失败"
+
+, "success"
+: "成功"
+
+, "Customfield, Customfields"
+: [
+  ""
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "错误"
 
 , "Please configure store for this field type"
 : ""
 
-, "Application, Applications"
-: [
-  ""
-
-]
 , "Record Class"
 : ""
 
@@ -126,9 +354,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : ""
 
-, "Model"
-: ""
-
 , "Custom field definition"
 : ""
 
@@ -165,12 +390,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: ""
-
-, "Label"
-: ""
-
 , "Length"
 : ""
 
@@ -188,180 +407,79 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
   ""
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : ""
 
-, "Customfield, Customfields"
+, "Enable Account"
+: ""
+
+, "Disable Account"
+: ""
+
+, "Reset Password"
+: ""
+
+, "Status"
+: "状态"
+
+, "Display name"
+: ""
+
+, "Login name"
+: ""
+
+, "Last name"
+: "姓"
+
+, "First name"
+: "名"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: "开放 ID"
+
+, "Last login at"
+: "上次登录时间"
+
+, "Last login from"
+: "上次登录于"
+
+, "Password Must Change"
+: "密码必须修改"
+
+, "Password changed"
+: "密码已修改"
+
+, "Expires"
+: "过期"
+
+, "Set new password"
+: "设置新密码"
+
+, "Please enter the new password:"
+: "请输入新密码"
+
+, "Users"
+: ""
+
+, "Samba User, Samba Users"
 : [
-  ""
+  "Samba 用户"
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
-  ""
+  "电子邮件用户"
 
 ]
-, "Value"
-: ""
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: "电脑名"
-
-, "Default Addressbook for new contacts and groups"
-: ""
-
-, "Please wait"
-: "请稍等"
-
-, "Updating Tag"
-: "更新标签..."
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: "请修复标明的错误"
-
-, "Allowed Contexts"
-: "允许的上下文"
-
-, "Context"
-: "上下文"
-
-, "Account Rights"
-: "账户权限"
-
-, "View"
-: "视图"
-
-, "Use"
-: "使用"
-
-, "Tag Name"
-: "标签名"
-
-, "Color"
-: "颜色"
-
-, "Transferring {0}..."
-: ""
-
-, "Tag"
-: ""
-
-, "Add New Tag"
-: "添加新标签"
-
-, "Edit Tag \"{0}\""
-: "编辑标签\"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "真的想删除选中的标签？"
-
-, "Deleting tag(s)..."
-: "删除标签"
-
-, "Add Tag"
-: ""
-
-, "Edit Tag"
-: ""
-
-, "Delete Tag"
-: ""
-
-, "Displaying tags {0} - {1} of {2}"
-: "显示标签{0} - {1} of {2}"
-
-, "No tags to display"
-: "没有标签要显示"
-
-, "Usage:&#160;"
-: ""
-
-, "Updating Memberships"
-: "更新会员身份"
-
-, "Could not save role."
-: "不能保存角色"
-
-, "Deleting role..."
-: "删除角色..."
-
-, "Some error occurred while trying to delete the role."
-: "当试图删除角色是发生错误"
-
-, "Rights"
-: "权限"
-
-, "Members"
-: "成员"
-
-, "Role Name"
-: "角色名"
-
-, "Role"
-: ""
-
-, "Add New Role"
-: "添加新角色"
-
-, "Edit Role \"{0}\""
-: "编辑角色 \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "真的想删除选中的角色？"
-
-, "Deleting role(s)..."
-: "删除角色 ..."
-
-, "Add Role"
-: ""
-
-, "Edit Role"
-: ""
-
-, "Delete Role"
-: ""
-
-, "Displaying roles {0} - {1} of {2}"
-: "显示角色{0} - {1} of {2}"
-
-, "No roles to display"
-: "没有角色要显示"
-
-, "Access Log, Access Logs"
-: [
-  ""
-
-]
-, "Groups"
-: "组"
-
-, "Applications"
-: "应用程序"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: ""
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -389,18 +507,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : "Home 盘"
 
-, "Login Time"
-: "登录时间"
-
 , "never logged in"
 : "从未登录"
 
 , "Home Path"
 : "Home 路径"
 
-, "Logout Time"
-: "登出时间"
-
 , "never logged off"
 : "从未登出"
 
@@ -422,9 +534,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : "没设置"
 
-, "Password Must Change"
-: "密码必须修改"
-
 , "Kick Off Time"
 : "开始时间"
 
@@ -458,11 +567,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : "上次登录"
 
-, "Domain not allowed"
-: ""
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
-: ""
+, "Forward Only"
+: "只转发"
 
 , "E-mail Alias"
 : ""
@@ -473,6 +579,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: ""
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : ""
 
@@ -485,9 +597,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: "只转发"
-
 , "Password confirmation"
 : "密码确认"
 
@@ -500,20 +609,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : "账户"
 
-, "First name"
-: "名"
-
-, "Last name"
-: "姓"
-
-, "Login name"
-: ""
-
 , "Password"
 : "密码"
 
-, "OpenID"
-: "开放 ID"
+, "Multi Factor Authentication Config"
+: ""
 
 , "enabled"
 : "启用的"
@@ -533,30 +633,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : ""
 
-, "Expires"
-: "过期"
-
-, "Visibility"
-: "可见度"
-
-, "Display in addressbook"
-: "在地址本中显示"
-
-, "Hide from addressbook"
-: "从地址本中隐藏"
-
-, "Saved in Addressbook"
-: ""
-
-, "Last login at"
-: "上次登录时间"
-
 , "don't know"
 : "不知道"
 
-, "Last login from"
-: "上次登录于"
-
 , "Password set"
 : "密码设置"
 
@@ -578,103 +657,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : "SMTP"
 
-, "User, Users"
-: [
-  ""
-
-]
-, "Users"
-: ""
-
-, "Samba User, Samba Users"
-: [
-  "Samba 用户"
-
-]
-, "Email User, Email Users"
-: [
-  "电子邮件用户"
-
-]
-, "Enable Account"
-: ""
-
-, "Disable Account"
-: ""
-
-, "Reset Password"
-: ""
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: ""
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "密码已修改"
-
-, "Set new password"
-: "设置新密码"
-
-, "Please enter the new password:"
-: "请输入新密码"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "组名"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "组成员"
-
-, "personal"
-: ""
-
-, "shared"
-: ""
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: ""
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  ""
-
-]
-, "Container Name"
-: ""
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   "电脑"
 
 ]
+, "Please wait"
+: "请稍等"
+
+, "Updating Memberships"
+: "更新会员身份"
+
+, "Could not save role."
+: "不能保存角色"
+
+, "Please fix the errors noted."
+: "请修复标明的错误"
+
+, "Deleting role..."
+: "删除角色..."
+
+, "Rights"
+: "权限"
+
+, "Members"
+: "成员"
+
+, "Role Name"
+: "角色名"
+
+, "Transferring {0}..."
+: ""
+
+, "Role"
+: ""
+
+, "Add New Role"
+: "添加新角色"
+
+, "Edit Role \"{0}\""
+: "编辑角色 \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -687,78 +713,69 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "角色"
+, "Updating Tag"
+: "更新标签..."
 
-, "Containers"
+, "Could not save tag ({0})"
 : ""
 
-, "Shared Tags"
-: "共享的标签"
+, "Allowed Contexts"
+: "允许的上下文"
 
-, "Customfields"
+, "Context"
+: "上下文"
+
+, "Account Rights"
+: "账户权限"
+
+, "View"
+: "视图"
+
+, "Use"
+: "使用"
+
+, "Tag Name"
+: "标签名"
+
+, "Tag"
 : ""
 
-, "Computers"
-: "电脑"
+, "Add New Tag"
+: "添加新标签"
 
-, "Server Information"
+, "Edit Tag \"{0}\""
+: "编辑标签\"{0}\""
+
+, "Enable Application"
 : ""
 
-, "ActiveSync Devices"
+, "Disable Application"
 : ""
 
-, "E-mail Accounts"
+, "Settings"
 : ""
 
-, "Admin"
-: "管理"
+, "{0} Settings"
+: "{0}设置"
 
-, "Refresh"
+, "Enabled"
 : ""
 
-, "Feature is disabled by configuration."
+, "Unknown status ({0})"
 : ""
 
-, "IP Address"
-: "IP 地址"
+, "Displaying application {0} - {1} of {2}"
+: "显示程序 {0} - {1} of {2}"
 
-, "Client Type"
+, "No applications to display"
+: "没有程序要显示"
+
+, "Version"
 : ""
 
-, "Session ID"
-: "会话 ID"
-
-, "Login Name"
-: "登录名"
-
-, "Result"
-: "结果"
-
-, "user blocked"
+, "Default password must change for new user settings"
 : ""
 
-, "password expired"
-: ""
-
-, "user disabled"
-: ""
-
-, "invalid password"
-: "无效的密码"
-
-, "ambiguous username"
-: "不清楚的用户名"
-
-, "user not found"
-: "没有发现用户"
-
-, "failure"
-: "失败"
-
-, "success"
-: "成功"
-
 , "Default IMAP user settings"
 : ""
 
@@ -780,6 +797,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : ""
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -834,6 +857,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -900,6 +929,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -931,24 +962,28 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : ""
 
-, "Group"
-: ""
-
-, "Customfield"
-: ""
-
-, "Config"
+, "User"
 : ""
 
 , "Access Log"
 : ""
 
-, "User"
+, "Config"
+: ""
+
+, "Container"
+: ""
+
+, "Customfield"
+: ""
+
+, "Group"
 : ""
 
 , "Samba User"
@@ -957,9 +992,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : "电子邮件用户"
 
-, "Container"
-: ""
-
 , "Computer"
 : "电脑"
 
