@@ -5,52 +5,235 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Admin **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nLanguage: zh_TW\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nLanguage: zh_TW\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Enable Application"
+, "ImportExportDefinition, ImportExportDefinitions"
+: [
+  ""
+
+]
+, "Application, Applications"
+: [
+  ""
+
+]
+, "User, Users"
+: [
+  ""
+
+]
+, "Groups"
+: "群組"
+
+, "Roles"
+: "角色"
+
+, "Applications"
+: "應用程式"
+
+, "Containers"
 : ""
 
-, "Disable Application"
+, "Shared Tags"
+: "分享標記"
+
+, "Customfields"
 : ""
 
-, "Settings"
+, "Computers"
 : ""
 
-, "{0} Settings"
+, "Access Log, Access Logs"
+: [
+  ""
+
+]
+, "Log"
+: ""
+
+, "Server Information"
+: ""
+
+, "ActiveSync Devices"
+: ""
+
+, "E-mail Accounts"
+: ""
+
+, "Import Export Definitions"
+: ""
+
+, "Admin"
+: "管理者"
+
+, "Refresh"
+: ""
+
+, "Disabled"
+: ""
+
+, "Feature is disabled by configuration."
+: ""
+
+, "Default Addressbook for new contacts and groups"
+: ""
+
+, "Computer Name"
+: ""
+
+, "Config, Configs"
+: [
+  ""
+
+]
+, "Description"
+: "描述"
+
+, "Name"
+: "名字"
+
+, "Label"
+: ""
+
+, "Value"
+: ""
+
+, "Default ({0})"
+: ""
+
+, "Yes"
+: ""
+
+, "No"
+: ""
+
+, "Group Name"
+: "群組名稱"
+
+, "Visibility"
+: ""
+
+, "Display in addressbook"
+: ""
+
+, "Hide from addressbook"
+: ""
+
+, "Saved in Addressbook"
+: ""
+
+, "E-mail"
+: ""
+
+, "Only system accounts can be added to Addressbook group"
+: ""
+
+, "Group Members"
+: "群組成員"
+
+, "Domain is not allowed. Check your SMTP domain configuration."
+: ""
+
+, "Confirm"
+: "再確認"
+
+, "Do you really want to delete the selected tags?"
+: "確認刪除已選的標籤嗎?"
+
+, "Deleting tag(s)..."
+: "正在刪除標籤..."
+
+, "Add Tag"
+: ""
+
+, "Edit Tag"
+: ""
+
+, "Delete Tag"
 : ""
 
 , "Search:"
 : "尋找:"
 
-, "Disabled"
+, "Displaying tags {0} - {1} of {2}"
 : ""
 
-, "Enabled"
+, "No tags to display"
+: "無此標記顯示"
+
+, "ID"
 : ""
 
-, "Unknown status ({0})"
+, "Color"
 : ""
 
-, "Displaying application {0} - {1} of {2}"
+, "Usage:&#160;"
 : ""
 
-, "No applications to display"
-: "無此應用程式顯示"
+, "Do you really want to delete the selected roles?"
+: "確認刪除已選的角色嗎?"
+
+, "Deleting role(s)..."
+: "正在刪除角色..."
+
+, "Failed"
+: "失敗"
+
+, "Some error occurred while trying to delete the role."
+: ""
+
+, "Add Role"
+: ""
+
+, "Edit Role"
+: ""
+
+, "Delete Role"
+: ""
+
+, "Displaying roles {0} - {1} of {2}"
+: ""
+
+, "No roles to display"
+: "無此角色"
+
+, "Container Name"
+: ""
+
+, "Type"
+: ""
+
+, "Container Order"
+: ""
+
+, "Container, Containers"
+: [
+  ""
+
+]
+, "Model"
+: ""
+
+, "personal"
+: ""
+
+, "shared"
+: ""
 
 , "Order"
 : ""
 
-, "Name"
-: "名字"
-
-, "Status"
-: "狀態"
-
-, "Version"
+, "Container Hierarchy/Name"
 : ""
 
-, "Confirm"
-: "再確認"
+, "Note for Owner"
+: ""
+
+, "Info"
+: ""
+
+, "Please create Resources in Addressbook or CoreData."
+: ""
 
 , "Do you really want to delete the selected groups?"
 : "確認刪除已選的群組嗎?"
@@ -58,9 +241,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Deleting group(s)..."
 : "正在刪除群組..."
 
-, "Failed"
-: "失敗"
-
 , "Some error occurred while trying to delete the group."
 : ""
 
@@ -79,15 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "No groups to display"
 : "無此群組"
 
-, "ID"
+, "Account only"
 : ""
 
-, "E-mail"
-: ""
-
-, "Description"
-: "描述"
-
 , "Creation Time"
 : ""
 
@@ -100,17 +274,71 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Modified By"
 : ""
 
+, "IP Address"
+: "IP 位址"
+
+, "Login Time"
+: "登入時間"
+
+, "Logout Time"
+: "登出時間"
+
+, "Client Type"
+: ""
+
+, "Session ID"
+: ""
+
+, "Login Name"
+: "登入帳號"
+
+, "Result"
+: ""
+
+, "User Agent"
+: ""
+
+, "user blocked"
+: ""
+
+, "password expired"
+: ""
+
+, "user disabled"
+: ""
+
+, "invalid password"
+: "密碼無效"
+
+, "ambiguous username"
+: ""
+
+, "user not found"
+: "無此帳號"
+
+, "failure"
+: "失敗"
+
+, "success"
+: "成功"
+
+, "Customfield, Customfields"
+: [
+  ""
+
+]
+, "This custom field is still in use!"
+: ""
+
+, "Are you sure you want to delete them?"
+: ""
+
 , "Errors"
 : "錯誤"
 
 , "Please configure store for this field type"
 : ""
 
-, "Application, Applications"
-: [
-  ""
-
-]
 , "Record Class"
 : ""
 
@@ -126,9 +354,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Configure store"
 : ""
 
-, "Model"
-: ""
-
 , "Custom field definition"
 : ""
 
@@ -165,12 +390,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Record List"
 : ""
 
-, "Type"
-: ""
-
-, "Label"
-: ""
-
 , "Length"
 : ""
 
@@ -188,180 +407,79 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
   ""
 
 ]
+, "Key"
+: ""
+
 , "Customfield already exists. Please choose another name."
 : ""
 
-, "Customfield, Customfields"
+, "Enable Account"
+: ""
+
+, "Disable Account"
+: ""
+
+, "Reset Password"
+: ""
+
+, "Status"
+: "狀態"
+
+, "Display name"
+: ""
+
+, "Login name"
+: ""
+
+, "Last name"
+: "姓氏"
+
+, "First name"
+: "名字"
+
+, "E-mail usage"
+: ""
+
+, "Filesystem usage"
+: ""
+
+, "OpenID"
+: ""
+
+, "Last login at"
+: "最後登入於"
+
+, "Last login from"
+: "最後登入從"
+
+, "Password Must Change"
+: ""
+
+, "Password changed"
+: "變更密碼"
+
+, "Expires"
+: "過期"
+
+, "Set new password"
+: "設定新密碼"
+
+, "Please enter the new password:"
+: "請輸入新密碼"
+
+, "Users"
+: ""
+
+, "Samba User, Samba Users"
 : [
   ""
 
 ]
-, "This custom field is still in use!"
-: ""
-
-, "Are you sure you want to delete them?"
-: ""
-
-, "Yes"
-: ""
-
-, "No"
-: ""
-
-, "Config, Configs"
+, "Email User, Email Users"
 : [
   ""
 
 ]
-, "Value"
-: ""
-
-, "Default ({0})"
-: ""
-
-, "Computer Name"
-: ""
-
-, "Default Addressbook for new contacts and groups"
-: ""
-
-, "Please wait"
-: "請稍後"
-
-, "Updating Tag"
-: ""
-
-, "Could not save tag ({0})"
-: ""
-
-, "Please fix the errors noted."
-: ""
-
-, "Allowed Contexts"
-: ""
-
-, "Context"
-: "內容"
-
-, "Account Rights"
-: "帳號權限"
-
-, "View"
-: "檢視"
-
-, "Use"
-: ""
-
-, "Tag Name"
-: "標籤名稱"
-
-, "Color"
-: ""
-
-, "Transferring {0}..."
-: ""
-
-, "Tag"
-: ""
-
-, "Add New Tag"
-: "加入新標籤"
-
-, "Edit Tag \"{0}\""
-: "編輯標籤 \"{0}\""
-
-, "Do you really want to delete the selected tags?"
-: "確認刪除已選的標籤嗎?"
-
-, "Deleting tag(s)..."
-: "正在刪除標籤..."
-
-, "Add Tag"
-: ""
-
-, "Edit Tag"
-: ""
-
-, "Delete Tag"
-: ""
-
-, "Displaying tags {0} - {1} of {2}"
-: ""
-
-, "No tags to display"
-: "無此標記顯示"
-
-, "Usage:&#160;"
-: ""
-
-, "Updating Memberships"
-: "更新會員資料"
-
-, "Could not save role."
-: "無法儲存角色"
-
-, "Deleting role..."
-: "正在刪除角色..."
-
-, "Some error occurred while trying to delete the role."
-: ""
-
-, "Rights"
-: "權限"
-
-, "Members"
-: "成員"
-
-, "Role Name"
-: "角色名稱"
-
-, "Role"
-: ""
-
-, "Add New Role"
-: "加入新角色"
-
-, "Edit Role \"{0}\""
-: "編輯角色 \"{0}\""
-
-, "Do you really want to delete the selected roles?"
-: "確認刪除已選的角色嗎?"
-
-, "Deleting role(s)..."
-: "正在刪除角色..."
-
-, "Add Role"
-: ""
-
-, "Edit Role"
-: ""
-
-, "Delete Role"
-: ""
-
-, "Displaying roles {0} - {1} of {2}"
-: ""
-
-, "No roles to display"
-: "無此角色"
-
-, "Access Log, Access Logs"
-: [
-  ""
-
-]
-, "Groups"
-: "群組"
-
-, "Applications"
-: "應用程式"
-
-, "Configs"
-: ""
-
-, "Domain is not allowed. Check your SMTP domain configuration."
-: ""
-
 , "Special characters are not allowed in login name."
 : ""
 
@@ -389,18 +507,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Home Drive"
 : ""
 
-, "Login Time"
-: "登入時間"
-
 , "never logged in"
 : "從未登入過"
 
 , "Home Path"
 : ""
 
-, "Logout Time"
-: "登出時間"
-
 , "never logged off"
 : ""
 
@@ -422,9 +534,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "not set"
 : ""
 
-, "Password Must Change"
-: ""
-
 , "Kick Off Time"
 : ""
 
@@ -458,10 +567,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Last Login"
 : ""
 
-, "Domain not allowed"
-: ""
-
-, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+, "Forward Only"
 : ""
 
 , "E-mail Alias"
@@ -473,6 +579,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "This alias can be used for sending e-mails."
 : ""
 
+, "Domain not allowed"
+: ""
+
+, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
+: ""
+
 , "Forwarding to self"
 : ""
 
@@ -485,9 +597,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add a forwarding address..."
 : ""
 
-, "Forward Only"
-: ""
-
 , "Password confirmation"
 : ""
 
@@ -500,19 +609,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Account"
 : ""
 
-, "First name"
-: "名字"
-
-, "Last name"
-: "姓氏"
-
-, "Login name"
-: ""
-
 , "Password"
 : "密碼"
 
-, "OpenID"
+, "Multi Factor Authentication Config"
 : ""
 
 , "enabled"
@@ -533,30 +633,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
 : ""
 
-, "Expires"
-: "過期"
-
-, "Visibility"
-: ""
-
-, "Display in addressbook"
-: ""
-
-, "Hide from addressbook"
-: ""
-
-, "Saved in Addressbook"
-: ""
-
-, "Last login at"
-: "最後登入於"
-
 , "don't know"
 : ""
 
-, "Last login from"
-: "最後登入從"
-
 , "Password set"
 : "設定密碼"
 
@@ -578,103 +657,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "SMTP"
 : ""
 
-, "User, Users"
-: [
-  ""
-
-]
-, "Users"
-: ""
-
-, "Samba User, Samba Users"
-: [
-  ""
-
-]
-, "Email User, Email Users"
-: [
-  ""
-
-]
-, "Enable Account"
-: ""
-
-, "Disable Account"
-: ""
-
-, "Reset Password"
-: ""
-
-, "Reset Pin"
-: ""
-
-, "Display name"
-: ""
-
-, "E-mail usage"
-: ""
-
-, "Filesystem usage"
-: ""
-
-, "Password changed"
-: "變更密碼"
-
-, "Set new password"
-: "設定新密碼"
-
-, "Please enter the new password:"
-: "請輸入新密碼"
-
-, "Set new pin"
-: ""
-
-, "Please enter the new pin:"
-: ""
-
-, "Group Name"
-: "群組名稱"
-
-, "Only system accounts can be added to Addressbook group"
-: ""
-
-, "Group Members"
-: "群組成員"
-
-, "personal"
-: ""
-
-, "shared"
-: ""
-
-, "Container Hierarchy/Name"
-: ""
-
-, "Note for Owner"
-: ""
-
-, "Info"
-: ""
-
-, "Please create Resources in Addressbook or CoreData."
-: ""
-
-, "Container, Containers"
-: [
-  ""
-
-]
-, "Container Name"
-: ""
-
-, "Container Order"
-: ""
-
 , "Computer, Computers"
 : [
   ""
 
 ]
+, "Please wait"
+: "請稍後"
+
+, "Updating Memberships"
+: "更新會員資料"
+
+, "Could not save role."
+: "無法儲存角色"
+
+, "Please fix the errors noted."
+: ""
+
+, "Deleting role..."
+: "正在刪除角色..."
+
+, "Rights"
+: "權限"
+
+, "Members"
+: "成員"
+
+, "Role Name"
+: "角色名稱"
+
+, "Transferring {0}..."
+: ""
+
+, "Role"
+: ""
+
+, "Add New Role"
+: "加入新角色"
+
+, "Edit Role \"{0}\""
+: "編輯角色 \"{0}\""
+
+, "Configs"
+: ""
+
 , "Size"
 : ""
 
@@ -687,78 +713,69 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Quota Usage"
 : ""
 
-, "Roles"
-: "角色"
-
-, "Containers"
+, "Updating Tag"
 : ""
 
-, "Shared Tags"
-: "分享標記"
-
-, "Customfields"
+, "Could not save tag ({0})"
 : ""
 
-, "Computers"
+, "Allowed Contexts"
 : ""
 
-, "Server Information"
+, "Context"
+: "內容"
+
+, "Account Rights"
+: "帳號權限"
+
+, "View"
+: "檢視"
+
+, "Use"
 : ""
 
-, "ActiveSync Devices"
+, "Tag Name"
+: "標籤名稱"
+
+, "Tag"
 : ""
 
-, "E-mail Accounts"
+, "Add New Tag"
+: "加入新標籤"
+
+, "Edit Tag \"{0}\""
+: "編輯標籤 \"{0}\""
+
+, "Enable Application"
 : ""
 
-, "Admin"
-: "管理者"
-
-, "Refresh"
+, "Disable Application"
 : ""
 
-, "Feature is disabled by configuration."
+, "Settings"
 : ""
 
-, "IP Address"
-: "IP 位址"
-
-, "Client Type"
+, "{0} Settings"
 : ""
 
-, "Session ID"
+, "Enabled"
 : ""
 
-, "Login Name"
-: "登入帳號"
-
-, "Result"
+, "Unknown status ({0})"
 : ""
 
-, "user blocked"
+, "Displaying application {0} - {1} of {2}"
 : ""
 
-, "password expired"
+, "No applications to display"
+: "無此應用程式顯示"
+
+, "Version"
 : ""
 
-, "user disabled"
+, "Default password must change for new user settings"
 : ""
 
-, "invalid password"
-: "密碼無效"
-
-, "ambiguous username"
-: ""
-
-, "user not found"
-: "無此帳號"
-
-, "failure"
-: "失敗"
-
-, "success"
-: "成功"
-
 , "Default IMAP user settings"
 : ""
 
@@ -780,6 +797,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Your container has been changed by %1$s %2$sNote: %3$s"
 : ""
 
+, "Password is needed for system account creation"
+: ""
+
+, "Notifications"
+: ""
+
 , "Manage access log"
 : ""
 
@@ -834,6 +857,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Add and edit customfields."
 : ""
 
+, "Manage import and export definitions"
+: ""
+
+, "Add and edit import and export definitions"
+: ""
+
 , "View access log"
 : ""
 
@@ -900,6 +929,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "View quota usage."
 : ""
 
+, "view ImportExportDefinitions"
+: ""
 
 
 
@@ -923,24 +954,28 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 
 
 
-
+, "ImportExportDefinition"
+: ""
 
 , "Application"
 : ""
 
-, "Group"
-: ""
-
-, "Customfield"
-: ""
-
-, "Config"
+, "User"
 : ""
 
 , "Access Log"
 : ""
 
-, "User"
+, "Config"
+: ""
+
+, "Container"
+: ""
+
+, "Customfield"
+: ""
+
+, "Group"
 : ""
 
 , "Samba User"
@@ -949,9 +984,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 , "Email User"
 : ""
 
-, "Container"
-: ""
-
 , "Computer"
 : ""
 
