@@ -5,167 +5,251 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "calendari personal de %s"
+, "{0}, the {1}. of {2}"
+: "{0}, el {1}. de {2}"
 
-, "Resources"
-: "Recursos"
+, "Recurrances"
+: "Recurrències"
 
-, "All my events"
-: "Tots els meus esdeveniments"
+, "No recurring rule defined"
+: "No s'ha definit cap regla de recurrència"
 
-, "Start Time"
-: "Hora d'inici"
-
-, "Position on the left time axis, day and week view should start with"
+, "Details"
 : ""
 
-, "End Time"
-: "Hora d'acabament"
+, "None"
+: "Cap"
 
-, "Position on the left time axis, day and week view should end with"
+, "Daily"
+: "Diàriament"
+
+, "Weekly"
+: "Setmanalment"
+
+, "Monthly"
+: "Mensualment"
+
+, "Yearly"
+: "Anualment"
+
+, "Exceptions of reccuring events can't have recurrences themselves."
 : ""
 
-, "Default Start Time"
+, "at"
+: "a"
+
+, "never"
 : ""
 
-, "Scroll position on the left time axis, day and week view should start with"
+, "after {0} occurrences"
 : ""
 
-, "Visible Time"
+, "Except"
 : ""
 
-, "Time to be displayed at once"
+, "during events in the calendars"
 : ""
 
-, "Default Calendar"
-: "Calendari per defecte"
+, "End"
+: "Finalització"
 
-, "The default calendar for invitations and new events"
-: "El calendari per defecte per a invitacions i per a nous esdeveniments"
+, "Until has to be after event start"
+: "Fins ha de ser posterior a l'inici de l'esdeveniment"
 
-, "Default Favorite"
-: "Preferit per defecte"
-
-, "The default favorite which is loaded on calendar startup"
-: "El preferit per defecte que es carrega a l'inici del calendari"
-
-, "Get Notification Emails"
-: "Rep correus electrònics de notificació"
-
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "El nivell de les accions de les quals voleu que se us notifiqui. Observeu que els organitzadors rebran notificacions de tota actualització incloent les respostes dels assistents a menys que establiu aquesta opció a \"Mai\""
-
-, "Send Notifications Emails of own Actions"
-: "Envia correus electrònics de notificació de les pròpies accions"
-
-, "Get notifications emails for actions you did yourself"
-: "Rep correus electrònics de notificació de les accions que hagueu fet"
-
-, "Send Alarm Notifications Emails"
+, "The event is longer than the recurring interval"
 : ""
 
-, "Get event alarms via email"
-: ""
+, "Every {0}. Day"
+: "Cada dia {0}"
 
-, "Enable Standard Alarm"
-: ""
+, "Every {0}. Week at"
+: "Cada setmana {0}"
 
-, "New events get a standard alarm as defined below"
-: ""
+, "Every {0}. Month"
+: "Cada mes {0}"
 
-, "Standard Alarm Time"
-: ""
+, "at the"
+: "a les / als"
 
-, "Minutes before the event starts"
-: ""
+, "first"
+: "primer"
 
-, "Default Attendee Strategy"
-: ""
+, "second"
+: "segon"
 
-, "Default Attendee Strategy for new events"
-: ""
+, "third"
+: "tercer"
 
-, "Time Increment"
-: ""
+, "fourth"
+: "quart"
 
-, "Increment of event time steps"
-: ""
+, "last"
+: "darrer"
 
-, "Default set Events to privat"
-: ""
+, "Every {0}. Year"
+: "Cada any {0}"
 
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: ""
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: ""
-
-, "On invitation and cancellation only"
-: ""
-
-, "On time changes"
-: ""
-
-, "On all updates but attendee responses"
-: ""
-
-, "On attendee responses too"
-: ""
-
-, "Events"
-: "Esdeveniments"
+, "of"
+: "de"
 
 , "Summary"
 : "Resum"
 
-, "Status"
-: "Estat"
+, "Organizer"
+: "Organitzador"
 
-, "No Information"
-: "Sense informació"
-
-, "recurring event"
-: ""
-
-, "recurring event exception"
-: ""
-
-, "Blocking"
-: "Blocant"
-
-, "Tentative"
-: "Temptativa"
+, "Description"
+: "Descripció"
 
 , "Location"
 : "Ubicació"
 
-, "Organizer"
-: "Organitzador"
+, "Start Time"
+: "Hora d'inici"
+
+, "End Time"
+: "Hora d'acabament"
 
 , "Attendee"
 : "Assistents"
 
+, "whole day"
+: "tot el dia"
+
+, "Week {0} :"
+: ""
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Nou esdeveniment"
+
+, "Calendar, Calendars"
+: [
+  "Calendari"
+ ,"Calendaris"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : ""
 
@@ -175,115 +259,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : ""
 
-, "Attachments"
-: ""
-
-, "Private"
-: "Privat"
-
-, "Tags"
-: ""
-
-, "whole day"
-: "tot el dia"
-
-, "Description"
-: "Descripció"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: ""
-
-, "This event is originally stored in {0}"
-: ""
-
-, "This event is additionally displayed in your personal calendar {0}"
-: ""
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: ""
-
-, "Role"
-: "Rol"
-
-, "Select Role"
-: ""
-
-, "Select Status"
-: ""
-
-, "Adding {0} Attendee to event"
-: ""
-
-, "Checking Calendar Data..."
-: ""
-
-, "Reply to Recurring Event"
-: ""
-
-, "You are responding to an recurring event. What would you like to do?"
-: ""
-
-, "Respond to whole series"
-: ""
-
-, "Do not respond"
-: ""
-
-, "The event of this message does not exist"
-: ""
-
-, "The sender is not authorised to update the event"
-: ""
-
-, "This message is already processed"
-: ""
-
-, "You are not an attendee of this event"
-: ""
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: ""
-
-, "This is an event invitation for someone else."
-: ""
-
-, "You have already replied to this event invitation."
-: ""
-
-, "You received an event invitation. Set your response to:"
-: ""
-
-, "An invited attendee responded to the invitation."
-: ""
-
-, "Unsupported method"
+, "Unavailable"
 : ""
 
 , "Loading events, please wait..."
@@ -325,6 +301,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +316,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : ""
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : ""
 
@@ -418,9 +400,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : ""
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Gestiona els recursos"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Selecciona assistents"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Privat"
+
+, "Tags"
+: ""
+
+, "Blocking"
+: "Blocant"
+
+, "Tentative"
+: "Temptativa"
+
 , "Import Definition Success!"
 : ""
 
@@ -457,9 +466,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -511,7 +517,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -535,156 +541,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: ""
-
-, "Details"
-: ""
-
-, "Saved in"
-: ""
-
-, "non-blocking"
-: "no blocant"
-
-, "Enter description"
-: "Introduïu una descripció"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "La data de finalització no és vàlida"
-
-, "End date must be after start date"
-: "La data de finalització ha de ser posterior a la d'inici"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "La data d'inici no és vàlida"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: ""
-
-, "Originally"
-: "Originàriament"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "set."
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Diàriament"
-
-, "Weekly"
-: "Setmanalment"
-
-, "Monthly"
-: "Mensualment"
-
-, "Yearly"
-: "Anualment"
-
-, "Name"
-: "Nom"
-
-, "Email"
-: "Correu electrònic"
-
-, "Type"
-: "Tipus"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Nou esdeveniment"
-
-, "{0} more..."
-: "{0} més..."
-
 , "private classification"
 : ""
 
+, "recurring event"
+: ""
+
+, "recurring event exception"
+: ""
+
 , "has alarm"
 : ""
 
@@ -694,62 +559,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, el {1}. de {2}"
+, "Mini Calendar"
+: "Minicalendari"
 
-, "Click here to invite another attender..."
-: "Feu clic aquí per a convidar un altre organitzador"
+, "WK"
+: "set."
 
-, "User"
-: "Usuari"
-
-, "Group"
-: "Grup"
-
-, "Resource, Resources"
-: [
-  "Recurs"
- ,"Recursos"
-
-]
-, "Member of group"
-: ""
-
-, "This is the calendar where the attender has saved this event in"
-: "Aquest és el calendari en què l'organitzador ha desat l'esdeveniment"
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Elimina organitzador"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(com a membre de grup)"
-
-, "External Attendee"
-: ""
+, "{0} more..."
+: "{0} més..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -769,6 +586,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -811,7 +631,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -841,102 +661,66 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: ""
+
+, "Role"
+: "Rol"
+
+, "Select Role"
+: ""
+
+, "Status"
+: "Estat"
+
+, "Select Status"
+: ""
+
+, "Adding {0} Attendee to event"
+: ""
+
 , "no events found"
 : ""
 
 , "Searching..."
 : ""
 
+, "Search Event"
+: ""
+
 , "Event, Events"
 : [
   "Esdeveniment"
  ,"Esdeveniments"
 
 ]
-, "Search Event"
+, "Additional Tags ..."
 : ""
 
-, "Switch to public poll"
+, "non-blocking"
+: "no blocant"
+
+, "Displayed in"
 : ""
 
-, "Welcome {name}"
+, "No Information"
+: "Sense informació"
+
+, "Event Location"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "From"
 : ""
 
-, "This poll is closed already"
+, "until"
 : ""
 
-, "I am not {name}"
-: ""
+, "Events"
+: "Esdeveniments"
 
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Minicalendari"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Calendari"
- ,"Calendaris"
-
-]
 , "Calendars"
 : "Calendaris"
 
@@ -970,6 +754,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -991,38 +787,239 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,""
 
 ]
+, "Resource, Resources"
+: [
+  "Recurs"
+ ,"Recursos"
+
+]
+, "Resources"
+: "Recursos"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Nom"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "Correu electrònic"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Tipus"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Feu clic aquí per a convidar un altre organitzador"
+
+, "User"
+: "Usuari"
+
+, "Group"
+: "Grup"
+
+, "Member of group"
+: ""
+
+, "This is the calendar where the attender has saved this event in"
+: "Aquest és el calendari en què l'organitzador ha desat l'esdeveniment"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Elimina organitzador"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(com a membre de grup)"
+
+, "External Attendee"
+: ""
+
+, "Originally"
+: "Originàriament"
+
+, "Checking Calendar Data..."
+: ""
+
+, "Reply to Recurring Event"
+: ""
+
+, "You are responding to an recurring event. What would you like to do?"
+: ""
+
+, "Respond to whole series"
+: ""
+
+, "Do not respond"
+: ""
+
+, "The event of this message does not exist"
+: ""
+
+, "The sender is not authorised to update the event"
+: ""
+
+, "This message is already processed"
+: ""
+
+, "You are not an attendee of this event"
+: ""
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: ""
+
+, "This is an event invitation for someone else."
+: ""
+
+, "You have already replied to this event invitation."
+: ""
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: ""
+
+, "An invited attendee responded to the invitation."
+: ""
+
+, "Unsupported method"
+: ""
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Introduïu una descripció"
 
 , "Grants"
 : ""
 
-, "Displayed in"
+, "This event is originally stored in a calendar you don't have access to."
 : ""
 
-, "Event not found"
+, "This event is originally stored in {0}"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "This event is additionally displayed in your personal calendar {0}"
 : ""
 
-, "GENDER_Attendee"
+, "Colors"
 : ""
 
-, "Select Attendee"
-: "Selecciona assistents"
+, "Side bar color"
+: ""
+
+, "Color by Calendar"
+: ""
+
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: ""
+
+, "Saved in"
+: ""
+
+, "Enter description"
+: "Introduïu una descripció"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "La data de finalització no és vàlida"
+
+, "End date must be after start date"
+: "La data de finalització ha de ser posterior a la d'inici"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "La data d'inici no és vàlida"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : ""
@@ -1036,127 +1033,142 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : ""
 
-, "Recurrances"
-: "Recurrències"
-
-, "No recurring rule defined"
-: "No s'ha definit cap regla de recurrència"
-
-, "None"
-: "Cap"
-
-, "Exceptions of reccuring events can't have recurrences themselves."
+, "Set This Date as Definite Event?"
 : ""
 
-, "at"
-: "a"
-
-, "never"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "after {0} occurrences"
+, "Attendee/Resources"
 : ""
 
-, "Except"
+, "Additional Attendees ..."
 : ""
 
-, "during events in the calendars"
+, "Default Status"
 : ""
 
-, "End"
-: "Finalització"
-
-, "Until has to be after event start"
-: "Fins ha de ser posterior a l'inici de l'esdeveniment"
-
-, "The event is longer than the recurring interval"
+, "No Access"
 : ""
 
-, "Every {0}. Day"
-: "Cada dia {0}"
+, "All my events"
+: "Tots els meus esdeveniments"
 
-, "Every {0}. Week at"
-: "Cada setmana {0}"
-
-, "Every {0}. Month"
-: "Cada mes {0}"
-
-, "at the"
-: "a les / als"
-
-, "first"
-: "primer"
-
-, "second"
-: "segon"
-
-, "third"
-: "tercer"
-
-, "fourth"
-: "quart"
-
-, "last"
-: "darrer"
-
-, "Every {0}. Year"
-: "Cada any {0}"
-
-, "of"
-: "de"
-
-, "First name, ĺast name"
+, "Position on the left time axis, day and week view should start with"
 : ""
 
-, "E-Mail address"
+, "Position on the left time axis, day and week view should end with"
 : ""
 
-, "Please wait..."
+, "Default Start Time"
 : ""
 
-, "General terms and conditions"
+, "Scroll position on the left time axis, day and week view should start with"
 : ""
 
-, "Relation, Relations"
-: [
-  ""
- ,""
-
-]
-, "All events I attend"
-: "Tots els esdeveniments als quals assisteixo"
-
-, "Required"
-: "Obligatori"
-
-, "Optional"
-: "Opcional"
-
-, "No response"
-: "Sense resposta"
-
-, "Accepted"
-: "Acceptat"
-
-, "Declined"
-: "Rebutjat"
-
-, "Awaiting response"
+, "Visible Time"
 : ""
 
-, "Events I have not yet responded to"
+, "Time to be displayed at once"
 : ""
 
-, "Declined events"
+, "Default Calendar"
+: "Calendari per defecte"
+
+, "The default calendar for invitations and new events"
+: "El calendari per defecte per a invitacions i per a nous esdeveniments"
+
+, "Default Favorite"
+: "Preferit per defecte"
+
+, "The default favorite which is loaded on calendar startup"
+: "El preferit per defecte que es carrega a l'inici del calendari"
+
+, "Get Notification Emails"
+: "Rep correus electrònics de notificació"
+
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "El nivell de les accions de les quals voleu que se us notifiqui. Observeu que els organitzadors rebran notificacions de tota actualització incloent les respostes dels assistents a menys que establiu aquesta opció a \"Mai\""
+
+, "Send Notifications Emails of own Actions"
+: "Envia correus electrònics de notificació de les pròpies accions"
+
+, "Get notifications emails for actions you did yourself"
+: "Rep correus electrònics de notificació de les accions que hagueu fet"
+
+, "Send Notifications Emails of tentative events"
 : ""
 
-, "Events I have declined"
+, "Get notifications emails of tentative events"
 : ""
 
-, "I'm organizer"
+, "Send Alarm Notifications Emails"
 : ""
 
-, "Events I'm the organizer of"
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: ""
+
+, "New events get a standard alarm as defined below"
+: ""
+
+, "Standard Alarm Time"
+: ""
+
+, "Minutes before the event starts"
+: ""
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: ""
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: ""
+
+, "On invitation and cancellation only"
+: ""
+
+, "On time changes"
+: ""
+
+, "On all updates but attendee responses"
+: ""
+
+, "On attendee responses too"
 : ""
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
@@ -1222,12 +1234,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Sense resposta"
+
+, "Accepted"
+: "Acceptat"
+
+, "Declined"
+: "Rebutjat"
+
 , "Attendee Roles Available"
 : ""
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Obligatori"
+
+, "Optional"
+: "Opcional"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1237,6 +1267,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1279,6 +1339,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1330,6 +1393,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1369,95 +1435,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Alarma per a l'esdeveniment  \"%1$s\" a %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Invitació a esdeveniment \"%1$s\" a %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "S'ha cancel·lat l'esdeveniment \"%1$s\" a %2$s"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+, "Group Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been updated"
-: "S'ha actualitzat l'esdeveniment \"%1$s\" a %2$s"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s ha acceptat l'esdeveniment \"%2$s\" a %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s ha rebutjat l'esdeveniment \"%2$s\" a %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "%1$s ha respost que potser assistirà a l'esdeveniment \"%2$s\" a %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Sense resposta de %1$s per a l'esdeveniment \"%2$s\" a %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Canvis d'assistents per a l'esdeveniment \"%1$s\" a %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Resource Additional Filters"
 : ""
 
-, "Resource Management"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "Polls for recurring events are not supported"
+, "%s's personal calendar"
+: "calendari personal de %s"
+
+, "Failed"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "The right Resource Admin must be set once."
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "Different Calendar"
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Exdate container move are not allowed"
 : ""
 
-, "Start"
-: "Inici"
+, "Invalid URL given"
+: ""
 
-, "Priority"
-: "Prioritat"
+, "The URL you used is invalid. Please use a valid one!"
+: ""
 
-, "Url"
-: "Url"
+, "Calendars to export"
+: ""
 
-, "Recurrance rule"
-: "Regla de recurrència"
+, "Export target"
+: ""
 
-, "Is all day event"
-: "És un esdeveniment de tot el dia"
+, "VCalendar/ICS"
+: ""
 
-, "Organizer timezone"
-: "Zona horària de l'organitzador"
+, "Export visible events to ics file"
+: ""
 
-, "No"
-: "No"
+, "Excel overview"
+: ""
 
-, "Yes"
-: "Sí"
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "desconegut"
@@ -1516,34 +1591,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: "Inici"
+
+, "Priority"
+: "Prioritat"
+
+, "Url"
+: "Url"
+
+, "Recurrance rule"
+: "Regla de recurrència"
+
+, "Is all day event"
+: "És un esdeveniment de tot el dia"
+
+, "Organizer timezone"
+: "Zona horària de l'organitzador"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Alarma per a l'esdeveniment  \"%1$s\" a %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Invitació a esdeveniment \"%1$s\" a %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "S'ha cancel·lat l'esdeveniment \"%1$s\" a %2$s"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Event \"%1$s\" at %2$s has been updated"
+: "S'ha actualitzat l'esdeveniment \"%1$s\" a %2$s"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s ha acceptat l'esdeveniment \"%2$s\" a %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s ha rebutjat l'esdeveniment \"%2$s\" a %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "%1$s ha respost que potser assistirà a l'esdeveniment \"%2$s\" a %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Sense resposta de %1$s per a l'esdeveniment \"%2$s\" a %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Canvis d'assistents per a l'esdeveniment \"%1$s\" a %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Word event sheet"
+, "Unknown action"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "Resource Management"
 : ""
 
-, "Excel all data"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Import iCal-files"
+, "Polls for recurring events are not supported"
+: ""
+
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1582,31 +1726,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Detalls de l'esdeveniment"
 
-, "The poll \"%1$s\" has been closed."
+, "All events I attend"
+: "Tots els esdeveniments als quals assisteixo"
+
+, "Awaiting response"
 : ""
 
-, "The definite event is scheduled for \"%1$s\""
+, "Events I have not yet responded to"
 : ""
 
-, "You can review the poll results here:"
+, "Declined events"
 : ""
 
-, "Thank you for attendening the poll \"%1$s\""
+, "Events I have declined"
 : ""
 
-, "To review or edit your status please use your personal link:"
+, "I'm organizer"
 : ""
 
-, "Different Calendar"
-: ""
-
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
+, "Events I'm the organizer of"
 : ""
 
 , "manage shared calendars"
@@ -1627,71 +1765,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Tots els permisos per a administrar recursos"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "És una ubicació"
-
-, "Do you really want to delete this event?"
-: "Esteu segur que voleu eliminar aquest esdeveniment?"
+, "Relation, Relations"
+: [
+  ""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Recurs"
+, "Calendar"
+: "Calendari"
+
+, "Do you really want to delete this event?"
+: "Esteu segur que voleu eliminar aquest esdeveniment?"
 
 , "Resource Grant"
 : ""
@@ -1699,12 +1816,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Esdeveniment"
 
-, "Calendar"
-: "Calendari"
-
 , "Attender"
 : ""
 
+, "Resource"
+: "Recurs"
+
 , "Relation"
 : ""
 
