@@ -5,167 +5,255 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "Osobní kalendář uživatele %s"
+, "{0}, the {1}. of {2}"
+: "{0}, {1}. {2}"
 
-, "Resources"
-: "Zdroje"
+, "Recurrances"
+: "Opakování"
 
-, "All my events"
-: "Všechny mé události"
+, "No recurring rule defined"
+: "Žádné pravidlo opakování není definováno"
 
-, "Start Time"
-: "Počáteční čas"
-
-, "Position on the left time axis, day and week view should start with"
+, "Details"
 : ""
 
-, "End Time"
-: "Čas ukončení"
+, "None"
+: "Žádný"
 
-, "Position on the left time axis, day and week view should end with"
+, "Daily"
+: "Denně"
+
+, "Weekly"
+: "Týdně"
+
+, "Monthly"
+: "Měsíčně"
+
+, "Yearly"
+: "Ročně"
+
+, "Exceptions of reccuring events can't have recurrences themselves."
 : ""
 
-, "Default Start Time"
+, "at"
+: "v"
+
+, "never"
 : ""
 
-, "Scroll position on the left time axis, day and week view should start with"
+, "after {0} occurrences"
 : ""
 
-, "Visible Time"
+, "Except"
 : ""
 
-, "Time to be displayed at once"
+, "during events in the calendars"
 : ""
 
-, "Default Calendar"
-: "Výchozí kalendář"
+, "End"
+: "Konec"
 
-, "The default calendar for invitations and new events"
-: "Výchozí kalendář pro pozvání a nové události"
+, "Until has to be after event start"
+: "Datum ukončení musí být po počátečním datu"
 
-, "Default Favorite"
-: "Výchozí oblíbené položky kalendáře"
-
-, "The default favorite which is loaded on calendar startup"
-: "Výchozí oblíbené položky, které jsou načteny při spuštění kalendáře"
-
-, "Get Notification Emails"
-: "Dostávat e-maily s upozorněním"
-
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "Úroveň (re)akcí o nichž chcete být informován(a). Pamatujte prosím, že organizátoři dostávají upozornění na všechny změny, včetně odpovědí účastníků, pokud tato volba není nastavena na \"Nikdy\""
-
-, "Send Notifications Emails of own Actions"
-: "Zasílat e-maily s upozorněním na vlastní akce"
-
-, "Get notifications emails for actions you did yourself"
-: "Dostávat e-maily s upozorněním na akce, které pořádám"
-
-, "Send Alarm Notifications Emails"
+, "The event is longer than the recurring interval"
 : ""
 
-, "Get event alarms via email"
-: ""
+, "Every {0}. Day"
+: "Každý {0}. den"
 
-, "Enable Standard Alarm"
-: ""
+, "Every {0}. Week at"
+: "Každý {0}. týden v"
 
-, "New events get a standard alarm as defined below"
-: ""
+, "Every {0}. Month"
+: "Každý {0}. měsíc"
 
-, "Standard Alarm Time"
-: ""
+, "at the"
+: "(kdy)"
 
-, "Minutes before the event starts"
-: ""
+, "first"
+: "první"
 
-, "Default Attendee Strategy"
-: ""
+, "second"
+: "druhý"
 
-, "Default Attendee Strategy for new events"
-: ""
+, "third"
+: "třetí"
 
-, "Time Increment"
-: ""
+, "fourth"
+: "čtvrtý"
 
-, "Increment of event time steps"
-: ""
+, "last"
+: "poslední"
 
-, "Default set Events to privat"
-: ""
+, "Every {0}. Year"
+: "Každý {0}. rok"
 
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: ""
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: ""
-
-, "On invitation and cancellation only"
-: ""
-
-, "On time changes"
-: ""
-
-, "On all updates but attendee responses"
-: ""
-
-, "On attendee responses too"
-: ""
-
-, "Events"
-: "Události"
+, "of"
+: "z"
 
 , "Summary"
 : "Shrnutí"
 
-, "Status"
-: "Stav"
+, "Organizer"
+: "Organizátor"
 
-, "No Information"
-: "Žádné informace"
-
-, "recurring event"
-: ""
-
-, "recurring event exception"
-: ""
-
-, "Blocking"
-: "Blokující"
-
-, "Tentative"
-: "Předběžná"
+, "Description"
+: "Popis"
 
 , "Location"
 : "Umístění"
 
-, "Organizer"
-: "Organizátor"
+, "Start Time"
+: "Počáteční čas"
+
+, "End Time"
+: "Čas ukončení"
 
 , "Attendee"
 : "Účastníci"
 
+, "whole day"
+: "celý den"
+
+, "Week {0} :"
+: ""
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Nová událost"
+
+, "Calendar, Calendars"
+: [
+  "Kalendář"
+ ,"Kalendáře"
+ ,"Kalendářů"
+ ,"Kalendářů"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : ""
 
@@ -175,115 +263,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : ""
 
-, "Attachments"
-: ""
-
-, "Private"
-: "Soukromé"
-
-, "Tags"
-: ""
-
-, "whole day"
-: "celý den"
-
-, "Description"
-: "Popis"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: ""
-
-, "This event is originally stored in {0}"
-: ""
-
-, "This event is additionally displayed in your personal calendar {0}"
-: ""
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: ""
-
-, "Role"
-: "Role"
-
-, "Select Role"
-: ""
-
-, "Select Status"
-: ""
-
-, "Adding {0} Attendee to event"
-: ""
-
-, "Checking Calendar Data..."
-: ""
-
-, "Reply to Recurring Event"
-: ""
-
-, "You are responding to an recurring event. What would you like to do?"
-: ""
-
-, "Respond to whole series"
-: ""
-
-, "Do not respond"
-: ""
-
-, "The event of this message does not exist"
-: ""
-
-, "The sender is not authorised to update the event"
-: ""
-
-, "This message is already processed"
-: ""
-
-, "You are not an attendee of this event"
-: ""
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: ""
-
-, "This is an event invitation for someone else."
-: ""
-
-, "You have already replied to this event invitation."
-: ""
-
-, "You received an event invitation. Set your response to:"
-: ""
-
-, "An invited attendee responded to the invitation."
-: ""
-
-, "Unsupported method"
+, "Unavailable"
 : ""
 
 , "Loading events, please wait..."
@@ -325,6 +305,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +320,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : ""
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : ""
 
@@ -420,9 +406,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : ""
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Spravovat zdroje"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Vybrat účastníky"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Soukromé"
+
+, "Tags"
+: ""
+
+, "Blocking"
+: "Blokující"
+
+, "Tentative"
+: "Předběžná"
+
 , "Import Definition Success!"
 : ""
 
@@ -459,9 +472,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -513,7 +523,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -537,157 +547,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: ""
-
-, "Details"
-: ""
-
-, "Saved in"
-: ""
-
-, "non-blocking"
-: "neblokující"
-
-, "Enter description"
-: "Zadejte popis"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "Datum ukončení je neplatné"
-
-, "End date must be after start date"
-: "Datum ukončení musí být po počátečním datu"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "Počáteční datum je neplatné"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: ""
-
-, "Originally"
-: "Původně"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "Týd"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Denně"
-
-, "Weekly"
-: "Týdně"
-
-, "Monthly"
-: "Měsíčně"
-
-, "Yearly"
-: "Ročně"
-
-, "Name"
-: "Název"
-
-, "Email"
-: "Email"
-
-, "Type"
-: "Typ"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Nová událost"
-
-, "{0} more..."
-: "{0} více..."
-
 , "private classification"
 : ""
 
+, "recurring event"
+: ""
+
+, "recurring event exception"
+: ""
+
 , "has alarm"
 : ""
 
@@ -697,70 +565,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, {1}. {2}"
+, "Mini Calendar"
+: "Malý kalendář"
 
-, "Click here to invite another attender..."
-: "Klikněte sem pro pozvání dalšího účastníka"
+, "WK"
+: "Týd"
 
-, "User"
-: "Uživatel"
-
-, "Group"
-: "Skupina"
-
-, "Resource, Resources"
-: [
-  "Zdroj"
- ,"Zdroje"
- ,"Zdrojů"
- ,"Zdrojů"
-
-]
-, "Member of group"
-: ""
-
-, "This is the calendar where the attender has saved this event in"
-: "Toto je kalendář, do kterého účastník tuto událost uložil"
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Odebrat účastníka"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(jako člen skupiny)"
-
-, "External Attendee"
-: ""
+, "{0} more..."
+: "{0} více..."
 
 , "Resource Grant, Resource Grants"
 : [
   ""
  ,""
  ,""
+ ,""
 
 ]
 , "Invite Resource"
@@ -775,6 +594,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -817,7 +639,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -847,12 +669,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: ""
+
+, "Role"
+: "Role"
+
+, "Select Role"
+: ""
+
+, "Status"
+: "Stav"
+
+, "Select Status"
+: ""
+
+, "Adding {0} Attendee to event"
+: ""
+
 , "no events found"
 : ""
 
 , "Searching..."
 : ""
 
+, "Search Event"
+: ""
+
 , "Event, Events"
 : [
   "Událost"
@@ -861,92 +707,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Událostí"
 
 ]
-, "Search Event"
+, "Additional Tags ..."
 : ""
 
-, "Switch to public poll"
+, "non-blocking"
+: "neblokující"
+
+, "Displayed in"
 : ""
 
-, "Welcome {name}"
+, "No Information"
+: "Žádné informace"
+
+, "Event Location"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "From"
 : ""
 
-, "This poll is closed already"
+, "until"
 : ""
 
-, "I am not {name}"
-: ""
+, "Events"
+: "Události"
 
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Malý kalendář"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Kalendář"
- ,"Kalendáře"
- ,"Kalendářů"
- ,"Kalendářů"
-
-]
 , "Calendars"
 : "Kalendáře"
 
@@ -980,6 +764,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -1003,38 +799,241 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Účastníků"
 
 ]
+, "Resource, Resources"
+: [
+  "Zdroj"
+ ,"Zdroje"
+ ,"Zdrojů"
+ ,"Zdrojů"
+
+]
+, "Resources"
+: "Zdroje"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Název"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "Email"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Typ"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Klikněte sem pro pozvání dalšího účastníka"
+
+, "User"
+: "Uživatel"
+
+, "Group"
+: "Skupina"
+
+, "Member of group"
+: ""
+
+, "This is the calendar where the attender has saved this event in"
+: "Toto je kalendář, do kterého účastník tuto událost uložil"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Odebrat účastníka"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(jako člen skupiny)"
+
+, "External Attendee"
+: ""
+
+, "Originally"
+: "Původně"
+
+, "Checking Calendar Data..."
+: ""
+
+, "Reply to Recurring Event"
+: ""
+
+, "You are responding to an recurring event. What would you like to do?"
+: ""
+
+, "Respond to whole series"
+: ""
+
+, "Do not respond"
+: ""
+
+, "The event of this message does not exist"
+: ""
+
+, "The sender is not authorised to update the event"
+: ""
+
+, "This message is already processed"
+: ""
+
+, "You are not an attendee of this event"
+: ""
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: ""
+
+, "This is an event invitation for someone else."
+: ""
+
+, "You have already replied to this event invitation."
+: ""
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: ""
+
+, "An invited attendee responded to the invitation."
+: ""
+
+, "Unsupported method"
+: ""
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Zadejte popis..."
 
 , "Grants"
 : ""
 
-, "Displayed in"
+, "This event is originally stored in a calendar you don't have access to."
 : ""
 
-, "Event not found"
+, "This event is originally stored in {0}"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "This event is additionally displayed in your personal calendar {0}"
 : ""
 
-, "GENDER_Attendee"
+, "Colors"
 : ""
 
-, "Select Attendee"
-: "Vybrat účastníky"
+, "Side bar color"
+: ""
+
+, "Color by Calendar"
+: ""
+
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: ""
+
+, "Saved in"
+: ""
+
+, "Enter description"
+: "Zadejte popis"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "Datum ukončení je neplatné"
+
+, "End date must be after start date"
+: "Datum ukončení musí být po počátečním datu"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "Počáteční datum je neplatné"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : ""
@@ -1048,128 +1047,142 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : ""
 
-, "Recurrances"
-: "Opakování"
-
-, "No recurring rule defined"
-: "Žádné pravidlo opakování není definováno"
-
-, "None"
-: "Žádný"
-
-, "Exceptions of reccuring events can't have recurrences themselves."
+, "Set This Date as Definite Event?"
 : ""
 
-, "at"
-: "v"
-
-, "never"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "after {0} occurrences"
+, "Attendee/Resources"
 : ""
 
-, "Except"
+, "Additional Attendees ..."
 : ""
 
-, "during events in the calendars"
+, "Default Status"
 : ""
 
-, "End"
-: "Konec"
-
-, "Until has to be after event start"
-: "Datum ukončení musí být po počátečním datu"
-
-, "The event is longer than the recurring interval"
+, "No Access"
 : ""
 
-, "Every {0}. Day"
-: "Každý {0}. den"
+, "All my events"
+: "Všechny mé události"
 
-, "Every {0}. Week at"
-: "Každý {0}. týden v"
-
-, "Every {0}. Month"
-: "Každý {0}. měsíc"
-
-, "at the"
-: "(kdy)"
-
-, "first"
-: "první"
-
-, "second"
-: "druhý"
-
-, "third"
-: "třetí"
-
-, "fourth"
-: "čtvrtý"
-
-, "last"
-: "poslední"
-
-, "Every {0}. Year"
-: "Každý {0}. rok"
-
-, "of"
-: "z"
-
-, "First name, ĺast name"
+, "Position on the left time axis, day and week view should start with"
 : ""
 
-, "E-Mail address"
+, "Position on the left time axis, day and week view should end with"
 : ""
 
-, "Please wait..."
+, "Default Start Time"
 : ""
 
-, "General terms and conditions"
+, "Scroll position on the left time axis, day and week view should start with"
 : ""
 
-, "Relation, Relations"
-: [
-  ""
- ,""
- ,""
-
-]
-, "All events I attend"
-: "Všechny události, kterých se účastním"
-
-, "Required"
-: "Povinné"
-
-, "Optional"
-: "Volitelné"
-
-, "No response"
-: "Bez odpovědi"
-
-, "Accepted"
-: "Přijatá"
-
-, "Declined"
-: "Odmítnutá"
-
-, "Awaiting response"
+, "Visible Time"
 : ""
 
-, "Events I have not yet responded to"
+, "Time to be displayed at once"
 : ""
 
-, "Declined events"
+, "Default Calendar"
+: "Výchozí kalendář"
+
+, "The default calendar for invitations and new events"
+: "Výchozí kalendář pro pozvání a nové události"
+
+, "Default Favorite"
+: "Výchozí oblíbené položky kalendáře"
+
+, "The default favorite which is loaded on calendar startup"
+: "Výchozí oblíbené položky, které jsou načteny při spuštění kalendáře"
+
+, "Get Notification Emails"
+: "Dostávat e-maily s upozorněním"
+
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "Úroveň (re)akcí o nichž chcete být informován(a). Pamatujte prosím, že organizátoři dostávají upozornění na všechny změny, včetně odpovědí účastníků, pokud tato volba není nastavena na \"Nikdy\""
+
+, "Send Notifications Emails of own Actions"
+: "Zasílat e-maily s upozorněním na vlastní akce"
+
+, "Get notifications emails for actions you did yourself"
+: "Dostávat e-maily s upozorněním na akce, které pořádám"
+
+, "Send Notifications Emails of tentative events"
 : ""
 
-, "Events I have declined"
+, "Get notifications emails of tentative events"
 : ""
 
-, "I'm organizer"
+, "Send Alarm Notifications Emails"
 : ""
 
-, "Events I'm the organizer of"
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: ""
+
+, "New events get a standard alarm as defined below"
+: ""
+
+, "Standard Alarm Time"
+: ""
+
+, "Minutes before the event starts"
+: ""
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: ""
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: ""
+
+, "On invitation and cancellation only"
+: ""
+
+, "On time changes"
+: ""
+
+, "On all updates but attendee responses"
+: ""
+
+, "On attendee responses too"
 : ""
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
@@ -1235,12 +1248,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Bez odpovědi"
+
+, "Accepted"
+: "Přijatá"
+
+, "Declined"
+: "Odmítnutá"
+
 , "Attendee Roles Available"
 : ""
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Povinné"
+
+, "Optional"
+: "Volitelné"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1250,6 +1281,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1292,6 +1353,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1343,6 +1407,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1382,95 +1449,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Alarm pro událost \"%1$s\" v %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Pozvánka na událost \"%1$s\" v %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "Událost \"%1$s\" v %2$s byla zrušena"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+, "Group Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been updated"
-: "Událost \"%1$s\" v %2$s byla zaktualizována"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s přijal(a) událost \"%2$s\" v %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s odmítnul(a) událost \"%2$s\" v %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "Předběžná odpověď od %1$s na událost \"%2$s\" v %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Žádná odpověď od %1$s na událost \"%2$s\" v %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Změna účastníků pro událost \"%1$s\" v %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Resource Additional Filters"
 : ""
 
-, "Resource Management"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "Polls for recurring events are not supported"
+, "%s's personal calendar"
+: "Osobní kalendář uživatele %s"
+
+, "Failed"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "The right Resource Admin must be set once."
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "Different Calendar"
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Exdate container move are not allowed"
 : ""
 
-, "Start"
-: "Začátek"
+, "Invalid URL given"
+: ""
 
-, "Priority"
-: "Priorita"
+, "The URL you used is invalid. Please use a valid one!"
+: ""
 
-, "Url"
-: "URL"
+, "Calendars to export"
+: ""
 
-, "Recurrance rule"
-: "Pravidlo opakování"
+, "Export target"
+: ""
 
-, "Is all day event"
-: "Celodenní událost"
+, "VCalendar/ICS"
+: ""
 
-, "Organizer timezone"
-: "Časové pásmo organizátora"
+, "Export visible events to ics file"
+: ""
 
-, "No"
-: "Ne"
+, "Excel overview"
+: ""
 
-, "Yes"
-: "Ano"
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "neznámý"
@@ -1529,34 +1605,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: "Začátek"
+
+, "Priority"
+: "Priorita"
+
+, "Url"
+: "URL"
+
+, "Recurrance rule"
+: "Pravidlo opakování"
+
+, "Is all day event"
+: "Celodenní událost"
+
+, "Organizer timezone"
+: "Časové pásmo organizátora"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Alarm pro událost \"%1$s\" v %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Pozvánka na událost \"%1$s\" v %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "Událost \"%1$s\" v %2$s byla zrušena"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Event \"%1$s\" at %2$s has been updated"
+: "Událost \"%1$s\" v %2$s byla zaktualizována"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s přijal(a) událost \"%2$s\" v %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s odmítnul(a) událost \"%2$s\" v %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "Předběžná odpověď od %1$s na událost \"%2$s\" v %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Žádná odpověď od %1$s na událost \"%2$s\" v %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Změna účastníků pro událost \"%1$s\" v %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Word event sheet"
+, "Unknown action"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "Resource Management"
 : ""
 
-, "Excel all data"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Import iCal-files"
+, "Polls for recurring events are not supported"
+: ""
+
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1595,31 +1740,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Detaily události"
 
-, "The poll \"%1$s\" has been closed."
+, "All events I attend"
+: "Všechny události, kterých se účastním"
+
+, "Awaiting response"
 : ""
 
-, "The definite event is scheduled for \"%1$s\""
+, "Events I have not yet responded to"
 : ""
 
-, "You can review the poll results here:"
+, "Declined events"
 : ""
 
-, "Thank you for attendening the poll \"%1$s\""
+, "Events I have declined"
 : ""
 
-, "To review or edit your status please use your personal link:"
+, "I'm organizer"
 : ""
 
-, "Different Calendar"
-: ""
-
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
+, "Events I'm the organizer of"
 : ""
 
 , "manage shared calendars"
@@ -1640,71 +1779,52 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Všechna oprávnění k administraci zdrojů"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "Je umístění"
-
-, "Do you really want to delete this event?"
-: "Opravdu chcete smazat tuto událost?"
+, "Relation, Relations"
+: [
+  ""
+ ,""
+ ,""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Zdroj"
+, "Calendar"
+: "Kalendář"
+
+, "Do you really want to delete this event?"
+: "Opravdu chcete smazat tuto událost?"
 
 , "Resource Grant"
 : ""
@@ -1712,12 +1832,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Událost"
 
-, "Calendar"
-: "Kalendář"
-
 , "Attender"
 : "Účastník"
 
+, "Resource"
+: "Zdroj"
+
 , "Relation"
 : ""
 
