@@ -5,167 +5,251 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nLanguage: en_AU\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nLanguage: en_AU\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "%s's personal calendar"
+, "{0}, the {1}. of {2}"
+: "{0}, {1}. {2}"
 
-, "Resources"
-: "Resources"
+, "Recurrances"
+: "Recurrances"
 
-, "All my events"
-: "All my events"
+, "No recurring rule defined"
+: "No recurring rule defined"
 
-, "Start Time"
-: "Start Time"
-
-, "Position on the left time axis, day and week view should start with"
-: "Position on the left time axis, day and week view should start with"
-
-, "End Time"
-: "End Time"
-
-, "Position on the left time axis, day and week view should end with"
+, "Details"
 : ""
 
-, "Default Start Time"
+, "None"
+: "None"
+
+, "Daily"
+: "Daily"
+
+, "Weekly"
+: "Weekly"
+
+, "Monthly"
+: "Monthly"
+
+, "Yearly"
+: "Yearly"
+
+, "Exceptions of reccuring events can't have recurrences themselves."
+: "Exceptions of reccuring events can't have recurrences themselves."
+
+, "at"
+: "at"
+
+, "never"
+: "never"
+
+, "after {0} occurrences"
+: "after {0} occurrences"
+
+, "Except"
 : ""
 
-, "Scroll position on the left time axis, day and week view should start with"
+, "during events in the calendars"
 : ""
 
-, "Visible Time"
+, "End"
+: "End"
+
+, "Until has to be after event start"
+: "Until has to be after event start"
+
+, "The event is longer than the recurring interval"
 : ""
 
-, "Time to be displayed at once"
-: ""
+, "Every {0}. Day"
+: "Every {0}. Day"
 
-, "Default Calendar"
-: "Default Calendar"
+, "Every {0}. Week at"
+: "Every {0}. Week at"
 
-, "The default calendar for invitations and new events"
-: "The default calendar for invitations and new events"
+, "Every {0}. Month"
+: "Every {0}. Month"
 
-, "Default Favorite"
-: "Default Favorite"
+, "at the"
+: "at the"
 
-, "The default favorite which is loaded on calendar startup"
-: "The default favorite which is loaded on calendar startup"
+, "first"
+: "first"
 
-, "Get Notification Emails"
-: "Get Notification Emails"
+, "second"
+: "second"
 
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+, "third"
+: "third"
 
-, "Send Notifications Emails of own Actions"
-: "Send Notifications Emails of own Actions"
+, "fourth"
+: "fourth"
 
-, "Get notifications emails for actions you did yourself"
-: "Get notifications emails for actions you did yourself"
+, "last"
+: "last"
 
-, "Send Alarm Notifications Emails"
-: ""
+, "Every {0}. Year"
+: "Every {0}. Year"
 
-, "Get event alarms via email"
-: ""
-
-, "Enable Standard Alarm"
-: ""
-
-, "New events get a standard alarm as defined below"
-: ""
-
-, "Standard Alarm Time"
-: ""
-
-, "Minutes before the event starts"
-: ""
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "Fixed Calendars"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: "Never"
-
-, "On invitation and cancellation only"
-: "On invitation and cancellation only"
-
-, "On time changes"
-: "On time changes"
-
-, "On all updates but attendee responses"
-: "On all updates but attendee responses"
-
-, "On attendee responses too"
-: "On attendee responses too"
-
-, "Events"
-: "Events"
+, "of"
+: "of"
 
 , "Summary"
 : "Summary"
 
-, "Status"
-: "Status"
+, "Organizer"
+: "Organizer"
 
-, "No Information"
-: "No Information"
-
-, "recurring event"
-: "recurring event"
-
-, "recurring event exception"
-: "recurring event exception"
-
-, "Blocking"
-: "Blocking"
-
-, "Tentative"
-: "Tentative"
+, "Description"
+: "Description"
 
 , "Location"
 : "Location"
 
-, "Organizer"
-: "Organizer"
+, "Start Time"
+: "Start Time"
+
+, "End Time"
+: "End Time"
 
 , "Attendee"
 : "Attendee"
 
+, "whole day"
+: "whole day"
+
+, "Week {0} :"
+: "Week {0} :"
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "New Event"
+
+, "Calendar, Calendars"
+: [
+  "Calendar"
+ ,"Calendars"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : ""
 
@@ -175,117 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : ""
 
-, "Attachments"
+, "Unavailable"
 : ""
 
-, "Private"
-: "Private"
-
-, "Tags"
-: "Tags"
-
-, "whole day"
-: "whole day"
-
-, "Description"
-: "Description"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: ""
-
-, "This event is originally stored in {0}"
-: ""
-
-, "This event is additionally displayed in your personal calendar {0}"
-: ""
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: "Please choose the Event to add the contacts to"
-
-, "Role"
-: "Role"
-
-, "Select Role"
-: "Select Role"
-
-, "Select Status"
-: "Select Status"
-
-, "Adding {0} Attendee to event"
-: "Adding {0} Attendee to event"
-
-, "Checking Calendar Data..."
-: "Checking Calendar Data..."
-
-, "Reply to Recurring Event"
-: "Reply to Recurring Event"
-
-, "You are responding to an recurring event. What would you like to do?"
-: "You are responding to an recurring event. What would you like to do?"
-
-, "Respond to whole series"
-: "Respond to whole series"
-
-, "Do not respond"
-: "Do not respond"
-
-, "The event of this message does not exist"
-: "The event of this message does not exist"
-
-, "The sender is not authorised to update the event"
-: "The sender is not authorised to update the event"
-
-, "This message is already processed"
-: "This message is already processed"
-
-, "You are not an attendee of this event"
-: "You are not an attendee of this event"
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: "Unsupported message"
-
-, "This is an event invitation for someone else."
-: "This is an event invitation for someone else."
-
-, "You have already replied to this event invitation."
-: "You have already replied to this event invitation."
-
-, "You received an event invitation. Set your response to:"
-: "You received an event invitation. Set your response to:"
-
-, "An invited attendee responded to the invitation."
-: "An invited attendee responded to the invitation."
-
-, "Unsupported method"
-: "Unsupported method"
-
 , "Loading events, please wait..."
 : "Loading events, please wait..."
 
@@ -325,6 +301,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +316,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : ""
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : "Updating event in the past"
 
@@ -418,9 +400,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : "Cancel this action"
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Manage Resources"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Select Attendee"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Private"
+
+, "Tags"
+: "Tags"
+
+, "Blocking"
+: "Blocking"
+
+, "Tentative"
+: "Tentative"
+
 , "Import Definition Success!"
 : ""
 
@@ -457,9 +466,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -511,7 +517,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -535,156 +541,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: ""
-
-, "Details"
-: ""
-
-, "Saved in"
-: ""
-
-, "non-blocking"
-: "non-blocking"
-
-, "Enter description"
-: "Enter description"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "End date is not valid"
-
-, "End date must be after start date"
-: "End date must be after start date"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "Start date is not valid"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: "Week {0} :"
-
-, "Originally"
-: "Originally"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "WK"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Daily"
-
-, "Weekly"
-: "Weekly"
-
-, "Monthly"
-: "Monthly"
-
-, "Yearly"
-: "Yearly"
-
-, "Name"
-: "Name"
-
-, "Email"
-: "Email"
-
-, "Type"
-: "Type"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "New Event"
-
-, "{0} more..."
-: "{0} more..."
-
 , "private classification"
 : "private classification"
 
+, "recurring event"
+: "recurring event"
+
+, "recurring event exception"
+: "recurring event exception"
+
 , "has alarm"
 : "has alarm"
 
@@ -694,62 +559,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, {1}. {2}"
+, "Mini Calendar"
+: "Mini Calendar"
 
-, "Click here to invite another attender..."
-: "Click here to invite another attendee..."
+, "WK"
+: "WK"
 
-, "User"
-: "User"
-
-, "Group"
-: "Group"
-
-, "Resource, Resources"
-: [
-  "Resource"
- ,"Resources"
-
-]
-, "Member of group"
-: "Member of group"
-
-, "This is the calendar where the attender has saved this event in"
-: "This is the calendar the attendee has saved this event in"
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Remove attendee"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(as a group member)"
-
-, "External Attendee"
-: ""
+, "{0} more..."
+: "{0} more..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -769,6 +586,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -811,7 +631,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -841,102 +661,66 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: "Please choose the Event to add the contacts to"
+
+, "Role"
+: "Role"
+
+, "Select Role"
+: "Select Role"
+
+, "Status"
+: "Status"
+
+, "Select Status"
+: "Select Status"
+
+, "Adding {0} Attendee to event"
+: "Adding {0} Attendee to event"
+
 , "no events found"
 : "no events found"
 
 , "Searching..."
 : "Searching..."
 
+, "Search Event"
+: "Search Event"
+
 , "Event, Events"
 : [
   "Event"
  ,"Events"
 
 ]
-, "Search Event"
-: "Search Event"
-
-, "Switch to public poll"
+, "Additional Tags ..."
 : ""
 
-, "Welcome {name}"
+, "non-blocking"
+: "non-blocking"
+
+, "Displayed in"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "No Information"
+: "No Information"
+
+, "Event Location"
 : ""
 
-, "This poll is closed already"
+, "From"
 : ""
 
-, "I am not {name}"
+, "until"
 : ""
 
-, "Login"
-: ""
+, "Events"
+: "Events"
 
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Mini Calendar"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Calendar"
- ,"Calendars"
-
-]
 , "Calendars"
 : "Calendars"
 
@@ -970,6 +754,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -991,38 +787,239 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Attendee"
 
 ]
+, "Resource, Resources"
+: [
+  "Resource"
+ ,"Resources"
+
+]
+, "Resources"
+: "Resources"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Name"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "Email"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Type"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Click here to invite another attendee..."
+
+, "User"
+: "User"
+
+, "Group"
+: "Group"
+
+, "Member of group"
+: "Member of group"
+
+, "This is the calendar where the attender has saved this event in"
+: "This is the calendar the attendee has saved this event in"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Remove attendee"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(as a group member)"
+
+, "External Attendee"
+: ""
+
+, "Originally"
+: "Originally"
+
+, "Checking Calendar Data..."
+: "Checking Calendar Data..."
+
+, "Reply to Recurring Event"
+: "Reply to Recurring Event"
+
+, "You are responding to an recurring event. What would you like to do?"
+: "You are responding to an recurring event. What would you like to do?"
+
+, "Respond to whole series"
+: "Respond to whole series"
+
+, "Do not respond"
+: "Do not respond"
+
+, "The event of this message does not exist"
+: "The event of this message does not exist"
+
+, "The sender is not authorised to update the event"
+: "The sender is not authorised to update the event"
+
+, "This message is already processed"
+: "This message is already processed"
+
+, "You are not an attendee of this event"
+: "You are not an attendee of this event"
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: "Unsupported message"
+
+, "This is an event invitation for someone else."
+: "This is an event invitation for someone else."
+
+, "You have already replied to this event invitation."
+: "You have already replied to this event invitation."
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: "You received an event invitation. Set your response to:"
+
+, "An invited attendee responded to the invitation."
+: "An invited attendee responded to the invitation."
+
+, "Unsupported method"
+: "Unsupported method"
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Enter description..."
 
 , "Grants"
 : ""
 
-, "Displayed in"
+, "This event is originally stored in a calendar you don't have access to."
 : ""
 
-, "Event not found"
+, "This event is originally stored in {0}"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "This event is additionally displayed in your personal calendar {0}"
 : ""
 
-, "GENDER_Attendee"
+, "Colors"
 : ""
 
-, "Select Attendee"
-: "Select Attendee"
+, "Side bar color"
+: ""
+
+, "Color by Calendar"
+: ""
+
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: ""
+
+, "Saved in"
+: ""
+
+, "Enter description"
+: "Enter description"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "End date is not valid"
+
+, "End date must be after start date"
+: "End date must be after start date"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "Start date is not valid"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : "The summary must not be longer than 255 characters."
@@ -1036,128 +1033,143 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : "Summary too Short"
 
-, "Recurrances"
-: "Recurrances"
-
-, "No recurring rule defined"
-: "No recurring rule defined"
-
-, "None"
-: "None"
-
-, "Exceptions of reccuring events can't have recurrences themselves."
-: "Exceptions of reccuring events can't have recurrences themselves."
-
-, "at"
-: "at"
-
-, "never"
-: "never"
-
-, "after {0} occurrences"
-: "after {0} occurrences"
-
-, "Except"
+, "Set This Date as Definite Event?"
 : ""
 
-, "during events in the calendars"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "End"
-: "End"
-
-, "Until has to be after event start"
-: "Until has to be after event start"
-
-, "The event is longer than the recurring interval"
+, "Attendee/Resources"
 : ""
 
-, "Every {0}. Day"
-: "Every {0}. Day"
-
-, "Every {0}. Week at"
-: "Every {0}. Week at"
-
-, "Every {0}. Month"
-: "Every {0}. Month"
-
-, "at the"
-: "at the"
-
-, "first"
-: "first"
-
-, "second"
-: "second"
-
-, "third"
-: "third"
-
-, "fourth"
-: "fourth"
-
-, "last"
-: "last"
-
-, "Every {0}. Year"
-: "Every {0}. Year"
-
-, "of"
-: "of"
-
-, "First name, ĺast name"
+, "Additional Attendees ..."
 : ""
 
-, "E-Mail address"
+, "Default Status"
 : ""
 
-, "Please wait..."
+, "No Access"
 : ""
 
-, "General terms and conditions"
+, "All my events"
+: "All my events"
+
+, "Position on the left time axis, day and week view should start with"
+: "Position on the left time axis, day and week view should start with"
+
+, "Position on the left time axis, day and week view should end with"
 : ""
 
-, "Relation, Relations"
-: [
-  ""
- ,""
+, "Default Start Time"
+: ""
 
-]
-, "All events I attend"
-: "All events I attend"
+, "Scroll position on the left time axis, day and week view should start with"
+: ""
 
-, "Required"
-: "Required"
+, "Visible Time"
+: ""
 
-, "Optional"
-: "Optional"
+, "Time to be displayed at once"
+: ""
 
-, "No response"
-: "No response"
+, "Default Calendar"
+: "Default Calendar"
 
-, "Accepted"
-: "Accepted"
+, "The default calendar for invitations and new events"
+: "The default calendar for invitations and new events"
 
-, "Declined"
-: "Declined"
+, "Default Favorite"
+: "Default Favorite"
 
-, "Awaiting response"
-: "Awaiting response"
+, "The default favorite which is loaded on calendar startup"
+: "The default favorite which is loaded on calendar startup"
 
-, "Events I have not yet responded to"
-: "Events I have not yet responded to"
+, "Get Notification Emails"
+: "Get Notification Emails"
 
-, "Declined events"
-: "Declined events"
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
 
-, "Events I have declined"
-: "Events I have declined"
+, "Send Notifications Emails of own Actions"
+: "Send Notifications Emails of own Actions"
 
-, "I'm organizer"
-: "I'm organizer"
+, "Get notifications emails for actions you did yourself"
+: "Get notifications emails for actions you did yourself"
 
-, "Events I'm the organizer of"
-: "Events I'm the organizer of"
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
+, "Send Alarm Notifications Emails"
+: ""
+
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: ""
+
+, "New events get a standard alarm as defined below"
+: ""
+
+, "Standard Alarm Time"
+: ""
+
+, "Minutes before the event starts"
+: ""
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "Fixed Calendars"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: "Never"
+
+, "On invitation and cancellation only"
+: "On invitation and cancellation only"
+
+, "On time changes"
+: "On time changes"
+
+, "On all updates but attendee responses"
+: "On all updates but attendee responses"
+
+, "On attendee responses too"
+: "On attendee responses too"
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
@@ -1222,12 +1234,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "No response"
+
+, "Accepted"
+: "Accepted"
+
+, "Declined"
+: "Declined"
+
 , "Attendee Roles Available"
 : "Attendee Roles Available"
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Required"
+
+, "Optional"
+: "Optional"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1237,6 +1267,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1279,6 +1339,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1330,6 +1393,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1369,95 +1435,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Alarm for event \"%1$s\" at %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Event invitation \"%1$s\" at %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "Event \"%1$s\" at %2$s has been canceled"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+, "Group Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been updated"
-: "Event \"%1$s\" at %2$s has been updated"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s accepted event \"%2$s\" at %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s declined event \"%2$s\" at %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "Tentative response from %1$s for event \"%2$s\" at %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "No response from %1$s for event \"%2$s\" at %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Attendee changes for event \"%1$s\" at %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Resource Additional Filters"
 : ""
 
-, "Resource Management"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "Polls for recurring events are not supported"
+, "%s's personal calendar"
+: "%s's personal calendar"
+
+, "Failed"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "The right Resource Admin must be set once."
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "Different Calendar"
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Exdate container move are not allowed"
 : ""
 
-, "Start"
-: "Start"
+, "Invalid URL given"
+: ""
 
-, "Priority"
-: "Priority"
+, "The URL you used is invalid. Please use a valid one!"
+: "This URL is invalid. Please use a valid one!"
 
-, "Url"
-: "Url"
+, "Calendars to export"
+: ""
 
-, "Recurrance rule"
-: "Recurrance rule"
+, "Export target"
+: ""
 
-, "Is all day event"
-: "Is all day event"
+, "VCalendar/ICS"
+: ""
 
-, "Organizer timezone"
-: "Organizer timezone"
+, "Export visible events to ics file"
+: ""
 
-, "No"
-: "No"
+, "Excel overview"
+: ""
 
-, "Yes"
-: "Yes"
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "unknown"
@@ -1516,34 +1591,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: "Start"
+
+, "Priority"
+: "Priority"
+
+, "Url"
+: "Url"
+
+, "Recurrance rule"
+: "Recurrance rule"
+
+, "Is all day event"
+: "Is all day event"
+
+, "Organizer timezone"
+: "Organizer timezone"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Alarm for event \"%1$s\" at %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Event invitation \"%1$s\" at %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "Event \"%1$s\" at %2$s has been canceled"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Event \"%1$s\" at %2$s has been updated"
+: "Event \"%1$s\" at %2$s has been updated"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s accepted event \"%2$s\" at %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s declined event \"%2$s\" at %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "Tentative response from %1$s for event \"%2$s\" at %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "No response from %1$s for event \"%2$s\" at %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Attendee changes for event \"%1$s\" at %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Word event sheet"
+, "Unknown action"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "Resource Management"
 : ""
 
-, "Excel all data"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Import iCal-files"
+, "Polls for recurring events are not supported"
+: ""
+
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1582,32 +1726,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Event details"
 
-, "The poll \"%1$s\" has been closed."
-: ""
+, "All events I attend"
+: "All events I attend"
 
-, "The definite event is scheduled for \"%1$s\""
-: ""
+, "Awaiting response"
+: "Awaiting response"
 
-, "You can review the poll results here:"
-: ""
+, "Events I have not yet responded to"
+: "Events I have not yet responded to"
 
-, "Thank you for attendening the poll \"%1$s\""
-: ""
+, "Declined events"
+: "Declined events"
 
-, "To review or edit your status please use your personal link:"
-: ""
+, "Events I have declined"
+: "Events I have declined"
 
-, "Different Calendar"
-: ""
+, "I'm organizer"
+: "I'm organizer"
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
-: "This URL is invalid. Please use a valid one!"
+, "Events I'm the organizer of"
+: "Events I'm the organizer of"
 
 , "manage shared calendars"
 : "manage shared calendars"
@@ -1627,71 +1765,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "All Rights to administrate resources"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "Is a location"
-
-, "Do you really want to delete this event?"
-: "Do you really want to delete this event?"
+, "Relation, Relations"
+: [
+  ""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Resource"
+, "Calendar"
+: "Calendar"
+
+, "Do you really want to delete this event?"
+: "Do you really want to delete this event?"
 
 , "Resource Grant"
 : ""
@@ -1699,12 +1816,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Event"
 
-, "Calendar"
-: "Calendar"
-
 , "Attender"
 : "Attender"
 
+, "Resource"
+: "Resource"
+
 , "Relation"
 : ""
 
