@@ -5,167 +5,251 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "Agenda personnel de %s"
+, "{0}, the {1}. of {2}"
+: "{0} {1} {2}"
 
-, "Resources"
-: "Ressources"
+, "Recurrances"
+: "Récurrences"
 
-, "All my events"
-: "Tous mes événements"
+, "No recurring rule defined"
+: "Aucune récurrence de définie"
 
-, "Start Time"
-: "Date de début"
+, "Details"
+: "Détails"
 
-, "Position on the left time axis, day and week view should start with"
-: "Début des vues \"Jour\" et \"Semaine\" sur l'axe du temps"
+, "None"
+: "Aucun"
 
-, "End Time"
-: "Date de fin"
+, "Daily"
+: "Quotidien"
 
-, "Position on the left time axis, day and week view should end with"
-: ""
+, "Weekly"
+: "Hebdomadaire"
 
-, "Default Start Time"
-: ""
+, "Monthly"
+: "Mensuel"
 
-, "Scroll position on the left time axis, day and week view should start with"
-: ""
+, "Yearly"
+: "Annuel"
 
-, "Visible Time"
-: ""
+, "Exceptions of reccuring events can't have recurrences themselves."
+: "Les événement récurrents ne peuvent pas être modifiés"
 
-, "Time to be displayed at once"
-: ""
+, "at"
+: "à"
 
-, "Default Calendar"
-: "Agenda par défaut"
-
-, "The default calendar for invitations and new events"
-: "Agenda par défaut pour les invitations et les nouveau événements"
-
-, "Default Favorite"
-: "Favoris par défaut"
-
-, "The default favorite which is loaded on calendar startup"
-: "Les favoris chargés par défaut au démarrage du gestionnaire d'agenda"
-
-, "Get Notification Emails"
-: "Recevoir les courriels de notification"
-
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "Niveau des actions dont vous voulez être notifié. Les organisateurs seront notifiés de toutes les mises à jour, incluant les réponses des participants, à moins que cette préférence soit définie à \"Jamais\""
-
-, "Send Notifications Emails of own Actions"
-: "Envoyer une notification de ses propres actions"
-
-, "Get notifications emails for actions you did yourself"
-: "Recevoir des notification par courriels de vos propres actions"
-
-, "Send Alarm Notifications Emails"
-: ""
-
-, "Get event alarms via email"
-: ""
-
-, "Enable Standard Alarm"
-: "Activer l'alarme"
-
-, "New events get a standard alarm as defined below"
-: "Les nouveaux événements auront un rappel comme indiqué"
-
-, "Standard Alarm Time"
-: "Alarme"
-
-, "Minutes before the event starts"
-: "Minutes avant le début de l'événement"
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "Agendas fixes"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
+, "never"
 : "Jamais"
 
-, "On invitation and cancellation only"
-: "Sur invitation et annulation uniquement"
+, "after {0} occurrences"
+: "après {0} occurrences"
 
-, "On time changes"
-: "Sur modification de la date / heure"
+, "Except"
+: ""
 
-, "On all updates but attendee responses"
-: "Sur toutes les mises à jour sauf réponse d'un participant"
+, "during events in the calendars"
+: ""
 
-, "On attendee responses too"
-: "Sur toutes les mises à jour y compris réponse d'un participant"
+, "End"
+: "Fin"
 
-, "Events"
-: "Événements"
+, "Until has to be after event start"
+: "La date de fin doit être postérieure à la date de début"
+
+, "The event is longer than the recurring interval"
+: ""
+
+, "Every {0}. Day"
+: "Tous les {0} jours"
+
+, "Every {0}. Week at"
+: "Tous les {0} semaines le"
+
+, "Every {0}. Month"
+: "Tous les {0} mois"
+
+, "at the"
+: "le"
+
+, "first"
+: "premier"
+
+, "second"
+: "deuxième"
+
+, "third"
+: "troisième"
+
+, "fourth"
+: "quatrième"
+
+, "last"
+: "dernier"
+
+, "Every {0}. Year"
+: "Tous les {0}. Année"
+
+, "of"
+: "de"
 
 , "Summary"
 : "Résumé"
 
-, "Status"
-: "Statut"
+, "Organizer"
+: "Organisateur"
 
-, "No Information"
-: "Pas d'information"
-
-, "recurring event"
-: "événement récurrent"
-
-, "recurring event exception"
-: "Erreur dans la récurrence de l'événement"
-
-, "Blocking"
-: "Bloquant"
-
-, "Tentative"
-: "Tentative"
+, "Description"
+: "Description"
 
 , "Location"
 : "Lieu"
 
-, "Organizer"
-: "Organisateur"
+, "Start Time"
+: "Date de début"
+
+, "End Time"
+: "Date de fin"
 
 , "Attendee"
 : "Participant"
 
+, "whole day"
+: "Journée"
+
+, "Week {0} :"
+: "Semaine {0} :"
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Nouvel événement"
+
+, "Calendar, Calendars"
+: [
+  "Agenda"
+ ,"Agendas"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : "Ajouter un participant"
 
@@ -175,117 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : "Filtrer pour ce participant"
 
-, "Attachments"
+, "Unavailable"
 : ""
 
-, "Private"
-: "Privé"
-
-, "Tags"
-: "Tags"
-
-, "whole day"
-: "Journée"
-
-, "Description"
-: "Description"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: "Cet événement est marqué dans un agenda auquel vous n'avez pas accès."
-
-, "This event is originally stored in {0}"
-: "Cet événement est marqué dans {0}"
-
-, "This event is additionally displayed in your personal calendar {0}"
-: "Cet événement est également affiché dans votre agenda personnel {0}"
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: "Veuillez sélectionner l'événement auquel les contacts seront ajoutés"
-
-, "Role"
-: "Rôle"
-
-, "Select Role"
-: "Sélectionner un role"
-
-, "Select Status"
-: "Sélectionner un statut"
-
-, "Adding {0} Attendee to event"
-: "Ajout de {0} participants à l'événement"
-
-, "Checking Calendar Data..."
-: "Vérification des agendas"
-
-, "Reply to Recurring Event"
-: "Répondre à l'événement récurrent"
-
-, "You are responding to an recurring event. What would you like to do?"
-: "Vous êtes en train de répondre à un événement récurrent. Que vous voulez faire ?"
-
-, "Respond to whole series"
-: "Répondre à toute la série"
-
-, "Do not respond"
-: "Ne pas répondre"
-
-, "The event of this message does not exist"
-: "L'événement de ce message n'existe pas"
-
-, "The sender is not authorised to update the event"
-: "Vous ne pouvez pas modifier l'événement"
-
-, "This message is already processed"
-: "Ce message a déjà été traité"
-
-, "You are not an attendee of this event"
-: "Vous ne participez pas à cet événement"
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: "Message non supporté"
-
-, "This is an event invitation for someone else."
-: "Cette invitation ne concerne pas ce compte."
-
-, "You have already replied to this event invitation."
-: "Vous avez déjà répondu à cette invitation"
-
-, "You received an event invitation. Set your response to:"
-: "Vous avez reçu une invitation. Quelle est votre réponse ?"
-
-, "An invited attendee responded to the invitation."
-: "Un participant a répondu à l'invitation"
-
-, "Unsupported method"
-: "Méthode non supportée"
-
 , "Loading events, please wait..."
 : "Chargement, veuillez patienter..."
 
@@ -325,6 +301,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +316,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : "Copier {0}"
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : "Mettre à jour un événement passé"
 
@@ -418,9 +400,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : "Annuler"
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Gérer les ressources"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Sélectionner un participant"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Privé"
+
+, "Tags"
+: "Tags"
+
+, "Blocking"
+: "Bloquant"
+
+, "Tentative"
+: "Tentative"
+
 , "Import Definition Success!"
 : ""
 
@@ -457,9 +466,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -511,7 +517,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -535,156 +541,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: "Voir en tant que"
-
-, "Details"
-: "Détails"
-
-, "Saved in"
-: "Sauvegardé"
-
-, "non-blocking"
-: "Non bloquant"
-
-, "Enter description"
-: "Saisir une description"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "Date de fin invalide"
-
-, "End date must be after start date"
-: "La date de fin doit être postérieure à la date de début"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "Date de début non valide"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: "Semaine {0} :"
-
-, "Originally"
-: "À l'origine"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "WK"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Quotidien"
-
-, "Weekly"
-: "Hebdomadaire"
-
-, "Monthly"
-: "Mensuel"
-
-, "Yearly"
-: "Annuel"
-
-, "Name"
-: "Nom"
-
-, "Email"
-: "Email"
-
-, "Type"
-: "Type"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Nouvel événement"
-
-, "{0} more..."
-: "{0} de plus..."
-
 , "private classification"
 : "Classer en privé"
 
+, "recurring event"
+: "événement récurrent"
+
+, "recurring event exception"
+: "Erreur dans la récurrence de l'événement"
+
 , "has alarm"
 : "rappel activé"
 
@@ -694,62 +559,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0} {1} {2}"
+, "Mini Calendar"
+: "Mini-calendrier"
 
-, "Click here to invite another attender..."
-: "Cliquez ici pour ajouter un participant..."
+, "WK"
+: "WK"
 
-, "User"
-: "Utilisateur"
-
-, "Group"
-: "Groupe"
-
-, "Resource, Resources"
-: [
-  "Ressource"
- ,"Ressources"
-
-]
-, "Member of group"
-: "Membre du groupe"
-
-, "This is the calendar where the attender has saved this event in"
-: "Agenda où le participant a enregistré cet événement"
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Supprimer le participant"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(comme membre du groupe)"
-
-, "External Attendee"
-: "Participant externe"
+, "{0} more..."
+: "{0} de plus..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -769,6 +586,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -811,7 +631,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -841,102 +661,66 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: "Veuillez sélectionner l'événement auquel les contacts seront ajoutés"
+
+, "Role"
+: "Rôle"
+
+, "Select Role"
+: "Sélectionner un role"
+
+, "Status"
+: "Statut"
+
+, "Select Status"
+: "Sélectionner un statut"
+
+, "Adding {0} Attendee to event"
+: "Ajout de {0} participants à l'événement"
+
 , "no events found"
 : "Aucun événement trouvé"
 
 , "Searching..."
 : "Recherche ..."
 
+, "Search Event"
+: "Recherche d'événement"
+
 , "Event, Events"
 : [
   "Événement"
  ,"Événements"
 
 ]
-, "Search Event"
-: "Recherche d'événement"
-
-, "Switch to public poll"
+, "Additional Tags ..."
 : ""
 
-, "Welcome {name}"
+, "non-blocking"
+: "Non bloquant"
+
+, "Displayed in"
+: "Marqué dans"
+
+, "No Information"
+: "Pas d'information"
+
+, "Event Location"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "From"
 : ""
 
-, "This poll is closed already"
+, "until"
 : ""
 
-, "I am not {name}"
-: ""
+, "Events"
+: "Événements"
 
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Mini-calendrier"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Agenda"
- ,"Agendas"
-
-]
 , "Calendars"
 : "Agendas"
 
@@ -970,6 +754,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -991,38 +787,239 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Participants"
 
 ]
+, "Resource, Resources"
+: [
+  "Ressource"
+ ,"Ressources"
+
+]
+, "Resources"
+: "Ressources"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Nom"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "Email"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Type"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Cliquez ici pour ajouter un participant..."
+
+, "User"
+: "Utilisateur"
+
+, "Group"
+: "Groupe"
+
+, "Member of group"
+: "Membre du groupe"
+
+, "This is the calendar where the attender has saved this event in"
+: "Agenda où le participant a enregistré cet événement"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Supprimer le participant"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(comme membre du groupe)"
+
+, "External Attendee"
+: "Participant externe"
+
+, "Originally"
+: "À l'origine"
+
+, "Checking Calendar Data..."
+: "Vérification des agendas"
+
+, "Reply to Recurring Event"
+: "Répondre à l'événement récurrent"
+
+, "You are responding to an recurring event. What would you like to do?"
+: "Vous êtes en train de répondre à un événement récurrent. Que vous voulez faire ?"
+
+, "Respond to whole series"
+: "Répondre à toute la série"
+
+, "Do not respond"
+: "Ne pas répondre"
+
+, "The event of this message does not exist"
+: "L'événement de ce message n'existe pas"
+
+, "The sender is not authorised to update the event"
+: "Vous ne pouvez pas modifier l'événement"
+
+, "This message is already processed"
+: "Ce message a déjà été traité"
+
+, "You are not an attendee of this event"
+: "Vous ne participez pas à cet événement"
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: "Message non supporté"
+
+, "This is an event invitation for someone else."
+: "Cette invitation ne concerne pas ce compte."
+
+, "You have already replied to this event invitation."
+: "Vous avez déjà répondu à cette invitation"
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: "Vous avez reçu une invitation. Quelle est votre réponse ?"
+
+, "An invited attendee responded to the invitation."
+: "Un participant a répondu à l'invitation"
+
+, "Unsupported method"
+: "Méthode non supportée"
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Saisissez une description..."
 
 , "Grants"
 : "Droits"
 
-, "Displayed in"
-: "Marqué dans"
+, "This event is originally stored in a calendar you don't have access to."
+: "Cet événement est marqué dans un agenda auquel vous n'avez pas accès."
 
-, "Event not found"
+, "This event is originally stored in {0}"
+: "Cet événement est marqué dans {0}"
+
+, "This event is additionally displayed in your personal calendar {0}"
+: "Cet événement est également affiché dans votre agenda personnel {0}"
+
+, "Colors"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "Side bar color"
 : ""
 
-, "GENDER_Attendee"
+, "Color by Calendar"
 : ""
 
-, "Select Attendee"
-: "Sélectionner un participant"
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: "Voir en tant que"
+
+, "Saved in"
+: "Sauvegardé"
+
+, "Enter description"
+: "Saisir une description"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "Date de fin invalide"
+
+, "End date must be after start date"
+: "La date de fin doit être postérieure à la date de début"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "Date de début non valide"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : "Le résumé ne doit pas dépasser 255 caractères"
@@ -1036,128 +1033,143 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : "Résumé obligatoire"
 
-, "Recurrances"
-: "Récurrences"
+, "Set This Date as Definite Event?"
+: ""
 
-, "No recurring rule defined"
-: "Aucune récurrence de définie"
+, "Do you want to close the poll and remove all other alternatives?"
+: ""
 
-, "None"
-: "Aucun"
+, "Attendee/Resources"
+: ""
 
-, "Exceptions of reccuring events can't have recurrences themselves."
-: "Les événement récurrents ne peuvent pas être modifiés"
+, "Additional Attendees ..."
+: ""
 
-, "at"
-: "à"
+, "Default Status"
+: ""
 
-, "never"
+, "No Access"
+: ""
+
+, "All my events"
+: "Tous mes événements"
+
+, "Position on the left time axis, day and week view should start with"
+: "Début des vues \"Jour\" et \"Semaine\" sur l'axe du temps"
+
+, "Position on the left time axis, day and week view should end with"
+: ""
+
+, "Default Start Time"
+: ""
+
+, "Scroll position on the left time axis, day and week view should start with"
+: ""
+
+, "Visible Time"
+: ""
+
+, "Time to be displayed at once"
+: ""
+
+, "Default Calendar"
+: "Agenda par défaut"
+
+, "The default calendar for invitations and new events"
+: "Agenda par défaut pour les invitations et les nouveau événements"
+
+, "Default Favorite"
+: "Favoris par défaut"
+
+, "The default favorite which is loaded on calendar startup"
+: "Les favoris chargés par défaut au démarrage du gestionnaire d'agenda"
+
+, "Get Notification Emails"
+: "Recevoir les courriels de notification"
+
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "Niveau des actions dont vous voulez être notifié. Les organisateurs seront notifiés de toutes les mises à jour, incluant les réponses des participants, à moins que cette préférence soit définie à \"Jamais\""
+
+, "Send Notifications Emails of own Actions"
+: "Envoyer une notification de ses propres actions"
+
+, "Get notifications emails for actions you did yourself"
+: "Recevoir des notification par courriels de vos propres actions"
+
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
+, "Send Alarm Notifications Emails"
+: ""
+
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: "Activer l'alarme"
+
+, "New events get a standard alarm as defined below"
+: "Les nouveaux événements auront un rappel comme indiqué"
+
+, "Standard Alarm Time"
+: "Alarme"
+
+, "Minutes before the event starts"
+: "Minutes avant le début de l'événement"
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "Agendas fixes"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
 : "Jamais"
 
-, "after {0} occurrences"
-: "après {0} occurrences"
+, "On invitation and cancellation only"
+: "Sur invitation et annulation uniquement"
 
-, "Except"
-: ""
+, "On time changes"
+: "Sur modification de la date / heure"
 
-, "during events in the calendars"
-: ""
+, "On all updates but attendee responses"
+: "Sur toutes les mises à jour sauf réponse d'un participant"
 
-, "End"
-: "Fin"
-
-, "Until has to be after event start"
-: "La date de fin doit être postérieure à la date de début"
-
-, "The event is longer than the recurring interval"
-: ""
-
-, "Every {0}. Day"
-: "Tous les {0} jours"
-
-, "Every {0}. Week at"
-: "Tous les {0} semaines le"
-
-, "Every {0}. Month"
-: "Tous les {0} mois"
-
-, "at the"
-: "le"
-
-, "first"
-: "premier"
-
-, "second"
-: "deuxième"
-
-, "third"
-: "troisième"
-
-, "fourth"
-: "quatrième"
-
-, "last"
-: "dernier"
-
-, "Every {0}. Year"
-: "Tous les {0}. Année"
-
-, "of"
-: "de"
-
-, "First name, ĺast name"
-: ""
-
-, "E-Mail address"
-: ""
-
-, "Please wait..."
-: ""
-
-, "General terms and conditions"
-: ""
-
-, "Relation, Relations"
-: [
-  ""
- ,""
-
-]
-, "All events I attend"
-: "Tous les événements auxquels j'assiste"
-
-, "Required"
-: "Requis"
-
-, "Optional"
-: "Facultatif"
-
-, "No response"
-: "Pas de réponse"
-
-, "Accepted"
-: "Accepté"
-
-, "Declined"
-: "Refusé"
-
-, "Awaiting response"
-: "En attente de la réponse"
-
-, "Events I have not yet responded to"
-: "Evènements auxquels je n'ai pas encore répondu"
-
-, "Declined events"
-: "Evènements refusés"
-
-, "Events I have declined"
-: "Evènements que j'ai refusé"
-
-, "I'm organizer"
-: "Je suis organisateur"
-
-, "Events I'm the organizer of"
-: "Evènements dont je suis l'oganisateur"
+, "On attendee responses too"
+: "Sur toutes les mises à jour y compris réponse d'un participant"
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : "Agendas qui sont toujours sélectionnés quelque soit le filtre. Par exemple, vous pouvez forcer le calendrier des jours fériés."
@@ -1222,12 +1234,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Pas de réponse"
+
+, "Accepted"
+: "Accepté"
+
+, "Declined"
+: "Refusé"
+
 , "Attendee Roles Available"
 : "Roles disponibles pour un participant"
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Requis"
+
+, "Optional"
+: "Facultatif"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1237,6 +1267,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1279,6 +1339,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1330,6 +1393,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1369,95 +1435,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Rappel pour l'événement \"%1$s\" à %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Invitation pour \"%1$s\" à %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "L'événement \"%1$s\" à %2$s a été annulé"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
-: "Evènenement\"%1$s\" a été replanifié de %2$s à %3$s"
-
-, "Event \"%1$s\" at %2$s has been updated"
-: "L'événement \"%1$s\" à %2$s a été mis à jour"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s a accepté \"%2$s\" à %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s a refusé \"%2$s\" à %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "%1$s tentera de participer à l'événement \"%2$s\" à %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Pas de réponse de %1$s pour l'événement \"%2$s\" à %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Changement de participants pour l'événement \"%1$s\" à %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Group Additional Filters"
 : ""
 
-, "Resource Management"
+, "Resource Additional Filters"
 : ""
 
-, "Polls for recurring events are not supported"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "%s's personal calendar"
+: "Agenda personnel de %s"
+
+, "Failed"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "The right Resource Admin must be set once."
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Different Calendar"
 : ""
 
-, "Start"
-: "Début"
+, "Exdate container move are not allowed"
+: ""
 
-, "Priority"
-: "Priorité"
+, "Invalid URL given"
+: ""
 
-, "Url"
-: "Site Internet"
+, "The URL you used is invalid. Please use a valid one!"
+: ""
 
-, "Recurrance rule"
-: "Récurrences"
+, "Calendars to export"
+: ""
 
-, "Is all day event"
-: "Toute la journée"
+, "Export target"
+: ""
 
-, "Organizer timezone"
-: "Fuseau horaire de l'organisateur"
+, "VCalendar/ICS"
+: ""
 
-, "No"
-: "Non"
+, "Export visible events to ics file"
+: ""
 
-, "Yes"
-: "Oui"
+, "Excel overview"
+: ""
+
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "inconnu"
@@ -1516,34 +1591,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : "ème"
 
+, "Start"
+: "Début"
+
+, "Priority"
+: "Priorité"
+
+, "Url"
+: "Site Internet"
+
+, "Recurrance rule"
+: "Récurrences"
+
+, "Is all day event"
+: "Toute la journée"
+
+, "Organizer timezone"
+: "Fuseau horaire de l'organisateur"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Rappel pour l'événement \"%1$s\" à %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Invitation pour \"%1$s\" à %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "L'événement \"%1$s\" à %2$s a été annulé"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+: "Evènenement\"%1$s\" a été replanifié de %2$s à %3$s"
+
+, "Event \"%1$s\" at %2$s has been updated"
+: "L'événement \"%1$s\" à %2$s a été mis à jour"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s a accepté \"%2$s\" à %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s a refusé \"%2$s\" à %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "%1$s tentera de participer à l'événement \"%2$s\" à %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Pas de réponse de %1$s pour l'événement \"%2$s\" à %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Changement de participants pour l'événement \"%1$s\" à %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Unknown action"
 : ""
 
-, "Word event sheet"
+, "Resource Management"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Excel all data"
+, "Polls for recurring events are not supported"
 : ""
 
-, "Import iCal-files"
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1582,32 +1726,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Détails de l'événement"
 
-, "The poll \"%1$s\" has been closed."
-: ""
+, "All events I attend"
+: "Tous les événements auxquels j'assiste"
 
-, "The definite event is scheduled for \"%1$s\""
-: ""
+, "Awaiting response"
+: "En attente de la réponse"
 
-, "You can review the poll results here:"
-: ""
+, "Events I have not yet responded to"
+: "Evènements auxquels je n'ai pas encore répondu"
 
-, "Thank you for attendening the poll \"%1$s\""
-: ""
+, "Declined events"
+: "Evènements refusés"
 
-, "To review or edit your status please use your personal link:"
-: ""
+, "Events I have declined"
+: "Evènements que j'ai refusé"
 
-, "Different Calendar"
-: ""
+, "I'm organizer"
+: "Je suis organisateur"
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
-: ""
+, "Events I'm the organizer of"
+: "Evènements dont je suis l'oganisateur"
 
 , "manage shared calendars"
 : "gérer les agendas partagés"
@@ -1627,74 +1765,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Tous les droits d'administration des ressources"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "Est un lieu"
-
-, "Errors"
-: "Erreurs"
-
-, "Do you really want to delete this event?"
-: "Êtes-vous sûr de vouloir supprimer l'événement sélectionné?"
+, "Relation, Relations"
+: [
+  ""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Ressource"
+, "Calendar"
+: "Agenda"
+
+, "Do you really want to delete this event?"
+: "Êtes-vous sûr de vouloir supprimer l'événement sélectionné?"
 
 , "Resource Grant"
 : ""
@@ -1702,12 +1816,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Événement"
 
-, "Calendar"
-: "Agenda"
-
 , "Attender"
 : "Participant"
 
+, "Resource"
+: "Ressource"
+
 , "Relation"
 : ""
 
