@@ -5,24 +5,1070 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Hebrew (Israel) (http://www.transifex.com/tine20/tine20/language/he_IL/)\nLanguage: he_IL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hebrew (Israel) (http://www.transifex.com/tine20/tine20/language/he_IL/)\nLanguage: he_IL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
+, "{0}, the {1}. of {2}"
 : ""
 
-, "Resources"
+, "Recurrances"
 : ""
 
-, "All my events"
+, "No recurring rule defined"
+: ""
+
+, "Details"
+: ""
+
+, "None"
+: ""
+
+, "Daily"
+: ""
+
+, "Weekly"
+: ""
+
+, "Monthly"
+: ""
+
+, "Yearly"
+: ""
+
+, "Exceptions of reccuring events can't have recurrences themselves."
+: ""
+
+, "at"
+: ""
+
+, "never"
+: ""
+
+, "after {0} occurrences"
+: ""
+
+, "Except"
+: ""
+
+, "during events in the calendars"
+: ""
+
+, "End"
+: ""
+
+, "Until has to be after event start"
+: ""
+
+, "The event is longer than the recurring interval"
+: ""
+
+, "Every {0}. Day"
+: ""
+
+, "Every {0}. Week at"
+: ""
+
+, "Every {0}. Month"
+: ""
+
+, "at the"
+: ""
+
+, "first"
+: ""
+
+, "second"
+: ""
+
+, "third"
+: ""
+
+, "fourth"
+: ""
+
+, "last"
+: ""
+
+, "Every {0}. Year"
+: ""
+
+, "of"
+: ""
+
+, "Summary"
+: ""
+
+, "Organizer"
+: ""
+
+, "Description"
+: ""
+
+, "Location"
 : ""
 
 , "Start Time"
 : ""
 
-, "Position on the left time axis, day and week view should start with"
+, "End Time"
 : ""
 
-, "End Time"
+, "Attendee"
+: ""
+
+, "whole day"
+: ""
+
+, "Week {0} :"
+: ""
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: ""
+
+, "Calendar, Calendars"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
+, "Add attendee"
+: ""
+
+, "Sort Attendee"
+: ""
+
+, "Check to filter for this attendee"
+: ""
+
+, "Unavailable"
+: ""
+
+, "Loading events, please wait..."
+: ""
+
+, "Cut event"
+: ""
+
+, "Copy Event to clipboard"
+: ""
+
+, "Stop cut / copy & paste"
+: ""
+
+, "Print Page"
+: ""
+
+, "Loose-Leaf"
+: ""
+
+, "Sheet"
+: ""
+
+, "Grid"
+: ""
+
+, "Timeline"
+: ""
+
+, "Day"
+: ""
+
+, "Week"
+: ""
+
+, "Month"
+: ""
+
+, "Year"
+: ""
+
+, "Custom Selection"
+: ""
+
+, "Import Events"
+: ""
+
+, "Paste event \"{0}\""
+: ""
+
+, "Set my response"
+: ""
+
+, "Copy {0}"
+: ""
+
+, "Set event status"
+: ""
+
+, "Updating event in the past"
+: ""
+
+, "Update this event"
+: ""
+
+, "Do not update this event"
+: ""
+
+, "Creating event in the past"
+: ""
+
+, "Create this event"
+: ""
+
+, "Do not create this event"
+: ""
+
+, "Update this event only"
+: ""
+
+, "Update this and all future events"
+: ""
+
+, "Update whole series"
+: ""
+
+, "Update nothing"
+: ""
+
+, "Update Event"
+: ""
+
+, "Please Change Selection"
+: ""
+
+, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
+: ""
+
+, "Delete Event"
+: ""
+
+, "Delete this event only"
+: ""
+
+, "Delete this and all future events"
+: ""
+
+, "Delete whole series"
+: ""
+
+, "Delete nothing"
+: ""
+
+, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Could not Print"
+: ""
+
+, "Sorry, your current view does not support printing."
+: ""
+
+, "Scheduling Conflict"
+: ""
+
+, "The following attendee are busy at the requested time:"
+: ""
+
+, "Ignore Conflict"
+: ""
+
+, "Edit Event"
+: ""
+
+, "Cancel this action"
+: ""
+
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
+, "Manage Resources"
+: ""
+
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: ""
+
+, "Attachments"
+: ""
+
+, "Private"
+: ""
+
+, "Tags"
+: ""
+
+, "Blocking"
+: ""
+
+, "Tentative"
+: ""
+
+, "Import Definition Success!"
+: ""
+
+, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
+: ""
+
+, "Choose Import File"
+: ""
+
+, "Please choose the file that contains the records you want to add to Tine 2.0"
+: ""
+
+, "Select file containing your {0}"
+: ""
+
+, "once"
+: ""
+
+, "hourly"
+: ""
+
+, "daily"
+: ""
+
+, "weekly"
+: ""
+
+, "Choose Remote Location"
+: ""
+
+, "Please choose a remote location you want to add to Tine 2.0"
+: ""
+
+, "Username"
+: ""
+
+, "Refresh time"
+: ""
+
+, "General Settings"
+: ""
+
+, "Calendar name (you need permissions to add events)"
+: ""
+
+, "What should the file you upload look like?"
+: ""
+
+, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
+: ""
+
+, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
+: ""
+
+, "Please select the import format of the file you want to upload"
+: ""
+
+, "Download example file"
+: ""
+
+, "Remote / ICS"
+: ""
+
+, "Remote / CalDAV (BETA)"
+: ""
+
+, "Upload"
+: ""
+
+, "Choose File and Format"
+: ""
+
+, "Select type of source"
+: ""
+
+, "Please select the type of source you want to add to Tine 2.0"
+: ""
+
+, "Importing {0}"
+: ""
+
+, "Back"
+: ""
+
+, "Next"
+: ""
+
+, "Ok"
+: ""
+
+, "Free Time Search"
+: ""
+
+, "Searching for Free Time..."
+: ""
+
+, "No Free Time found"
+: ""
+
+, "No free timeslot could be found Until {0}. Do you want to continue?"
+: ""
+
+, "Continue"
+: ""
+
+, "Give up"
+: ""
+
+, "Free Time Search Options"
+: ""
+
+, "private classification"
+: ""
+
+, "recurring event"
+: ""
+
+, "recurring event exception"
+: ""
+
+, "has alarm"
+: ""
+
+, "has attachments"
+: ""
+
+, "is part of an open poll"
+: ""
+
+, "Mini Calendar"
+: ""
+
+, "WK"
+: ""
+
+, "{0} more..."
+: ""
+
+, "Resource Grant, Resource Grants"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Invite Resource"
+: ""
+
+, "The grant to invite the resource to an event"
+: ""
+
+, "Read Resource"
+: ""
+
+, "The grant to read the resource itself"
+: ""
+
+, "Edit Resource"
+: ""
+
+, "The grant to edit the resource itself"
+: ""
+
+, "Export Resource"
+: ""
+
+, "The grant to export the resource itself"
+: ""
+
+, "Sync Resource"
+: ""
+
+, "The grant to synchronise the resource itself"
+: ""
+
+, "Resource Admin"
+: ""
+
+, "The grant to administrate the resource itself"
+: ""
+
+, "Add Events"
+: ""
+
+, "The grant to directly add events into this resource calendar"
+: ""
+
+, "Read Events"
+: ""
+
+, "The grant to read events from this resource calendar"
+: ""
+
+, "Export Events"
+: ""
+
+, "The grant to export events from this resource calendar"
+: ""
+
+, "Sync Events"
+: ""
+
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
+: ""
+
+, "Events Free Busy"
+: ""
+
+, "The grant to get free/busy information of events from this resource calendar"
+: ""
+
+, "Edit Events"
+: ""
+
+, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
+: ""
+
+, "Delete Events"
+: ""
+
+, "The grant to delete events directly stored in this resource calendar"
+: ""
+
+, "Free Busy"
+: ""
+
+, "The grant to get free/busy information of events in this calendar"
+: ""
+
+, "The grant to access events marked as private in this calendar"
+: ""
+
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: ""
+
+, "Role"
+: ""
+
+, "Select Role"
+: ""
+
+, "Status"
+: ""
+
+, "Select Status"
+: ""
+
+, "Adding {0} Attendee to event"
+: ""
+
+, "no events found"
+: ""
+
+, "Searching..."
+: ""
+
+, "Search Event"
+: ""
+
+, "Event, Events"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Additional Tags ..."
+: ""
+
+, "non-blocking"
+: ""
+
+, "Displayed in"
+: ""
+
+, "No Information"
+: ""
+
+, "Event Location"
+: ""
+
+, "From"
+: ""
+
+, "until"
+: ""
+
+, "Events"
+: ""
+
+, "Calendars"
+: ""
+
+, "Quick Search"
+: ""
+
+, "GENDER_Calendar"
+: ""
+
+, "Attendee Status"
+: ""
+
+, "GENDER_Attendee Status"
+: ""
+
+, "Attendee Role"
+: ""
+
+, "GENDER_Attendee Role"
+: ""
+
+, "GENDER_Status"
+: ""
+
+, "GENDER_Blocking"
+: ""
+
+, "Classification"
+: ""
+
+, "GENDER_Classification"
+: ""
+
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
+, "Unknown date"
+: ""
+
+, "{0} {1} o'clock"
+: ""
+
+, "Event (as attendee)"
+: ""
+
+, "Event (as organizer)"
+: ""
+
+, "Event attendee"
+: ""
+
+, "Attender, Attendee"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Resource, Resources"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Resources"
+: ""
+
+, "Anyone"
+: ""
+
+, "Name"
+: ""
+
+, "Calendar Hierarchy/Name"
+: ""
+
+, "Email"
+: ""
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: ""
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: ""
+
+, "User"
+: ""
+
+, "Group"
+: ""
+
+, "Member of group"
+: ""
+
+, "This is the calendar where the attender has saved this event in"
+: ""
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: ""
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: ""
+
+, "External Attendee"
+: ""
+
+, "Originally"
+: ""
+
+, "Checking Calendar Data..."
+: ""
+
+, "Reply to Recurring Event"
+: ""
+
+, "You are responding to an recurring event. What would you like to do?"
+: ""
+
+, "Respond to whole series"
+: ""
+
+, "Do not respond"
+: ""
+
+, "The event of this message does not exist"
+: ""
+
+, "The sender is not authorised to update the event"
+: ""
+
+, "This message is already processed"
+: ""
+
+, "You are not an attendee of this event"
+: ""
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: ""
+
+, "This is an event invitation for someone else."
+: ""
+
+, "You have already replied to this event invitation."
+: ""
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: ""
+
+, "An invited attendee responded to the invitation."
+: ""
+
+, "Unsupported method"
+: ""
+
+, "Suppress notification"
+: ""
+
+, "Color"
+: ""
+
+, "Enter description..."
+: ""
+
+, "Grants"
+: ""
+
+, "This event is originally stored in a calendar you don't have access to."
+: ""
+
+, "This event is originally stored in {0}"
+: ""
+
+, "This event is additionally displayed in your personal calendar {0}"
+: ""
+
+, "Colors"
+: ""
+
+, "Side bar color"
+: ""
+
+, "Color by Calendar"
+: ""
+
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: ""
+
+, "Saved in"
+: ""
+
+, "Enter description"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: ""
+
+, "End date must be after start date"
+: ""
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: ""
+
+, "Start date is not allowed to be before the configured time."
+: ""
+
+, "The summary must not be longer than 255 characters."
+: ""
+
+, "The summary must have at least 1 character."
+: ""
+
+, "Summary too Long"
+: ""
+
+, "Summary too Short"
+: ""
+
+, "Set This Date as Definite Event?"
+: ""
+
+, "Do you want to close the poll and remove all other alternatives?"
+: ""
+
+, "Attendee/Resources"
+: ""
+
+, "Additional Attendees ..."
+: ""
+
+, "Default Status"
+: ""
+
+, "No Access"
+: ""
+
+, "All my events"
+: ""
+
+, "Position on the left time axis, day and week view should start with"
 : ""
 
 , "Position on the left time axis, day and week view should end with"
@@ -64,6 +1110,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Get notifications emails for actions you did yourself"
 : ""
 
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
 , "Send Alarm Notifications Emails"
 : ""
 
@@ -133,1032 +1185,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "On attendee responses too"
 : ""
 
-, "Events"
-: ""
-
-, "Summary"
-: ""
-
-, "Status"
-: ""
-
-, "No Information"
-: ""
-
-, "recurring event"
-: ""
-
-, "recurring event exception"
-: ""
-
-, "Blocking"
-: ""
-
-, "Tentative"
-: ""
-
-, "Location"
-: ""
-
-, "Organizer"
-: ""
-
-, "Attendee"
-: ""
-
-, "Add attendee"
-: ""
-
-, "Sort Attendee"
-: ""
-
-, "Check to filter for this attendee"
-: ""
-
-, "Attachments"
-: ""
-
-, "Private"
-: ""
-
-, "Tags"
-: ""
-
-, "whole day"
-: ""
-
-, "Description"
-: ""
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: ""
-
-, "This event is originally stored in {0}"
-: ""
-
-, "This event is additionally displayed in your personal calendar {0}"
-: ""
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: ""
-
-, "Role"
-: ""
-
-, "Select Role"
-: ""
-
-, "Select Status"
-: ""
-
-, "Adding {0} Attendee to event"
-: ""
-
-, "Checking Calendar Data..."
-: ""
-
-, "Reply to Recurring Event"
-: ""
-
-, "You are responding to an recurring event. What would you like to do?"
-: ""
-
-, "Respond to whole series"
-: ""
-
-, "Do not respond"
-: ""
-
-, "The event of this message does not exist"
-: ""
-
-, "The sender is not authorised to update the event"
-: ""
-
-, "This message is already processed"
-: ""
-
-, "You are not an attendee of this event"
-: ""
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: ""
-
-, "This is an event invitation for someone else."
-: ""
-
-, "You have already replied to this event invitation."
-: ""
-
-, "You received an event invitation. Set your response to:"
-: ""
-
-, "An invited attendee responded to the invitation."
-: ""
-
-, "Unsupported method"
-: ""
-
-, "Loading events, please wait..."
-: ""
-
-, "Cut event"
-: ""
-
-, "Copy Event to clipboard"
-: ""
-
-, "Stop cut / copy & paste"
-: ""
-
-, "Print Page"
-: ""
-
-, "Loose-Leaf"
-: ""
-
-, "Sheet"
-: ""
-
-, "Grid"
-: ""
-
-, "Timeline"
-: ""
-
-, "Day"
-: ""
-
-, "Week"
-: ""
-
-, "Month"
-: ""
-
-, "Year"
-: ""
-
-, "Import Events"
-: ""
-
-, "Paste event \"{0}\""
-: ""
-
-, "Set my response"
-: ""
-
-, "Copy {0}"
-: ""
-
-, "Updating event in the past"
-: ""
-
-, "Update this event"
-: ""
-
-, "Do not update this event"
-: ""
-
-, "Creating event in the past"
-: ""
-
-, "Create this event"
-: ""
-
-, "Do not create this event"
-: ""
-
-, "Update this event only"
-: ""
-
-, "Update this and all future events"
-: ""
-
-, "Update whole series"
-: ""
-
-, "Update nothing"
-: ""
-
-, "Update Event"
-: ""
-
-, "Please Change Selection"
-: ""
-
-, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
-: ""
-
-, "Delete Event"
-: ""
-
-, "Delete this event only"
-: ""
-
-, "Delete this and all future events"
-: ""
-
-, "Delete whole series"
-: ""
-
-, "Delete nothing"
-: ""
-
-, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
-: [
-  ""
- ,""
-
-]
-, "Could not Print"
-: ""
-
-, "Sorry, your current view does not support printing."
-: ""
-
-, "Scheduling Conflict"
-: ""
-
-, "The following attendee are busy at the requested time:"
-: ""
-
-, "Ignore Conflict"
-: ""
-
-, "Edit Event"
-: ""
-
-, "Cancel this action"
-: ""
-
-, "Manage Resources"
-: ""
-
-, "Import Definition Success!"
-: ""
-
-, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
-: ""
-
-, "Choose Import File"
-: ""
-
-, "Please choose the file that contains the records you want to add to Tine 2.0"
-: ""
-
-, "Select file containing your {0}"
-: ""
-
-, "once"
-: ""
-
-, "hourly"
-: ""
-
-, "daily"
-: ""
-
-, "weekly"
-: ""
-
-, "Choose Remote Location"
-: ""
-
-, "Please choose a remote location you want to add to Tine 2.0"
-: ""
-
-, "Username"
-: ""
-
-, "Password"
-: ""
-
-, "Refresh time"
-: ""
-
-, "General Settings"
-: ""
-
-, "Calendar name (you need permissions to add events)"
-: ""
-
-, "What should the file you upload look like?"
-: ""
-
-, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
-: ""
-
-, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
-: ""
-
-, "Please select the import format of the file you want to upload"
-: ""
-
-, "Download example file"
-: ""
-
-, "Remote / ICS"
-: ""
-
-, "Remote / CalDAV (BETA)"
-: ""
-
-, "Upload"
-: ""
-
-, "Choose File and Format"
-: ""
-
-, "Select type of source"
-: ""
-
-, "Please select the type of source you want to add to Tine 2.0"
-: ""
-
-, "Importing {0}"
-: ""
-
-, "Back"
-: ""
-
-, "Next"
-: ""
-
-, "Options"
-: ""
-
-, "Free Time Search"
-: ""
-
-, "Searching for Free Time..."
-: ""
-
-, "No Free Time found"
-: ""
-
-, "No free timeslot could be found Until {0}. Do you want to continue?"
-: ""
-
-, "Continue"
-: ""
-
-, "Give up"
-: ""
-
-, "Free Time Search Options"
-: ""
-
-, "View"
-: ""
-
-, "Details"
-: ""
-
-, "Saved in"
-: ""
-
-, "non-blocking"
-: ""
-
-, "Enter description"
-: ""
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: ""
-
-, "End date must be after start date"
-: ""
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: ""
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: ""
-
-, "Originally"
-: ""
-
-, "Poll, Polls"
-: [
-  ""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: ""
-
-, "Rrule"
-: ""
-
-, "Daily"
-: ""
-
-, "Weekly"
-: ""
-
-, "Monthly"
-: ""
-
-, "Yearly"
-: ""
-
-, "Name"
-: ""
-
-, "Email"
-: ""
-
-, "Type"
-: ""
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: ""
-
-, "{0} more..."
-: ""
-
-, "private classification"
-: ""
-
-, "has alarm"
-: ""
-
-, "has attachments"
-: ""
-
-, "is part of an open poll"
-: ""
-
-, "{0}, the {1}. of {2}"
-: ""
-
-, "Click here to invite another attender..."
-: ""
-
-, "User"
-: ""
-
-, "Group"
-: ""
-
-, "Resource, Resources"
-: [
-  ""
- ,""
-
-]
-, "Member of group"
-: ""
-
-, "This is the calendar where the attender has saved this event in"
-: ""
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: ""
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: ""
-
-, "External Attendee"
-: ""
-
-, "Resource Grant, Resource Grants"
-: [
-  ""
- ,""
-
-]
-, "Invite Resource"
-: ""
-
-, "The grant to invite the resource to an event"
-: ""
-
-, "Read Resource"
-: ""
-
-, "The grant to read the resource itself"
-: ""
-
-, "The grant to edit the resource itself"
-: ""
-
-, "Export Resource"
-: ""
-
-, "The grant to export the resource itself"
-: ""
-
-, "Sync Resource"
-: ""
-
-, "The grant to synchronise the resource itself"
-: ""
-
-, "Resource Admin"
-: ""
-
-, "The grant to administrate the resource itself"
-: ""
-
-, "Add Events"
-: ""
-
-, "The grant to directly add events into this resource calendar"
-: ""
-
-, "Read Events"
-: ""
-
-, "The grant to read events from this resource calendar"
-: ""
-
-, "Export Events"
-: ""
-
-, "The grant to export events from this resource calendar"
-: ""
-
-, "Sync Events"
-: ""
-
-, "The grant to synchronise events from this resource calendar"
-: ""
-
-, "Events Free Busy"
-: ""
-
-, "The grant to get free/busy information of events from this resource calendar"
-: ""
-
-, "Edit Events"
-: ""
-
-, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
-: ""
-
-, "Delete Events"
-: ""
-
-, "The grant to delete events directly stored in this resource calendar"
-: ""
-
-, "Free Busy"
-: ""
-
-, "The grant to get free/busy information of events in this calendar"
-: ""
-
-, "The grant to access events marked as private in this calendar"
-: ""
-
-, "no events found"
-: ""
-
-, "Searching..."
-: ""
-
-, "Event, Events"
-: [
-  ""
- ,""
-
-]
-, "Search Event"
-: ""
-
-, "Switch to public poll"
-: ""
-
-, "Welcome {name}"
-: ""
-
-, "This is a closed poll. No Attendee can be added."
-: ""
-
-, "This poll is closed already"
-: ""
-
-, "I am not {name}"
-: ""
-
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: ""
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  ""
- ,""
-
-]
-, "Calendars"
-: ""
-
-, "Quick Search"
-: ""
-
-, "GENDER_Calendar"
-: ""
-
-, "Attendee Status"
-: ""
-
-, "GENDER_Attendee Status"
-: ""
-
-, "Attendee Role"
-: ""
-
-, "GENDER_Attendee Role"
-: ""
-
-, "GENDER_Status"
-: ""
-
-, "GENDER_Blocking"
-: ""
-
-, "Classification"
-: ""
-
-, "GENDER_Classification"
-: ""
-
-, "Unknown date"
-: ""
-
-, "{0} {1} o'clock"
-: ""
-
-, "Event (as attendee)"
-: ""
-
-, "Event (as organizer)"
-: ""
-
-, "Event attendee"
-: ""
-
-, "Attender, Attendee"
-: [
-  ""
- ,""
-
-]
-, "Anyone"
-: ""
-
-, "Default attendee status"
-: ""
-
-, "Calendar Hierarchy/Name"
-: ""
-
-, "Suppress notification"
-: ""
-
-, "Enter description..."
-: ""
-
-, "Grants"
-: ""
-
-, "Displayed in"
-: ""
-
-, "Event not found"
-: ""
-
-, "The Event was deleted in the meantime or you don't have access rights to it."
-: ""
-
-, "GENDER_Attendee"
-: ""
-
-, "Select Attendee"
-: ""
-
-, "The summary must not be longer than 255 characters."
-: ""
-
-, "The summary must have at least 1 character."
-: ""
-
-, "Summary too Long"
-: ""
-
-, "Summary too Short"
-: ""
-
-, "Recurrances"
-: ""
-
-, "No recurring rule defined"
-: ""
-
-, "None"
-: ""
-
-, "Exceptions of reccuring events can't have recurrences themselves."
-: ""
-
-, "at"
-: ""
-
-, "never"
-: ""
-
-, "after {0} occurrences"
-: ""
-
-, "Except"
-: ""
-
-, "during events in the calendars"
-: ""
-
-, "End"
-: ""
-
-, "Until has to be after event start"
-: ""
-
-, "The event is longer than the recurring interval"
-: ""
-
-, "Every {0}. Day"
-: ""
-
-, "Every {0}. Week at"
-: ""
-
-, "Every {0}. Month"
-: ""
-
-, "at the"
-: ""
-
-, "first"
-: ""
-
-, "second"
-: ""
-
-, "third"
-: ""
-
-, "fourth"
-: ""
-
-, "last"
-: ""
-
-, "Every {0}. Year"
-: ""
-
-, "of"
-: ""
-
-, "First name, ĺast name"
-: ""
-
-, "E-Mail address"
-: ""
-
-, "Please wait..."
-: ""
-
-, "General terms and conditions"
-: ""
-
-, "Relation, Relations"
-: [
-  ""
- ,""
-
-]
-, "All events I attend"
-: ""
-
-, "Required"
-: ""
-
-, "Optional"
-: ""
-
-, "No response"
-: ""
-
-, "Accepted"
-: ""
-
-, "Declined"
-: ""
-
-, "Awaiting response"
-: ""
-
-, "Events I have not yet responded to"
-: ""
-
-, "Declined events"
-: ""
-
-, "Events I have declined"
-: ""
-
-, "I'm organizer"
-: ""
-
-, "Events I'm the organizer of"
-: ""
-
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : ""
 
@@ -1222,12 +1248,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: ""
+
+, "Accepted"
+: ""
+
+, "Declined"
+: ""
+
 , "Attendee Roles Available"
 : ""
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: ""
+
+, "Optional"
+: ""
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1237,6 +1281,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1279,6 +1353,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1330,6 +1407,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1369,94 +1449,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
+, "User Additional Filters"
 : ""
 
-, "Event invitation \"%1$s\" at %2$s"
+, "Group Additional Filters"
 : ""
 
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "Resource Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+, "%s's personal calendar"
 : ""
 
-, "Event \"%1$s\" at %2$s has been updated"
+, "Failed"
 : ""
 
-, "%1$s accepted event \"%2$s\" at %3$s"
+, "The right Resource Admin must be set once."
 : ""
 
-, "%1$s declined event \"%2$s\" at %3$s"
+, "Different Calendar"
 : ""
 
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+, "Exdate container move are not allowed"
 : ""
 
-, "No response from %1$s for event \"%2$s\" at %3$s"
+, "Invalid URL given"
 : ""
 
-, "Attendee changes for event \"%1$s\" at %2$s"
+, "The URL you used is invalid. Please use a valid one!"
 : ""
 
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Calendars to export"
 : ""
 
-, "Resource Management"
+, "Export target"
 : ""
 
-, "Polls for recurring events are not supported"
+, "VCalendar/ICS"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "Export visible events to ics file"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "Excel overview"
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Word event sheet"
 : ""
 
-, "Start"
+, "Export Events as Calendar Sheet"
 : ""
 
-, "Priority"
+, "VCalendar Report"
 : ""
 
-, "Url"
+, "Export multiple calendars to ics files"
 : ""
 
-, "Recurrance rule"
+, "OpenDocument all data"
 : ""
 
-, "Is all day event"
+, "Export event data into ods spreadsheet"
 : ""
 
-, "Organizer timezone"
+, "Word details"
 : ""
 
-, "No"
+, "Excel all data"
 : ""
 
-, "Yes"
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
 : ""
 
 , "unknown"
@@ -1516,34 +1605,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: ""
+
+, "Priority"
+: ""
+
+, "Url"
+: ""
+
+, "Recurrance rule"
+: ""
+
+, "Is all day event"
+: ""
+
+, "Organizer timezone"
+: ""
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
 : ""
 
-, "Excel overview"
+, "Event invitation \"%1$s\" at %2$s"
 : ""
 
-, "OpenDocument all data"
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Event \"%1$s\" at %2$s has been canceled"
 : ""
 
-, "Word event sheet"
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "Event \"%1$s\" at %2$s has been updated"
 : ""
 
-, "Excel all data"
+, "%1$s accepted event \"%2$s\" at %3$s"
 : ""
 
-, "Import iCal-files"
+, "%1$s declined event \"%2$s\" at %3$s"
+: ""
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: ""
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: ""
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
+: ""
+
+, "Attendee changes for event \"%1$s\" at %2$s"
+: ""
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
+: ""
+
+, "Unknown action"
+: ""
+
+, "Resource Management"
+: ""
+
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+: ""
+
+, "Polls for recurring events are not supported"
+: ""
+
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1582,31 +1740,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : ""
 
-, "The poll \"%1$s\" has been closed."
+, "All events I attend"
 : ""
 
-, "The definite event is scheduled for \"%1$s\""
+, "Awaiting response"
 : ""
 
-, "You can review the poll results here:"
+, "Events I have not yet responded to"
 : ""
 
-, "Thank you for attendening the poll \"%1$s\""
+, "Declined events"
 : ""
 
-, "To review or edit your status please use your personal link:"
+, "Events I have declined"
 : ""
 
-, "Different Calendar"
+, "I'm organizer"
 : ""
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
+, "Events I'm the organizer of"
 : ""
 
 , "manage shared calendars"
@@ -1627,67 +1779,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : ""
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Do you really want to delete this event?"
-: ""
+, "Relation, Relations"
+: [
+  ""
+ ,""
+ ,""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
+, "Calendar"
+: ""
+
+, "Do you really want to delete this event?"
 : ""
 
 , "Resource Grant"
@@ -1696,10 +1832,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : ""
 
-, "Calendar"
+, "Attender"
 : ""
 
-, "Attender"
+, "Resource"
 : ""
 
 , "Relation"
