@@ -5,167 +5,253 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "%s osobni kalendar"
+, "{0}, the {1}. of {2}"
+: "{0}, {1}. {2}"
 
-, "Resources"
-: "Resursi"
+, "Recurrances"
+: "Ponavljanja"
 
-, "All my events"
-: "Svi moji događaji"
+, "No recurring rule defined"
+: "Niti jedno pravilo ponavljanja nije definirano"
 
-, "Start Time"
-: "Početno vrijeme"
+, "Details"
+: "Detalji"
 
-, "Position on the left time axis, day and week view should start with"
-: "Pozicija na lijevoj strani vremenske osi, dan i tjedan s kojim bi pregled trebao započeti"
+, "None"
+: "Niti jedno"
 
-, "End Time"
-: "Završno vrijeme"
+, "Daily"
+: "Dnevno"
 
-, "Position on the left time axis, day and week view should end with"
+, "Weekly"
+: "Tjedno"
+
+, "Monthly"
+: "Mjesečno"
+
+, "Yearly"
+: "Godišnje"
+
+, "Exceptions of reccuring events can't have recurrences themselves."
+: "Iznimke od ponavljajućeg događaja ne mogu i same imati ponavljanja"
+
+, "at"
+: "u"
+
+, "never"
+: "nikad"
+
+, "after {0} occurrences"
+: "nakon {0} pojavljivanja"
+
+, "Except"
 : ""
 
-, "Default Start Time"
+, "during events in the calendars"
 : ""
 
-, "Scroll position on the left time axis, day and week view should start with"
+, "End"
+: "Kraj"
+
+, "Until has to be after event start"
+: "Do mora biti nakon početka događaja"
+
+, "The event is longer than the recurring interval"
 : ""
 
-, "Visible Time"
-: ""
+, "Every {0}. Day"
+: "Svaki {0}. dan"
 
-, "Time to be displayed at once"
-: ""
+, "Every {0}. Week at"
+: "Svaki {0}. tjedan u"
 
-, "Default Calendar"
-: "Početni kalendar"
+, "Every {0}. Month"
+: "Svaki {0}. mjesec"
 
-, "The default calendar for invitations and new events"
-: "Početni kalendar za pozivnice i nove događaje"
+, "at the"
+: "u"
 
-, "Default Favorite"
-: "Početni favorit"
+, "first"
+: "prvi"
 
-, "The default favorite which is loaded on calendar startup"
-: "Početni favorit koji se učitava prilikom starta kalendara"
+, "second"
+: "drugi"
 
-, "Get Notification Emails"
-: "Zaprimanje email obavijesti"
+, "third"
+: "treći"
 
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "Nivo akcija za koje želite biti obavijesšteni. Uzmite u obzir da će organizator biti obaviješten o svim izmjenama uključujući odogovre sudionika ukoliko nije odabrana opcija \"Nikada\""
+, "fourth"
+: "četvrti"
 
-, "Send Notifications Emails of own Actions"
-: "Slanje email obavijesti o vlastitim akcijama"
+, "last"
+: "zadnji"
 
-, "Get notifications emails for actions you did yourself"
-: "Zaprimanje email obavijesti o akcijama koje ste sami napravili"
+, "Every {0}. Year"
+: "Svake {0}. godine"
 
-, "Send Alarm Notifications Emails"
-: ""
-
-, "Get event alarms via email"
-: ""
-
-, "Enable Standard Alarm"
-: "Omogućiti standardni alarm"
-
-, "New events get a standard alarm as defined below"
-: "Novi događaji dobije standardni alarm kao što je definirano u nastavku"
-
-, "Standard Alarm Time"
-: "Standardna vrijeme alarma"
-
-, "Minutes before the event starts"
-: "Minuta prije nego događaj započne"
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "Fiksni kalendar"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: "Nikada"
-
-, "On invitation and cancellation only"
-: "Samo kod pozivanja i otkazivanja"
-
-, "On time changes"
-: "Na promjeni vrijemena"
-
-, "On all updates but attendee responses"
-: "Na svim promjenama, ali odgovora sudionika"
-
-, "On attendee responses too"
-: "Na sudionik odgovora isto"
-
-, "Events"
-: "Događaji"
+, "of"
+: "od"
 
 , "Summary"
 : "Sažetak"
 
-, "Status"
-: "Status"
+, "Organizer"
+: "Organizator"
 
-, "No Information"
-: "Nema informacija"
-
-, "recurring event"
-: "ponavljajući događaj"
-
-, "recurring event exception"
-: "iznimka od ponavljanja događaja"
-
-, "Blocking"
-: "Blokirajući"
-
-, "Tentative"
-: "Uvjetan"
+, "Description"
+: "Opis"
 
 , "Location"
 : "Lokacija"
 
-, "Organizer"
-: "Organizator"
+, "Start Time"
+: "Početno vrijeme"
+
+, "End Time"
+: "Završno vrijeme"
 
 , "Attendee"
 : "Sudionik"
 
+, "whole day"
+: "cijeli dan"
+
+, "Week {0} :"
+: "Tjedan {0}:"
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Novi događaj"
+
+, "Calendar, Calendars"
+: [
+  "Kalendar"
+ ,"Kalendara"
+ ,"Kalendara"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : "Dodaj sudionike"
 
@@ -175,117 +261,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : "Označite za filtriranje ovog sudionika"
 
-, "Attachments"
+, "Unavailable"
 : ""
 
-, "Private"
-: "Privatno"
-
-, "Tags"
-: "Oznake"
-
-, "whole day"
-: "cijeli dan"
-
-, "Description"
-: "Opis"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: "Ovaj događaj je izvorno pohranjen u kalendaru u koji nemate pristup."
-
-, "This event is originally stored in {0}"
-: "Ovaj događaj je izvorno pohranjen u {0}"
-
-, "This event is additionally displayed in your personal calendar {0}"
-: "Ovaj događaj dodatno je prikazan u tvoj osobni kalendar {0}"
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: "Molimo izaberite događaj za dodavanje kontakata"
-
-, "Role"
-: "Uloga"
-
-, "Select Role"
-: "Odaberite ulogu"
-
-, "Select Status"
-: "Odaberite status"
-
-, "Adding {0} Attendee to event"
-: "Dodavanje {0} sudionika na događaju"
-
-, "Checking Calendar Data..."
-: "Provjera podataka kalendara..."
-
-, "Reply to Recurring Event"
-: "Odgovor na ponavljajući događaj"
-
-, "You are responding to an recurring event. What would you like to do?"
-: "Vi ste reagirati na ponavljajući događaj. Što želite učiniti?"
-
-, "Respond to whole series"
-: "Odgovorite na cijelom nizu"
-
-, "Do not respond"
-: "Ne reagira"
-
-, "The event of this message does not exist"
-: "Događaj ove poruke ne postoji"
-
-, "The sender is not authorised to update the event"
-: "Pošiljatelj nije ovlašten ažurirati događaj"
-
-, "This message is already processed"
-: "Ova poruka je već obrađena"
-
-, "You are not an attendee of this event"
-: "Niste sudionik ovog događaja"
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: "Nepodržana poruka"
-
-, "This is an event invitation for someone else."
-: "Ovo je događaj namijenjen za nekoga drugog."
-
-, "You have already replied to this event invitation."
-: "Već ste odgovorili na ovaj poziv."
-
-, "You received an event invitation. Set your response to:"
-: "Dobili ste pozivnicu za događaj. Postavite svoj ​​odgovor na:"
-
-, "An invited attendee responded to the invitation."
-: "Pozvani sudionik odazvao se pozivu."
-
-, "Unsupported method"
-: "Nepodržana metoda"
-
 , "Loading events, please wait..."
 : "Učitavanje događaja, molimo pričekajte..."
 
@@ -325,6 +303,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +318,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : "Kopiraj {0}"
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : "Ažuriranje događaja u prošlosti"
 
@@ -419,9 +403,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : "Otkaži ovu akciju"
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Upravljanje resursima"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Odaberite sudionika"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Privatno"
+
+, "Tags"
+: "Oznake"
+
+, "Blocking"
+: "Blokirajući"
+
+, "Tentative"
+: "Uvjetan"
+
 , "Import Definition Success!"
 : ""
 
@@ -458,9 +469,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -512,7 +520,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -536,157 +544,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: "Pregled"
-
-, "Details"
-: "Detalji"
-
-, "Saved in"
-: "Spremljeno u"
-
-, "non-blocking"
-: "nije blokirajući"
-
-, "Enter description"
-: "Unesite opis"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "Datum završetka nije pravilan"
-
-, "End date must be after start date"
-: "Datum završetka mora biti poslije datuma početka"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "Datum početka nije pravilan"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: "Tjedan {0}:"
-
-, "Originally"
-: "Izvorno"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "Td"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Dnevno"
-
-, "Weekly"
-: "Tjedno"
-
-, "Monthly"
-: "Mjesečno"
-
-, "Yearly"
-: "Godišnje"
-
-, "Name"
-: "Ime"
-
-, "Email"
-: "Email"
-
-, "Type"
-: "Tip"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Novi događaj"
-
-, "{0} more..."
-: "{0} više..."
-
 , "private classification"
 : "privatna klasifikacija"
 
+, "recurring event"
+: "ponavljajući događaj"
+
+, "recurring event exception"
+: "iznimka od ponavljanja događaja"
+
 , "has alarm"
 : "ima alarm"
 
@@ -696,63 +562,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, {1}. {2}"
+, "Mini Calendar"
+: "Mini Kalendar"
 
-, "Click here to invite another attender..."
-: "Kliknite ovdje za pozivanje drugih sudionika"
+, "WK"
+: "Td"
 
-, "User"
-: "Korisnik"
-
-, "Group"
-: "Grupa"
-
-, "Resource, Resources"
-: [
-  "Resurs"
- ,"Resursa"
- ,"Resursa"
-
-]
-, "Member of group"
-: "Član grupe"
-
-, "This is the calendar where the attender has saved this event in"
-: "Ovo je kalendar u koji je sudionik spremio ovaj događaj"
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Ukloni sudionika"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(kao član grupe)"
-
-, "External Attendee"
-: "Vanjski sudionici"
+, "{0} more..."
+: "{0} više..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -773,6 +590,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -815,7 +635,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -845,12 +665,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: "Molimo izaberite događaj za dodavanje kontakata"
+
+, "Role"
+: "Uloga"
+
+, "Select Role"
+: "Odaberite ulogu"
+
+, "Status"
+: "Status"
+
+, "Select Status"
+: "Odaberite status"
+
+, "Adding {0} Attendee to event"
+: "Dodavanje {0} sudionika na događaju"
+
 , "no events found"
 : "Događaji nisu pronađeni"
 
 , "Searching..."
 : "Tražim..."
 
+, "Search Event"
+: "Traži događaje"
+
 , "Event, Events"
 : [
   "Događaj"
@@ -858,91 +702,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Događaja"
 
 ]
-, "Search Event"
-: "Traži događaje"
-
-, "Switch to public poll"
+, "Additional Tags ..."
 : ""
 
-, "Welcome {name}"
+, "non-blocking"
+: "nije blokirajući"
+
+, "Displayed in"
+: "Prikaži u"
+
+, "No Information"
+: "Nema informacija"
+
+, "Event Location"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "From"
 : ""
 
-, "This poll is closed already"
+, "until"
 : ""
 
-, "I am not {name}"
-: ""
+, "Events"
+: "Događaji"
 
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Mini Kalendar"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Kalendar"
- ,"Kalendara"
- ,"Kalendara"
-
-]
 , "Calendars"
 : "Kalendari"
 
@@ -976,6 +759,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -998,38 +793,240 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Sudionika"
 
 ]
+, "Resource, Resources"
+: [
+  "Resurs"
+ ,"Resursa"
+ ,"Resursa"
+
+]
+, "Resources"
+: "Resursi"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Ime"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "Email"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Tip"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Kliknite ovdje za pozivanje drugih sudionika"
+
+, "User"
+: "Korisnik"
+
+, "Group"
+: "Grupa"
+
+, "Member of group"
+: "Član grupe"
+
+, "This is the calendar where the attender has saved this event in"
+: "Ovo je kalendar u koji je sudionik spremio ovaj događaj"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Ukloni sudionika"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(kao član grupe)"
+
+, "External Attendee"
+: "Vanjski sudionici"
+
+, "Originally"
+: "Izvorno"
+
+, "Checking Calendar Data..."
+: "Provjera podataka kalendara..."
+
+, "Reply to Recurring Event"
+: "Odgovor na ponavljajući događaj"
+
+, "You are responding to an recurring event. What would you like to do?"
+: "Vi ste reagirati na ponavljajući događaj. Što želite učiniti?"
+
+, "Respond to whole series"
+: "Odgovorite na cijelom nizu"
+
+, "Do not respond"
+: "Ne reagira"
+
+, "The event of this message does not exist"
+: "Događaj ove poruke ne postoji"
+
+, "The sender is not authorised to update the event"
+: "Pošiljatelj nije ovlašten ažurirati događaj"
+
+, "This message is already processed"
+: "Ova poruka je već obrađena"
+
+, "You are not an attendee of this event"
+: "Niste sudionik ovog događaja"
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: "Nepodržana poruka"
+
+, "This is an event invitation for someone else."
+: "Ovo je događaj namijenjen za nekoga drugog."
+
+, "You have already replied to this event invitation."
+: "Već ste odgovorili na ovaj poziv."
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: "Dobili ste pozivnicu za događaj. Postavite svoj ​​odgovor na:"
+
+, "An invited attendee responded to the invitation."
+: "Pozvani sudionik odazvao se pozivu."
+
+, "Unsupported method"
+: "Nepodržana metoda"
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Unesite opis..."
 
 , "Grants"
 : "Dozvole"
 
-, "Displayed in"
-: "Prikaži u"
+, "This event is originally stored in a calendar you don't have access to."
+: "Ovaj događaj je izvorno pohranjen u kalendaru u koji nemate pristup."
 
-, "Event not found"
+, "This event is originally stored in {0}"
+: "Ovaj događaj je izvorno pohranjen u {0}"
+
+, "This event is additionally displayed in your personal calendar {0}"
+: "Ovaj događaj dodatno je prikazan u tvoj osobni kalendar {0}"
+
+, "Colors"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "Side bar color"
 : ""
 
-, "GENDER_Attendee"
+, "Color by Calendar"
 : ""
 
-, "Select Attendee"
-: "Odaberite sudionika"
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: "Pregled"
+
+, "Saved in"
+: "Spremljeno u"
+
+, "Enter description"
+: "Unesite opis"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "Datum završetka nije pravilan"
+
+, "End date must be after start date"
+: "Datum završetka mora biti poslije datuma početka"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "Datum početka nije pravilan"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : "Sažetak ne smije biti duže od 255 znakova."
@@ -1043,129 +1040,143 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : "Sažetak je prekratak"
 
-, "Recurrances"
-: "Ponavljanja"
-
-, "No recurring rule defined"
-: "Niti jedno pravilo ponavljanja nije definirano"
-
-, "None"
-: "Niti jedno"
-
-, "Exceptions of reccuring events can't have recurrences themselves."
-: "Iznimke od ponavljajućeg događaja ne mogu i same imati ponavljanja"
-
-, "at"
-: "u"
-
-, "never"
-: "nikad"
-
-, "after {0} occurrences"
-: "nakon {0} pojavljivanja"
-
-, "Except"
+, "Set This Date as Definite Event?"
 : ""
 
-, "during events in the calendars"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "End"
-: "Kraj"
-
-, "Until has to be after event start"
-: "Do mora biti nakon početka događaja"
-
-, "The event is longer than the recurring interval"
+, "Attendee/Resources"
 : ""
 
-, "Every {0}. Day"
-: "Svaki {0}. dan"
-
-, "Every {0}. Week at"
-: "Svaki {0}. tjedan u"
-
-, "Every {0}. Month"
-: "Svaki {0}. mjesec"
-
-, "at the"
-: "u"
-
-, "first"
-: "prvi"
-
-, "second"
-: "drugi"
-
-, "third"
-: "treći"
-
-, "fourth"
-: "četvrti"
-
-, "last"
-: "zadnji"
-
-, "Every {0}. Year"
-: "Svake {0}. godine"
-
-, "of"
-: "od"
-
-, "First name, ĺast name"
+, "Additional Attendees ..."
 : ""
 
-, "E-Mail address"
+, "Default Status"
 : ""
 
-, "Please wait..."
+, "No Access"
 : ""
 
-, "General terms and conditions"
+, "All my events"
+: "Svi moji događaji"
+
+, "Position on the left time axis, day and week view should start with"
+: "Pozicija na lijevoj strani vremenske osi, dan i tjedan s kojim bi pregled trebao započeti"
+
+, "Position on the left time axis, day and week view should end with"
 : ""
 
-, "Relation, Relations"
-: [
-  ""
- ,""
- ,""
+, "Default Start Time"
+: ""
 
-]
-, "All events I attend"
-: "Svi događaji kojima sam prisustvovao"
+, "Scroll position on the left time axis, day and week view should start with"
+: ""
 
-, "Required"
-: "Obavezno"
+, "Visible Time"
+: ""
 
-, "Optional"
-: "Opcionalno"
+, "Time to be displayed at once"
+: ""
 
-, "No response"
-: "Bez odgovora"
+, "Default Calendar"
+: "Početni kalendar"
 
-, "Accepted"
-: "Prihvaćeno"
+, "The default calendar for invitations and new events"
+: "Početni kalendar za pozivnice i nove događaje"
 
-, "Declined"
-: "Odbijeno"
+, "Default Favorite"
+: "Početni favorit"
 
-, "Awaiting response"
-: "U čekanju odgovora"
+, "The default favorite which is loaded on calendar startup"
+: "Početni favorit koji se učitava prilikom starta kalendara"
 
-, "Events I have not yet responded to"
-: "Događaji na koje nisam odgovorio"
+, "Get Notification Emails"
+: "Zaprimanje email obavijesti"
 
-, "Declined events"
-: "Odbijeni događaji"
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "Nivo akcija za koje želite biti obavijesšteni. Uzmite u obzir da će organizator biti obaviješten o svim izmjenama uključujući odogovre sudionika ukoliko nije odabrana opcija \"Nikada\""
 
-, "Events I have declined"
-: "Događaji koje sam odbio"
+, "Send Notifications Emails of own Actions"
+: "Slanje email obavijesti o vlastitim akcijama"
 
-, "I'm organizer"
-: "Ja sam organizator"
+, "Get notifications emails for actions you did yourself"
+: "Zaprimanje email obavijesti o akcijama koje ste sami napravili"
 
-, "Events I'm the organizer of"
-: "Događaji koje sam ja organizirao"
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
+, "Send Alarm Notifications Emails"
+: ""
+
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: "Omogućiti standardni alarm"
+
+, "New events get a standard alarm as defined below"
+: "Novi događaji dobije standardni alarm kao što je definirano u nastavku"
+
+, "Standard Alarm Time"
+: "Standardna vrijeme alarma"
+
+, "Minutes before the event starts"
+: "Minuta prije nego događaj započne"
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "Fiksni kalendar"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: "Nikada"
+
+, "On invitation and cancellation only"
+: "Samo kod pozivanja i otkazivanja"
+
+, "On time changes"
+: "Na promjeni vrijemena"
+
+, "On all updates but attendee responses"
+: "Na svim promjenama, ali odgovora sudionika"
+
+, "On attendee responses too"
+: "Na sudionik odgovora isto"
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : "Kalendari su uvijek odabrani bez obzira na parametare u filtru. Stoga postoji mogućnost da se uporno prikazuju određeni neradni dani u kalendaru."
@@ -1230,12 +1241,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Bez odgovora"
+
+, "Accepted"
+: "Prihvaćeno"
+
+, "Declined"
+: "Odbijeno"
+
 , "Attendee Roles Available"
 : "Raspoložive uloge sudionika"
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Obavezno"
+
+, "Optional"
+: "Opcionalno"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1245,6 +1274,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1287,6 +1346,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1338,6 +1400,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1377,95 +1442,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Alarm za događaj \"%1$s\" u %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Pozivnica za događaj \"%1$s\" u %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "Događaj \"%1$s\" u %2$s je otkazan"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
-: "Događaj \"%1$s\" premješteno je s%2$s%3$s"
-
-, "Event \"%1$s\" at %2$s has been updated"
-: "Događaj \"%1$s\" u %2$s je ažuriran"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s je prihvatio/la događaj \"%2$s\" u %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s je odbio/la događaj \"%2$s\" u %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "Odgovor o mogućem dolasku od %1$s za događaj \"%2$s\" u %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Nema odgovora od %1$s za događaj \"%2$s\" u %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Izmjena sudionika za događaj \"%1$s\" u %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Group Additional Filters"
 : ""
 
-, "Resource Management"
+, "Resource Additional Filters"
 : ""
 
-, "Polls for recurring events are not supported"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "%s's personal calendar"
+: "%s osobni kalendar"
+
+, "Failed"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "The right Resource Admin must be set once."
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Different Calendar"
 : ""
 
-, "Start"
-: "Početak"
+, "Exdate container move are not allowed"
+: ""
 
-, "Priority"
-: "Prioritet"
+, "Invalid URL given"
+: ""
 
-, "Url"
-: "URL"
+, "The URL you used is invalid. Please use a valid one!"
+: ""
 
-, "Recurrance rule"
-: "Pravilo ponavljanja"
+, "Calendars to export"
+: ""
 
-, "Is all day event"
-: "Događaj za cijeli dan"
+, "Export target"
+: ""
 
-, "Organizer timezone"
-: "Vremenska zona organizatora"
+, "VCalendar/ICS"
+: ""
 
-, "No"
-: "Ne"
+, "Export visible events to ics file"
+: ""
 
-, "Yes"
-: "Da"
+, "Excel overview"
+: ""
+
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "nepoznato"
@@ -1524,34 +1598,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: "Početak"
+
+, "Priority"
+: "Prioritet"
+
+, "Url"
+: "URL"
+
+, "Recurrance rule"
+: "Pravilo ponavljanja"
+
+, "Is all day event"
+: "Događaj za cijeli dan"
+
+, "Organizer timezone"
+: "Vremenska zona organizatora"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Alarm za događaj \"%1$s\" u %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Pozivnica za događaj \"%1$s\" u %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "Događaj \"%1$s\" u %2$s je otkazan"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+: "Događaj \"%1$s\" premješteno je s%2$s%3$s"
+
+, "Event \"%1$s\" at %2$s has been updated"
+: "Događaj \"%1$s\" u %2$s je ažuriran"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s je prihvatio/la događaj \"%2$s\" u %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s je odbio/la događaj \"%2$s\" u %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "Odgovor o mogućem dolasku od %1$s za događaj \"%2$s\" u %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Nema odgovora od %1$s za događaj \"%2$s\" u %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Izmjena sudionika za događaj \"%1$s\" u %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Unknown action"
 : ""
 
-, "Word event sheet"
+, "Resource Management"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Excel all data"
+, "Polls for recurring events are not supported"
 : ""
 
-, "Import iCal-files"
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1590,32 +1733,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Detalji odgađaja"
 
-, "The poll \"%1$s\" has been closed."
-: ""
+, "All events I attend"
+: "Svi događaji kojima sam prisustvovao"
 
-, "The definite event is scheduled for \"%1$s\""
-: ""
+, "Awaiting response"
+: "U čekanju odgovora"
 
-, "You can review the poll results here:"
-: ""
+, "Events I have not yet responded to"
+: "Događaji na koje nisam odgovorio"
 
-, "Thank you for attendening the poll \"%1$s\""
-: ""
+, "Declined events"
+: "Odbijeni događaji"
 
-, "To review or edit your status please use your personal link:"
-: ""
+, "Events I have declined"
+: "Događaji koje sam odbio"
 
-, "Different Calendar"
-: ""
+, "I'm organizer"
+: "Ja sam organizator"
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
-: ""
+, "Events I'm the organizer of"
+: "Događaji koje sam ja organizirao"
 
 , "manage shared calendars"
 : "Upravljanje dijeljenim kalendarima"
@@ -1635,74 +1772,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Sva prava za administriranje resursa"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "Je lokacija"
-
-, "Errors"
-: "Greške"
-
-, "Do you really want to delete this event?"
-: "Da li zaista želite obrisati ovaj događaj?"
+, "Relation, Relations"
+: [
+  ""
+ ,""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Resurs"
+, "Calendar"
+: "Kalendar"
+
+, "Do you really want to delete this event?"
+: "Da li zaista želite obrisati ovaj događaj?"
 
 , "Resource Grant"
 : ""
@@ -1710,12 +1824,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Događaj"
 
-, "Calendar"
-: "Kalendar"
-
 , "Attender"
 : "Sudionik"
 
+, "Resource"
+: "Resurs"
+
 , "Relation"
 : ""
 
