@@ -5,167 +5,251 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "calendario personale di %s"
+, "{0}, the {1}. of {2}"
+: "{0}, il {1}. di {2}"
 
-, "Resources"
-: "Risorse"
+, "Recurrances"
+: "Ricorrenze"
 
-, "All my events"
-: "Tutti miei eventi"
+, "No recurring rule defined"
+: "Nessuna regola ricorrente definita"
 
-, "Start Time"
-: "Ora di inizio"
+, "Details"
+: "Dettagli"
 
-, "Position on the left time axis, day and week view should start with"
-: "Posizione sull'asse del tempo a sinistra, giorno e settimana dovrebbero iniziare con"
+, "None"
+: "Nessuno"
 
-, "End Time"
-: "Ora di fine"
+, "Daily"
+: "Quotidiano"
 
-, "Position on the left time axis, day and week view should end with"
+, "Weekly"
+: "Settimanale"
+
+, "Monthly"
+: "Mensile"
+
+, "Yearly"
+: "Annuale"
+
+, "Exceptions of reccuring events can't have recurrences themselves."
+: "Eccezioni di eventi che si ripetono non possono ripertersi su se stessi."
+
+, "at"
+: "a"
+
+, "never"
+: "mai"
+
+, "after {0} occurrences"
+: "dopo {0} occorrenze"
+
+, "Except"
 : ""
 
-, "Default Start Time"
+, "during events in the calendars"
 : ""
 
-, "Scroll position on the left time axis, day and week view should start with"
+, "End"
+: "Fine"
+
+, "Until has to be after event start"
+: "Fino a deve essere successivo alla data di inizio dell'evento"
+
+, "The event is longer than the recurring interval"
 : ""
 
-, "Visible Time"
-: ""
+, "Every {0}. Day"
+: "Ogni {0}. Giornalmente"
 
-, "Time to be displayed at once"
-: ""
+, "Every {0}. Week at"
+: "Ogni {0}. Settimanalmente"
 
-, "Default Calendar"
-: "Calendario di default"
+, "Every {0}. Month"
+: "Ogni {0}. Mensilmente"
 
-, "The default calendar for invitations and new events"
-: "Il calendario di default per gli inviti e i nuovi eventi"
+, "at the"
+: "a"
 
-, "Default Favorite"
-: "Preferiti predefiniti"
+, "first"
+: "primo"
 
-, "The default favorite which is loaded on calendar startup"
-: "Il preferito di default che è caricato all'apertura del calendario"
+, "second"
+: "secondo"
 
-, "Get Notification Emails"
-: "Prendi le email di notifica"
+, "third"
+: "terzo"
 
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "I livelli di azione per cui vuoi essere notificato. Attenzione che gli organizzatori riceveranno notifiche per tutti gli aggiornamenti includendo le risposte dei partecipanti a meno che tale impostazione sia impostata a \"Mai\""
+, "fourth"
+: "quarto"
 
-, "Send Notifications Emails of own Actions"
-: "Invia Notifiche Email per le tue Azioni"
+, "last"
+: "ultimo"
 
-, "Get notifications emails for actions you did yourself"
-: "Ricevi notifiche email per le azioni compiute da te stesso"
+, "Every {0}. Year"
+: "Ogni {0}. Annualmente"
 
-, "Send Alarm Notifications Emails"
-: ""
-
-, "Get event alarms via email"
-: ""
-
-, "Enable Standard Alarm"
-: "Attiva Avviso Standard"
-
-, "New events get a standard alarm as defined below"
-: "I nuovi eventi hanno un avviso standard come definito di seguito"
-
-, "Standard Alarm Time"
-: "Orario Avviso Standard"
-
-, "Minutes before the event starts"
-: "Minuti prima dell'inizio dell'evento"
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "Calendari fissi"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: "Mai"
-
-, "On invitation and cancellation only"
-: "Su invito e recesso unicamente"
-
-, "On time changes"
-: "Nei cambiamenti di orario"
-
-, "On all updates but attendee responses"
-: "Su tutti gli aggiornamenti ma le risposte dei partecipanti"
-
-, "On attendee responses too"
-: "Troppe risposte dai partecipanti"
-
-, "Events"
-: "Eventi"
+, "of"
+: "di"
 
 , "Summary"
 : "Sommario"
 
-, "Status"
-: "Stato"
+, "Organizer"
+: "Organizzatore"
 
-, "No Information"
-: "Nessuna informazione"
-
-, "recurring event"
-: "evento ricorrente"
-
-, "recurring event exception"
-: "eccezione di evento ricorrente"
-
-, "Blocking"
-: "Bloccante"
-
-, "Tentative"
-: "Tentativo"
+, "Description"
+: "Descrizione"
 
 , "Location"
 : "Luogo"
 
-, "Organizer"
-: "Organizzatore"
+, "Start Time"
+: "Ora di inizio"
+
+, "End Time"
+: "Ora di fine"
 
 , "Attendee"
 : "Partecipante"
 
+, "whole day"
+: "giorno intero"
+
+, "Week {0} :"
+: "Settimana {0} :"
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Nuovo Evento"
+
+, "Calendar, Calendars"
+: [
+  "Calendario"
+ ,"Calendari"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : "Aggiungi partecipante"
 
@@ -175,117 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : "Spuntare per filtrare per questo partecipante"
 
-, "Attachments"
+, "Unavailable"
 : ""
 
-, "Private"
-: "Privato"
-
-, "Tags"
-: "Tags"
-
-, "whole day"
-: "giorno intero"
-
-, "Description"
-: "Descrizione"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: "Questo evento è originariamente memorizzato in un calendario di cui non hai accesso."
-
-, "This event is originally stored in {0}"
-: "Questo evento è originariamente memorizzato in {0}"
-
-, "This event is additionally displayed in your personal calendar {0}"
-: "Questo evento è inoltre visualizzato nel calendario personale {0}"
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: "Si prega di scegliere l'evento da aggiungere ai contatti"
-
-, "Role"
-: "Ruolo"
-
-, "Select Role"
-: "Seleziona Ruolo"
-
-, "Select Status"
-: "Seleziona Stato"
-
-, "Adding {0} Attendee to event"
-: "Aggiunti {0} Partecipanti all'evento"
-
-, "Checking Calendar Data..."
-: "Verifica Dati Calendario ..."
-
-, "Reply to Recurring Event"
-: "Rispondi a Evento Ricorrente"
-
-, "You are responding to an recurring event. What would you like to do?"
-: "Stai rispondendo ad un evento ricorrente. Cosa desideri fare?"
-
-, "Respond to whole series"
-: "Rispondi all'intera serie"
-
-, "Do not respond"
-: "Non rispondere"
-
-, "The event of this message does not exist"
-: "L'evento di questo messaggio non esiste"
-
-, "The sender is not authorised to update the event"
-: "Il mittente non è autorizzato ad aggiornare l'evento"
-
-, "This message is already processed"
-: "Questo messaggio è già stato elaborato"
-
-, "You are not an attendee of this event"
-: "Non sei un partecipante di questo evento"
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: "messaggio non supportato"
-
-, "This is an event invitation for someone else."
-: "Questo è un invito per l'evento per qualcun altro."
-
-, "You have already replied to this event invitation."
-: "Hai già risposto a questo invito per l'evento."
-
-, "You received an event invitation. Set your response to:"
-: "Hai ricevuto un invito per un evento. Imposta la risposta a:"
-
-, "An invited attendee responded to the invitation."
-: "Un partecipante invitato ha risposto all'invito."
-
-, "Unsupported method"
-: "Metodo non supportato"
-
 , "Loading events, please wait..."
 : "Eventi in modifica, per favore attendi..."
 
@@ -325,6 +301,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +316,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : "Copia {0}"
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : "Aggiornamento evento passato"
 
@@ -418,9 +400,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : "Annulla questa azione"
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Gestisci risorse"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Seleziona Partecipante"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Privato"
+
+, "Tags"
+: "Tags"
+
+, "Blocking"
+: "Bloccante"
+
+, "Tentative"
+: "Tentativo"
+
 , "Import Definition Success!"
 : ""
 
@@ -457,9 +466,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -511,7 +517,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -535,156 +541,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: "Visualizza"
-
-, "Details"
-: "Dettagli"
-
-, "Saved in"
-: "Salvato in"
-
-, "non-blocking"
-: "non-bloccante"
-
-, "Enter description"
-: "Inserisci descrizione"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "La data di fine non è valida"
-
-, "End date must be after start date"
-: "La data di fine deve essere successiva della data di inizio"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "La data di inizio non è valida"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: "Settimana {0} :"
-
-, "Originally"
-: "Originariamente"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "SE"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Quotidiano"
-
-, "Weekly"
-: "Settimanale"
-
-, "Monthly"
-: "Mensile"
-
-, "Yearly"
-: "Annuale"
-
-, "Name"
-: "Nome"
-
-, "Email"
-: "Email"
-
-, "Type"
-: "Tipo"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Nuovo Evento"
-
-, "{0} more..."
-: "{0} o più..."
-
 , "private classification"
 : "Classificazione privata"
 
+, "recurring event"
+: "evento ricorrente"
+
+, "recurring event exception"
+: "eccezione di evento ricorrente"
+
 , "has alarm"
 : "è allarme"
 
@@ -694,62 +559,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, il {1}. di {2}"
+, "Mini Calendar"
+: "Mini Calendario"
 
-, "Click here to invite another attender..."
-: "Clicca qui per invitare un altro partecipante..."
+, "WK"
+: "SE"
 
-, "User"
-: "Utente"
-
-, "Group"
-: "Gruppo"
-
-, "Resource, Resources"
-: [
-  "Risorsa"
- ,"Risorse"
-
-]
-, "Member of group"
-: "Membro del gruppo"
-
-, "This is the calendar where the attender has saved this event in"
-: "Questo è il calendario in cui il partecipante ha salvato l'evento"
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Rimuovi partecipante"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(come membro del gruppo)"
-
-, "External Attendee"
-: "Partecipante Esterno"
+, "{0} more..."
+: "{0} o più..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -769,6 +586,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -811,7 +631,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -841,102 +661,66 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: "Si prega di scegliere l'evento da aggiungere ai contatti"
+
+, "Role"
+: "Ruolo"
+
+, "Select Role"
+: "Seleziona Ruolo"
+
+, "Status"
+: "Stato"
+
+, "Select Status"
+: "Seleziona Stato"
+
+, "Adding {0} Attendee to event"
+: "Aggiunti {0} Partecipanti all'evento"
+
 , "no events found"
 : "nessun evento trovato"
 
 , "Searching..."
 : "Ricerca..."
 
+, "Search Event"
+: "Cerca Evento"
+
 , "Event, Events"
 : [
   "Evento"
  ,"Eventi"
 
 ]
-, "Search Event"
-: "Cerca Evento"
-
-, "Switch to public poll"
+, "Additional Tags ..."
 : ""
 
-, "Welcome {name}"
+, "non-blocking"
+: "non-bloccante"
+
+, "Displayed in"
+: "Visualizzato in"
+
+, "No Information"
+: "Nessuna informazione"
+
+, "Event Location"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "From"
 : ""
 
-, "This poll is closed already"
+, "until"
 : ""
 
-, "I am not {name}"
-: ""
+, "Events"
+: "Eventi"
 
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Mini Calendario"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Calendario"
- ,"Calendari"
-
-]
 , "Calendars"
 : "Calendari"
 
@@ -970,6 +754,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -991,38 +787,239 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Partecipanti"
 
 ]
+, "Resource, Resources"
+: [
+  "Risorsa"
+ ,"Risorse"
+
+]
+, "Resources"
+: "Risorse"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Nome"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "Email"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Tipo"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Clicca qui per invitare un altro partecipante..."
+
+, "User"
+: "Utente"
+
+, "Group"
+: "Gruppo"
+
+, "Member of group"
+: "Membro del gruppo"
+
+, "This is the calendar where the attender has saved this event in"
+: "Questo è il calendario in cui il partecipante ha salvato l'evento"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Rimuovi partecipante"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(come membro del gruppo)"
+
+, "External Attendee"
+: "Partecipante Esterno"
+
+, "Originally"
+: "Originariamente"
+
+, "Checking Calendar Data..."
+: "Verifica Dati Calendario ..."
+
+, "Reply to Recurring Event"
+: "Rispondi a Evento Ricorrente"
+
+, "You are responding to an recurring event. What would you like to do?"
+: "Stai rispondendo ad un evento ricorrente. Cosa desideri fare?"
+
+, "Respond to whole series"
+: "Rispondi all'intera serie"
+
+, "Do not respond"
+: "Non rispondere"
+
+, "The event of this message does not exist"
+: "L'evento di questo messaggio non esiste"
+
+, "The sender is not authorised to update the event"
+: "Il mittente non è autorizzato ad aggiornare l'evento"
+
+, "This message is already processed"
+: "Questo messaggio è già stato elaborato"
+
+, "You are not an attendee of this event"
+: "Non sei un partecipante di questo evento"
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: "messaggio non supportato"
+
+, "This is an event invitation for someone else."
+: "Questo è un invito per l'evento per qualcun altro."
+
+, "You have already replied to this event invitation."
+: "Hai già risposto a questo invito per l'evento."
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: "Hai ricevuto un invito per un evento. Imposta la risposta a:"
+
+, "An invited attendee responded to the invitation."
+: "Un partecipante invitato ha risposto all'invito."
+
+, "Unsupported method"
+: "Metodo non supportato"
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Inserisci descrizione..."
 
 , "Grants"
 : "Permessi"
 
-, "Displayed in"
-: "Visualizzato in"
+, "This event is originally stored in a calendar you don't have access to."
+: "Questo evento è originariamente memorizzato in un calendario di cui non hai accesso."
 
-, "Event not found"
+, "This event is originally stored in {0}"
+: "Questo evento è originariamente memorizzato in {0}"
+
+, "This event is additionally displayed in your personal calendar {0}"
+: "Questo evento è inoltre visualizzato nel calendario personale {0}"
+
+, "Colors"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "Side bar color"
 : ""
 
-, "GENDER_Attendee"
+, "Color by Calendar"
 : ""
 
-, "Select Attendee"
-: "Seleziona Partecipante"
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: "Visualizza"
+
+, "Saved in"
+: "Salvato in"
+
+, "Enter description"
+: "Inserisci descrizione"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "La data di fine non è valida"
+
+, "End date must be after start date"
+: "La data di fine deve essere successiva della data di inizio"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "La data di inizio non è valida"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : "l riepilogo non deve essere più lungo di 255 caratteri."
@@ -1036,128 +1033,143 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : "Sommario troppo corto"
 
-, "Recurrances"
-: "Ricorrenze"
-
-, "No recurring rule defined"
-: "Nessuna regola ricorrente definita"
-
-, "None"
-: "Nessuno"
-
-, "Exceptions of reccuring events can't have recurrences themselves."
-: "Eccezioni di eventi che si ripetono non possono ripertersi su se stessi."
-
-, "at"
-: "a"
-
-, "never"
-: "mai"
-
-, "after {0} occurrences"
-: "dopo {0} occorrenze"
-
-, "Except"
+, "Set This Date as Definite Event?"
 : ""
 
-, "during events in the calendars"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "End"
-: "Fine"
-
-, "Until has to be after event start"
-: "Fino a deve essere successivo alla data di inizio dell'evento"
-
-, "The event is longer than the recurring interval"
+, "Attendee/Resources"
 : ""
 
-, "Every {0}. Day"
-: "Ogni {0}. Giornalmente"
-
-, "Every {0}. Week at"
-: "Ogni {0}. Settimanalmente"
-
-, "Every {0}. Month"
-: "Ogni {0}. Mensilmente"
-
-, "at the"
-: "a"
-
-, "first"
-: "primo"
-
-, "second"
-: "secondo"
-
-, "third"
-: "terzo"
-
-, "fourth"
-: "quarto"
-
-, "last"
-: "ultimo"
-
-, "Every {0}. Year"
-: "Ogni {0}. Annualmente"
-
-, "of"
-: "di"
-
-, "First name, ĺast name"
+, "Additional Attendees ..."
 : ""
 
-, "E-Mail address"
+, "Default Status"
 : ""
 
-, "Please wait..."
+, "No Access"
 : ""
 
-, "General terms and conditions"
+, "All my events"
+: "Tutti miei eventi"
+
+, "Position on the left time axis, day and week view should start with"
+: "Posizione sull'asse del tempo a sinistra, giorno e settimana dovrebbero iniziare con"
+
+, "Position on the left time axis, day and week view should end with"
 : ""
 
-, "Relation, Relations"
-: [
-  ""
- ,""
+, "Default Start Time"
+: ""
 
-]
-, "All events I attend"
-: "Tutti gli eventi a cui partecipo"
+, "Scroll position on the left time axis, day and week view should start with"
+: ""
 
-, "Required"
-: "Richiesto"
+, "Visible Time"
+: ""
 
-, "Optional"
-: "Opzionale"
+, "Time to be displayed at once"
+: ""
 
-, "No response"
-: "Nessuna risposta"
+, "Default Calendar"
+: "Calendario di default"
 
-, "Accepted"
-: "Accettato"
+, "The default calendar for invitations and new events"
+: "Il calendario di default per gli inviti e i nuovi eventi"
 
-, "Declined"
-: "Respinto"
+, "Default Favorite"
+: "Preferiti predefiniti"
 
-, "Awaiting response"
-: "In attesa di risposta"
+, "The default favorite which is loaded on calendar startup"
+: "Il preferito di default che è caricato all'apertura del calendario"
 
-, "Events I have not yet responded to"
-: "Eventi a cui non ho ancora risposto"
+, "Get Notification Emails"
+: "Prendi le email di notifica"
 
-, "Declined events"
-: "Eventi declinati"
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "I livelli di azione per cui vuoi essere notificato. Attenzione che gli organizzatori riceveranno notifiche per tutti gli aggiornamenti includendo le risposte dei partecipanti a meno che tale impostazione sia impostata a \"Mai\""
 
-, "Events I have declined"
-: "Eventi che ho rifiutato"
+, "Send Notifications Emails of own Actions"
+: "Invia Notifiche Email per le tue Azioni"
 
-, "I'm organizer"
-: "Sono organizzatore"
+, "Get notifications emails for actions you did yourself"
+: "Ricevi notifiche email per le azioni compiute da te stesso"
 
-, "Events I'm the organizer of"
-: "Eventi di cui sono l'organizzatore"
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
+, "Send Alarm Notifications Emails"
+: ""
+
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: "Attiva Avviso Standard"
+
+, "New events get a standard alarm as defined below"
+: "I nuovi eventi hanno un avviso standard come definito di seguito"
+
+, "Standard Alarm Time"
+: "Orario Avviso Standard"
+
+, "Minutes before the event starts"
+: "Minuti prima dell'inizio dell'evento"
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "Calendari fissi"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: "Mai"
+
+, "On invitation and cancellation only"
+: "Su invito e recesso unicamente"
+
+, "On time changes"
+: "Nei cambiamenti di orario"
+
+, "On all updates but attendee responses"
+: "Su tutti gli aggiornamenti ma le risposte dei partecipanti"
+
+, "On attendee responses too"
+: "Troppe risposte dai partecipanti"
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : "Calendari sempre selezionati indipendentemente da tutti i parametri di filtro. Un esempio di utilizzo potrebbe essere quello di forzare la visualizzazione di un determinato calendario ferie o vacanza."
@@ -1222,12 +1234,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Nessuna risposta"
+
+, "Accepted"
+: "Accettato"
+
+, "Declined"
+: "Respinto"
+
 , "Attendee Roles Available"
 : "Ruoli Partecipante disponibili"
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Richiesto"
+
+, "Optional"
+: "Opzionale"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1237,6 +1267,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1279,6 +1339,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1330,6 +1393,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1369,95 +1435,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Allarme per evento \"%1$s\" a %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Evento invito \"%1$s\" a %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "L'evento \"%1$s\" al %2$s è stato cancellato"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
-: "L'evento \"%1$s\" è stato riprogrammato dal %2$s al %3$s"
-
-, "Event \"%1$s\" at %2$s has been updated"
-: "L'evento \"%1$s\" a %2$s è stato aggiornato"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s ha accettato \"%2$s\" a %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s ha declinato l'evento \"%2$s\" a %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "Risposta provvisoria da %1$s per l'evento \"%2$s\" a %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Nessuna risposta da %1$s per l'evento \"%2$s\" a %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Il partecipanete ha cambiato per l'evento \"%1$s\" a %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Group Additional Filters"
 : ""
 
-, "Resource Management"
+, "Resource Additional Filters"
 : ""
 
-, "Polls for recurring events are not supported"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "%s's personal calendar"
+: "calendario personale di %s"
+
+, "Failed"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "The right Resource Admin must be set once."
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Different Calendar"
 : ""
 
-, "Start"
-: "Inizio"
+, "Exdate container move are not allowed"
+: ""
 
-, "Priority"
-: "Priorità"
+, "Invalid URL given"
+: ""
 
-, "Url"
-: "Url"
+, "The URL you used is invalid. Please use a valid one!"
+: ""
 
-, "Recurrance rule"
-: "Regola ricorrente"
+, "Calendars to export"
+: ""
 
-, "Is all day event"
-: "E' un evento che dura tutto il giorno"
+, "Export target"
+: ""
 
-, "Organizer timezone"
-: "Fuso orario organizzatore"
+, "VCalendar/ICS"
+: ""
 
-, "No"
-: "No"
+, "Export visible events to ics file"
+: ""
 
-, "Yes"
-: "Sì"
+, "Excel overview"
+: ""
+
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "sconosciuto"
@@ -1516,34 +1591,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: "Inizio"
+
+, "Priority"
+: "Priorità"
+
+, "Url"
+: "Url"
+
+, "Recurrance rule"
+: "Regola ricorrente"
+
+, "Is all day event"
+: "E' un evento che dura tutto il giorno"
+
+, "Organizer timezone"
+: "Fuso orario organizzatore"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Allarme per evento \"%1$s\" a %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Evento invito \"%1$s\" a %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "L'evento \"%1$s\" al %2$s è stato cancellato"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+: "L'evento \"%1$s\" è stato riprogrammato dal %2$s al %3$s"
+
+, "Event \"%1$s\" at %2$s has been updated"
+: "L'evento \"%1$s\" a %2$s è stato aggiornato"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s ha accettato \"%2$s\" a %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s ha declinato l'evento \"%2$s\" a %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "Risposta provvisoria da %1$s per l'evento \"%2$s\" a %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Nessuna risposta da %1$s per l'evento \"%2$s\" a %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Il partecipanete ha cambiato per l'evento \"%1$s\" a %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Unknown action"
 : ""
 
-, "Word event sheet"
+, "Resource Management"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Excel all data"
+, "Polls for recurring events are not supported"
 : ""
 
-, "Import iCal-files"
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1582,32 +1726,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Dettagli Evento"
 
-, "The poll \"%1$s\" has been closed."
-: ""
+, "All events I attend"
+: "Tutti gli eventi a cui partecipo"
 
-, "The definite event is scheduled for \"%1$s\""
-: ""
+, "Awaiting response"
+: "In attesa di risposta"
 
-, "You can review the poll results here:"
-: ""
+, "Events I have not yet responded to"
+: "Eventi a cui non ho ancora risposto"
 
-, "Thank you for attendening the poll \"%1$s\""
-: ""
+, "Declined events"
+: "Eventi declinati"
 
-, "To review or edit your status please use your personal link:"
-: ""
+, "Events I have declined"
+: "Eventi che ho rifiutato"
 
-, "Different Calendar"
-: ""
+, "I'm organizer"
+: "Sono organizzatore"
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
-: ""
+, "Events I'm the organizer of"
+: "Eventi di cui sono l'organizzatore"
 
 , "manage shared calendars"
 : "gestisci calendari condivisi"
@@ -1627,74 +1765,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Tutti i diritti per amministrare le risorse"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "E' un luogo"
-
-, "Errors"
-: "Errori"
-
-, "Do you really want to delete this event?"
-: "Vuoi veramente cancellare questo evento?"
+, "Relation, Relations"
+: [
+  ""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Risorsa"
+, "Calendar"
+: "Calendario"
+
+, "Do you really want to delete this event?"
+: "Vuoi veramente cancellare questo evento?"
 
 , "Resource Grant"
 : ""
@@ -1702,12 +1816,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Evento"
 
-, "Calendar"
-: "Calendario"
-
 , "Attender"
 : "Partecipante"
 
+, "Resource"
+: "Risorsa"
+
 , "Relation"
 : ""
 
