@@ -5,167 +5,251 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "%s' personlige kalender"
+, "{0}, the {1}. of {2}"
+: "{0}, den {1}. av {2}"
 
-, "Resources"
-: "Resurser"
+, "Recurrances"
+: "Gjentagelser"
 
-, "All my events"
+, "No recurring rule defined"
+: "Ingen gjentagende regel definert"
+
+, "Details"
+: "Detaljer:"
+
+, "None"
+: "Inegn"
+
+, "Daily"
+: "Daglig"
+
+, "Weekly"
+: "Ukentlig"
+
+, "Monthly"
+: "Månedlig"
+
+, "Yearly"
+: "Årlig"
+
+, "Exceptions of reccuring events can't have recurrences themselves."
 : ""
 
-, "Start Time"
-: "Start Tid"
+, "at"
+: "på"
 
-, "Position on the left time axis, day and week view should start with"
+, "never"
 : ""
 
-, "End Time"
-: "Slutt Tid"
-
-, "Position on the left time axis, day and week view should end with"
+, "after {0} occurrences"
 : ""
 
-, "Default Start Time"
+, "Except"
 : ""
 
-, "Scroll position on the left time axis, day and week view should start with"
+, "during events in the calendars"
 : ""
 
-, "Visible Time"
+, "End"
+: "Slutt"
+
+, "Until has to be after event start"
+: "Til må være etter hendelses start"
+
+, "The event is longer than the recurring interval"
 : ""
 
-, "Time to be displayed at once"
+, "Every {0}. Day"
 : ""
 
-, "Default Calendar"
-: "Standard Kalender"
-
-, "The default calendar for invitations and new events"
-: "Standard kalenderen for invitasjoner og nye hendelser"
-
-, "Default Favorite"
+, "Every {0}. Week at"
 : ""
 
-, "The default favorite which is loaded on calendar startup"
+, "Every {0}. Month"
 : ""
 
-, "Get Notification Emails"
-: "Få Varslings E-post"
+, "at the"
+: "på den"
 
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "Ønsket nivå du vil bli varslet om. Vennligst noter at organiserere vil få varslinger for alle oppdateringer inkludert deltager svar hvis ikke dette valget er satt til \"Aldri\""
+, "first"
+: "første"
 
-, "Send Notifications Emails of own Actions"
-: "Send Varslings E-post på egne Handligner"
+, "second"
+: "andre"
 
-, "Get notifications emails for actions you did yourself"
-: "Få varslings e-post for handligner du selv har gjort"
+, "third"
+: "tredje"
 
-, "Send Alarm Notifications Emails"
+, "fourth"
+: "fjerde"
+
+, "last"
+: "siste"
+
+, "Every {0}. Year"
 : ""
 
-, "Get event alarms via email"
-: ""
-
-, "Enable Standard Alarm"
-: ""
-
-, "New events get a standard alarm as defined below"
-: ""
-
-, "Standard Alarm Time"
-: "Standard Alarm tid"
-
-, "Minutes before the event starts"
-: ""
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: ""
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: "aldri"
-
-, "On invitation and cancellation only"
-: ""
-
-, "On time changes"
-: ""
-
-, "On all updates but attendee responses"
-: ""
-
-, "On attendee responses too"
-: ""
-
-, "Events"
-: "Hendelser"
+, "of"
+: "av"
 
 , "Summary"
 : "Oppsumering"
 
-, "Status"
-: "Status"
+, "Organizer"
+: "Organiserer"
 
-, "No Information"
-: "Ingen Informasjon"
-
-, "recurring event"
-: ""
-
-, "recurring event exception"
-: ""
-
-, "Blocking"
-: "Blokkerer"
-
-, "Tentative"
-: "Foreløpig"
+, "Description"
+: "Beskrivelse"
 
 , "Location"
 : "Sted"
 
-, "Organizer"
-: "Organiserer"
+, "Start Time"
+: "Start Tid"
+
+, "End Time"
+: "Slutt Tid"
 
 , "Attendee"
 : "Deltager"
 
+, "whole day"
+: "hele dagen"
+
+, "Week {0} :"
+: ""
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Ny Hendelse"
+
+, "Calendar, Calendars"
+: [
+  "Kalender"
+ ,"Kalendere"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : ""
 
@@ -175,115 +259,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : ""
 
-, "Attachments"
-: ""
-
-, "Private"
-: "Privat"
-
-, "Tags"
-: ""
-
-, "whole day"
-: "hele dagen"
-
-, "Description"
-: "Beskrivelse"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: ""
-
-, "This event is originally stored in {0}"
-: ""
-
-, "This event is additionally displayed in your personal calendar {0}"
-: ""
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: ""
-
-, "Role"
-: "Rolle"
-
-, "Select Role"
-: ""
-
-, "Select Status"
-: ""
-
-, "Adding {0} Attendee to event"
-: ""
-
-, "Checking Calendar Data..."
-: ""
-
-, "Reply to Recurring Event"
-: ""
-
-, "You are responding to an recurring event. What would you like to do?"
-: ""
-
-, "Respond to whole series"
-: ""
-
-, "Do not respond"
-: ""
-
-, "The event of this message does not exist"
-: ""
-
-, "The sender is not authorised to update the event"
-: ""
-
-, "This message is already processed"
-: ""
-
-, "You are not an attendee of this event"
-: ""
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: ""
-
-, "This is an event invitation for someone else."
-: ""
-
-, "You have already replied to this event invitation."
-: ""
-
-, "You received an event invitation. Set your response to:"
-: ""
-
-, "An invited attendee responded to the invitation."
-: ""
-
-, "Unsupported method"
+, "Unavailable"
 : ""
 
 , "Loading events, please wait..."
@@ -325,6 +301,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +316,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : ""
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : ""
 
@@ -418,9 +400,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : ""
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Behandle Resurser"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: ""
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Privat"
+
+, "Tags"
+: ""
+
+, "Blocking"
+: "Blokkerer"
+
+, "Tentative"
+: "Foreløpig"
+
 , "Import Definition Success!"
 : ""
 
@@ -457,9 +466,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -511,7 +517,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -535,156 +541,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: ""
-
-, "Details"
-: "Detaljer:"
-
-, "Saved in"
-: "Lagret i"
-
-, "non-blocking"
-: "ikke-blokert"
-
-, "Enter description"
-: "Tast inn beskrivelse"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "Slutt dato er ikke gyldig"
-
-, "End date must be after start date"
-: "Slutt dato må være etter start dato"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "Start datoen er ikke gyldig"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: ""
-
-, "Originally"
-: "Orginalt"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "U"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Daglig"
-
-, "Weekly"
-: "Ukentlig"
-
-, "Monthly"
-: "Månedlig"
-
-, "Yearly"
-: "Årlig"
-
-, "Name"
-: "Navn"
-
-, "Email"
-: "E-post"
-
-, "Type"
-: "Type"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Ny Hendelse"
-
-, "{0} more..."
-: "{0} mer..."
-
 , "private classification"
 : ""
 
+, "recurring event"
+: ""
+
+, "recurring event exception"
+: ""
+
 , "has alarm"
 : ""
 
@@ -694,62 +559,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, den {1}. av {2}"
-
-, "Click here to invite another attender..."
-: "Trykk her for å invitere en annen deltager..."
-
-, "User"
-: "Bruker"
-
-, "Group"
-: "Gruppe"
-
-, "Resource, Resources"
-: [
-  "Resurs"
- ,"Resurser"
-
-]
-, "Member of group"
+, "Mini Calendar"
 : ""
 
-, "This is the calendar where the attender has saved this event in"
-: "Dette er kalenderen hvor deltager har lagret denne hendelsen i"
+, "WK"
+: "U"
 
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Fjern Deltaker"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(som et gruppe medlem)"
-
-, "External Attendee"
-: ""
+, "{0} more..."
+: "{0} mer..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -769,6 +586,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -811,7 +631,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -841,102 +661,66 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: ""
+
+, "Role"
+: "Rolle"
+
+, "Select Role"
+: ""
+
+, "Status"
+: "Status"
+
+, "Select Status"
+: ""
+
+, "Adding {0} Attendee to event"
+: ""
+
 , "no events found"
 : ""
 
 , "Searching..."
 : ""
 
+, "Search Event"
+: ""
+
 , "Event, Events"
 : [
   "Hendelse"
  ,"Hendelser"
 
 ]
-, "Search Event"
+, "Additional Tags ..."
 : ""
 
-, "Switch to public poll"
+, "non-blocking"
+: "ikke-blokert"
+
+, "Displayed in"
 : ""
 
-, "Welcome {name}"
+, "No Information"
+: "Ingen Informasjon"
+
+, "Event Location"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "From"
 : ""
 
-, "This poll is closed already"
+, "until"
 : ""
 
-, "I am not {name}"
-: ""
+, "Events"
+: "Hendelser"
 
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: ""
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Kalender"
- ,"Kalendere"
-
-]
 , "Calendars"
 : "Kalendere"
 
@@ -970,6 +754,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -991,37 +787,238 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Deltagere"
 
 ]
+, "Resource, Resources"
+: [
+  "Resurs"
+ ,"Resurser"
+
+]
+, "Resources"
+: "Resurser"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Navn"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "E-post"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Type"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Trykk her for å invitere en annen deltager..."
+
+, "User"
+: "Bruker"
+
+, "Group"
+: "Gruppe"
+
+, "Member of group"
+: ""
+
+, "This is the calendar where the attender has saved this event in"
+: "Dette er kalenderen hvor deltager har lagret denne hendelsen i"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Fjern Deltaker"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(som et gruppe medlem)"
+
+, "External Attendee"
+: ""
+
+, "Originally"
+: "Orginalt"
+
+, "Checking Calendar Data..."
+: ""
+
+, "Reply to Recurring Event"
+: ""
+
+, "You are responding to an recurring event. What would you like to do?"
+: ""
+
+, "Respond to whole series"
+: ""
+
+, "Do not respond"
+: ""
+
+, "The event of this message does not exist"
+: ""
+
+, "The sender is not authorised to update the event"
+: ""
+
+, "This message is already processed"
+: ""
+
+, "You are not an attendee of this event"
+: ""
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: ""
+
+, "This is an event invitation for someone else."
+: ""
+
+, "You have already replied to this event invitation."
+: ""
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: ""
+
+, "An invited attendee responded to the invitation."
+: ""
+
+, "Unsupported method"
+: ""
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Tast inn beskrivelse..."
 
 , "Grants"
 : ""
 
-, "Displayed in"
+, "This event is originally stored in a calendar you don't have access to."
 : ""
 
-, "Event not found"
+, "This event is originally stored in {0}"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "This event is additionally displayed in your personal calendar {0}"
 : ""
 
-, "GENDER_Attendee"
+, "Colors"
 : ""
 
-, "Select Attendee"
+, "Side bar color"
+: ""
+
+, "Color by Calendar"
+: ""
+
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: ""
+
+, "Saved in"
+: "Lagret i"
+
+, "Enter description"
+: "Tast inn beskrivelse"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "Slutt dato er ikke gyldig"
+
+, "End date must be after start date"
+: "Slutt dato må være etter start dato"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "Start datoen er ikke gyldig"
+
+, "Start date is not allowed to be before the configured time."
 : ""
 
 , "The summary must not be longer than 255 characters."
@@ -1036,127 +1033,142 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : ""
 
-, "Recurrances"
-: "Gjentagelser"
-
-, "No recurring rule defined"
-: "Ingen gjentagende regel definert"
-
-, "None"
-: "Inegn"
-
-, "Exceptions of reccuring events can't have recurrences themselves."
+, "Set This Date as Definite Event?"
 : ""
 
-, "at"
-: "på"
-
-, "never"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "after {0} occurrences"
+, "Attendee/Resources"
 : ""
 
-, "Except"
+, "Additional Attendees ..."
 : ""
 
-, "during events in the calendars"
+, "Default Status"
 : ""
 
-, "End"
-: "Slutt"
-
-, "Until has to be after event start"
-: "Til må være etter hendelses start"
-
-, "The event is longer than the recurring interval"
+, "No Access"
 : ""
 
-, "Every {0}. Day"
+, "All my events"
 : ""
 
-, "Every {0}. Week at"
+, "Position on the left time axis, day and week view should start with"
 : ""
 
-, "Every {0}. Month"
+, "Position on the left time axis, day and week view should end with"
 : ""
 
-, "at the"
-: "på den"
-
-, "first"
-: "første"
-
-, "second"
-: "andre"
-
-, "third"
-: "tredje"
-
-, "fourth"
-: "fjerde"
-
-, "last"
-: "siste"
-
-, "Every {0}. Year"
+, "Default Start Time"
 : ""
 
-, "of"
-: "av"
-
-, "First name, ĺast name"
+, "Scroll position on the left time axis, day and week view should start with"
 : ""
 
-, "E-Mail address"
+, "Visible Time"
 : ""
 
-, "Please wait..."
+, "Time to be displayed at once"
 : ""
 
-, "General terms and conditions"
+, "Default Calendar"
+: "Standard Kalender"
+
+, "The default calendar for invitations and new events"
+: "Standard kalenderen for invitasjoner og nye hendelser"
+
+, "Default Favorite"
 : ""
 
-, "Relation, Relations"
-: [
-  ""
- ,""
-
-]
-, "All events I attend"
+, "The default favorite which is loaded on calendar startup"
 : ""
 
-, "Required"
-: "Påkrevd"
+, "Get Notification Emails"
+: "Få Varslings E-post"
 
-, "Optional"
-: "Valgfri"
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "Ønsket nivå du vil bli varslet om. Vennligst noter at organiserere vil få varslinger for alle oppdateringer inkludert deltager svar hvis ikke dette valget er satt til \"Aldri\""
 
-, "No response"
-: "Ingen svar"
+, "Send Notifications Emails of own Actions"
+: "Send Varslings E-post på egne Handligner"
 
-, "Accepted"
-: "Godkjent"
+, "Get notifications emails for actions you did yourself"
+: "Få varslings e-post for handligner du selv har gjort"
 
-, "Declined"
-: "Avvist"
-
-, "Awaiting response"
+, "Send Notifications Emails of tentative events"
 : ""
 
-, "Events I have not yet responded to"
+, "Get notifications emails of tentative events"
 : ""
 
-, "Declined events"
+, "Send Alarm Notifications Emails"
 : ""
 
-, "Events I have declined"
+, "Get event alarms via email"
 : ""
 
-, "I'm organizer"
+, "Enable Standard Alarm"
 : ""
 
-, "Events I'm the organizer of"
+, "New events get a standard alarm as defined below"
+: ""
+
+, "Standard Alarm Time"
+: "Standard Alarm tid"
+
+, "Minutes before the event starts"
+: ""
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: ""
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: "aldri"
+
+, "On invitation and cancellation only"
+: ""
+
+, "On time changes"
+: ""
+
+, "On all updates but attendee responses"
+: ""
+
+, "On attendee responses too"
 : ""
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
@@ -1222,12 +1234,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Ingen svar"
+
+, "Accepted"
+: "Godkjent"
+
+, "Declined"
+: "Avvist"
+
 , "Attendee Roles Available"
 : ""
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Påkrevd"
+
+, "Optional"
+: "Valgfri"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1237,6 +1267,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1279,6 +1339,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1330,6 +1393,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1369,95 +1435,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Alarm for hendelse \"%1$s\" på %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Hendelse invitasjon  \"%1$s\" på %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
+, "Group Additional Filters"
 : ""
 
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+, "Resource Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been updated"
-: "Hendelse  \"%1$s\" på %2$s har blitt oppdatert"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s godkjent hendelse \"%2$s\" på %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s avvist hendelse \"%2$s\" på %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "Foreløbig svar fra %1$s for hendelse \"%2$s\" at %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Ingen svar fra %1$s for hendelse \"%2$s\" at %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Deltager endringer for hendelse \"%1$s\" på %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "Resource Management"
+, "%s's personal calendar"
+: "%s' personlige kalender"
+
+, "Failed"
 : ""
 
-, "Polls for recurring events are not supported"
+, "The right Resource Admin must be set once."
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "Different Calendar"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "Exdate container move are not allowed"
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Invalid URL given"
 : ""
 
-, "Start"
-: "Start"
+, "The URL you used is invalid. Please use a valid one!"
+: ""
 
-, "Priority"
-: "Prioritet"
+, "Calendars to export"
+: ""
 
-, "Url"
-: "Url"
+, "Export target"
+: ""
 
-, "Recurrance rule"
-: "Gjentagelse regel"
+, "VCalendar/ICS"
+: ""
 
-, "Is all day event"
-: "Er hele dagen hendelse"
+, "Export visible events to ics file"
+: ""
 
-, "Organizer timezone"
-: "Organiserer tidssone"
+, "Excel overview"
+: ""
 
-, "No"
-: "Nei"
+, "Word event sheet"
+: ""
 
-, "Yes"
-: "Ja"
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "ukjent"
@@ -1516,34 +1591,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: "Start"
+
+, "Priority"
+: "Prioritet"
+
+, "Url"
+: "Url"
+
+, "Recurrance rule"
+: "Gjentagelse regel"
+
+, "Is all day event"
+: "Er hele dagen hendelse"
+
+, "Organizer timezone"
+: "Organiserer tidssone"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Alarm for hendelse \"%1$s\" på %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Hendelse invitasjon  \"%1$s\" på %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
 : ""
 
-, "OpenDocument all data"
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Event \"%1$s\" at %2$s has been updated"
+: "Hendelse  \"%1$s\" på %2$s har blitt oppdatert"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s godkjent hendelse \"%2$s\" på %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s avvist hendelse \"%2$s\" på %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "Foreløbig svar fra %1$s for hendelse \"%2$s\" at %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Ingen svar fra %1$s for hendelse \"%2$s\" at %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "Word event sheet"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Deltager endringer for hendelse \"%1$s\" på %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "Unknown action"
 : ""
 
-, "Excel all data"
+, "Resource Management"
 : ""
 
-, "Import iCal-files"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+: ""
+
+, "Polls for recurring events are not supported"
+: ""
+
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1582,31 +1726,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Hendelse detaljer"
 
-, "The poll \"%1$s\" has been closed."
+, "All events I attend"
 : ""
 
-, "The definite event is scheduled for \"%1$s\""
+, "Awaiting response"
 : ""
 
-, "You can review the poll results here:"
+, "Events I have not yet responded to"
 : ""
 
-, "Thank you for attendening the poll \"%1$s\""
+, "Declined events"
 : ""
 
-, "To review or edit your status please use your personal link:"
+, "Events I have declined"
 : ""
 
-, "Different Calendar"
+, "I'm organizer"
 : ""
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
+, "Events I'm the organizer of"
 : ""
 
 , "manage shared calendars"
@@ -1627,74 +1765,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Alle Rettigheter til Administrative resurser"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "Er et sted"
-
-, "Errors"
-: "Feil"
-
-, "Do you really want to delete this event?"
-: "Vil du virkelig slette denn hendelsen?"
+, "Relation, Relations"
+: [
+  ""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Resurs"
+, "Calendar"
+: "Kalender"
+
+, "Do you really want to delete this event?"
+: "Vil du virkelig slette denn hendelsen?"
 
 , "Resource Grant"
 : ""
@@ -1702,12 +1816,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Hendelse"
 
-, "Calendar"
-: "Kalender"
-
 , "Attender"
 : "Deltager"
 
+, "Resource"
+: "Resurs"
+
 , "Relation"
 : ""
 
