@@ -5,167 +5,251 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:42+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "%s's persoonlijke agenda"
+, "{0}, the {1}. of {2}"
+: "{0}, de {1}. van {2}"
 
-, "Resources"
-: "Bronnen"
+, "Recurrances"
+: "Herhalingen"
 
-, "All my events"
-: "Al mijn evenementen"
+, "No recurring rule defined"
+: "Geen terugkerende regel gedefinieerd"
 
-, "Start Time"
-: "Begin tijd"
+, "Details"
+: "Details"
 
-, "Position on the left time axis, day and week view should start with"
-: ""
+, "None"
+: "Geen"
 
-, "End Time"
-: "Eind tijd"
+, "Daily"
+: "Dagelijks"
 
-, "Position on the left time axis, day and week view should end with"
-: ""
+, "Weekly"
+: "Wekelijks"
 
-, "Default Start Time"
-: "Standaard start tijd"
+, "Monthly"
+: "Maandelijks"
 
-, "Scroll position on the left time axis, day and week view should start with"
-: ""
+, "Yearly"
+: "Jaarlijks"
 
-, "Visible Time"
-: ""
+, "Exceptions of reccuring events can't have recurrences themselves."
+: "Uitzonderingen van herhalende gebeurtenissen kunnen niet zelf herhalend zijn."
 
-, "Time to be displayed at once"
-: ""
+, "at"
+: "op"
 
-, "Default Calendar"
-: "Standaard agenda"
-
-, "The default calendar for invitations and new events"
-: "De standaard agenda voor uitnodigingen en nieuwe evenementen"
-
-, "Default Favorite"
-: "Standaard favoriet"
-
-, "The default favorite which is loaded on calendar startup"
-: "De standaard favoriet die bij het opstarten van agenda wordt geladen"
-
-, "Get Notification Emails"
-: "Stuur e-mail melding"
-
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "Het niveau van de acties die u wilt worden geïnformeerd. Houd er rekening mee dat de organisatoren meldingen krijgt voor alle updates, waaronder genodigde antwoorden, tenzij deze voorkeur is ingesteld op \"Never \""
-
-, "Send Notifications Emails of own Actions"
-: "Stuur Email meldingen van eigen acties"
-
-, "Get notifications emails for actions you did yourself"
-: "Email meldingen krijgen voor acties die u zelf heeft gedaan"
-
-, "Send Alarm Notifications Emails"
-: ""
-
-, "Get event alarms via email"
-: ""
-
-, "Enable Standard Alarm"
-: "Standaard alarm aan"
-
-, "New events get a standard alarm as defined below"
-: "Nieuwe evenementen krijgen een standaard alarm zoals hieronder gedefinieerd"
-
-, "Standard Alarm Time"
-: "Standaard Alarm tijd"
-
-, "Minutes before the event starts"
-: "Minuten voordat het evenement begint"
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "Vaste kalenders"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
+, "never"
 : "Nooit"
 
-, "On invitation and cancellation only"
-: "Op uitnodiging en annulering alleen"
+, "after {0} occurrences"
+: "na {0} herhalingen"
 
-, "On time changes"
-: "Op tijd veranderingen"
+, "Except"
+: ""
 
-, "On all updates but attendee responses"
-: "Op alle updates, maar genodigde reacties"
+, "during events in the calendars"
+: ""
 
-, "On attendee responses too"
-: "Reactie genodigden"
+, "End"
+: "Einde"
 
-, "Events"
-: "Evenementen"
+, "Until has to be after event start"
+: "Einde moet na de start van het evenement vallen"
+
+, "The event is longer than the recurring interval"
+: "De gebeurtenis is langer dan het herhalende interval"
+
+, "Every {0}. Day"
+: "Elke {0} dag"
+
+, "Every {0}. Week at"
+: "Elke {0} week op"
+
+, "Every {0}. Month"
+: "Elke {0} maand"
+
+, "at the"
+: "op de"
+
+, "first"
+: "eerste"
+
+, "second"
+: "tweede"
+
+, "third"
+: "derde"
+
+, "fourth"
+: "vierde"
+
+, "last"
+: "laatste"
+
+, "Every {0}. Year"
+: "Elke {0} jaar"
+
+, "of"
+: " "
 
 , "Summary"
 : "Samenvatting"
 
-, "Status"
-: "Status"
+, "Organizer"
+: "Organisator"
 
-, "No Information"
-: "Geen informatie"
-
-, "recurring event"
-: "Terugkerend evenement"
-
-, "recurring event exception"
-: "uitzondering op terugkerend evenement"
-
-, "Blocking"
-: "Blokkerend"
-
-, "Tentative"
-: "Onder voorbehoud"
+, "Description"
+: "Beschrijving"
 
 , "Location"
 : "Locatie"
 
-, "Organizer"
-: "Organisator"
+, "Start Time"
+: "Begin tijd"
+
+, "End Time"
+: "Eind tijd"
 
 , "Attendee"
 : "Genodigde"
 
+, "whole day"
+: "Gehele dag"
+
+, "Week {0} :"
+: "Week {0} :"
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Nieuw evenement"
+
+, "Calendar, Calendars"
+: [
+  "Agenda"
+ ,"Agenda's"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : "Voeg genodigde toe"
 
@@ -175,117 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : "Vink aan om te filteren op deze attendee"
 
-, "Attachments"
+, "Unavailable"
 : ""
 
-, "Private"
-: "Prive"
-
-, "Tags"
-: "Tags"
-
-, "whole day"
-: "Gehele dag"
-
-, "Description"
-: "Beschrijving"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: "Dit evenement is geplaatst in een agenda waar je geen toegang tot hebt."
-
-, "This event is originally stored in {0}"
-: "Dit evenement is geplaatst in {0}"
-
-, "This event is additionally displayed in your personal calendar {0}"
-: "Dit evenement wordt bovendien weergegeven in uw persoonlijke kalender {0}"
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: "Selecteer het evenement waaraan de contacten toegevoegd moeten worden"
-
-, "Role"
-: "Functie"
-
-, "Select Role"
-: "Selecteer functie"
-
-, "Select Status"
-: "Selecteer status"
-
-, "Adding {0} Attendee to event"
-: "Toevoegen {0} deelnemer aan event"
-
-, "Checking Calendar Data..."
-: "Controleren van kalender data..."
-
-, "Reply to Recurring Event"
-: "Antwoorden op terugkerend evenement"
-
-, "You are responding to an recurring event. What would you like to do?"
-: "U beantwoordt een terugkerend evenement. Wat wilt u doen?"
-
-, "Respond to whole series"
-: "Beantwoord de gehele serie"
-
-, "Do not respond"
-: "Niet antwoorden"
-
-, "The event of this message does not exist"
-: "Het evenement van dit bericht bestaat niet"
-
-, "The sender is not authorised to update the event"
-: "De afzender is niet geautoriseerd om het evenement aan te passen"
-
-, "This message is already processed"
-: "Dit bericht is al verwerkt"
-
-, "You are not an attendee of this event"
-: "Je bent geen genodigde voor dit evenement"
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: "Niet ondersteund bericht"
-
-, "This is an event invitation for someone else."
-: "Dit is een evenementen uitnodiging voor iemand anders"
-
-, "You have already replied to this event invitation."
-: "U heeft deze uitnodiging al beantwoord."
-
-, "You received an event invitation. Set your response to:"
-: "U heeft een uitnodiging ontvangen. Zet het antwoord op:"
-
-, "An invited attendee responded to the invitation."
-: "Een genodigde beantwoordde de uitnodiging."
-
-, "Unsupported method"
-: "Niet ondersteunde methode"
-
 , "Loading events, please wait..."
 : "Laden van de evenementen. Moment..."
 
@@ -325,6 +301,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : "Importeer evenement"
 
@@ -337,6 +316,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : "Kopieer {0}"
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : "Aanpassen van evenement in het verleden"
 
@@ -418,9 +400,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : "Breek deze actie af"
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Beheer bronnen"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Selecteer genodigde"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Prive"
+
+, "Tags"
+: "Tags"
+
+, "Blocking"
+: "Blokkerend"
+
+, "Tentative"
+: "Onder voorbehoud"
+
 , "Import Definition Success!"
 : "Import van definitie gelukt!"
 
@@ -457,9 +466,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : "Ververstijd"
 
@@ -511,7 +517,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -535,156 +541,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: "Bekijk"
-
-, "Details"
-: "Details"
-
-, "Saved in"
-: "Opgeslagen in"
-
-, "non-blocking"
-: "Niet-blokkerend"
-
-, "Enter description"
-: "Voer omschrijving in"
-
-, "Mute Notification"
-: "Notificatie uit"
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "Eind datum is niet mogelijk"
-
-, "End date must be after start date"
-: "Eind datum moet na begin datum vallen"
-
-, "End time is not allowed to be after the configured time."
-: "Eindtijd mag niet na de geconfigureerde tijd zijn."
-
-, "Start date is not valid"
-: "Begin datum is niet mogelijk"
-
-, "Start date is not allowed to be before the configured time."
-: "Startdatum mag niet voor de geconfigureerde tijd zijn."
-
-, "Week {0} :"
-: "Week {0} :"
-
-, "Originally"
-: "Origineel"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "WK"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Dagelijks"
-
-, "Weekly"
-: "Wekelijks"
-
-, "Monthly"
-: "Maandelijks"
-
-, "Yearly"
-: "Jaarlijks"
-
-, "Name"
-: "Naam"
-
-, "Email"
-: "E-mail"
-
-, "Type"
-: "Type"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Nieuw evenement"
-
-, "{0} more..."
-: "{0} meer..."
-
 , "private classification"
 : "privé klassificatie"
 
+, "recurring event"
+: "Terugkerend evenement"
+
+, "recurring event exception"
+: "uitzondering op terugkerend evenement"
+
 , "has alarm"
 : "heeft alarm"
 
@@ -694,62 +559,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, de {1}. van {2}"
+, "Mini Calendar"
+: "Kleine agenda"
 
-, "Click here to invite another attender..."
-: "Klik hier om nog een genodigde toe te voegen..."
+, "WK"
+: "WK"
 
-, "User"
-: "Gebruiker"
-
-, "Group"
-: "Groep"
-
-, "Resource, Resources"
-: [
-  "Bron"
- ,"Bronnen"
-
-]
-, "Member of group"
-: "Groepslid"
-
-, "This is the calendar where the attender has saved this event in"
-: "Dit is de kalender waar de genodigde het evenement heeft opgeslagen"
-
-, "Click icon to change"
-: "Klik op het icoon om aan te passen"
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Verwijder genodigde"
-
-, "Compose email"
-: "Maak een email"
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(als een groepslid)"
-
-, "External Attendee"
-: "Externe genodigde "
+, "{0} more..."
+: "{0} meer..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -769,6 +586,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -811,7 +631,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -841,102 +661,66 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: "Selecteer het evenement waaraan de contacten toegevoegd moeten worden"
+
+, "Role"
+: "Functie"
+
+, "Select Role"
+: "Selecteer functie"
+
+, "Status"
+: "Status"
+
+, "Select Status"
+: "Selecteer status"
+
+, "Adding {0} Attendee to event"
+: "Toevoegen {0} deelnemer aan event"
+
 , "no events found"
 : "Geen evenementen gevonden"
 
 , "Searching..."
 : "Zoeken..."
 
+, "Search Event"
+: "Zoek evenement"
+
 , "Event, Events"
 : [
   "Evenement"
  ,"Evenementen"
 
 ]
-, "Search Event"
-: "Zoek evenement"
-
-, "Switch to public poll"
+, "Additional Tags ..."
 : ""
 
-, "Welcome {name}"
+, "non-blocking"
+: "Niet-blokkerend"
+
+, "Displayed in"
+: "Weergegeven in"
+
+, "No Information"
+: "Geen informatie"
+
+, "Event Location"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "From"
 : ""
 
-, "This poll is closed already"
+, "until"
 : ""
 
-, "I am not {name}"
-: ""
+, "Events"
+: "Evenementen"
 
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Kleine agenda"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Agenda"
- ,"Agenda's"
-
-]
 , "Calendars"
 : "Agenda's"
 
@@ -970,6 +754,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : "Onbekende datum"
 
@@ -991,38 +787,239 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Genodigden"
 
 ]
+, "Resource, Resources"
+: [
+  "Bron"
+ ,"Bronnen"
+
+]
+, "Resources"
+: "Bronnen"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Naam"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "E-mail"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Type"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Klik hier om nog een genodigde toe te voegen..."
+
+, "User"
+: "Gebruiker"
+
+, "Group"
+: "Groep"
+
+, "Member of group"
+: "Groepslid"
+
+, "This is the calendar where the attender has saved this event in"
+: "Dit is de kalender waar de genodigde het evenement heeft opgeslagen"
+
+, "Click icon to change"
+: "Klik op het icoon om aan te passen"
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Verwijder genodigde"
+
+, "Compose email"
+: "Maak een email"
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(als een groepslid)"
+
+, "External Attendee"
+: "Externe genodigde "
+
+, "Originally"
+: "Origineel"
+
+, "Checking Calendar Data..."
+: "Controleren van kalender data..."
+
+, "Reply to Recurring Event"
+: "Antwoorden op terugkerend evenement"
+
+, "You are responding to an recurring event. What would you like to do?"
+: "U beantwoordt een terugkerend evenement. Wat wilt u doen?"
+
+, "Respond to whole series"
+: "Beantwoord de gehele serie"
+
+, "Do not respond"
+: "Niet antwoorden"
+
+, "The event of this message does not exist"
+: "Het evenement van dit bericht bestaat niet"
+
+, "The sender is not authorised to update the event"
+: "De afzender is niet geautoriseerd om het evenement aan te passen"
+
+, "This message is already processed"
+: "Dit bericht is al verwerkt"
+
+, "You are not an attendee of this event"
+: "Je bent geen genodigde voor dit evenement"
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: "Niet ondersteund bericht"
+
+, "This is an event invitation for someone else."
+: "Dit is een evenementen uitnodiging voor iemand anders"
+
+, "You have already replied to this event invitation."
+: "U heeft deze uitnodiging al beantwoord."
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: "U heeft een uitnodiging ontvangen. Zet het antwoord op:"
+
+, "An invited attendee responded to the invitation."
+: "Een genodigde beantwoordde de uitnodiging."
+
+, "Unsupported method"
+: "Niet ondersteunde methode"
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Voer omschrijving in..."
 
 , "Grants"
 : "Rechten"
 
-, "Displayed in"
-: "Weergegeven in"
+, "This event is originally stored in a calendar you don't have access to."
+: "Dit evenement is geplaatst in een agenda waar je geen toegang tot hebt."
 
-, "Event not found"
+, "This event is originally stored in {0}"
+: "Dit evenement is geplaatst in {0}"
+
+, "This event is additionally displayed in your personal calendar {0}"
+: "Dit evenement wordt bovendien weergegeven in uw persoonlijke kalender {0}"
+
+, "Colors"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "Side bar color"
 : ""
 
-, "GENDER_Attendee"
+, "Color by Calendar"
 : ""
 
-, "Select Attendee"
-: "Selecteer genodigde"
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: "Bekijk"
+
+, "Saved in"
+: "Opgeslagen in"
+
+, "Enter description"
+: "Voer omschrijving in"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "Eind datum is niet mogelijk"
+
+, "End date must be after start date"
+: "Eind datum moet na begin datum vallen"
+
+, "End time is not allowed to be after the configured time."
+: "Eindtijd mag niet na de geconfigureerde tijd zijn."
+
+, "Start date is not valid"
+: "Begin datum is niet mogelijk"
+
+, "Start date is not allowed to be before the configured time."
+: "Startdatum mag niet voor de geconfigureerde tijd zijn."
 
 , "The summary must not be longer than 255 characters."
 : "De samenvatting mag niet langer dan 255 tekens"
@@ -1036,128 +1033,143 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : "Samenvatting te kort"
 
-, "Recurrances"
-: "Herhalingen"
+, "Set This Date as Definite Event?"
+: ""
 
-, "No recurring rule defined"
-: "Geen terugkerende regel gedefinieerd"
+, "Do you want to close the poll and remove all other alternatives?"
+: ""
 
-, "None"
-: "Geen"
+, "Attendee/Resources"
+: ""
 
-, "Exceptions of reccuring events can't have recurrences themselves."
-: "Uitzonderingen van herhalende gebeurtenissen kunnen niet zelf herhalend zijn."
+, "Additional Attendees ..."
+: ""
 
-, "at"
-: "op"
+, "Default Status"
+: ""
 
-, "never"
+, "No Access"
+: ""
+
+, "All my events"
+: "Al mijn evenementen"
+
+, "Position on the left time axis, day and week view should start with"
+: ""
+
+, "Position on the left time axis, day and week view should end with"
+: ""
+
+, "Default Start Time"
+: "Standaard start tijd"
+
+, "Scroll position on the left time axis, day and week view should start with"
+: ""
+
+, "Visible Time"
+: ""
+
+, "Time to be displayed at once"
+: ""
+
+, "Default Calendar"
+: "Standaard agenda"
+
+, "The default calendar for invitations and new events"
+: "De standaard agenda voor uitnodigingen en nieuwe evenementen"
+
+, "Default Favorite"
+: "Standaard favoriet"
+
+, "The default favorite which is loaded on calendar startup"
+: "De standaard favoriet die bij het opstarten van agenda wordt geladen"
+
+, "Get Notification Emails"
+: "Stuur e-mail melding"
+
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "Het niveau van de acties die u wilt worden geïnformeerd. Houd er rekening mee dat de organisatoren meldingen krijgt voor alle updates, waaronder genodigde antwoorden, tenzij deze voorkeur is ingesteld op \"Never \""
+
+, "Send Notifications Emails of own Actions"
+: "Stuur Email meldingen van eigen acties"
+
+, "Get notifications emails for actions you did yourself"
+: "Email meldingen krijgen voor acties die u zelf heeft gedaan"
+
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
+, "Send Alarm Notifications Emails"
+: ""
+
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: "Standaard alarm aan"
+
+, "New events get a standard alarm as defined below"
+: "Nieuwe evenementen krijgen een standaard alarm zoals hieronder gedefinieerd"
+
+, "Standard Alarm Time"
+: "Standaard Alarm tijd"
+
+, "Minutes before the event starts"
+: "Minuten voordat het evenement begint"
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "Vaste kalenders"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
 : "Nooit"
 
-, "after {0} occurrences"
-: "na {0} herhalingen"
+, "On invitation and cancellation only"
+: "Op uitnodiging en annulering alleen"
 
-, "Except"
-: ""
+, "On time changes"
+: "Op tijd veranderingen"
 
-, "during events in the calendars"
-: ""
+, "On all updates but attendee responses"
+: "Op alle updates, maar genodigde reacties"
 
-, "End"
-: "Einde"
-
-, "Until has to be after event start"
-: "Einde moet na de start van het evenement vallen"
-
-, "The event is longer than the recurring interval"
-: "De gebeurtenis is langer dan het herhalende interval"
-
-, "Every {0}. Day"
-: "Elke {0} dag"
-
-, "Every {0}. Week at"
-: "Elke {0} week op"
-
-, "Every {0}. Month"
-: "Elke {0} maand"
-
-, "at the"
-: "op de"
-
-, "first"
-: "eerste"
-
-, "second"
-: "tweede"
-
-, "third"
-: "derde"
-
-, "fourth"
-: "vierde"
-
-, "last"
-: "laatste"
-
-, "Every {0}. Year"
-: "Elke {0} jaar"
-
-, "of"
-: " "
-
-, "First name, ĺast name"
-: ""
-
-, "E-Mail address"
-: ""
-
-, "Please wait..."
-: ""
-
-, "General terms and conditions"
-: ""
-
-, "Relation, Relations"
-: [
-  ""
- ,""
-
-]
-, "All events I attend"
-: "Alle evenementen waar ik aanwezig ben"
-
-, "Required"
-: "Verplicht"
-
-, "Optional"
-: "Optioneel"
-
-, "No response"
-: "Geen reactie"
-
-, "Accepted"
-: "Geaccepteerd"
-
-, "Declined"
-: "Afgewezen"
-
-, "Awaiting response"
-: "Wacht op reactie"
-
-, "Events I have not yet responded to"
-: "Evenementen waar ik nog niet op gereageerd heb"
-
-, "Declined events"
-: "Afgewezen evenementen"
-
-, "Events I have declined"
-: "Evenementen die ik heb afgewezen"
-
-, "I'm organizer"
-: "Ik ben organisator"
-
-, "Events I'm the organizer of"
-: "Evenement waar ik de organisator van ben"
+, "On attendee responses too"
+: "Reactie genodigden"
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : "Kalenders altijd geselecteerd ongeacht alle filterparameters. Een geldige use case zou kunnen zijn om de weergave van een bepaalde vakantie kalender dwingen."
@@ -1222,12 +1234,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Geen reactie"
+
+, "Accepted"
+: "Geaccepteerd"
+
+, "Declined"
+: "Afgewezen"
+
 , "Attendee Roles Available"
 : ""
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Verplicht"
+
+, "Optional"
+: "Optioneel"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1237,6 +1267,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1279,6 +1339,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1330,6 +1393,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1369,95 +1435,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Alarm voor evenement \"1$s\" op %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Uitnodiging evenement \"%1$s\" op %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "Evenement \"%1$s\" op %2$s is afgelast"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
-: "Evenement \"%1$s\" is verzet naar %2$s tot %3$s"
-
-, "Event \"%1$s\" at %2$s has been updated"
-: "Evenement \"%1$s\" op %2$s is aangepast"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s heeft evenement \"%2$s\" op %3$s geaccepteerd "
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s heeft evenement \"%2$s\" op %3$s afgewezen"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "%1$s is er misschien tijdens evenement \"%2$s\" op %3$s "
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Geen reactie van %1$s voor evenement \"%2$s\" op %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Genodigde aanpassingen voor event \"%1$s\" at %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Group Additional Filters"
 : ""
 
-, "Resource Management"
+, "Resource Additional Filters"
 : ""
 
-, "Polls for recurring events are not supported"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "%s's personal calendar"
+: "%s's persoonlijke agenda"
+
+, "Failed"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "The right Resource Admin must be set once."
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Different Calendar"
 : ""
 
-, "Start"
-: "Begin"
+, "Exdate container move are not allowed"
+: ""
 
-, "Priority"
-: "Prioriteit"
+, "Invalid URL given"
+: "Ongeldige URL opgegeven"
 
-, "Url"
-: "Url"
+, "The URL you used is invalid. Please use a valid one!"
+: "De URL die u gebruikt is niet geldig. Kies een geldige!"
 
-, "Recurrance rule"
-: "Herhalings regel"
+, "Calendars to export"
+: ""
 
-, "Is all day event"
-: "Hele dag afspraak"
+, "Export target"
+: ""
 
-, "Organizer timezone"
-: "Tijdzone origanisator"
+, "VCalendar/ICS"
+: ""
 
-, "No"
-: "Nee"
+, "Export visible events to ics file"
+: ""
 
-, "Yes"
-: "Ja"
+, "Excel overview"
+: ""
+
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: "Importeer iCal-bestanden"
 
 , "unknown"
 : "onbekend"
@@ -1516,35 +1591,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : "e"
 
+, "Start"
+: "Begin"
+
+, "Priority"
+: "Prioriteit"
+
+, "Url"
+: "Url"
+
+, "Recurrance rule"
+: "Herhalings regel"
+
+, "Is all day event"
+: "Hele dag afspraak"
+
+, "Organizer timezone"
+: "Tijdzone origanisator"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Alarm voor evenement \"1$s\" op %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Uitnodiging evenement \"%1$s\" op %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "Evenement \"%1$s\" op %2$s is afgelast"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+: "Evenement \"%1$s\" is verzet naar %2$s tot %3$s"
+
+, "Event \"%1$s\" at %2$s has been updated"
+: "Evenement \"%1$s\" op %2$s is aangepast"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s heeft evenement \"%2$s\" op %3$s geaccepteerd "
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s heeft evenement \"%2$s\" op %3$s afgewezen"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "%1$s is er misschien tijdens evenement \"%2$s\" op %3$s "
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Geen reactie van %1$s voor evenement \"%2$s\" op %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Genodigde aanpassingen voor event \"%1$s\" at %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Unknown action"
 : ""
 
-, "Word event sheet"
+, "Resource Management"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Excel all data"
+, "Polls for recurring events are not supported"
 : ""
 
-, "Import iCal-files"
-: "Importeer iCal-bestanden"
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
+: ""
 
 , "Updates"
 : "Updaten"
@@ -1582,32 +1726,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Details evenement"
 
-, "The poll \"%1$s\" has been closed."
-: ""
+, "All events I attend"
+: "Alle evenementen waar ik aanwezig ben"
 
-, "The definite event is scheduled for \"%1$s\""
-: ""
+, "Awaiting response"
+: "Wacht op reactie"
 
-, "You can review the poll results here:"
-: ""
+, "Events I have not yet responded to"
+: "Evenementen waar ik nog niet op gereageerd heb"
 
-, "Thank you for attendening the poll \"%1$s\""
-: ""
+, "Declined events"
+: "Afgewezen evenementen"
 
-, "To review or edit your status please use your personal link:"
-: ""
+, "Events I have declined"
+: "Evenementen die ik heb afgewezen"
 
-, "Different Calendar"
-: ""
+, "I'm organizer"
+: "Ik ben organisator"
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: "Ongeldige URL opgegeven"
-
-, "The URL you used is invalid. Please use a valid one!"
-: "De URL die u gebruikt is niet geldig. Kies een geldige!"
+, "Events I'm the organizer of"
+: "Evenement waar ik de organisator van ben"
 
 , "manage shared calendars"
 : "beheer gedeelde kalenders"
@@ -1627,80 +1765,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Alle rechten voor administratieve bronnen"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
+, "Relation, Relations"
+: [
+  ""
+ ,""
 
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Container name / New or existing if it already exists you need permissions to add to."
-: "Container  naam / Nieuw of bestaand. Bij bestaande moet u permissies toekennen. "
-
-, "or"
-: "of"
-
-, "Is a location"
-: "Is een locatie"
-
-, "Errors"
-: "Fouten"
-
-, "Do you really want to delete this event?"
-: "Weet u zeker dat dit evenement verwijderd moet worden?"
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Bron"
+, "Calendar"
+: "Agenda"
+
+, "Do you really want to delete this event?"
+: "Weet u zeker dat dit evenement verwijderd moet worden?"
 
 , "Resource Grant"
 : ""
@@ -1708,12 +1817,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Evenement"
 
-, "Calendar"
-: "Agenda"
-
 , "Attender"
 : "Genodigde"
 
+, "Resource"
+: "Bron"
+
 , "Relation"
 : ""
 
