@@ -5,167 +5,251 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "Calendário pessoal de %s"
+, "{0}, the {1}. of {2}"
+: "{0}, o {1}. de {2}"
 
-, "Resources"
-: "Recursos"
+, "Recurrances"
+: "Recorrências"
 
-, "All my events"
-: "Todos os meus eventos"
+, "No recurring rule defined"
+: "Nenhuma regra recorrente definida"
 
-, "Start Time"
-: "Hora de Início"
+, "Details"
+: "Detalhes"
 
-, "Position on the left time axis, day and week view should start with"
-: "Posição no eixo de tempo esquerdo, visão do dia e da semana deve começar com"
+, "None"
+: "Nenhum"
 
-, "End Time"
-: "Hora Final"
+, "Daily"
+: "Diariamente"
 
-, "Position on the left time axis, day and week view should end with"
-: ""
+, "Weekly"
+: "Semanalmente"
 
-, "Default Start Time"
-: ""
+, "Monthly"
+: "Mensalmente"
 
-, "Scroll position on the left time axis, day and week view should start with"
-: ""
+, "Yearly"
+: "Anualmente"
 
-, "Visible Time"
-: ""
+, "Exceptions of reccuring events can't have recurrences themselves."
+: "Exceções de eventos recorrentes não podem ter recorrências deles mesmos."
 
-, "Time to be displayed at once"
-: ""
+, "at"
+: "em"
 
-, "Default Calendar"
-: "Calendário Padrão"
+, "never"
+: "nunca"
 
-, "The default calendar for invitations and new events"
-: "O calendário padrão para convites e novos eventos"
+, "after {0} occurrences"
+: "após {0} ocorrências"
 
-, "Default Favorite"
-: "Favorito Padrão"
+, "Except"
+: "Exceto"
 
-, "The default favorite which is loaded on calendar startup"
-: "O favorito padrão que foi carregado no calendário de inicialização"
+, "during events in the calendars"
+: "durante eventos nos calendários"
 
-, "Get Notification Emails"
-: "Obter Emails de Notificações"
+, "End"
+: "Fim"
 
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "O nível de ações que você quer ser notificado.  Favor observe que a menos que esta preferência esteja assinalado no \"Nunca\""
+, "Until has to be after event start"
+: "Até que esteja após o início do evento"
 
-, "Send Notifications Emails of own Actions"
-: "Enviar Emails de Notificações das suas próprias Ações"
+, "The event is longer than the recurring interval"
+: "O evento é maior do que o intervalo de recorrência"
 
-, "Get notifications emails for actions you did yourself"
-: "Obter emails de notificações feitos por você mesmo"
+, "Every {0}. Day"
+: "Cada {0}. Dia"
 
-, "Send Alarm Notifications Emails"
-: ""
+, "Every {0}. Week at"
+: "Cada {0}. Semana em"
 
-, "Get event alarms via email"
-: ""
+, "Every {0}. Month"
+: "Cada {0}. Mes"
 
-, "Enable Standard Alarm"
-: "Ativar Alarme Padrão"
+, "at the"
+: "no"
 
-, "New events get a standard alarm as defined below"
-: "Novos eventos têm um padrão de alarme como definido abaixo"
+, "first"
+: "primeiro"
 
-, "Standard Alarm Time"
-: "Hora do Alarme Padrão"
+, "second"
+: "segundo"
 
-, "Minutes before the event starts"
-: "Minutos antes do evento começar"
+, "third"
+: "terceiro"
 
-, "Default Attendee Strategy"
-: ""
+, "fourth"
+: "quarto"
 
-, "Default Attendee Strategy for new events"
-: ""
+, "last"
+: "último"
 
-, "Time Increment"
-: ""
+, "Every {0}. Year"
+: "Cada {0}. Ano"
 
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "Calendários fixos"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: "Nunca"
-
-, "On invitation and cancellation only"
-: "A convite e cancelamento somente"
-
-, "On time changes"
-: "Mudanças na hora"
-
-, "On all updates but attendee responses"
-: "Em todas as atualizações mas respostas dos participantes"
-
-, "On attendee responses too"
-: "Em respostas dos participantes também"
-
-, "Events"
-: "Eventos"
+, "of"
+: "de"
 
 , "Summary"
 : "Sumário"
 
-, "Status"
-: "Situação"
+, "Organizer"
+: "Organizador"
 
-, "No Information"
-: "Sem informação"
-
-, "recurring event"
-: "evento recorrente"
-
-, "recurring event exception"
-: "evento de exceção recorrente"
-
-, "Blocking"
-: "Bloqueando"
-
-, "Tentative"
-: "Tentativa"
+, "Description"
+: "Descrição"
 
 , "Location"
 : "Locação"
 
-, "Organizer"
-: "Organizador"
+, "Start Time"
+: "Hora de Início"
+
+, "End Time"
+: "Hora Final"
 
 , "Attendee"
 : "Participante"
 
+, "whole day"
+: "dia inteiro"
+
+, "Week {0} :"
+: "Semana {0} :"
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Novo Evento"
+
+, "Calendar, Calendars"
+: [
+  "Calendário"
+ ,"Calendários"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: "Cancelar"
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: "Senha"
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : "Adicionar participante"
 
@@ -175,117 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : "Verifique antes de filtrar este participante"
 
-, "Attachments"
+, "Unavailable"
 : ""
 
-, "Private"
-: "Privado"
-
-, "Tags"
-: "Identificações"
-
-, "whole day"
-: "dia inteiro"
-
-, "Description"
-: "Descrição"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: "Cancelar"
-
-, "Ok"
-: "OK"
-
-, "This event is originally stored in a calendar you don't have access to."
-: "Este evento foi originalmente carregado no calendário e você não tem acesso"
-
-, "This event is originally stored in {0}"
-: "Este evendo foi originalmente carregado em {0}"
-
-, "This event is additionally displayed in your personal calendar {0}"
-: "Este evento foi exibido adicionalmente no seu calendário pessoal {0}"
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: "Favor escolher o Evento para adicionar os contatos"
-
-, "Role"
-: "Função"
-
-, "Select Role"
-: "Selecionar Função"
-
-, "Select Status"
-: "Selecionar estado"
-
-, "Adding {0} Attendee to event"
-: "Adicionando {0} Participante ao evento"
-
-, "Checking Calendar Data..."
-: "Checando Dados do Calendário..."
-
-, "Reply to Recurring Event"
-: "Responder ao Evento Recorrente"
-
-, "You are responding to an recurring event. What would you like to do?"
-: "Você está respondendo a um evento recorrente.  O que você quer fazer?"
-
-, "Respond to whole series"
-: "Responder para series inteiras"
-
-, "Do not respond"
-: "Não responda"
-
-, "The event of this message does not exist"
-: "O evento dessa mensagem não existe"
-
-, "The sender is not authorised to update the event"
-: "O remetente não está autorizado a atualizar o evento"
-
-, "This message is already processed"
-: "Esta mensagem já foi processada"
-
-, "You are not an attendee of this event"
-: "Você não é participante deste evento"
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: "Este evento foi cancelado"
-
-, "Unsupported message"
-: "Mensagem não suportada"
-
-, "This is an event invitation for someone else."
-: "Este é um convite de evento para alguém."
-
-, "You have already replied to this event invitation."
-: "Você já respondeu a este convite de evento"
-
-, "You received an event invitation. Set your response to:"
-: "Você recebeu um convite para evento. Enviar sua resposta para:"
-
-, "An invited attendee responded to the invitation."
-: "Um participante convidado respondeu ao convite."
-
-, "Unsupported method"
-: "Método não suportado"
-
 , "Loading events, please wait..."
 : "Carregando eventos, favor aguardar..."
 
@@ -325,6 +301,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : "Ano"
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : "Importar Eventos"
 
@@ -337,6 +316,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : "Copiar {0}"
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : "Atualizando evento na pasta"
 
@@ -418,9 +400,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : "Cancelar esta ação"
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Administrar Recursos"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Selecionar Participante"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Privado"
+
+, "Tags"
+: "Identificações"
+
+, "Blocking"
+: "Bloqueando"
+
+, "Tentative"
+: "Tentativa"
+
 , "Import Definition Success!"
 : ""
 
@@ -457,9 +466,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: "Senha"
-
 , "Refresh time"
 : ""
 
@@ -511,8 +517,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
-: ""
+, "Ok"
+: "OK"
 
 , "Free Time Search"
 : ""
@@ -535,156 +541,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: "Visão"
-
-, "Details"
-: "Detalhes"
-
-, "Saved in"
-: "Salvo em"
-
-, "non-blocking"
-: "sem bloqueio"
-
-, "Enter description"
-: "Informe a descrição"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "Data final não é válida"
-
-, "End date must be after start date"
-: "Data final deve ser posterior à data de início"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "Data de início não é válida"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: "Semana {0} :"
-
-, "Originally"
-: "Originalmente"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "WK"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Diariamente"
-
-, "Weekly"
-: "Semanalmente"
-
-, "Monthly"
-: "Mensalmente"
-
-, "Yearly"
-: "Anualmente"
-
-, "Name"
-: "Nome"
-
-, "Email"
-: "Email"
-
-, "Type"
-: "Tipo"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Novo Evento"
-
-, "{0} more..."
-: "{0} mais..."
-
 , "private classification"
 : "classificação privada"
 
+, "recurring event"
+: "evento recorrente"
+
+, "recurring event exception"
+: "evento de exceção recorrente"
+
 , "has alarm"
 : "tem alarme"
 
@@ -694,62 +559,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, o {1}. de {2}"
+, "Mini Calendar"
+: "Mini Calendário"
 
-, "Click here to invite another attender..."
-: "Clique aqui para convidar outro participante..."
+, "WK"
+: "WK"
 
-, "User"
-: "Usuário"
-
-, "Group"
-: "Grupo"
-
-, "Resource, Resources"
-: [
-  "Recurso"
- ,"Recursos"
-
-]
-, "Member of group"
-: "Membro do grupo"
-
-, "This is the calendar where the attender has saved this event in"
-: "Este é o calendário onde o participante salvou este evento no"
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Remover Participante"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(como um membro do grupo)"
-
-, "External Attendee"
-: "Participante Externo"
+, "{0} more..."
+: "{0} mais..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -769,6 +586,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -811,7 +631,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -841,102 +661,66 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: "Favor escolher o Evento para adicionar os contatos"
+
+, "Role"
+: "Função"
+
+, "Select Role"
+: "Selecionar Função"
+
+, "Status"
+: "Situação"
+
+, "Select Status"
+: "Selecionar estado"
+
+, "Adding {0} Attendee to event"
+: "Adicionando {0} Participante ao evento"
+
 , "no events found"
 : "nenhum evento encontrado"
 
 , "Searching..."
 : "Pesquisando..."
 
+, "Search Event"
+: "Pesquisar Evento"
+
 , "Event, Events"
 : [
   "Evento"
  ,"Eventos"
 
 ]
-, "Search Event"
-: "Pesquisar Evento"
-
-, "Switch to public poll"
+, "Additional Tags ..."
 : ""
 
-, "Welcome {name}"
+, "non-blocking"
+: "sem bloqueio"
+
+, "Displayed in"
+: "Exibido em"
+
+, "No Information"
+: "Sem informação"
+
+, "Event Location"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "From"
 : ""
 
-, "This poll is closed already"
+, "until"
 : ""
 
-, "I am not {name}"
-: ""
+, "Events"
+: "Eventos"
 
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Mini Calendário"
-
-, "Colors"
-: "Cores"
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Calendário"
- ,"Calendários"
-
-]
 , "Calendars"
 : "Calendários"
 
@@ -970,6 +754,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : "Data desconhecida"
 
@@ -991,38 +787,239 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Participantes"
 
 ]
+, "Resource, Resources"
+: [
+  "Recurso"
+ ,"Recursos"
+
+]
+, "Resources"
+: "Recursos"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Nome"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "Email"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Tipo"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Clique aqui para convidar outro participante..."
+
+, "User"
+: "Usuário"
+
+, "Group"
+: "Grupo"
+
+, "Member of group"
+: "Membro do grupo"
+
+, "This is the calendar where the attender has saved this event in"
+: "Este é o calendário onde o participante salvou este evento no"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Remover Participante"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(como um membro do grupo)"
+
+, "External Attendee"
+: "Participante Externo"
+
+, "Originally"
+: "Originalmente"
+
+, "Checking Calendar Data..."
+: "Checando Dados do Calendário..."
+
+, "Reply to Recurring Event"
+: "Responder ao Evento Recorrente"
+
+, "You are responding to an recurring event. What would you like to do?"
+: "Você está respondendo a um evento recorrente.  O que você quer fazer?"
+
+, "Respond to whole series"
+: "Responder para series inteiras"
+
+, "Do not respond"
+: "Não responda"
+
+, "The event of this message does not exist"
+: "O evento dessa mensagem não existe"
+
+, "The sender is not authorised to update the event"
+: "O remetente não está autorizado a atualizar o evento"
+
+, "This message is already processed"
+: "Esta mensagem já foi processada"
+
+, "You are not an attendee of this event"
+: "Você não é participante deste evento"
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: "Este evento foi cancelado"
+
+, "Unsupported message"
+: "Mensagem não suportada"
+
+, "This is an event invitation for someone else."
+: "Este é um convite de evento para alguém."
+
+, "You have already replied to this event invitation."
+: "Você já respondeu a este convite de evento"
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: "Você recebeu um convite para evento. Enviar sua resposta para:"
+
+, "An invited attendee responded to the invitation."
+: "Um participante convidado respondeu ao convite."
+
+, "Unsupported method"
+: "Método não suportado"
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Informar descrição..."
 
 , "Grants"
 : "Concessões"
 
-, "Displayed in"
-: "Exibido em"
+, "This event is originally stored in a calendar you don't have access to."
+: "Este evento foi originalmente carregado no calendário e você não tem acesso"
 
-, "Event not found"
+, "This event is originally stored in {0}"
+: "Este evendo foi originalmente carregado em {0}"
+
+, "This event is additionally displayed in your personal calendar {0}"
+: "Este evento foi exibido adicionalmente no seu calendário pessoal {0}"
+
+, "Colors"
+: "Cores"
+
+, "Side bar color"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "Color by Calendar"
 : ""
 
-, "GENDER_Attendee"
+, "Color by Attendee Calendar"
 : ""
 
-, "Select Attendee"
-: "Selecionar Participante"
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: "Visão"
+
+, "Saved in"
+: "Salvo em"
+
+, "Enter description"
+: "Informe a descrição"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "Data final não é válida"
+
+, "End date must be after start date"
+: "Data final deve ser posterior à data de início"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "Data de início não é válida"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : "O sumário não pode ter mais que 255 caracteres"
@@ -1036,128 +1033,143 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : "Sumário muito pequeno"
 
-, "Recurrances"
-: "Recorrências"
-
-, "No recurring rule defined"
-: "Nenhuma regra recorrente definida"
-
-, "None"
-: "Nenhum"
-
-, "Exceptions of reccuring events can't have recurrences themselves."
-: "Exceções de eventos recorrentes não podem ter recorrências deles mesmos."
-
-, "at"
-: "em"
-
-, "never"
-: "nunca"
-
-, "after {0} occurrences"
-: "após {0} ocorrências"
-
-, "Except"
-: "Exceto"
-
-, "during events in the calendars"
-: "durante eventos nos calendários"
-
-, "End"
-: "Fim"
-
-, "Until has to be after event start"
-: "Até que esteja após o início do evento"
-
-, "The event is longer than the recurring interval"
-: "O evento é maior do que o intervalo de recorrência"
-
-, "Every {0}. Day"
-: "Cada {0}. Dia"
-
-, "Every {0}. Week at"
-: "Cada {0}. Semana em"
-
-, "Every {0}. Month"
-: "Cada {0}. Mes"
-
-, "at the"
-: "no"
-
-, "first"
-: "primeiro"
-
-, "second"
-: "segundo"
-
-, "third"
-: "terceiro"
-
-, "fourth"
-: "quarto"
-
-, "last"
-: "último"
-
-, "Every {0}. Year"
-: "Cada {0}. Ano"
-
-, "of"
-: "de"
-
-, "First name, ĺast name"
+, "Set This Date as Definite Event?"
 : ""
 
-, "E-Mail address"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "Please wait..."
+, "Attendee/Resources"
 : ""
 
-, "General terms and conditions"
+, "Additional Attendees ..."
 : ""
 
-, "Relation, Relations"
-: [
-  ""
- ,""
+, "Default Status"
+: ""
 
-]
-, "All events I attend"
-: "Todos os eventos que eu participo"
+, "No Access"
+: ""
 
-, "Required"
-: "Exigido"
+, "All my events"
+: "Todos os meus eventos"
 
-, "Optional"
-: "Opcional"
+, "Position on the left time axis, day and week view should start with"
+: "Posição no eixo de tempo esquerdo, visão do dia e da semana deve começar com"
 
-, "No response"
-: "Sem resposta"
+, "Position on the left time axis, day and week view should end with"
+: ""
 
-, "Accepted"
-: "Aceito"
+, "Default Start Time"
+: ""
 
-, "Declined"
-: "Recusado"
+, "Scroll position on the left time axis, day and week view should start with"
+: ""
 
-, "Awaiting response"
-: "Aguardando resposta"
+, "Visible Time"
+: ""
 
-, "Events I have not yet responded to"
-: "Eventos que eu ainda não tenho resposta"
+, "Time to be displayed at once"
+: ""
 
-, "Declined events"
-: "Eventos recusados"
+, "Default Calendar"
+: "Calendário Padrão"
 
-, "Events I have declined"
-: "Eventos que eu recusei"
+, "The default calendar for invitations and new events"
+: "O calendário padrão para convites e novos eventos"
 
-, "I'm organizer"
-: "Eu sou organizador"
+, "Default Favorite"
+: "Favorito Padrão"
 
-, "Events I'm the organizer of"
-: "Eventos que eu sou organizador de"
+, "The default favorite which is loaded on calendar startup"
+: "O favorito padrão que foi carregado no calendário de inicialização"
+
+, "Get Notification Emails"
+: "Obter Emails de Notificações"
+
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "O nível de ações que você quer ser notificado.  Favor observe que a menos que esta preferência esteja assinalado no \"Nunca\""
+
+, "Send Notifications Emails of own Actions"
+: "Enviar Emails de Notificações das suas próprias Ações"
+
+, "Get notifications emails for actions you did yourself"
+: "Obter emails de notificações feitos por você mesmo"
+
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
+, "Send Alarm Notifications Emails"
+: ""
+
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: "Ativar Alarme Padrão"
+
+, "New events get a standard alarm as defined below"
+: "Novos eventos têm um padrão de alarme como definido abaixo"
+
+, "Standard Alarm Time"
+: "Hora do Alarme Padrão"
+
+, "Minutes before the event starts"
+: "Minutos antes do evento começar"
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "Calendários fixos"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: "Nunca"
+
+, "On invitation and cancellation only"
+: "A convite e cancelamento somente"
+
+, "On time changes"
+: "Mudanças na hora"
+
+, "On all updates but attendee responses"
+: "Em todas as atualizações mas respostas dos participantes"
+
+, "On attendee responses too"
+: "Em respostas dos participantes também"
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : "Calendários sempre selecionados independentemente de todos os parâmetros de filtro. Um caso de utilização válida poderia ser a de forçar a apresentação de um certo calendário de férias."
@@ -1222,12 +1234,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Sem resposta"
+
+, "Accepted"
+: "Aceito"
+
+, "Declined"
+: "Recusado"
+
 , "Attendee Roles Available"
 : "Funções de Participante Disponíveis"
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Exigido"
+
+, "Optional"
+: "Opcional"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1237,6 +1267,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1279,6 +1339,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1330,6 +1393,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1369,95 +1435,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Alarme para eventos \"%1$s\" at %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Convite para Eventos \"%1$s\" em %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
-: "Recurso \"%1$s\" foi reservado por \"%2$s\" em %3$s"
-
-, "Event \"%1$s\" at %2$s has been canceled"
-: "Eventos \"%1$s\" em %2$s foi cancelado"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
-: "Evento \"%1$s\" foi reagendado de %2$s para %3$s"
-
-, "Event \"%1$s\" at %2$s has been updated"
-: "Evento \"%1$s\" em  %2$s foi atualizado"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s aceitou evento \"%2$s\" em %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s evento recusado \"%2$s\" em %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "Tentativa de resposta de %1$s para o \"%2$s\" em %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Nenhuma resposta de %1$s para o evento \"%2$s\" em %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Modificações de participante para o evento \"%1$s\" em %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "User Additional Filters"
 : ""
 
-, "Resource Management"
+, "Group Additional Filters"
 : ""
 
-, "Polls for recurring events are not supported"
+, "Resource Additional Filters"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "%s's personal calendar"
+: "Calendário pessoal de %s"
+
+, "Failed"
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "The right Resource Admin must be set once."
 : ""
 
-, "Start"
-: "Início"
+, "Different Calendar"
+: ""
 
-, "Priority"
-: "Prioridade"
+, "Exdate container move are not allowed"
+: ""
 
-, "Url"
-: "Url"
+, "Invalid URL given"
+: ""
 
-, "Recurrance rule"
-: "Regra de recorrência"
+, "The URL you used is invalid. Please use a valid one!"
+: "A URL que você usou é inválida. Por favor use uma válida!"
 
-, "Is all day event"
-: "São todos os eventos do dia"
+, "Calendars to export"
+: ""
 
-, "Organizer timezone"
-: "Fuso horário organizador"
+, "Export target"
+: ""
 
-, "No"
-: "Não"
+, "VCalendar/ICS"
+: ""
 
-, "Yes"
-: "Sim"
+, "Export visible events to ics file"
+: ""
+
+, "Excel overview"
+: ""
+
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: "Importar Arquivos iCal"
 
 , "unknown"
 : "desconhecido"
@@ -1516,35 +1591,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: "Início"
+
+, "Priority"
+: "Prioridade"
+
+, "Url"
+: "Url"
+
+, "Recurrance rule"
+: "Regra de recorrência"
+
+, "Is all day event"
+: "São todos os eventos do dia"
+
+, "Organizer timezone"
+: "Fuso horário organizador"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Alarme para eventos \"%1$s\" at %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Convite para Eventos \"%1$s\" em %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+: "Recurso \"%1$s\" foi reservado por \"%2$s\" em %3$s"
+
+, "Event \"%1$s\" at %2$s has been canceled"
+: "Eventos \"%1$s\" em %2$s foi cancelado"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+: "Evento \"%1$s\" foi reagendado de %2$s para %3$s"
+
+, "Event \"%1$s\" at %2$s has been updated"
+: "Evento \"%1$s\" em  %2$s foi atualizado"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s aceitou evento \"%2$s\" em %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s evento recusado \"%2$s\" em %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "Tentativa de resposta de %1$s para o \"%2$s\" em %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Nenhuma resposta de %1$s para o evento \"%2$s\" em %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Modificações de participante para o evento \"%1$s\" em %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "OpenDocument all data"
+, "Unknown action"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Resource Management"
 : ""
 
-, "Word event sheet"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "Polls for recurring events are not supported"
 : ""
 
-, "Excel all data"
+, "This contact has been automatically added by the system as a poll attendee"
 : ""
 
-, "Import iCal-files"
-: "Importar Arquivos iCal"
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
+: ""
 
 , "Updates"
 : "Atualizados"
@@ -1582,32 +1726,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Detalhes do evento"
 
-, "The poll \"%1$s\" has been closed."
-: ""
+, "All events I attend"
+: "Todos os eventos que eu participo"
 
-, "The definite event is scheduled for \"%1$s\""
-: ""
+, "Awaiting response"
+: "Aguardando resposta"
 
-, "You can review the poll results here:"
-: ""
+, "Events I have not yet responded to"
+: "Eventos que eu ainda não tenho resposta"
 
-, "Thank you for attendening the poll \"%1$s\""
-: ""
+, "Declined events"
+: "Eventos recusados"
 
-, "To review or edit your status please use your personal link:"
-: ""
+, "Events I have declined"
+: "Eventos que eu recusei"
 
-, "Different Calendar"
-: ""
+, "I'm organizer"
+: "Eu sou organizador"
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
-: "A URL que você usou é inválida. Por favor use uma válida!"
+, "Events I'm the organizer of"
+: "Eventos que eu sou organizador de"
 
 , "manage shared calendars"
 : "administrar calendários compartilhados"
@@ -1627,77 +1765,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Todos os direitos para administrar recursos"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "É a localização"
-
-, "Errors"
-: "Erros"
-
-, "If enabled every created event is always privat."
-: "Se habilitado todo evento criado sempre será privado"
-
-, "Do you really want to delete this event?"
-: "Você quer realmente apagar este evento?"
+, "Relation, Relations"
+: [
+  ""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Recurso"
+, "Calendar"
+: "Calendário"
+
+, "Do you really want to delete this event?"
+: "Você quer realmente apagar este evento?"
 
 , "Resource Grant"
 : ""
@@ -1705,12 +1816,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Evento"
 
-, "Calendar"
-: "Calendário"
-
 , "Attender"
 : "Participante"
 
+, "Resource"
+: "Recurso"
+
 , "Relation"
 : ""
 
