@@ -5,167 +5,251 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "Kalendari perosnal i %s"
+, "{0}, the {1}. of {2}"
+: "{0}, në {1}. të {2}"
 
-, "Resources"
-: "Burime"
+, "Recurrances"
+: "Përsëritje"
 
-, "All my events"
-: "Të gjitha ngjarjet e mia"
+, "No recurring rule defined"
+: "Nuk është përcaktuar një rregull përseritës"
 
-, "Start Time"
-: "Koha e fillimit"
+, "Details"
+: "Detaje"
 
-, "Position on the left time axis, day and week view should start with"
-: "Pozicioni i krahut të majte kohor, pamja e ditës dhe javës duhet të fillojë me  "
+, "None"
+: "Asnjë"
 
-, "End Time"
-: "Koha e mbarimit"
+, "Daily"
+: "I Përditshëm"
 
-, "Position on the left time axis, day and week view should end with"
+, "Weekly"
+: "I Përjavshëm"
+
+, "Monthly"
+: "I Përmuajshëm"
+
+, "Yearly"
+: "I Përvitshëm"
+
+, "Exceptions of reccuring events can't have recurrences themselves."
+: "Përjashtimet e ngjarjeve përsëritëse nuk mund të përsërisin vetvehten"
+
+, "at"
+: "në"
+
+, "never"
+: "asnjëherë"
+
+, "after {0} occurrences"
+: "pas {0} ndodhive"
+
+, "Except"
 : ""
 
-, "Default Start Time"
+, "during events in the calendars"
 : ""
 
-, "Scroll position on the left time axis, day and week view should start with"
+, "End"
+: "Fund"
+
+, "Until has to be after event start"
+: "Derisa të jetë pasi ngjarja fillon"
+
+, "The event is longer than the recurring interval"
 : ""
 
-, "Visible Time"
-: ""
+, "Every {0}. Day"
+: "Çdo {0}. Ditë"
 
-, "Time to be displayed at once"
-: ""
+, "Every {0}. Week at"
+: "Çdo {0}. Javë në"
 
-, "Default Calendar"
-: "Kalendari i paracaktuar"
+, "Every {0}. Month"
+: "Çdo {0}. Muaj"
 
-, "The default calendar for invitations and new events"
-: "Kalendari i paracaktuar për ftesa dhe ngjarje të reja"
+, "at the"
+: "Në"
 
-, "Default Favorite"
-: "Të preferuarat e Paracaktuara"
+, "first"
+: "i pari"
 
-, "The default favorite which is loaded on calendar startup"
-: "E preferuara e paracaktuar që ngarkohet në nisje të kalendarit"
+, "second"
+: "i dyti"
 
-, "Get Notification Emails"
-: "Merr E-Postë njoftuese"
+, "third"
+: "i treti"
 
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "Niveli i veprimeve që ju doni të njoftoheni. Ju lutem kini parasysh që organizuesit do të marrin njoftimpër të gjithë përditësimet, përfshirë edhe përgjigjet e vijuesëve, derisa kjo preferncë të jetë vendosur në \"Never\""
+, "fourth"
+: "i katërti"
 
-, "Send Notifications Emails of own Actions"
-: "Dërgo E-Postë njoftuese për Veprimet vetjake"
+, "last"
+: "i fundit"
 
-, "Get notifications emails for actions you did yourself"
-: "Dërgo E-Postë njoftuese për veprimet që bëre vetë"
+, "Every {0}. Year"
+: "Çdo {0}. Vit"
 
-, "Send Alarm Notifications Emails"
-: ""
-
-, "Get event alarms via email"
-: ""
-
-, "Enable Standard Alarm"
-: "Aktivizo Alarmin Standart"
-
-, "New events get a standard alarm as defined below"
-: "Ngjarjet e reja marrin një alarm standart siç përcaktohet më poshtë"
-
-, "Standard Alarm Time"
-: "Koha e Alarmit Standart"
-
-, "Minutes before the event starts"
-: "Minuta përpara se ngjarja të fillojë"
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "Kalendarë fiks"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: "Asnjëherë"
-
-, "On invitation and cancellation only"
-: "Vetëm në ftesa dhe anullime"
-
-, "On time changes"
-: "Në ndryshime të kohës"
-
-, "On all updates but attendee responses"
-: "Në të gjithë përditësimet e përgjigjeve të vijuesve"
-
-, "On attendee responses too"
-: "Gjithashtu në përgjigje të vijuesve"
-
-, "Events"
-: "Ngjarje"
+, "of"
+: "e"
 
 , "Summary"
 : "Përmbledhje"
 
-, "Status"
-: "Statusi"
+, "Organizer"
+: "Organizuesi"
 
-, "No Information"
-: "Nuk ka informacion"
-
-, "recurring event"
-: "ngjarje periodike"
-
-, "recurring event exception"
-: "përjashtim i ngjarjes periodike"
-
-, "Blocking"
-: "Bllokim"
-
-, "Tentative"
-: "E paqarte"
+, "Description"
+: "Përshkrimi"
 
 , "Location"
 : "Vëndi"
 
-, "Organizer"
-: "Organizuesi"
+, "Start Time"
+: "Koha e fillimit"
+
+, "End Time"
+: "Koha e mbarimit"
 
 , "Attendee"
 : "Vijues"
 
+, "whole day"
+: "të gjithë ditën"
+
+, "Week {0} :"
+: "Java {0} :"
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Ngjarje e Re"
+
+, "Calendar, Calendars"
+: [
+  "Kalendar"
+ ,"Kalendarë"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : "Shto vijues"
 
@@ -175,117 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : "Kontrollo tek filtri për këtë vijues"
 
-, "Attachments"
+, "Unavailable"
 : ""
 
-, "Private"
-: "Private"
-
-, "Tags"
-: "Etiketa"
-
-, "whole day"
-: "të gjithë ditën"
-
-, "Description"
-: "Përshkrimi"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: "Kjo ngjarje është vendosur fillimisht në një kalendar ku ju nuk kini të drejta"
-
-, "This event is originally stored in {0}"
-: "Kjo ngjarje është vendosur fillimisht në {0}"
-
-, "This event is additionally displayed in your personal calendar {0}"
-: "Kjo ngjarje është shfaqur gjithashtu tek kalendari juaj personal {0}"
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: "Lutemi zgjidhni Ngjarjen ku të shtohen kontaktet"
-
-, "Role"
-: "Role"
-
-, "Select Role"
-: "Zgjidhni Rolin"
-
-, "Select Status"
-: "Zgjidhni Statusin"
-
-, "Adding {0} Attendee to event"
-: "Duke i shtuar {0} vijues ngjarjes"
-
-, "Checking Calendar Data..."
-: "Duke kontrolluar të dhënat e kalendarit..."
-
-, "Reply to Recurring Event"
-: "Përgjigju Ngjarjes Periodike"
-
-, "You are responding to an recurring event. What would you like to do?"
-: "Ju po i përgjigjeni një ngjarje periodike. Çfarë doni të bëni?"
-
-, "Respond to whole series"
-: "Përgjigju të gjithë serive"
-
-, "Do not respond"
-: "Mos u përgjigj"
-
-, "The event of this message does not exist"
-: "Ngjarja e këtij mesazhi nuk ekziston"
-
-, "The sender is not authorised to update the event"
-: "Dërguesi nuk është i autorizuar te përditësoje këte ngjarje"
-
-, "This message is already processed"
-: "Ky mesazh është tashmë i përpunuar"
-
-, "You are not an attendee of this event"
-: "Ju nuk jeni në vijim të kësaj ngjarje"
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: "Mesazh i pa mbështetshëm"
-
-, "This is an event invitation for someone else."
-: "Kjo është një ftesë ngjarje për dikë tjetër"
-
-, "You have already replied to this event invitation."
-: "Ju i jeni përgjigjur tashmë ftesës së kesaj ngjarjeje"
-
-, "You received an event invitation. Set your response to:"
-: "Ju ka ardhur një ftesë ngjarjeje. Vendosni përgjigjen tuaj tek:"
-
-, "An invited attendee responded to the invitation."
-: "Një vijues i ftuar i është përgjigjur ftesës"
-
-, "Unsupported method"
-: "Metodë e pa mbështetshme"
-
 , "Loading events, please wait..."
 : "Duke ngarkuar ngjarjet, ju lutem prisni..."
 
@@ -325,6 +301,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +316,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : "Kopje {0}"
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : "Duke përditësuar ngjarjen në të shkuarën"
 
@@ -418,9 +400,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : "Anullo këtë veprim"
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Menaxho Burimet"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Zgjidhni Vijues"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Private"
+
+, "Tags"
+: "Etiketa"
+
+, "Blocking"
+: "Bllokim"
+
+, "Tentative"
+: "E paqarte"
+
 , "Import Definition Success!"
 : ""
 
@@ -457,9 +466,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -511,7 +517,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -535,156 +541,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: "Shiko"
-
-, "Details"
-: "Detaje"
-
-, "Saved in"
-: "Ruajtur në"
-
-, "non-blocking"
-: "jo-bllokuar"
-
-, "Enter description"
-: "Fusni përshkrimin"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "Data e mbarimit nuk është e vlefshme"
-
-, "End date must be after start date"
-: "Data e mbarimit duhet të jetë mbas datës së fillimit"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "Data e fillimit nuk është e vlefshme"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: "Java {0} :"
-
-, "Originally"
-: "Fillimisht"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "JV"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "I Përditshëm"
-
-, "Weekly"
-: "I Përjavshëm"
-
-, "Monthly"
-: "I Përmuajshëm"
-
-, "Yearly"
-: "I Përvitshëm"
-
-, "Name"
-: "Emri"
-
-, "Email"
-: "E-Postë"
-
-, "Type"
-: "Tipi"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Ngjarje e Re"
-
-, "{0} more..."
-: "{0} më shumë..."
-
 , "private classification"
 : "klasifikim privat"
 
+, "recurring event"
+: "ngjarje periodike"
+
+, "recurring event exception"
+: "përjashtim i ngjarjes periodike"
+
 , "has alarm"
 : "ka alarm"
 
@@ -694,62 +559,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, në {1}. të {2}"
+, "Mini Calendar"
+: "Mini Kalendar"
 
-, "Click here to invite another attender..."
-: "Kliko këtu për të ftuar një vijues tjetër"
+, "WK"
+: "JV"
 
-, "User"
-: "Përdorues"
-
-, "Group"
-: "Grup"
-
-, "Resource, Resources"
-: [
-  "Burim"
- ,"Burime"
-
-]
-, "Member of group"
-: "Pjesëtar i grupit"
-
-, "This is the calendar where the attender has saved this event in"
-: "Ky është kalendari ku vijuesi ka ruajtur këtë ngjarje"
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Hiqni Vijuesin"
-
-, "Compose email"
-: "Krijo E-Poste"
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(si pjesëtar i grupit)"
-
-, "External Attendee"
-: "Vijues i Jashtem"
+, "{0} more..."
+: "{0} më shumë..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -769,6 +586,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -811,7 +631,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -841,102 +661,66 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: "Lutemi zgjidhni Ngjarjen ku të shtohen kontaktet"
+
+, "Role"
+: "Role"
+
+, "Select Role"
+: "Zgjidhni Rolin"
+
+, "Status"
+: "Statusi"
+
+, "Select Status"
+: "Zgjidhni Statusin"
+
+, "Adding {0} Attendee to event"
+: "Duke i shtuar {0} vijues ngjarjes"
+
 , "no events found"
 : "nuk u gjendën ngjarje"
 
 , "Searching..."
 : "Duke Kërkuar"
 
+, "Search Event"
+: "Kërko Ngjarje"
+
 , "Event, Events"
 : [
   "Ngjarje"
  ,"Ngjarje"
 
 ]
-, "Search Event"
-: "Kërko Ngjarje"
-
-, "Switch to public poll"
+, "Additional Tags ..."
 : ""
 
-, "Welcome {name}"
+, "non-blocking"
+: "jo-bllokuar"
+
+, "Displayed in"
+: "E shfaqur në"
+
+, "No Information"
+: "Nuk ka informacion"
+
+, "Event Location"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "From"
 : ""
 
-, "This poll is closed already"
+, "until"
 : ""
 
-, "I am not {name}"
-: ""
+, "Events"
+: "Ngjarje"
 
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Mini Kalendar"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Kalendar"
- ,"Kalendarë"
-
-]
 , "Calendars"
 : "Kalendarë"
 
@@ -970,6 +754,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : "Date e panjohur"
 
@@ -991,38 +787,239 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Vijues"
 
 ]
+, "Resource, Resources"
+: [
+  "Burim"
+ ,"Burime"
+
+]
+, "Resources"
+: "Burime"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Emri"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "E-Postë"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Tipi"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Kliko këtu për të ftuar një vijues tjetër"
+
+, "User"
+: "Përdorues"
+
+, "Group"
+: "Grup"
+
+, "Member of group"
+: "Pjesëtar i grupit"
+
+, "This is the calendar where the attender has saved this event in"
+: "Ky është kalendari ku vijuesi ka ruajtur këtë ngjarje"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Hiqni Vijuesin"
+
+, "Compose email"
+: "Krijo E-Poste"
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(si pjesëtar i grupit)"
+
+, "External Attendee"
+: "Vijues i Jashtem"
+
+, "Originally"
+: "Fillimisht"
+
+, "Checking Calendar Data..."
+: "Duke kontrolluar të dhënat e kalendarit..."
+
+, "Reply to Recurring Event"
+: "Përgjigju Ngjarjes Periodike"
+
+, "You are responding to an recurring event. What would you like to do?"
+: "Ju po i përgjigjeni një ngjarje periodike. Çfarë doni të bëni?"
+
+, "Respond to whole series"
+: "Përgjigju të gjithë serive"
+
+, "Do not respond"
+: "Mos u përgjigj"
+
+, "The event of this message does not exist"
+: "Ngjarja e këtij mesazhi nuk ekziston"
+
+, "The sender is not authorised to update the event"
+: "Dërguesi nuk është i autorizuar te përditësoje këte ngjarje"
+
+, "This message is already processed"
+: "Ky mesazh është tashmë i përpunuar"
+
+, "You are not an attendee of this event"
+: "Ju nuk jeni në vijim të kësaj ngjarje"
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: "Mesazh i pa mbështetshëm"
+
+, "This is an event invitation for someone else."
+: "Kjo është një ftesë ngjarje për dikë tjetër"
+
+, "You have already replied to this event invitation."
+: "Ju i jeni përgjigjur tashmë ftesës së kesaj ngjarjeje"
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: "Ju ka ardhur një ftesë ngjarjeje. Vendosni përgjigjen tuaj tek:"
+
+, "An invited attendee responded to the invitation."
+: "Një vijues i ftuar i është përgjigjur ftesës"
+
+, "Unsupported method"
+: "Metodë e pa mbështetshme"
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Vendosni përshkrimin..."
 
 , "Grants"
 : "Të Drejta"
 
-, "Displayed in"
-: "E shfaqur në"
+, "This event is originally stored in a calendar you don't have access to."
+: "Kjo ngjarje është vendosur fillimisht në një kalendar ku ju nuk kini të drejta"
 
-, "Event not found"
+, "This event is originally stored in {0}"
+: "Kjo ngjarje është vendosur fillimisht në {0}"
+
+, "This event is additionally displayed in your personal calendar {0}"
+: "Kjo ngjarje është shfaqur gjithashtu tek kalendari juaj personal {0}"
+
+, "Colors"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "Side bar color"
 : ""
 
-, "GENDER_Attendee"
+, "Color by Calendar"
 : ""
 
-, "Select Attendee"
-: "Zgjidhni Vijues"
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: "Shiko"
+
+, "Saved in"
+: "Ruajtur në"
+
+, "Enter description"
+: "Fusni përshkrimin"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "Data e mbarimit nuk është e vlefshme"
+
+, "End date must be after start date"
+: "Data e mbarimit duhet të jetë mbas datës së fillimit"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "Data e fillimit nuk është e vlefshme"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : "Përmbledhja nuk mund të jetë më e gjatë se 255 karaktere"
@@ -1036,128 +1033,143 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : "Përmbledhja shumë e shkurtër"
 
-, "Recurrances"
-: "Përsëritje"
-
-, "No recurring rule defined"
-: "Nuk është përcaktuar një rregull përseritës"
-
-, "None"
-: "Asnjë"
-
-, "Exceptions of reccuring events can't have recurrences themselves."
-: "Përjashtimet e ngjarjeve përsëritëse nuk mund të përsërisin vetvehten"
-
-, "at"
-: "në"
-
-, "never"
-: "asnjëherë"
-
-, "after {0} occurrences"
-: "pas {0} ndodhive"
-
-, "Except"
+, "Set This Date as Definite Event?"
 : ""
 
-, "during events in the calendars"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "End"
-: "Fund"
-
-, "Until has to be after event start"
-: "Derisa të jetë pasi ngjarja fillon"
-
-, "The event is longer than the recurring interval"
+, "Attendee/Resources"
 : ""
 
-, "Every {0}. Day"
-: "Çdo {0}. Ditë"
-
-, "Every {0}. Week at"
-: "Çdo {0}. Javë në"
-
-, "Every {0}. Month"
-: "Çdo {0}. Muaj"
-
-, "at the"
-: "Në"
-
-, "first"
-: "i pari"
-
-, "second"
-: "i dyti"
-
-, "third"
-: "i treti"
-
-, "fourth"
-: "i katërti"
-
-, "last"
-: "i fundit"
-
-, "Every {0}. Year"
-: "Çdo {0}. Vit"
-
-, "of"
-: "e"
-
-, "First name, ĺast name"
+, "Additional Attendees ..."
 : ""
 
-, "E-Mail address"
+, "Default Status"
 : ""
 
-, "Please wait..."
+, "No Access"
 : ""
 
-, "General terms and conditions"
+, "All my events"
+: "Të gjitha ngjarjet e mia"
+
+, "Position on the left time axis, day and week view should start with"
+: "Pozicioni i krahut të majte kohor, pamja e ditës dhe javës duhet të fillojë me  "
+
+, "Position on the left time axis, day and week view should end with"
 : ""
 
-, "Relation, Relations"
-: [
-  ""
- ,""
+, "Default Start Time"
+: ""
 
-]
-, "All events I attend"
-: "Të gjithë ngjarjet që unë pres"
+, "Scroll position on the left time axis, day and week view should start with"
+: ""
 
-, "Required"
-: "Të kërkuara"
+, "Visible Time"
+: ""
 
-, "Optional"
-: "Opsionale"
+, "Time to be displayed at once"
+: ""
 
-, "No response"
-: "Pa përgjigje"
+, "Default Calendar"
+: "Kalendari i paracaktuar"
 
-, "Accepted"
-: "E pranuar"
+, "The default calendar for invitations and new events"
+: "Kalendari i paracaktuar për ftesa dhe ngjarje të reja"
 
-, "Declined"
-: "E pa pranuar"
+, "Default Favorite"
+: "Të preferuarat e Paracaktuara"
 
-, "Awaiting response"
-: "Duke pritur përgjigje"
+, "The default favorite which is loaded on calendar startup"
+: "E preferuara e paracaktuar që ngarkohet në nisje të kalendarit"
 
-, "Events I have not yet responded to"
-: "Ngjarje që nuk i jam përgjigjur"
+, "Get Notification Emails"
+: "Merr E-Postë njoftuese"
 
-, "Declined events"
-: "Ngjarje të papranuara"
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "Niveli i veprimeve që ju doni të njoftoheni. Ju lutem kini parasysh që organizuesit do të marrin njoftimpër të gjithë përditësimet, përfshirë edhe përgjigjet e vijuesëve, derisa kjo preferncë të jetë vendosur në \"Never\""
 
-, "Events I have declined"
-: "Ngjarje që nuk i kam pranuar"
+, "Send Notifications Emails of own Actions"
+: "Dërgo E-Postë njoftuese për Veprimet vetjake"
 
-, "I'm organizer"
-: "Unë jam organizues"
+, "Get notifications emails for actions you did yourself"
+: "Dërgo E-Postë njoftuese për veprimet që bëre vetë"
 
-, "Events I'm the organizer of"
-: "Ngjarje që unë jam organizuesi"
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
+, "Send Alarm Notifications Emails"
+: ""
+
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: "Aktivizo Alarmin Standart"
+
+, "New events get a standard alarm as defined below"
+: "Ngjarjet e reja marrin një alarm standart siç përcaktohet më poshtë"
+
+, "Standard Alarm Time"
+: "Koha e Alarmit Standart"
+
+, "Minutes before the event starts"
+: "Minuta përpara se ngjarja të fillojë"
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "Kalendarë fiks"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: "Asnjëherë"
+
+, "On invitation and cancellation only"
+: "Vetëm në ftesa dhe anullime"
+
+, "On time changes"
+: "Në ndryshime të kohës"
+
+, "On all updates but attendee responses"
+: "Në të gjithë përditësimet e përgjigjeve të vijuesve"
+
+, "On attendee responses too"
+: "Gjithashtu në përgjigje të vijuesve"
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : "Kalendarët zgjidhen gjithmonë në pamvarësi të parametrave të filtrave. Një përdorim i vlefshëmmund të jetë të shfaqet me forcë një kalendar pushimesh"
@@ -1222,12 +1234,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Pa përgjigje"
+
+, "Accepted"
+: "E pranuar"
+
+, "Declined"
+: "E pa pranuar"
+
 , "Attendee Roles Available"
 : "Role Vijuesi të disponueshëm"
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Të kërkuara"
+
+, "Optional"
+: "Opsionale"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1237,6 +1267,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1279,6 +1339,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1330,6 +1393,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1369,95 +1435,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Alarm për ngjarjen \"%1$s\" në %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Ftesë për ngjarje  \"%1$s\" në %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "Ngjarja \"%1$s\" në %2$s është anulluar"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
-: "Ngjarja \"%1$s\" është riplanifikuar nga %2$s në %3$s"
-
-, "Event \"%1$s\" at %2$s has been updated"
-: "Ngjarja \"%1$s\" në %2$s është përditësuar"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s ngjarje e pranuar \"%2$s\" në %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s ngjarje e refuzuar \"%2$s\" në %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "Përgjigje e pa qartë nga %1$s për ngjarjen \"%2$s\" në %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Nuk ka përgjigje nga %1$s për ngjarjen \"%2$s\" në %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Ndryshime në vijim për ngjarjen \"%1$s\" në %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Group Additional Filters"
 : ""
 
-, "Resource Management"
+, "Resource Additional Filters"
 : ""
 
-, "Polls for recurring events are not supported"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "%s's personal calendar"
+: "Kalendari perosnal i %s"
+
+, "Failed"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "The right Resource Admin must be set once."
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Different Calendar"
 : ""
 
-, "Start"
-: "Fillo"
+, "Exdate container move are not allowed"
+: ""
 
-, "Priority"
-: "Prioriteti"
+, "Invalid URL given"
+: ""
 
-, "Url"
-: "Url"
+, "The URL you used is invalid. Please use a valid one!"
+: ""
 
-, "Recurrance rule"
-: "Rregull i përsëritjes"
+, "Calendars to export"
+: ""
 
-, "Is all day event"
-: "Është ngjarje e të gjithë ditës"
+, "Export target"
+: ""
 
-, "Organizer timezone"
-: "Organizues i brezit kohor"
+, "VCalendar/ICS"
+: ""
 
-, "No"
-: "Jo"
+, "Export visible events to ics file"
+: ""
 
-, "Yes"
-: "Po"
+, "Excel overview"
+: ""
+
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "i panjohur"
@@ -1516,34 +1591,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : "ët"
 
+, "Start"
+: "Fillo"
+
+, "Priority"
+: "Prioriteti"
+
+, "Url"
+: "Url"
+
+, "Recurrance rule"
+: "Rregull i përsëritjes"
+
+, "Is all day event"
+: "Është ngjarje e të gjithë ditës"
+
+, "Organizer timezone"
+: "Organizues i brezit kohor"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Alarm për ngjarjen \"%1$s\" në %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Ftesë për ngjarje  \"%1$s\" në %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "Ngjarja \"%1$s\" në %2$s është anulluar"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+: "Ngjarja \"%1$s\" është riplanifikuar nga %2$s në %3$s"
+
+, "Event \"%1$s\" at %2$s has been updated"
+: "Ngjarja \"%1$s\" në %2$s është përditësuar"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s ngjarje e pranuar \"%2$s\" në %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s ngjarje e refuzuar \"%2$s\" në %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "Përgjigje e pa qartë nga %1$s për ngjarjen \"%2$s\" në %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Nuk ka përgjigje nga %1$s për ngjarjen \"%2$s\" në %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Ndryshime në vijim për ngjarjen \"%1$s\" në %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Unknown action"
 : ""
 
-, "Word event sheet"
+, "Resource Management"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Excel all data"
+, "Polls for recurring events are not supported"
 : ""
 
-, "Import iCal-files"
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1582,32 +1726,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Detaje të ngjarjes"
 
-, "The poll \"%1$s\" has been closed."
-: ""
+, "All events I attend"
+: "Të gjithë ngjarjet që unë pres"
 
-, "The definite event is scheduled for \"%1$s\""
-: ""
+, "Awaiting response"
+: "Duke pritur përgjigje"
 
-, "You can review the poll results here:"
-: ""
+, "Events I have not yet responded to"
+: "Ngjarje që nuk i jam përgjigjur"
 
-, "Thank you for attendening the poll \"%1$s\""
-: ""
+, "Declined events"
+: "Ngjarje të papranuara"
 
-, "To review or edit your status please use your personal link:"
-: ""
+, "Events I have declined"
+: "Ngjarje që nuk i kam pranuar"
 
-, "Different Calendar"
-: ""
+, "I'm organizer"
+: "Unë jam organizues"
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
-: ""
+, "Events I'm the organizer of"
+: "Ngjarje që unë jam organizuesi"
 
 , "manage shared calendars"
 : "menaxho kalendarët e ndarë"
@@ -1627,74 +1765,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Të gjithë të drejtat për administrimin e burimeve"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "është një vend"
-
-, "Errors"
-: "Gabime"
-
-, "Do you really want to delete this event?"
-: "Doni vërtetë të fshini këtë ngjarje?"
+, "Relation, Relations"
+: [
+  ""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Burim"
+, "Calendar"
+: "Kalendar"
+
+, "Do you really want to delete this event?"
+: "Doni vërtetë të fshini këtë ngjarje?"
 
 , "Resource Grant"
 : ""
@@ -1702,12 +1816,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Ngjarje"
 
-, "Calendar"
-: "Kalendar"
-
 , "Attender"
 : "Vijues"
 
+, "Resource"
+: "Burim"
+
 , "Relation"
 : ""
 
