@@ -5,167 +5,251 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "%s's personliga kalender"
+, "{0}, the {1}. of {2}"
+: "{0} är {1}. av {2}"
 
-, "Resources"
-: "Resurser"
+, "Recurrances"
+: "Recurrances"
 
-, "All my events"
-: "Alla mina event"
+, "No recurring rule defined"
+: "Ingen återkommande regel definieras"
 
-, "Start Time"
-: "Starttid"
+, "Details"
+: "Detaljer"
 
-, "Position on the left time axis, day and week view should start with"
-: "Placera på den vänstra tidsaxeln, dag och vecka vy ska börja med"
+, "None"
+: "Ingen"
 
-, "End Time"
-: "Sluttid"
+, "Daily"
+: "Dagligen"
 
-, "Position on the left time axis, day and week view should end with"
+, "Weekly"
+: "Veckovis"
+
+, "Monthly"
+: "Månadsvis"
+
+, "Yearly"
+: "Årligen"
+
+, "Exceptions of reccuring events can't have recurrences themselves."
+: "Undantag för återfallna händelser kan inte ha återfall själva."
+
+, "at"
+: "vid"
+
+, "never"
+: "aldrig"
+
+, "after {0} occurrences"
+: "efter {0} händelser"
+
+, "Except"
 : ""
 
-, "Default Start Time"
+, "during events in the calendars"
 : ""
 
-, "Scroll position on the left time axis, day and week view should start with"
+, "End"
+: "Slut"
+
+, "Until has to be after event start"
+: "Tills måste vara efter händelse start"
+
+, "The event is longer than the recurring interval"
 : ""
 
-, "Visible Time"
-: ""
+, "Every {0}. Day"
+: "Varje {0}. dag"
 
-, "Time to be displayed at once"
-: ""
+, "Every {0}. Week at"
+: "Varje {0}. vecka"
 
-, "Default Calendar"
-: "Standard kalender"
+, "Every {0}. Month"
+: "Varje {0}. månad"
 
-, "The default calendar for invitations and new events"
-: "Standard kalendern för inbjudningar och nya händelser"
+, "at the"
+: "vid"
 
-, "Default Favorite"
-: "Standard Favorit"
+, "first"
+: "först"
 
-, "The default favorite which is loaded on calendar startup"
-: "Standard favorit som är laddad på kalender start"
+, "second"
+: "andra"
 
-, "Get Notification Emails"
-: "Få Notifierings Mail"
+, "third"
+: "tredje"
 
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "Nivån på åtgärder som du vill bli informerad om. Observera att arrangörerna kommer att få meddelanden för alla uppdateringar, inklusive deltagarnas svar om den här inställningen är inställd på \"Aldrig\""
+, "fourth"
+: "fjärde"
 
-, "Send Notifications Emails of own Actions"
-: "Skicka Notifierings Mail av egna Åtgärder"
+, "last"
+: "sista"
 
-, "Get notifications emails for actions you did yourself"
-: "Få notifierings mail för åtgärder som du skapade själv"
+, "Every {0}. Year"
+: "Varje {0}. år"
 
-, "Send Alarm Notifications Emails"
-: ""
-
-, "Get event alarms via email"
-: ""
-
-, "Enable Standard Alarm"
-: "Aktivera standardlarm"
-
-, "New events get a standard alarm as defined below"
-: "Nya händelser får ett standardlarm som definerat nedan"
-
-, "Standard Alarm Time"
-: "Tid för standardlarm"
-
-, "Minutes before the event starts"
-: "Minuter innan händelsens början"
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "Korrigerade kalendrar"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: "Aldrig"
-
-, "On invitation and cancellation only"
-: "På inbjudan och avbokning enbart"
-
-, "On time changes"
-: "På tids ändringar"
-
-, "On all updates but attendee responses"
-: "På alla uppdateringar men deltagarens svar"
-
-, "On attendee responses too"
-: "På deltagerens svar också"
-
-, "Events"
-: "Händelse"
+, "of"
+: "av"
 
 , "Summary"
 : "Sammanfattning"
 
-, "Status"
-: "Status"
+, "Organizer"
+: "Organiserare"
 
-, "No Information"
-: "Ingen information"
-
-, "recurring event"
-: "återkommande händelse"
-
-, "recurring event exception"
-: "återkommande händelse undantag"
-
-, "Blocking"
-: "blockerande"
-
-, "Tentative"
-: "Preliminärt"
+, "Description"
+: "Beskrivning"
 
 , "Location"
 : "Plats"
 
-, "Organizer"
-: "Organiserare"
+, "Start Time"
+: "Starttid"
+
+, "End Time"
+: "Sluttid"
 
 , "Attendee"
 : "Deltagare"
 
+, "whole day"
+: "hela dagen"
+
+, "Week {0} :"
+: "Vecka {0} :"
+
+, "Poll, Polls"
+: [
+  ""
+ ,""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Ny händelse"
+
+, "Calendar, Calendars"
+: [
+  "Kalender"
+ ,"Kalendrar"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : ""
 
@@ -175,117 +259,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : ""
 
-, "Attachments"
+, "Unavailable"
 : ""
 
-, "Private"
-: "Privat"
-
-, "Tags"
-: "Taggar"
-
-, "whole day"
-: "hela dagen"
-
-, "Description"
-: "Beskrivning"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: "Den här händelsen lagrades ursprungligen i en kalender du inte har tillgång till."
-
-, "This event is originally stored in {0}"
-: "Den här händelsen lagrades ursprungligen i {0}"
-
-, "This event is additionally displayed in your personal calendar {0}"
-: "Denna händelse visas också i din personliga kalender {0}"
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: "Vänligen välj en händelse att lägga till kontakterna på"
-
-, "Role"
-: "Roll"
-
-, "Select Role"
-: "Välj roll"
-
-, "Select Status"
-: "Välj status"
-
-, "Adding {0} Attendee to event"
-: "Lägger till {0} deltagare till händelsen"
-
-, "Checking Calendar Data..."
-: "Kontrollerar kalenderdata..."
-
-, "Reply to Recurring Event"
-: "Svara på återkommande händelse"
-
-, "You are responding to an recurring event. What would you like to do?"
-: "Du svarar på ett återkommande evenemang. Vad vill du göra?"
-
-, "Respond to whole series"
-: "Svara på hela serien"
-
-, "Do not respond"
-: "Svara inte"
-
-, "The event of this message does not exist"
-: "Evenemanget av detta meddelande finns inte"
-
-, "The sender is not authorised to update the event"
-: "Avsändaren är inte tillåten att uppdatera evenemanget"
-
-, "This message is already processed"
-: "Detta meddelande är redan behandlat"
-
-, "You are not an attendee of this event"
-: "Du är inte en deltagare av denna händelse"
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: "Icke godkännt meddelande"
-
-, "This is an event invitation for someone else."
-: "Detta är en händelse inbjudan till någon annan."
-
-, "You have already replied to this event invitation."
-: "Du har redan svarat på den här händelsen inbjudan."
-
-, "You received an event invitation. Set your response to:"
-: "Du har fått en händelse inbjudan. Ställ ditt svar till:"
-
-, "An invited attendee responded to the invitation."
-: "En inbjuden deltagare svarade på inbjudan."
-
-, "Unsupported method"
-: "Icke godkännd metod"
-
 , "Loading events, please wait..."
 : "Laddar händelser, var god vänta..."
 
@@ -325,6 +301,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +316,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : "Kopiera {0}"
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : "Uppdatera händelser i det förflutna"
 
@@ -418,9 +400,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : "Avbryt denna åtgärd"
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Hantera resurser"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Välj deltagare"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Privat"
+
+, "Tags"
+: "Taggar"
+
+, "Blocking"
+: "blockerande"
+
+, "Tentative"
+: "Preliminärt"
+
 , "Import Definition Success!"
 : ""
 
@@ -457,9 +466,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -511,7 +517,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -535,156 +541,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: "Visa"
-
-, "Details"
-: "Detaljer"
-
-, "Saved in"
-: "Sparad i"
-
-, "non-blocking"
-: "icke-blockerande"
-
-, "Enter description"
-: "Beskrivning"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "Slutdatum är ogiltigt"
-
-, "End date must be after start date"
-: "Slutdatum måste vara efter startdatum"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "Startdatum är ogiligt"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: "Vecka {0} :"
-
-, "Originally"
-: "Ursprungligen"
-
-, "Poll, Polls"
-: [
-  ""
- ,""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "WK"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Dagligen"
-
-, "Weekly"
-: "Veckovis"
-
-, "Monthly"
-: "Månadsvis"
-
-, "Yearly"
-: "Årligen"
-
-, "Name"
-: "Namn"
-
-, "Email"
-: "Email"
-
-, "Type"
-: "Typ"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Ny händelse"
-
-, "{0} more..."
-: "{0} mer..."
-
 , "private classification"
 : "privat klassificering"
 
+, "recurring event"
+: "återkommande händelse"
+
+, "recurring event exception"
+: "återkommande händelse undantag"
+
 , "has alarm"
 : "har larm"
 
@@ -694,62 +559,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0} är {1}. av {2}"
+, "Mini Calendar"
+: "Mini Kalender"
 
-, "Click here to invite another attender..."
-: "Klicka här för att bjuda in ytterligare deltagare"
+, "WK"
+: "WK"
 
-, "User"
-: "Användare"
-
-, "Group"
-: "Grupp"
-
-, "Resource, Resources"
-: [
-  "Resurs"
- ,"Resurser"
-
-]
-, "Member of group"
-: "Medlem i grupp"
-
-, "This is the calendar where the attender has saved this event in"
-: "Detta är den kalender som deltagaren har sparat händelsen i"
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Ta bort deltagare"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(som gruppmedlem)"
-
-, "External Attendee"
-: ""
+, "{0} more..."
+: "{0} mer..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -769,6 +586,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -811,7 +631,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -841,102 +661,66 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: "Vänligen välj en händelse att lägga till kontakterna på"
+
+, "Role"
+: "Roll"
+
+, "Select Role"
+: "Välj roll"
+
+, "Status"
+: "Status"
+
+, "Select Status"
+: "Välj status"
+
+, "Adding {0} Attendee to event"
+: "Lägger till {0} deltagare till händelsen"
+
 , "no events found"
 : "inga händelser funna"
 
 , "Searching..."
 : "Söker..."
 
+, "Search Event"
+: "Sök Händelse"
+
 , "Event, Events"
 : [
   "Händelse"
  ,"Händelser"
 
 ]
-, "Search Event"
-: "Sök Händelse"
-
-, "Switch to public poll"
+, "Additional Tags ..."
 : ""
 
-, "Welcome {name}"
+, "non-blocking"
+: "icke-blockerande"
+
+, "Displayed in"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "No Information"
+: "Ingen information"
+
+, "Event Location"
 : ""
 
-, "This poll is closed already"
+, "From"
 : ""
 
-, "I am not {name}"
+, "until"
 : ""
 
-, "Login"
-: ""
+, "Events"
+: "Händelse"
 
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Mini Kalender"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "Kalender"
- ,"Kalendrar"
-
-]
 , "Calendars"
 : "Kalendrar"
 
@@ -970,6 +754,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -991,38 +787,239 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
  ,"Deltagare"
 
 ]
+, "Resource, Resources"
+: [
+  "Resurs"
+ ,"Resurser"
+
+]
+, "Resources"
+: "Resurser"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Namn"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "Email"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Typ"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Klicka här för att bjuda in ytterligare deltagare"
+
+, "User"
+: "Användare"
+
+, "Group"
+: "Grupp"
+
+, "Member of group"
+: "Medlem i grupp"
+
+, "This is the calendar where the attender has saved this event in"
+: "Detta är den kalender som deltagaren har sparat händelsen i"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Ta bort deltagare"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(som gruppmedlem)"
+
+, "External Attendee"
+: ""
+
+, "Originally"
+: "Ursprungligen"
+
+, "Checking Calendar Data..."
+: "Kontrollerar kalenderdata..."
+
+, "Reply to Recurring Event"
+: "Svara på återkommande händelse"
+
+, "You are responding to an recurring event. What would you like to do?"
+: "Du svarar på ett återkommande evenemang. Vad vill du göra?"
+
+, "Respond to whole series"
+: "Svara på hela serien"
+
+, "Do not respond"
+: "Svara inte"
+
+, "The event of this message does not exist"
+: "Evenemanget av detta meddelande finns inte"
+
+, "The sender is not authorised to update the event"
+: "Avsändaren är inte tillåten att uppdatera evenemanget"
+
+, "This message is already processed"
+: "Detta meddelande är redan behandlat"
+
+, "You are not an attendee of this event"
+: "Du är inte en deltagare av denna händelse"
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: "Icke godkännt meddelande"
+
+, "This is an event invitation for someone else."
+: "Detta är en händelse inbjudan till någon annan."
+
+, "You have already replied to this event invitation."
+: "Du har redan svarat på den här händelsen inbjudan."
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: "Du har fått en händelse inbjudan. Ställ ditt svar till:"
+
+, "An invited attendee responded to the invitation."
+: "En inbjuden deltagare svarade på inbjudan."
+
+, "Unsupported method"
+: "Icke godkännd metod"
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Fyll i beskrivning"
 
 , "Grants"
 : ""
 
-, "Displayed in"
+, "This event is originally stored in a calendar you don't have access to."
+: "Den här händelsen lagrades ursprungligen i en kalender du inte har tillgång till."
+
+, "This event is originally stored in {0}"
+: "Den här händelsen lagrades ursprungligen i {0}"
+
+, "This event is additionally displayed in your personal calendar {0}"
+: "Denna händelse visas också i din personliga kalender {0}"
+
+, "Colors"
 : ""
 
-, "Event not found"
+, "Side bar color"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "Color by Calendar"
 : ""
 
-, "GENDER_Attendee"
+, "Color by Attendee Calendar"
 : ""
 
-, "Select Attendee"
-: "Välj deltagare"
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: "Visa"
+
+, "Saved in"
+: "Sparad i"
+
+, "Enter description"
+: "Beskrivning"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "Slutdatum är ogiltigt"
+
+, "End date must be after start date"
+: "Slutdatum måste vara efter startdatum"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "Startdatum är ogiligt"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : "Sammanfattningen får inte vara längre än 255 tecken."
@@ -1036,128 +1033,143 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : "Sammanfattningen är för kort"
 
-, "Recurrances"
-: "Recurrances"
-
-, "No recurring rule defined"
-: "Ingen återkommande regel definieras"
-
-, "None"
-: "Ingen"
-
-, "Exceptions of reccuring events can't have recurrences themselves."
-: "Undantag för återfallna händelser kan inte ha återfall själva."
-
-, "at"
-: "vid"
-
-, "never"
-: "aldrig"
-
-, "after {0} occurrences"
-: "efter {0} händelser"
-
-, "Except"
+, "Set This Date as Definite Event?"
 : ""
 
-, "during events in the calendars"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "End"
-: "Slut"
-
-, "Until has to be after event start"
-: "Tills måste vara efter händelse start"
-
-, "The event is longer than the recurring interval"
+, "Attendee/Resources"
 : ""
 
-, "Every {0}. Day"
-: "Varje {0}. dag"
-
-, "Every {0}. Week at"
-: "Varje {0}. vecka"
-
-, "Every {0}. Month"
-: "Varje {0}. månad"
-
-, "at the"
-: "vid"
-
-, "first"
-: "först"
-
-, "second"
-: "andra"
-
-, "third"
-: "tredje"
-
-, "fourth"
-: "fjärde"
-
-, "last"
-: "sista"
-
-, "Every {0}. Year"
-: "Varje {0}. år"
-
-, "of"
-: "av"
-
-, "First name, ĺast name"
+, "Additional Attendees ..."
 : ""
 
-, "E-Mail address"
+, "Default Status"
 : ""
 
-, "Please wait..."
+, "No Access"
 : ""
 
-, "General terms and conditions"
+, "All my events"
+: "Alla mina event"
+
+, "Position on the left time axis, day and week view should start with"
+: "Placera på den vänstra tidsaxeln, dag och vecka vy ska börja med"
+
+, "Position on the left time axis, day and week view should end with"
 : ""
 
-, "Relation, Relations"
-: [
-  ""
- ,""
+, "Default Start Time"
+: ""
 
-]
-, "All events I attend"
-: "Alla händelser Jag varit med på"
+, "Scroll position on the left time axis, day and week view should start with"
+: ""
 
-, "Required"
-: "Krävs"
+, "Visible Time"
+: ""
 
-, "Optional"
-: "Valfritt"
+, "Time to be displayed at once"
+: ""
 
-, "No response"
-: "Inget svar"
+, "Default Calendar"
+: "Standard kalender"
 
-, "Accepted"
-: "Godkännt"
+, "The default calendar for invitations and new events"
+: "Standard kalendern för inbjudningar och nya händelser"
 
-, "Declined"
-: "Nekat"
+, "Default Favorite"
+: "Standard Favorit"
 
-, "Awaiting response"
-: "Avvaktar svar"
+, "The default favorite which is loaded on calendar startup"
+: "Standard favorit som är laddad på kalender start"
 
-, "Events I have not yet responded to"
-: "Händelser Jag inte ännu svarat på"
+, "Get Notification Emails"
+: "Få Notifierings Mail"
 
-, "Declined events"
-: "Tacka nej händelser"
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "Nivån på åtgärder som du vill bli informerad om. Observera att arrangörerna kommer att få meddelanden för alla uppdateringar, inklusive deltagarnas svar om den här inställningen är inställd på \"Aldrig\""
 
-, "Events I have declined"
-: "Händerlser Jag tackat nej till"
+, "Send Notifications Emails of own Actions"
+: "Skicka Notifierings Mail av egna Åtgärder"
 
-, "I'm organizer"
-: "Jag är arrangör"
+, "Get notifications emails for actions you did yourself"
+: "Få notifierings mail för åtgärder som du skapade själv"
 
-, "Events I'm the organizer of"
-: "Händelser Jag är arrangör för."
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
+, "Send Alarm Notifications Emails"
+: ""
+
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: "Aktivera standardlarm"
+
+, "New events get a standard alarm as defined below"
+: "Nya händelser får ett standardlarm som definerat nedan"
+
+, "Standard Alarm Time"
+: "Tid för standardlarm"
+
+, "Minutes before the event starts"
+: "Minuter innan händelsens början"
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "Korrigerade kalendrar"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: "Aldrig"
+
+, "On invitation and cancellation only"
+: "På inbjudan och avbokning enbart"
+
+, "On time changes"
+: "På tids ändringar"
+
+, "On all updates but attendee responses"
+: "På alla uppdateringar men deltagarens svar"
+
+, "On attendee responses too"
+: "På deltagerens svar också"
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : "Kalendrar alltid utvalda oavsett av alla filter parametrar. En godkännd användning kan vara att tvinga visning av en viss helgdag kalender."
@@ -1222,12 +1234,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Inget svar"
+
+, "Accepted"
+: "Godkännt"
+
+, "Declined"
+: "Nekat"
+
 , "Attendee Roles Available"
 : "Tillgängliga deltagarroller"
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Krävs"
+
+, "Optional"
+: "Valfritt"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1237,6 +1267,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1279,6 +1339,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1330,6 +1393,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1369,95 +1435,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Alarm för händelse \"%1$s\" vid %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Inbjudan till händelse \"%1$s\" vid %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "Händelse \"%1$s\" vid %2$s har blivit inställd"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
-: "Händelse \"%1$s\" har blivit flyttad från %2$s till %3$s"
-
-, "Event \"%1$s\" at %2$s has been updated"
-: "Händelse \"%1$s\" vid %2$s har blivit uppdaterad"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s accepterade händelsen \"%2$s\" vid %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s nekade händelsen \"%2$s\" vid %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "Preliminärt svar från %1$s för evenemanget \"%2$s\" på %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Ingen respons från %1$s för händelsen \"%2$s\" vid %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Deltagarens förändringar för evenemanget \"%1$s\" på %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Group Additional Filters"
 : ""
 
-, "Resource Management"
+, "Resource Additional Filters"
 : ""
 
-, "Polls for recurring events are not supported"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "%s's personal calendar"
+: "%s's personliga kalender"
+
+, "Failed"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "The right Resource Admin must be set once."
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Different Calendar"
 : ""
 
-, "Start"
-: "Start"
+, "Exdate container move are not allowed"
+: ""
 
-, "Priority"
-: "Prioritet"
+, "Invalid URL given"
+: ""
 
-, "Url"
-: "Url"
+, "The URL you used is invalid. Please use a valid one!"
+: ""
 
-, "Recurrance rule"
-: "Återfalls regel"
+, "Calendars to export"
+: ""
 
-, "Is all day event"
-: "Är en heldags händelse"
+, "Export target"
+: ""
 
-, "Organizer timezone"
-: "Organisera tidzoner"
+, "VCalendar/ICS"
+: ""
 
-, "No"
-: "Nej"
+, "Export visible events to ics file"
+: ""
 
-, "Yes"
-: "Ja"
+, "Excel overview"
+: ""
+
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "okänd"
@@ -1516,34 +1591,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: "Start"
+
+, "Priority"
+: "Prioritet"
+
+, "Url"
+: "Url"
+
+, "Recurrance rule"
+: "Återfalls regel"
+
+, "Is all day event"
+: "Är en heldags händelse"
+
+, "Organizer timezone"
+: "Organisera tidzoner"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Alarm för händelse \"%1$s\" vid %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Inbjudan till händelse \"%1$s\" vid %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "Händelse \"%1$s\" vid %2$s har blivit inställd"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+: "Händelse \"%1$s\" har blivit flyttad från %2$s till %3$s"
+
+, "Event \"%1$s\" at %2$s has been updated"
+: "Händelse \"%1$s\" vid %2$s har blivit uppdaterad"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s accepterade händelsen \"%2$s\" vid %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s nekade händelsen \"%2$s\" vid %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "Preliminärt svar från %1$s för evenemanget \"%2$s\" på %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Ingen respons från %1$s för händelsen \"%2$s\" vid %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Deltagarens förändringar för evenemanget \"%1$s\" på %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Unknown action"
 : ""
 
-, "Word event sheet"
+, "Resource Management"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Excel all data"
+, "Polls for recurring events are not supported"
 : ""
 
-, "Import iCal-files"
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1582,32 +1726,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Händelse detaljer"
 
-, "The poll \"%1$s\" has been closed."
-: ""
+, "All events I attend"
+: "Alla händelser Jag varit med på"
 
-, "The definite event is scheduled for \"%1$s\""
-: ""
+, "Awaiting response"
+: "Avvaktar svar"
 
-, "You can review the poll results here:"
-: ""
+, "Events I have not yet responded to"
+: "Händelser Jag inte ännu svarat på"
 
-, "Thank you for attendening the poll \"%1$s\""
-: ""
+, "Declined events"
+: "Tacka nej händelser"
 
-, "To review or edit your status please use your personal link:"
-: ""
+, "Events I have declined"
+: "Händerlser Jag tackat nej till"
 
-, "Different Calendar"
-: ""
+, "I'm organizer"
+: "Jag är arrangör"
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
-: ""
+, "Events I'm the organizer of"
+: "Händelser Jag är arrangör för."
 
 , "manage shared calendars"
 : "Hantera delade kalendrar"
@@ -1627,74 +1765,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Alla rättigheter för att administrera resurser"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "Är en plats"
-
-, "Errors"
-: "Fel"
-
-, "Do you really want to delete this event?"
-: "Vill du verkligen radera denna händelse?"
+, "Relation, Relations"
+: [
+  ""
+ ,""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "Resurs"
+, "Calendar"
+: "Kalender"
+
+, "Do you really want to delete this event?"
+: "Vill du verkligen radera denna händelse?"
 
 , "Resource Grant"
 : ""
@@ -1702,12 +1816,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "Händelse"
 
-, "Calendar"
-: "Kalender"
-
 , "Attender"
 : "Deltagare"
 
+, "Resource"
+: "Resurs"
+
 , "Relation"
 : ""
 
