@@ -5,167 +5,249 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "%s ของปฏิทินส่วนตัว"
+, "{0}, the {1}. of {2}"
+: "{0}, ที่ {1} จาก {2}"
 
-, "Resources"
-: "แหล่งที่มา"
+, "Recurrances"
+: "ความซ้ำซ้อน"
 
-, "All my events"
-: "เหตุการณ์ทั้งหมดของฉัน"
+, "No recurring rule defined"
+: "ไม่ได้มีกฎเกี่ยวกับการซ้ำซ้อนระบุไว้"
 
-, "Start Time"
-: "เวลาที่เริ่ม"
+, "Details"
+: "รายละเอียด"
 
-, "Position on the left time axis, day and week view should start with"
-: "เนื่องด้วยตำแหน่งบนเส้นเวลาที่เหลือ การดูแบบวันและแบบสัปดาห์ควรเริ่มต้นด้วย"
+, "None"
+: "ไม่มีเลย"
 
-, "End Time"
-: "เวลาที่สิ้นสุด"
+, "Daily"
+: "ทุกวัน"
 
-, "Position on the left time axis, day and week view should end with"
-: ""
+, "Weekly"
+: "ทุกสัปดาห์"
 
-, "Default Start Time"
-: ""
+, "Monthly"
+: "ทุกเดือน"
 
-, "Scroll position on the left time axis, day and week view should start with"
-: ""
+, "Yearly"
+: "ทุกปี"
 
-, "Visible Time"
-: ""
+, "Exceptions of reccuring events can't have recurrences themselves."
+: "ข้อยกเว้นเกี่ยวกับเหตุการณ์ที่ซ้ำซ้อนไม่สามารถมีสิ่งที่ซ้ำซ้อนอยู่ในตัวมันเองได้"
 
-, "Time to be displayed at once"
-: ""
+, "at"
+: "ณ"
 
-, "Default Calendar"
-: "ปฏิทินหลัก"
-
-, "The default calendar for invitations and new events"
-: "ปฏิทินหลักสำหรับคำเชิญและเหตุการณ์ใหม่"
-
-, "Default Favorite"
-: "ค่าที่ชอบหลัก"
-
-, "The default favorite which is loaded on calendar startup"
-: "ค่าที่ชอบหลักจะโหลดทันทีเมื่อเริ่มเปิดปฏิทิน"
-
-, "Get Notification Emails"
-: "ได้อีเมลแจ้งเตือน"
-
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "ระดับของการกระทำที่คุณต้องการรับทราบ พึงระลึกว่าผู้ทำการนัดหมายจะได้รับการแจ้งเตือนเกี่ยวกับทุก ๆ อัพเดท รวมถึงทุก ๆ คำตอบของผู้เข้า นอกเสียจากว่าจะมีตั้งค่าเป็น \"ไม่เลย\""
-
-, "Send Notifications Emails of own Actions"
-: "ส่งอีเมลแจ้งเตือนของการกระทำของตัวเอง"
-
-, "Get notifications emails for actions you did yourself"
-: "ได้อีเมลแจ้งเตือนสำหรับสิ่งที่คุณได้ทำด้วยตัวคุณเอง"
-
-, "Send Alarm Notifications Emails"
-: ""
-
-, "Get event alarms via email"
-: ""
-
-, "Enable Standard Alarm"
-: "ตั้งการเตือนมาตรฐานได้"
-
-, "New events get a standard alarm as defined below"
-: "เหตุการณ์ใหม่ ๆ จะได้รับการเตือนที่ตั้งเป็นมาตรฐานได้ดังที่กำหนดไว้เบื้องล่างนี้"
-
-, "Standard Alarm Time"
-: "เวลาเตือนมาตรฐาน"
-
-, "Minutes before the event starts"
-: "จำนวนนาทีก่อนเหตุการณ์จะเริ่ม"
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "ปฏิทินหลัก"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
+, "never"
 : "ไม่เลย"
 
-, "On invitation and cancellation only"
-: "เฉพาะเรื่องคำเชิญและการยกเลิกเท่านั้น"
+, "after {0} occurrences"
+: "หลังจากเกิดขึ้น {0} ครั้ง"
 
-, "On time changes"
-: "ตามการเปลี่ยนแปลงตามกำหนดการ"
-
-, "On all updates but attendee responses"
+, "Except"
 : ""
 
-, "On attendee responses too"
-: "ตามที่ผู้เข้าร่วมตอบรับด้วย"
+, "during events in the calendars"
+: ""
 
-, "Events"
-: "เหตุการณ์"
+, "End"
+: "สิ้นสุด"
+
+, "Until has to be after event start"
+: "จนถึง ต้องไปอยู่"
+
+, "The event is longer than the recurring interval"
+: ""
+
+, "Every {0}. Day"
+: "ทุกๆ {0} วัน"
+
+, "Every {0}. Week at"
+: "ทุกๆ {0} สัปดาห์ เมื่อ"
+
+, "Every {0}. Month"
+: "ทุกๆ {0} เดือน"
+
+, "at the"
+: "เมื่อ"
+
+, "first"
+: "ลำดับที่หนึ่ง"
+
+, "second"
+: "ลำดับที่สอง"
+
+, "third"
+: "ลำดับที่สาม"
+
+, "fourth"
+: "ลำดับที่สี่"
+
+, "last"
+: "ลำดับสุดท้าย"
+
+, "Every {0}. Year"
+: "ทุกๆ {0} ปี"
+
+, "of"
+: "ของ"
 
 , "Summary"
 : "ข้อสรุป"
 
-, "Status"
-: "สถานะ"
+, "Organizer"
+: "ผู้นัดหมาย"
 
-, "No Information"
-: "ไม่มีข้อมูล"
-
-, "recurring event"
-: "เหตุการณ์ซ้ำซ้อน"
-
-, "recurring event exception"
-: "ข้อยกเว้นเมื่อเหตุการณ์ซ้ำซ้อน"
-
-, "Blocking"
-: "การจัดกลุ่มระเบียน"
-
-, "Tentative"
-: "เบื้องต้น"
+, "Description"
+: "การอธิบาย"
 
 , "Location"
 : "สถานที่"
 
-, "Organizer"
-: "ผู้นัดหมาย"
+, "Start Time"
+: "เวลาที่เริ่ม"
+
+, "End Time"
+: "เวลาที่สิ้นสุด"
 
 , "Attendee"
 : "ผู้เข้าร่วม"
 
+, "whole day"
+: "ทั้งวัน"
+
+, "Week {0} :"
+: "สัปดาห์ที่ {0}"
+
+, "Poll, Polls"
+: [
+  ""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "เหตุการณ์ใหม่"
+
+, "Calendar, Calendars"
+: [
+  "ปฏิทิน"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : "เพิ่มผู้เข้าร่วม"
 
@@ -175,117 +257,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : "ทำสัญลักษณ์เพื่อกรองให้ผู้เข้าร่วมคนนี้"
 
-, "Attachments"
+, "Unavailable"
 : ""
 
-, "Private"
-: "ส่วนตัว"
-
-, "Tags"
-: "ป้ายกำกับ"
-
-, "whole day"
-: "ทั้งวัน"
-
-, "Description"
-: "การอธิบาย"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: "เหตุการณ์นี้ได้รับการบันทึกแรกเริ่มในปฏิทินที่คุณไม่สามารถเข้าไปดูได้"
-
-, "This event is originally stored in {0}"
-: "เหตุการณ์นี้ได้รับการบันทึกแรกเริ่มใน {0}"
-
-, "This event is additionally displayed in your personal calendar {0}"
-: "เหตุการณ์นี้จะเพิ่มเข้าไปอัตโนมัติในปฏิทิน {0} ส่วนตัวของคุณ"
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: "กรุณาเลือกเหตุการณ์เพื่อเพิ่มการติดต่อ"
-
-, "Role"
-: "หน้าที่"
-
-, "Select Role"
-: "เลือก หน้าที่"
-
-, "Select Status"
-: "เลือก สถานะ"
-
-, "Adding {0} Attendee to event"
-: "กำลังเพิ่มผู้เข้าร่วม {0} คนในเหตุการณ์นี้"
-
-, "Checking Calendar Data..."
-: "กำลังตรวจสอบข้อมูลปฏิทิน"
-
-, "Reply to Recurring Event"
-: "ตอบสนองต่อเหตุการณ์ซ้ำซ้อน"
-
-, "You are responding to an recurring event. What would you like to do?"
-: "คุณกำลังตอบสนองต่อเหตุการณ์ที่ซ้ำซ้อน คุณจะทำอะไร?"
-
-, "Respond to whole series"
-: "ตอบสนองต่อทุกชุด"
-
-, "Do not respond"
-: "ไม่ตอบสนอง"
-
-, "The event of this message does not exist"
-: "เหตุการณ์ในข้อความนี้ไม่มีอยู่"
-
-, "The sender is not authorised to update the event"
-: "ผู้ส่งไม่ได้รับอนุญาตให้ปรับปรุงเหตุการณ์"
-
-, "This message is already processed"
-: "ข้อความนี้ได้ถูกดำเนินการแล้ว"
-
-, "You are not an attendee of this event"
-: "คุณไม่ได้เป็นผุ้เข้าร่วมในเหตุการณ์นี้"
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: "ข้อความที่ไม่ได้รับการสนับสนุน"
-
-, "This is an event invitation for someone else."
-: "นี่เป็นการเชิญให้ร่วมเหตุการณ์สำหรับผู้อื่น"
-
-, "You have already replied to this event invitation."
-: "คุณได้ตอบกลับไปยังคำเชิญเข้าร่วมเหตุการณ์นี้แล้ว"
-
-, "You received an event invitation. Set your response to:"
-: "คุณได้รับคำเชิญเข้าร่วมเหตุการณ์ ตั้งค่าการตอบรับไปยัง:"
-
-, "An invited attendee responded to the invitation."
-: "ผุ้เข้าร่วมที่ได้รับเชิญได้ตอบกลับเรื่องคำเชิญแล้ว"
-
-, "Unsupported method"
-: "วิธีการที่ไม่สนับสนุน"
-
 , "Loading events, please wait..."
 : "กำลังโหลดเหตุการณ์ กรุณารอสักครู่"
 
@@ -325,6 +299,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : "นำเข้า เหตุการณ์"
 
@@ -337,6 +314,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : "คัดลอก {0}"
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : "ปรับปรุงเหตุการณ์ที่ผ่านมา"
 
@@ -417,9 +397,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : "ยกเลิกการกระทำนี้"
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "จัดการ แหล่งที่มา"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "เลือก ผู้เข้าร่วม"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "ส่วนตัว"
+
+, "Tags"
+: "ป้ายกำกับ"
+
+, "Blocking"
+: "การจัดกลุ่มระเบียน"
+
+, "Tentative"
+: "เบื้องต้น"
+
 , "Import Definition Success!"
 : "นำเข้าคำจำกัดความ ประสบความสำเร็จ!"
 
@@ -456,9 +463,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -510,7 +514,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -534,155 +538,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: "ดู"
-
-, "Details"
-: "รายละเอียด"
-
-, "Saved in"
-: "ได้บันทึกใน"
-
-, "non-blocking"
-: "ไม่ได้บล็อค"
-
-, "Enter description"
-: "ใส่ คำอธิบาย"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "วันที่สิ้นสุดไม่ถูกต้อง"
-
-, "End date must be after start date"
-: "วันที่สิ้นสุดต้องตามหลังวันที่เริ่มต้น"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "วันที่เริ่มต้นไม่ถูกต้อง"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: "สัปดาห์ที่ {0}"
-
-, "Originally"
-: "โดยเริ่มแรก"
-
-, "Poll, Polls"
-: [
-  ""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "สัปดาห์"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "ทุกวัน"
-
-, "Weekly"
-: "ทุกสัปดาห์"
-
-, "Monthly"
-: "ทุกเดือน"
-
-, "Yearly"
-: "ทุกปี"
-
-, "Name"
-: "ชื่อ"
-
-, "Email"
-: "อีเมล"
-
-, "Type"
-: "ประเภท"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "เหตุการณ์ใหม่"
-
-, "{0} more..."
-: "เพิ่มขึ้น {0}"
-
 , "private classification"
 : "การแยกประเภทส่วนบุคคล"
 
+, "recurring event"
+: "เหตุการณ์ซ้ำซ้อน"
+
+, "recurring event exception"
+: "ข้อยกเว้นเมื่อเหตุการณ์ซ้ำซ้อน"
+
 , "has alarm"
 : "มีการแจ้งเตือน"
 
@@ -692,61 +556,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, ที่ {1} จาก {2}"
+, "Mini Calendar"
+: "ปฏิทินย่อ"
 
-, "Click here to invite another attender..."
-: "คลิ๊กที่นี่เพื่อเชิญผู้เข้าร่วมท่านอื่น..."
+, "WK"
+: "สัปดาห์"
 
-, "User"
-: "ผู้ใช้"
-
-, "Group"
-: "กลุ่ม"
-
-, "Resource, Resources"
-: [
-  "แหล่งที่มา"
-
-]
-, "Member of group"
-: "สมาชิกของกลุ่ม"
-
-, "This is the calendar where the attender has saved this event in"
-: "นี่เป็นปฏิทินที่ผู้เข้าร่วมจัดเก็บเหตุการณ์นี้ไว้"
-
-, "Click icon to change"
-: "กดที่เครื่องหมายเพื่อเปลี่ยน"
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "เอาผู้เข้าร่วมออก"
-
-, "Compose email"
-: "เขียนอีเมล"
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(ในฐานะสมาชิกกลุ่ม)"
-
-, "External Attendee"
-: "ผู้เข้าร่วมจากภายนอก"
+, "{0} more..."
+: "เพิ่มขึ้น {0}"
 
 , "Resource Grant, Resource Grants"
 : [
@@ -765,6 +582,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -807,7 +627,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -837,100 +657,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: "กรุณาเลือกเหตุการณ์เพื่อเพิ่มการติดต่อ"
+
+, "Role"
+: "หน้าที่"
+
+, "Select Role"
+: "เลือก หน้าที่"
+
+, "Status"
+: "สถานะ"
+
+, "Select Status"
+: "เลือก สถานะ"
+
+, "Adding {0} Attendee to event"
+: "กำลังเพิ่มผู้เข้าร่วม {0} คนในเหตุการณ์นี้"
+
 , "no events found"
 : "ไม่พบเหตุการณ์"
 
 , "Searching..."
 : "กำลังค้นหา"
 
+, "Search Event"
+: "ค้นหาเหตุการณ์"
+
 , "Event, Events"
 : [
   "เหตุการณ์"
 
 ]
-, "Search Event"
-: "ค้นหาเหตุการณ์"
-
-, "Switch to public poll"
+, "Additional Tags ..."
 : ""
 
-, "Welcome {name}"
+, "non-blocking"
+: "ไม่ได้บล็อค"
+
+, "Displayed in"
+: "ได้แสดงใน"
+
+, "No Information"
+: "ไม่มีข้อมูล"
+
+, "Event Location"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "From"
 : ""
 
-, "This poll is closed already"
+, "until"
 : ""
 
-, "I am not {name}"
-: ""
+, "Events"
+: "เหตุการณ์"
 
-, "Login"
-: ""
-
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "ปฏิทินย่อ"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "ปฏิทิน"
-
-]
 , "Calendars"
 : "ปฏิทิน"
 
@@ -964,6 +749,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : "ไม่ระบุวัน"
 
@@ -984,38 +781,238 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
   "ผู้เข้าร่วม"
 
 ]
+, "Resource, Resources"
+: [
+  "แหล่งที่มา"
+
+]
+, "Resources"
+: "แหล่งที่มา"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "ชื่อ"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "อีเมล"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "ประเภท"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "คลิ๊กที่นี่เพื่อเชิญผู้เข้าร่วมท่านอื่น..."
+
+, "User"
+: "ผู้ใช้"
+
+, "Group"
+: "กลุ่ม"
+
+, "Member of group"
+: "สมาชิกของกลุ่ม"
+
+, "This is the calendar where the attender has saved this event in"
+: "นี่เป็นปฏิทินที่ผู้เข้าร่วมจัดเก็บเหตุการณ์นี้ไว้"
+
+, "Click icon to change"
+: "กดที่เครื่องหมายเพื่อเปลี่ยน"
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "เอาผู้เข้าร่วมออก"
+
+, "Compose email"
+: "เขียนอีเมล"
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(ในฐานะสมาชิกกลุ่ม)"
+
+, "External Attendee"
+: "ผู้เข้าร่วมจากภายนอก"
+
+, "Originally"
+: "โดยเริ่มแรก"
+
+, "Checking Calendar Data..."
+: "กำลังตรวจสอบข้อมูลปฏิทิน"
+
+, "Reply to Recurring Event"
+: "ตอบสนองต่อเหตุการณ์ซ้ำซ้อน"
+
+, "You are responding to an recurring event. What would you like to do?"
+: "คุณกำลังตอบสนองต่อเหตุการณ์ที่ซ้ำซ้อน คุณจะทำอะไร?"
+
+, "Respond to whole series"
+: "ตอบสนองต่อทุกชุด"
+
+, "Do not respond"
+: "ไม่ตอบสนอง"
+
+, "The event of this message does not exist"
+: "เหตุการณ์ในข้อความนี้ไม่มีอยู่"
+
+, "The sender is not authorised to update the event"
+: "ผู้ส่งไม่ได้รับอนุญาตให้ปรับปรุงเหตุการณ์"
+
+, "This message is already processed"
+: "ข้อความนี้ได้ถูกดำเนินการแล้ว"
+
+, "You are not an attendee of this event"
+: "คุณไม่ได้เป็นผุ้เข้าร่วมในเหตุการณ์นี้"
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: "ข้อความที่ไม่ได้รับการสนับสนุน"
+
+, "This is an event invitation for someone else."
+: "นี่เป็นการเชิญให้ร่วมเหตุการณ์สำหรับผู้อื่น"
+
+, "You have already replied to this event invitation."
+: "คุณได้ตอบกลับไปยังคำเชิญเข้าร่วมเหตุการณ์นี้แล้ว"
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: "คุณได้รับคำเชิญเข้าร่วมเหตุการณ์ ตั้งค่าการตอบรับไปยัง:"
+
+, "An invited attendee responded to the invitation."
+: "ผุ้เข้าร่วมที่ได้รับเชิญได้ตอบกลับเรื่องคำเชิญแล้ว"
+
+, "Unsupported method"
+: "วิธีการที่ไม่สนับสนุน"
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "ใส่ คำอธิบาย"
 
 , "Grants"
 : "อนุญาต"
 
-, "Displayed in"
-: "ได้แสดงใน"
+, "This event is originally stored in a calendar you don't have access to."
+: "เหตุการณ์นี้ได้รับการบันทึกแรกเริ่มในปฏิทินที่คุณไม่สามารถเข้าไปดูได้"
 
-, "Event not found"
+, "This event is originally stored in {0}"
+: "เหตุการณ์นี้ได้รับการบันทึกแรกเริ่มใน {0}"
+
+, "This event is additionally displayed in your personal calendar {0}"
+: "เหตุการณ์นี้จะเพิ่มเข้าไปอัตโนมัติในปฏิทิน {0} ส่วนตัวของคุณ"
+
+, "Colors"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "Side bar color"
 : ""
 
-, "GENDER_Attendee"
+, "Color by Calendar"
 : ""
 
-, "Select Attendee"
-: "เลือก ผู้เข้าร่วม"
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: "ดู"
+
+, "Saved in"
+: "ได้บันทึกใน"
+
+, "Enter description"
+: "ใส่ คำอธิบาย"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "วันที่สิ้นสุดไม่ถูกต้อง"
+
+, "End date must be after start date"
+: "วันที่สิ้นสุดต้องตามหลังวันที่เริ่มต้น"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "วันที่เริ่มต้นไม่ถูกต้อง"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : "ข้อสรุปต้องไม่มากไปกว่า 255 ตัวอักษร"
@@ -1029,127 +1026,143 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : "ข้อสรุปสั้นเกินไป"
 
-, "Recurrances"
-: "ความซ้ำซ้อน"
+, "Set This Date as Definite Event?"
+: ""
 
-, "No recurring rule defined"
-: "ไม่ได้มีกฎเกี่ยวกับการซ้ำซ้อนระบุไว้"
+, "Do you want to close the poll and remove all other alternatives?"
+: ""
 
-, "None"
-: "ไม่มีเลย"
+, "Attendee/Resources"
+: ""
 
-, "Exceptions of reccuring events can't have recurrences themselves."
-: "ข้อยกเว้นเกี่ยวกับเหตุการณ์ที่ซ้ำซ้อนไม่สามารถมีสิ่งที่ซ้ำซ้อนอยู่ในตัวมันเองได้"
+, "Additional Attendees ..."
+: ""
 
-, "at"
-: "ณ"
+, "Default Status"
+: ""
 
-, "never"
+, "No Access"
+: ""
+
+, "All my events"
+: "เหตุการณ์ทั้งหมดของฉัน"
+
+, "Position on the left time axis, day and week view should start with"
+: "เนื่องด้วยตำแหน่งบนเส้นเวลาที่เหลือ การดูแบบวันและแบบสัปดาห์ควรเริ่มต้นด้วย"
+
+, "Position on the left time axis, day and week view should end with"
+: ""
+
+, "Default Start Time"
+: ""
+
+, "Scroll position on the left time axis, day and week view should start with"
+: ""
+
+, "Visible Time"
+: ""
+
+, "Time to be displayed at once"
+: ""
+
+, "Default Calendar"
+: "ปฏิทินหลัก"
+
+, "The default calendar for invitations and new events"
+: "ปฏิทินหลักสำหรับคำเชิญและเหตุการณ์ใหม่"
+
+, "Default Favorite"
+: "ค่าที่ชอบหลัก"
+
+, "The default favorite which is loaded on calendar startup"
+: "ค่าที่ชอบหลักจะโหลดทันทีเมื่อเริ่มเปิดปฏิทิน"
+
+, "Get Notification Emails"
+: "ได้อีเมลแจ้งเตือน"
+
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "ระดับของการกระทำที่คุณต้องการรับทราบ พึงระลึกว่าผู้ทำการนัดหมายจะได้รับการแจ้งเตือนเกี่ยวกับทุก ๆ อัพเดท รวมถึงทุก ๆ คำตอบของผู้เข้า นอกเสียจากว่าจะมีตั้งค่าเป็น \"ไม่เลย\""
+
+, "Send Notifications Emails of own Actions"
+: "ส่งอีเมลแจ้งเตือนของการกระทำของตัวเอง"
+
+, "Get notifications emails for actions you did yourself"
+: "ได้อีเมลแจ้งเตือนสำหรับสิ่งที่คุณได้ทำด้วยตัวคุณเอง"
+
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
+, "Send Alarm Notifications Emails"
+: ""
+
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: "ตั้งการเตือนมาตรฐานได้"
+
+, "New events get a standard alarm as defined below"
+: "เหตุการณ์ใหม่ ๆ จะได้รับการเตือนที่ตั้งเป็นมาตรฐานได้ดังที่กำหนดไว้เบื้องล่างนี้"
+
+, "Standard Alarm Time"
+: "เวลาเตือนมาตรฐาน"
+
+, "Minutes before the event starts"
+: "จำนวนนาทีก่อนเหตุการณ์จะเริ่ม"
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "ปฏิทินหลัก"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
 : "ไม่เลย"
 
-, "after {0} occurrences"
-: "หลังจากเกิดขึ้น {0} ครั้ง"
+, "On invitation and cancellation only"
+: "เฉพาะเรื่องคำเชิญและการยกเลิกเท่านั้น"
 
-, "Except"
+, "On time changes"
+: "ตามการเปลี่ยนแปลงตามกำหนดการ"
+
+, "On all updates but attendee responses"
 : ""
 
-, "during events in the calendars"
-: ""
-
-, "End"
-: "สิ้นสุด"
-
-, "Until has to be after event start"
-: "จนถึง ต้องไปอยู่"
-
-, "The event is longer than the recurring interval"
-: ""
-
-, "Every {0}. Day"
-: "ทุกๆ {0} วัน"
-
-, "Every {0}. Week at"
-: "ทุกๆ {0} สัปดาห์ เมื่อ"
-
-, "Every {0}. Month"
-: "ทุกๆ {0} เดือน"
-
-, "at the"
-: "เมื่อ"
-
-, "first"
-: "ลำดับที่หนึ่ง"
-
-, "second"
-: "ลำดับที่สอง"
-
-, "third"
-: "ลำดับที่สาม"
-
-, "fourth"
-: "ลำดับที่สี่"
-
-, "last"
-: "ลำดับสุดท้าย"
-
-, "Every {0}. Year"
-: "ทุกๆ {0} ปี"
-
-, "of"
-: "ของ"
-
-, "First name, ĺast name"
-: ""
-
-, "E-Mail address"
-: ""
-
-, "Please wait..."
-: ""
-
-, "General terms and conditions"
-: ""
-
-, "Relation, Relations"
-: [
-  ""
-
-]
-, "All events I attend"
-: "ทุกเหตุการณ์ที่ฉันเข้าร่วม"
-
-, "Required"
-: "ได้ต้องการ"
-
-, "Optional"
-: "ตามแต่จะเลือก"
-
-, "No response"
-: "ไม่มีการตอบรับ"
-
-, "Accepted"
-: "ได้ยอมรับแล้ว"
-
-, "Declined"
-: "ได้ปฏิเสธแล้ว"
-
-, "Awaiting response"
-: "กำลังรอการตอบรับ"
-
-, "Events I have not yet responded to"
-: "เหตุการณ์ที่ฉันยังไม่ได้ตอบรับ"
-
-, "Declined events"
-: "เหตุการณ์ที่ได้ปฏิเสธไป"
-
-, "Events I have declined"
-: "เหตุการณ์ที่ฉันได้ปฏิเสธไป"
-
-, "I'm organizer"
-: "ฉันเป็นผู้นัดหมาย"
-
-, "Events I'm the organizer of"
-: "เหตุการณ์ที่ฉันเป็นผู้นัดหมาย"
+, "On attendee responses too"
+: "ตามที่ผู้เข้าร่วมตอบรับด้วย"
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : ""
@@ -1214,12 +1227,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "ไม่มีการตอบรับ"
+
+, "Accepted"
+: "ได้ยอมรับแล้ว"
+
+, "Declined"
+: "ได้ปฏิเสธแล้ว"
+
 , "Attendee Roles Available"
 : "หน้าที่ของผู้เข้าร่วม ว่าง"
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "ได้ต้องการ"
+
+, "Optional"
+: "ตามแต่จะเลือก"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1229,6 +1260,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1271,6 +1332,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1322,6 +1386,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1361,95 +1428,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "แจ้งเตือน เหตุการณ์ \"%1$s\" เมื่อ %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "คำเชิญเข้าร่วมเหตุการณ์ \"%1$s\" เมื่อ %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "เหตุการณ์ \"%1$s\" เมื่อ %2$s ได้ถูกยกเลิก"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
-: "เหตุการณ์ \"%1$s\" ได้เปลี่ยนจาก %2$s ไปเป็น %3$s"
-
-, "Event \"%1$s\" at %2$s has been updated"
-: "เหตุการณ์ \"%1$s\" เมื่อ %2$s ได้ถูกปรับปรุง"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s ได้ยอมรับเหตุการณ์ \"%2$s\" เมื่อ %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s ได้ปฏิเสธเหตุการณ์ \"%2$s\" เมื่อ %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "การตอบรับที่ยังไม่แน่นอนจาก %1$s สำหรับเหตุการณ์ \"%2$s\" เมื่อ %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "ไม่มีการตอบรับจาก %1$s สำหรับเหตุการณ์ \"%2$s\" เมื่อ %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "มีการเปลี่ยนแปลงเกี่ยวกับผู้เข้าร่วมสำหรับเหตุการณ์ \"%1$s\" เมื่อ %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Group Additional Filters"
 : ""
 
-, "Resource Management"
+, "Resource Additional Filters"
 : ""
 
-, "Polls for recurring events are not supported"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "%s's personal calendar"
+: "%s ของปฏิทินส่วนตัว"
+
+, "Failed"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "The right Resource Admin must be set once."
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Different Calendar"
 : ""
 
-, "Start"
-: "เริ่มต้น"
+, "Exdate container move are not allowed"
+: ""
 
-, "Priority"
-: "ลำดับความสำคัญ"
+, "Invalid URL given"
+: "URL ที่ให้มาไม่ถูกต้อง"
 
-, "Url"
-: "Url"
+, "The URL you used is invalid. Please use a valid one!"
+: "URL ที่คุณใช้ไม่ถูกต้อง กรุณาใช้ที่ถูกต้อง!"
 
-, "Recurrance rule"
-: "กฎเกี่ยวกับการซ้ำซ้อน"
+, "Calendars to export"
+: ""
 
-, "Is all day event"
-: "คือเหตุการณ์ทั้งวัน"
+, "Export target"
+: ""
 
-, "Organizer timezone"
-: "โซนเวลาของผู้นัดหมาย"
+, "VCalendar/ICS"
+: ""
 
-, "No"
-: "ไม่ใช่"
+, "Export visible events to ics file"
+: ""
 
-, "Yes"
-: "ใช่"
+, "Excel overview"
+: ""
+
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "ไม่รู้จัก"
@@ -1508,34 +1584,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : "ที่"
 
+, "Start"
+: "เริ่มต้น"
+
+, "Priority"
+: "ลำดับความสำคัญ"
+
+, "Url"
+: "Url"
+
+, "Recurrance rule"
+: "กฎเกี่ยวกับการซ้ำซ้อน"
+
+, "Is all day event"
+: "คือเหตุการณ์ทั้งวัน"
+
+, "Organizer timezone"
+: "โซนเวลาของผู้นัดหมาย"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "แจ้งเตือน เหตุการณ์ \"%1$s\" เมื่อ %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "คำเชิญเข้าร่วมเหตุการณ์ \"%1$s\" เมื่อ %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "เหตุการณ์ \"%1$s\" เมื่อ %2$s ได้ถูกยกเลิก"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+: "เหตุการณ์ \"%1$s\" ได้เปลี่ยนจาก %2$s ไปเป็น %3$s"
+
+, "Event \"%1$s\" at %2$s has been updated"
+: "เหตุการณ์ \"%1$s\" เมื่อ %2$s ได้ถูกปรับปรุง"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s ได้ยอมรับเหตุการณ์ \"%2$s\" เมื่อ %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s ได้ปฏิเสธเหตุการณ์ \"%2$s\" เมื่อ %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "การตอบรับที่ยังไม่แน่นอนจาก %1$s สำหรับเหตุการณ์ \"%2$s\" เมื่อ %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "ไม่มีการตอบรับจาก %1$s สำหรับเหตุการณ์ \"%2$s\" เมื่อ %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "มีการเปลี่ยนแปลงเกี่ยวกับผู้เข้าร่วมสำหรับเหตุการณ์ \"%1$s\" เมื่อ %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Unknown action"
 : ""
 
-, "Word event sheet"
+, "Resource Management"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Excel all data"
+, "Polls for recurring events are not supported"
 : ""
 
-, "Import iCal-files"
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1574,32 +1719,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "รายละเอียดของเหตุการณ์"
 
-, "The poll \"%1$s\" has been closed."
-: ""
+, "All events I attend"
+: "ทุกเหตุการณ์ที่ฉันเข้าร่วม"
 
-, "The definite event is scheduled for \"%1$s\""
-: ""
+, "Awaiting response"
+: "กำลังรอการตอบรับ"
 
-, "You can review the poll results here:"
-: ""
+, "Events I have not yet responded to"
+: "เหตุการณ์ที่ฉันยังไม่ได้ตอบรับ"
 
-, "Thank you for attendening the poll \"%1$s\""
-: ""
+, "Declined events"
+: "เหตุการณ์ที่ได้ปฏิเสธไป"
 
-, "To review or edit your status please use your personal link:"
-: ""
+, "Events I have declined"
+: "เหตุการณ์ที่ฉันได้ปฏิเสธไป"
 
-, "Different Calendar"
-: ""
+, "I'm organizer"
+: "ฉันเป็นผู้นัดหมาย"
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: "URL ที่ให้มาไม่ถูกต้อง"
-
-, "The URL you used is invalid. Please use a valid one!"
-: "URL ที่คุณใช้ไม่ถูกต้อง กรุณาใช้ที่ถูกต้อง!"
+, "Events I'm the organizer of"
+: "เหตุการณ์ที่ฉันเป็นผู้นัดหมาย"
 
 , "manage shared calendars"
 : "จัดการ ปฏิทินที่ใช้ร่วมกัน"
@@ -1619,77 +1758,49 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : ""
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "or"
-: "หรือ"
-
-, "Is a location"
-: "คือสถานที่"
-
-, "Errors"
-: "ข้อผิดพลาด"
-
-, "Do you really want to delete this event?"
-: "คุณแน่ใจว่าคุณต้องการลบ {0} เหตุการณ์ที่เลือก?"
+, "Relation, Relations"
+: [
+  ""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "แหล่งที่มา"
+, "Calendar"
+: "ปฏิทิน"
+
+, "Do you really want to delete this event?"
+: "คุณแน่ใจว่าคุณต้องการลบ {0} เหตุการณ์ที่เลือก?"
 
 , "Resource Grant"
 : ""
@@ -1697,12 +1808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "เหตุการณ์"
 
-, "Calendar"
-: "ปฏิทิน"
-
 , "Attender"
 : "ผู้เข้าร่วม"
 
+, "Resource"
+: "แหล่งที่มา"
+
 , "Relation"
 : ""
 
