@@ -5,167 +5,249 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "lịch cá nhân của %s'"
+, "{0}, the {1}. of {2}"
+: "{0}, {1} của {2}"
 
-, "Resources"
-: "Tài nguyên"
+, "Recurrances"
+: "Lặp lại"
 
-, "All my events"
-: "Tất cả sự kiện của tôi"
+, "No recurring rule defined"
+: "Không định nghĩa quy tắc lặp lại"
 
-, "Start Time"
-: "Thời gian bắt đầu"
+, "Details"
+: "Chi tiết"
 
-, "Position on the left time axis, day and week view should start with"
-: "Vị trí trên trục thời gian còn lại, kiểu xem ngày và tuần bắt đầu"
+, "None"
+: "Không"
 
-, "End Time"
-: "Thời gian kết thúc"
+, "Daily"
+: "Hàng ngày"
 
-, "Position on the left time axis, day and week view should end with"
-: ""
+, "Weekly"
+: "Hàng tuần"
 
-, "Default Start Time"
-: ""
+, "Monthly"
+: "Hàng tháng"
 
-, "Scroll position on the left time axis, day and week view should start with"
-: ""
+, "Yearly"
+: "Hàng năm"
 
-, "Visible Time"
-: ""
+, "Exceptions of reccuring events can't have recurrences themselves."
+: "Trừ sự kiện lặp lại không thể tự có sự kiện lặp lại"
 
-, "Time to be displayed at once"
-: ""
+, "at"
+: "tại"
 
-, "Default Calendar"
-: "Lịch mặc định"
-
-, "The default calendar for invitations and new events"
-: "Lịch mặc định cho lời mời và sự kiện mới"
-
-, "Default Favorite"
-: "Lối tắt mặc định"
-
-, "The default favorite which is loaded on calendar startup"
-: "Lối tắt mặc định được nạp khi lịch khởi động"
-
-, "Get Notification Emails"
-: "Tải email thông báo"
-
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "Mức độ hoạt động bạn muốn được thông báo. Xin hãy ghi nhớ rằng tổ chức nhận thông báo cho mọi cập nhật bao gồm người tham gia trả lời trừ khi thiết lập được đặt là \"Không bao giờ\""
-
-, "Send Notifications Emails of own Actions"
-: "Gửi email thông báo tới chức năng của chính người sở hữu"
-
-, "Get notifications emails for actions you did yourself"
-: "Nhận email thông báo cho chức năng của chính bạn"
-
-, "Send Alarm Notifications Emails"
-: ""
-
-, "Get event alarms via email"
-: ""
-
-, "Enable Standard Alarm"
-: "Mở tính năng cảnh báo chuẩn"
-
-, "New events get a standard alarm as defined below"
-: "Sự kiện mới có nhắc việc chuẩn như được định nghĩa dưới đây"
-
-, "Standard Alarm Time"
-: "Thời gian nhắc việc chuẩn"
-
-, "Minutes before the event starts"
-: "Số phút trước khi sự kiện xảy ra"
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "Lịch cố định"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
+, "never"
 : "Không bao giờ"
 
-, "On invitation and cancellation only"
-: "Chỉ khi có lời mời và hủy bỏ"
+, "after {0} occurrences"
+: "sau {0} lần diễn ra"
 
-, "On time changes"
-: "Chỉ khi thời gian thay đổi"
+, "Except"
+: ""
 
-, "On all updates but attendee responses"
-: "Khi có mọi cập nhật trừ trả lời của người tham gia"
+, "during events in the calendars"
+: ""
 
-, "On attendee responses too"
-: "Cả khi người tham gia trả lời"
+, "End"
+: "Kết thúc"
 
-, "Events"
-: "Sự kiện"
+, "Until has to be after event start"
+: "Cho tới khi sự kiện bắt đaafu"
+
+, "The event is longer than the recurring interval"
+: ""
+
+, "Every {0}. Day"
+: "Mỗi {0}. Ngày"
+
+, "Every {0}. Week at"
+: "Mỗi {0}. Tuần"
+
+, "Every {0}. Month"
+: "Mỗi {0}. Tháng"
+
+, "at the"
+: "tại"
+
+, "first"
+: "đầu tiên"
+
+, "second"
+: "thứ hai"
+
+, "third"
+: "thứ ba"
+
+, "fourth"
+: "thứ tư"
+
+, "last"
+: "cuối"
+
+, "Every {0}. Year"
+: "Mỗi {0}. Năm"
+
+, "of"
+: "của"
 
 , "Summary"
 : "Tóm tắt"
 
-, "Status"
-: "Trạng thái"
+, "Organizer"
+: "Tổ chức"
 
-, "No Information"
-: "Không có thông tin"
-
-, "recurring event"
-: "sự kiện lặp lại"
-
-, "recurring event exception"
-: "ngoại trừ sự kiện lặp lại"
-
-, "Blocking"
-: "Ngăn chặn"
-
-, "Tentative"
-: "Phân vân"
+, "Description"
+: "Mô tả"
 
 , "Location"
 : "Địa điểm"
 
-, "Organizer"
-: "Tổ chức"
+, "Start Time"
+: "Thời gian bắt đầu"
+
+, "End Time"
+: "Thời gian kết thúc"
 
 , "Attendee"
 : "Người tham dự"
 
+, "whole day"
+: "cả ngày"
+
+, "Week {0} :"
+: "Tuần {0}:"
+
+, "Poll, Polls"
+: [
+  ""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "Tạo sự kiện"
+
+, "Calendar, Calendars"
+: [
+  "one:Lịch\nother:Lịch"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : "Thêm người tham dự"
 
@@ -175,117 +257,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : ""
 
-, "Attachments"
+, "Unavailable"
 : ""
 
-, "Private"
-: "Riêng tư"
-
-, "Tags"
-: "Thẻ"
-
-, "whole day"
-: "cả ngày"
-
-, "Description"
-: "Mô tả"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: "Sự kiện này được lưu ban đầu ở lịch bạn không có quyền truy cập"
-
-, "This event is originally stored in {0}"
-: "Sự kiện này được lưu ban đầu ở {0}"
-
-, "This event is additionally displayed in your personal calendar {0}"
-: "Sự kiện này đồng thời hiển thị trong lịch cá nhân của bạn {0}"
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: "Xin chọn sự kiện để thêm liên hệ vào đó"
-
-, "Role"
-: "Vai trò"
-
-, "Select Role"
-: "Chọn vai trò"
-
-, "Select Status"
-: "Chọn trạng thái"
-
-, "Adding {0} Attendee to event"
-: "Thêm người tham gia {0} vào sự kiện"
-
-, "Checking Calendar Data..."
-: "Đang kiểm tra dữ liệu lịch..."
-
-, "Reply to Recurring Event"
-: "Trả lời sự kiện lặp lại"
-
-, "You are responding to an recurring event. What would you like to do?"
-: "Bạn đang trả lời sự kiện lặp lại. Bạn muốn làm gì?"
-
-, "Respond to whole series"
-: "Trả lời toàn bộ chuỗi sự kiện"
-
-, "Do not respond"
-: "Không trả lời"
-
-, "The event of this message does not exist"
-: "Sự kiện của tin nhắn này không tồn tại"
-
-, "The sender is not authorised to update the event"
-: "Người gửi không có quyền cập nhật sự kiện"
-
-, "This message is already processed"
-: "Tin nhắn đã được xử lý rồi"
-
-, "You are not an attendee of this event"
-: "Bạn không phải là người tham gia sự kiện này"
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: "Tin nhắn không được hỗ trợ"
-
-, "This is an event invitation for someone else."
-: "Đây là 1 lời mời từ ai đó"
-
-, "You have already replied to this event invitation."
-: "Bạn đã trả lời lời mời tham gia sự kiện này"
-
-, "You received an event invitation. Set your response to:"
-: "Bạn đã nhận 1 lời mời. Đặt câu trả lời tới:"
-
-, "An invited attendee responded to the invitation."
-: "Người tham d được mời đã trả lời lời mời"
-
-, "Unsupported method"
-: "Phương pháp không được hỗ trợ"
-
 , "Loading events, please wait..."
 : "Đang tải sự kiện, xin đợi trong giây lát..."
 
@@ -325,6 +299,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +314,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : "Sao chép {0}"
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : "Cập nhật sự kiện trong quá khứ"
 
@@ -417,9 +397,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : "Hủy hành động này"
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "Quản lý tài nguyên"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "Chọn người tham dự"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "Riêng tư"
+
+, "Tags"
+: "Thẻ"
+
+, "Blocking"
+: "Ngăn chặn"
+
+, "Tentative"
+: "Phân vân"
+
 , "Import Definition Success!"
 : ""
 
@@ -456,9 +463,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -510,7 +514,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -534,155 +538,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: "Xem"
-
-, "Details"
-: "Chi tiết"
-
-, "Saved in"
-: "Lưu trong"
-
-, "non-blocking"
-: "không chặn"
-
-, "Enter description"
-: "Nhập mô tả"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "Ngày kết thúc không hợp lệ"
-
-, "End date must be after start date"
-: "Ngày kết thúc phải sau ngày bắt đầu"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "Ngày bắt đầu không hợp lệ"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: "Tuần {0}:"
-
-, "Originally"
-: "Gốc"
-
-, "Poll, Polls"
-: [
-  ""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: "WK"
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "Hàng ngày"
-
-, "Weekly"
-: "Hàng tuần"
-
-, "Monthly"
-: "Hàng tháng"
-
-, "Yearly"
-: "Hàng năm"
-
-, "Name"
-: "Tên"
-
-, "Email"
-: "Email"
-
-, "Type"
-: "Loại"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "Tạo sự kiện"
-
-, "{0} more..."
-: "{0} thêm..."
-
 , "private classification"
 : "phân loại cá nhân"
 
+, "recurring event"
+: "sự kiện lặp lại"
+
+, "recurring event exception"
+: "ngoại trừ sự kiện lặp lại"
+
 , "has alarm"
 : "có nhắc việc"
 
@@ -692,61 +556,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
-: "{0}, {1} của {2}"
+, "Mini Calendar"
+: "Lịch rút gọn"
 
-, "Click here to invite another attender..."
-: "Click vào đây để mời người tham dự khác"
+, "WK"
+: "WK"
 
-, "User"
-: "Người dùng"
-
-, "Group"
-: "Nhóm"
-
-, "Resource, Resources"
-: [
-  "one: Tài nguyên\nother:Tài nguyên"
-
-]
-, "Member of group"
-: "Thành viên trong nhóm"
-
-, "This is the calendar where the attender has saved this event in"
-: "Đây là lịch mà người tham dự đã lưu trong sự kiện này ở"
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "Xóa người tham dự"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: "(là 1 thành viên nhóm)"
-
-, "External Attendee"
-: ""
+, "{0} more..."
+: "{0} thêm..."
 
 , "Resource Grant, Resource Grants"
 : [
@@ -765,6 +582,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -807,7 +627,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -837,100 +657,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: "Xin chọn sự kiện để thêm liên hệ vào đó"
+
+, "Role"
+: "Vai trò"
+
+, "Select Role"
+: "Chọn vai trò"
+
+, "Status"
+: "Trạng thái"
+
+, "Select Status"
+: "Chọn trạng thái"
+
+, "Adding {0} Attendee to event"
+: "Thêm người tham gia {0} vào sự kiện"
+
 , "no events found"
 : "không thấy sự kiện nào"
 
 , "Searching..."
 : "Đang tìm"
 
+, "Search Event"
+: "Tìm sự kiện"
+
 , "Event, Events"
 : [
   "one: Sự kiện\nother: Sự kiện"
 
 ]
-, "Search Event"
-: "Tìm sự kiện"
-
-, "Switch to public poll"
+, "Additional Tags ..."
 : ""
 
-, "Welcome {name}"
+, "non-blocking"
+: "không chặn"
+
+, "Displayed in"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "No Information"
+: "Không có thông tin"
+
+, "Event Location"
 : ""
 
-, "This poll is closed already"
+, "From"
 : ""
 
-, "I am not {name}"
+, "until"
 : ""
 
-, "Login"
-: ""
+, "Events"
+: "Sự kiện"
 
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: "Lịch rút gọn"
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "one:Lịch\nother:Lịch"
-
-]
 , "Calendars"
 : "Lịch"
 
@@ -964,6 +749,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -984,38 +781,238 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
   "one: Người tham dự\nother: Người tham dự"
 
 ]
+, "Resource, Resources"
+: [
+  "one: Tài nguyên\nother:Tài nguyên"
+
+]
+, "Resources"
+: "Tài nguyên"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "Tên"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "Email"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "Loại"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: "Click vào đây để mời người tham dự khác"
+
+, "User"
+: "Người dùng"
+
+, "Group"
+: "Nhóm"
+
+, "Member of group"
+: "Thành viên trong nhóm"
+
+, "This is the calendar where the attender has saved this event in"
+: "Đây là lịch mà người tham dự đã lưu trong sự kiện này ở"
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "Xóa người tham dự"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: "(là 1 thành viên nhóm)"
+
+, "External Attendee"
+: ""
+
+, "Originally"
+: "Gốc"
+
+, "Checking Calendar Data..."
+: "Đang kiểm tra dữ liệu lịch..."
+
+, "Reply to Recurring Event"
+: "Trả lời sự kiện lặp lại"
+
+, "You are responding to an recurring event. What would you like to do?"
+: "Bạn đang trả lời sự kiện lặp lại. Bạn muốn làm gì?"
+
+, "Respond to whole series"
+: "Trả lời toàn bộ chuỗi sự kiện"
+
+, "Do not respond"
+: "Không trả lời"
+
+, "The event of this message does not exist"
+: "Sự kiện của tin nhắn này không tồn tại"
+
+, "The sender is not authorised to update the event"
+: "Người gửi không có quyền cập nhật sự kiện"
+
+, "This message is already processed"
+: "Tin nhắn đã được xử lý rồi"
+
+, "You are not an attendee of this event"
+: "Bạn không phải là người tham gia sự kiện này"
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: "Tin nhắn không được hỗ trợ"
+
+, "This is an event invitation for someone else."
+: "Đây là 1 lời mời từ ai đó"
+
+, "You have already replied to this event invitation."
+: "Bạn đã trả lời lời mời tham gia sự kiện này"
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: "Bạn đã nhận 1 lời mời. Đặt câu trả lời tới:"
+
+, "An invited attendee responded to the invitation."
+: "Người tham d được mời đã trả lời lời mời"
+
+, "Unsupported method"
+: "Phương pháp không được hỗ trợ"
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "Nhập mô tả"
 
 , "Grants"
 : ""
 
-, "Displayed in"
+, "This event is originally stored in a calendar you don't have access to."
+: "Sự kiện này được lưu ban đầu ở lịch bạn không có quyền truy cập"
+
+, "This event is originally stored in {0}"
+: "Sự kiện này được lưu ban đầu ở {0}"
+
+, "This event is additionally displayed in your personal calendar {0}"
+: "Sự kiện này đồng thời hiển thị trong lịch cá nhân của bạn {0}"
+
+, "Colors"
 : ""
 
-, "Event not found"
+, "Side bar color"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "Color by Calendar"
 : ""
 
-, "GENDER_Attendee"
+, "Color by Attendee Calendar"
 : ""
 
-, "Select Attendee"
-: "Chọn người tham dự"
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: "Xem"
+
+, "Saved in"
+: "Lưu trong"
+
+, "Enter description"
+: "Nhập mô tả"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "Ngày kết thúc không hợp lệ"
+
+, "End date must be after start date"
+: "Ngày kết thúc phải sau ngày bắt đầu"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "Ngày bắt đầu không hợp lệ"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : "Tóm tắt không được dài hơn 255 ký tự"
@@ -1029,127 +1026,143 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : "Tóm tắt quá ngắn"
 
-, "Recurrances"
-: "Lặp lại"
+, "Set This Date as Definite Event?"
+: ""
 
-, "No recurring rule defined"
-: "Không định nghĩa quy tắc lặp lại"
+, "Do you want to close the poll and remove all other alternatives?"
+: ""
 
-, "None"
-: "Không"
+, "Attendee/Resources"
+: ""
 
-, "Exceptions of reccuring events can't have recurrences themselves."
-: "Trừ sự kiện lặp lại không thể tự có sự kiện lặp lại"
+, "Additional Attendees ..."
+: ""
 
-, "at"
-: "tại"
+, "Default Status"
+: ""
 
-, "never"
+, "No Access"
+: ""
+
+, "All my events"
+: "Tất cả sự kiện của tôi"
+
+, "Position on the left time axis, day and week view should start with"
+: "Vị trí trên trục thời gian còn lại, kiểu xem ngày và tuần bắt đầu"
+
+, "Position on the left time axis, day and week view should end with"
+: ""
+
+, "Default Start Time"
+: ""
+
+, "Scroll position on the left time axis, day and week view should start with"
+: ""
+
+, "Visible Time"
+: ""
+
+, "Time to be displayed at once"
+: ""
+
+, "Default Calendar"
+: "Lịch mặc định"
+
+, "The default calendar for invitations and new events"
+: "Lịch mặc định cho lời mời và sự kiện mới"
+
+, "Default Favorite"
+: "Lối tắt mặc định"
+
+, "The default favorite which is loaded on calendar startup"
+: "Lối tắt mặc định được nạp khi lịch khởi động"
+
+, "Get Notification Emails"
+: "Tải email thông báo"
+
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "Mức độ hoạt động bạn muốn được thông báo. Xin hãy ghi nhớ rằng tổ chức nhận thông báo cho mọi cập nhật bao gồm người tham gia trả lời trừ khi thiết lập được đặt là \"Không bao giờ\""
+
+, "Send Notifications Emails of own Actions"
+: "Gửi email thông báo tới chức năng của chính người sở hữu"
+
+, "Get notifications emails for actions you did yourself"
+: "Nhận email thông báo cho chức năng của chính bạn"
+
+, "Send Notifications Emails of tentative events"
+: ""
+
+, "Get notifications emails of tentative events"
+: ""
+
+, "Send Alarm Notifications Emails"
+: ""
+
+, "Get event alarms via email"
+: ""
+
+, "Enable Standard Alarm"
+: "Mở tính năng cảnh báo chuẩn"
+
+, "New events get a standard alarm as defined below"
+: "Sự kiện mới có nhắc việc chuẩn như được định nghĩa dưới đây"
+
+, "Standard Alarm Time"
+: "Thời gian nhắc việc chuẩn"
+
+, "Minutes before the event starts"
+: "Số phút trước khi sự kiện xảy ra"
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "Lịch cố định"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
 : "Không bao giờ"
 
-, "after {0} occurrences"
-: "sau {0} lần diễn ra"
+, "On invitation and cancellation only"
+: "Chỉ khi có lời mời và hủy bỏ"
 
-, "Except"
-: ""
+, "On time changes"
+: "Chỉ khi thời gian thay đổi"
 
-, "during events in the calendars"
-: ""
+, "On all updates but attendee responses"
+: "Khi có mọi cập nhật trừ trả lời của người tham gia"
 
-, "End"
-: "Kết thúc"
-
-, "Until has to be after event start"
-: "Cho tới khi sự kiện bắt đaafu"
-
-, "The event is longer than the recurring interval"
-: ""
-
-, "Every {0}. Day"
-: "Mỗi {0}. Ngày"
-
-, "Every {0}. Week at"
-: "Mỗi {0}. Tuần"
-
-, "Every {0}. Month"
-: "Mỗi {0}. Tháng"
-
-, "at the"
-: "tại"
-
-, "first"
-: "đầu tiên"
-
-, "second"
-: "thứ hai"
-
-, "third"
-: "thứ ba"
-
-, "fourth"
-: "thứ tư"
-
-, "last"
-: "cuối"
-
-, "Every {0}. Year"
-: "Mỗi {0}. Năm"
-
-, "of"
-: "của"
-
-, "First name, ĺast name"
-: ""
-
-, "E-Mail address"
-: ""
-
-, "Please wait..."
-: ""
-
-, "General terms and conditions"
-: ""
-
-, "Relation, Relations"
-: [
-  ""
-
-]
-, "All events I attend"
-: "Mọi sự kiện tôi tham gia"
-
-, "Required"
-: "Bắt buộc"
-
-, "Optional"
-: "Tùy chọn"
-
-, "No response"
-: "Không trả lời"
-
-, "Accepted"
-: "Chấp nhận"
-
-, "Declined"
-: "Từ chối"
-
-, "Awaiting response"
-: "Chờ trả lời"
-
-, "Events I have not yet responded to"
-: "Sự kiện tôi chưa trả lời"
-
-, "Declined events"
-: "Sự kiện bị từ chối"
-
-, "Events I have declined"
-: "Sự kiện tôi đã từ chối"
-
-, "I'm organizer"
-: "Tôi là người tổ chức"
-
-, "Events I'm the organizer of"
-: "Sự kiện mà tôi là người tổ chức của"
+, "On attendee responses too"
+: "Cả khi người tham gia trả lời"
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
 : "Lịch luôn được chọn không phụ thuộc vào bất kỳ bộ lọc nào. Trường hợp sử dụng hợp lệ có thể buộc hiển thị 1 lịch nghỉ."
@@ -1214,12 +1227,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "Không trả lời"
+
+, "Accepted"
+: "Chấp nhận"
+
+, "Declined"
+: "Từ chối"
+
 , "Attendee Roles Available"
 : "Trạng thái vai trò người tham dự sẵn sàng"
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "Bắt buộc"
+
+, "Optional"
+: "Tùy chọn"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1229,6 +1260,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1271,6 +1332,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1322,6 +1386,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1361,95 +1428,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
-: "Nhắc cho sự kiện  \"%1$s\" tại %2$s"
-
-, "Event invitation \"%1$s\" at %2$s"
-: "Mời tham dự sự kiện \"%1$s\" tại %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "User Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "Sự kiện \"%1$s\" tại %2$s đã bị hủy"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
-: "Sự kiện \"%1$s\" đã được đặt lại lịch từ %2$s đến %3$s"
-
-, "Event \"%1$s\" at %2$s has been updated"
-: "Sự kiện \"%1$s\" tại %2$s đã được cập nhật"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s chấp nhận sự kiện \"%2$s\" tại %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s từ chối sự kiện \"%2$s\" tại %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
-: "Trả lời phân vân từ %1$s cho sự kiện \"%2$s\" tại %3$s"
-
-, "No response from %1$s for event \"%2$s\" at %3$s"
-: "Không trả lời từ %1$s cho sự kiện  \"%2$s\" tại %3$s"
-
-, "Attendee changes for event \"%1$s\" at %2$s"
-: "Người tham dự cho sự kiện  \"%1$s\" tại %2$s"
-
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Group Additional Filters"
 : ""
 
-, "Resource Management"
+, "Resource Additional Filters"
 : ""
 
-, "Polls for recurring events are not supported"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "%s's personal calendar"
+: "lịch cá nhân của %s'"
+
+, "Failed"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "The right Resource Admin must be set once."
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Different Calendar"
 : ""
 
-, "Start"
-: "Bắt đầu"
+, "Exdate container move are not allowed"
+: ""
 
-, "Priority"
-: "Quan trọng"
+, "Invalid URL given"
+: ""
 
-, "Url"
-: "URL"
+, "The URL you used is invalid. Please use a valid one!"
+: ""
 
-, "Recurrance rule"
-: "Quy tắc lặp lại"
+, "Calendars to export"
+: ""
 
-, "Is all day event"
-: "Sự kiện hàng ngày"
+, "Export target"
+: ""
 
-, "Organizer timezone"
-: "Múi giờ tổ chức"
+, "VCalendar/ICS"
+: ""
 
-, "No"
-: "Không"
+, "Export visible events to ics file"
+: ""
 
-, "Yes"
-: "Có"
+, "Excel overview"
+: ""
+
+, "Word event sheet"
+: ""
+
+, "Export Events as Calendar Sheet"
+: ""
+
+, "VCalendar Report"
+: ""
+
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "không rõ"
@@ -1508,34 +1584,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: "Bắt đầu"
+
+, "Priority"
+: "Quan trọng"
+
+, "Url"
+: "URL"
+
+, "Recurrance rule"
+: "Quy tắc lặp lại"
+
+, "Is all day event"
+: "Sự kiện hàng ngày"
+
+, "Organizer timezone"
+: "Múi giờ tổ chức"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
+: "Nhắc cho sự kiện  \"%1$s\" tại %2$s"
+
+, "Event invitation \"%1$s\" at %2$s"
+: "Mời tham dự sự kiện \"%1$s\" tại %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Excel overview"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "Sự kiện \"%1$s\" tại %2$s đã bị hủy"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+: "Sự kiện \"%1$s\" đã được đặt lại lịch từ %2$s đến %3$s"
+
+, "Event \"%1$s\" at %2$s has been updated"
+: "Sự kiện \"%1$s\" tại %2$s đã được cập nhật"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s chấp nhận sự kiện \"%2$s\" tại %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s từ chối sự kiện \"%2$s\" tại %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: "Trả lời phân vân từ %1$s cho sự kiện \"%2$s\" tại %3$s"
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: "Không trả lời từ %1$s cho sự kiện  \"%2$s\" tại %3$s"
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Attendee changes for event \"%1$s\" at %2$s"
+: "Người tham dự cho sự kiện  \"%1$s\" tại %2$s"
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Unknown action"
 : ""
 
-, "Word event sheet"
+, "Resource Management"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
 : ""
 
-, "Excel all data"
+, "Polls for recurring events are not supported"
 : ""
 
-, "Import iCal-files"
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1574,32 +1719,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "Chi tiết sự kiện"
 
-, "The poll \"%1$s\" has been closed."
-: ""
+, "All events I attend"
+: "Mọi sự kiện tôi tham gia"
 
-, "The definite event is scheduled for \"%1$s\""
-: ""
+, "Awaiting response"
+: "Chờ trả lời"
 
-, "You can review the poll results here:"
-: ""
+, "Events I have not yet responded to"
+: "Sự kiện tôi chưa trả lời"
 
-, "Thank you for attendening the poll \"%1$s\""
-: ""
+, "Declined events"
+: "Sự kiện bị từ chối"
 
-, "To review or edit your status please use your personal link:"
-: ""
+, "Events I have declined"
+: "Sự kiện tôi đã từ chối"
 
-, "Different Calendar"
-: ""
+, "I'm organizer"
+: "Tôi là người tổ chức"
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
-: ""
+, "Events I'm the organizer of"
+: "Sự kiện mà tôi là người tổ chức của"
 
 , "manage shared calendars"
 : "Quản lý lịch dùng chung"
@@ -1619,74 +1758,49 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : "Tất cả quyền để quản lý tài nguyên"
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "Là 1 địa danh"
-
-, "Errors"
-: "Lỗi"
-
-, "Do you really want to delete this event?"
-: "one: Bạn có muốn xóa sự kiện này\nother: Bạn có muốn xóa các sự kiện đã chọn {0}"
+, "Relation, Relations"
+: [
+  ""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "one: Tài nguyên\nother:Tài nguyên"
+, "Calendar"
+: "one:Lịch\nother:Lịch"
+
+, "Do you really want to delete this event?"
+: "one: Bạn có muốn xóa sự kiện này\nother: Bạn có muốn xóa các sự kiện đã chọn {0}"
 
 , "Resource Grant"
 : ""
@@ -1694,12 +1808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "one: Sự kiện\nother: Sự kiện"
 
-, "Calendar"
-: "one:Lịch\nother:Lịch"
-
 , "Attender"
 : "one: Người tham dự\nother: Người tham dự"
 
+, "Resource"
+: "one: Tài nguyên\nother:Tài nguyên"
+
 , "Relation"
 : ""
 
