@@ -5,167 +5,249 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Vietnamese (Viet Nam) (http://www.transifex.com/tine20/tine20/language/vi_VN/)\nLanguage: vi_VN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (Viet Nam) (http://www.transifex.com/tine20/tine20/language/vi_VN/)\nLanguage: vi_VN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
+, "{0}, the {1}. of {2}"
 : ""
 
-, "Resources"
+, "Recurrances"
 : ""
 
-, "All my events"
+, "No recurring rule defined"
 : ""
 
-, "Start Time"
+, "Details"
 : ""
 
-, "Position on the left time axis, day and week view should start with"
+, "None"
 : ""
 
-, "End Time"
+, "Daily"
 : ""
 
-, "Position on the left time axis, day and week view should end with"
+, "Weekly"
 : ""
 
-, "Default Start Time"
+, "Monthly"
 : ""
 
-, "Scroll position on the left time axis, day and week view should start with"
+, "Yearly"
 : ""
 
-, "Visible Time"
+, "Exceptions of reccuring events can't have recurrences themselves."
 : ""
 
-, "Time to be displayed at once"
+, "at"
 : ""
 
-, "Default Calendar"
+, "never"
 : ""
 
-, "The default calendar for invitations and new events"
+, "after {0} occurrences"
 : ""
 
-, "Default Favorite"
+, "Except"
 : ""
 
-, "The default favorite which is loaded on calendar startup"
+, "during events in the calendars"
 : ""
 
-, "Get Notification Emails"
+, "End"
 : ""
 
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+, "Until has to be after event start"
 : ""
 
-, "Send Notifications Emails of own Actions"
+, "The event is longer than the recurring interval"
 : ""
 
-, "Get notifications emails for actions you did yourself"
+, "Every {0}. Day"
 : ""
 
-, "Send Alarm Notifications Emails"
+, "Every {0}. Week at"
 : ""
 
-, "Get event alarms via email"
+, "Every {0}. Month"
 : ""
 
-, "Enable Standard Alarm"
+, "at the"
 : ""
 
-, "New events get a standard alarm as defined below"
+, "first"
 : ""
 
-, "Standard Alarm Time"
+, "second"
 : ""
 
-, "Minutes before the event starts"
+, "third"
 : ""
 
-, "Default Attendee Strategy"
+, "fourth"
 : ""
 
-, "Default Attendee Strategy for new events"
+, "last"
 : ""
 
-, "Time Increment"
+, "Every {0}. Year"
 : ""
 
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: ""
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: ""
-
-, "On invitation and cancellation only"
-: ""
-
-, "On time changes"
-: ""
-
-, "On all updates but attendee responses"
-: ""
-
-, "On attendee responses too"
-: ""
-
-, "Events"
+, "of"
 : ""
 
 , "Summary"
 : ""
 
-, "Status"
+, "Organizer"
 : ""
 
-, "No Information"
-: ""
-
-, "recurring event"
-: ""
-
-, "recurring event exception"
-: ""
-
-, "Blocking"
-: ""
-
-, "Tentative"
+, "Description"
 : ""
 
 , "Location"
 : ""
 
-, "Organizer"
+, "Start Time"
+: ""
+
+, "End Time"
 : ""
 
 , "Attendee"
 : ""
 
+, "whole day"
+: ""
+
+, "Week {0} :"
+: ""
+
+, "Poll, Polls"
+: [
+  ""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: ""
+
+, "Calendar, Calendars"
+: [
+  ""
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : ""
 
@@ -175,115 +257,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : ""
 
-, "Attachments"
-: ""
-
-, "Private"
-: ""
-
-, "Tags"
-: ""
-
-, "whole day"
-: ""
-
-, "Description"
-: ""
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: ""
-
-, "This event is originally stored in {0}"
-: ""
-
-, "This event is additionally displayed in your personal calendar {0}"
-: ""
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: ""
-
-, "Role"
-: ""
-
-, "Select Role"
-: ""
-
-, "Select Status"
-: ""
-
-, "Adding {0} Attendee to event"
-: ""
-
-, "Checking Calendar Data..."
-: ""
-
-, "Reply to Recurring Event"
-: ""
-
-, "You are responding to an recurring event. What would you like to do?"
-: ""
-
-, "Respond to whole series"
-: ""
-
-, "Do not respond"
-: ""
-
-, "The event of this message does not exist"
-: ""
-
-, "The sender is not authorised to update the event"
-: ""
-
-, "This message is already processed"
-: ""
-
-, "You are not an attendee of this event"
-: ""
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: ""
-
-, "This is an event invitation for someone else."
-: ""
-
-, "You have already replied to this event invitation."
-: ""
-
-, "You received an event invitation. Set your response to:"
-: ""
-
-, "An invited attendee responded to the invitation."
-: ""
-
-, "Unsupported method"
+, "Unavailable"
 : ""
 
 , "Loading events, please wait..."
@@ -325,6 +299,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +314,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : ""
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : ""
 
@@ -417,9 +397,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : ""
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : ""
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: ""
+
+, "Attachments"
+: ""
+
+, "Private"
+: ""
+
+, "Tags"
+: ""
+
+, "Blocking"
+: ""
+
+, "Tentative"
+: ""
+
 , "Import Definition Success!"
 : ""
 
@@ -456,9 +463,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -510,7 +514,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -534,155 +538,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: ""
-
-, "Details"
-: ""
-
-, "Saved in"
-: ""
-
-, "non-blocking"
-: ""
-
-, "Enter description"
-: ""
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: ""
-
-, "End date must be after start date"
-: ""
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: ""
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: ""
-
-, "Originally"
-: ""
-
-, "Poll, Polls"
-: [
-  ""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: ""
-
-, "Rrule"
-: ""
-
-, "Daily"
-: ""
-
-, "Weekly"
-: ""
-
-, "Monthly"
-: ""
-
-, "Yearly"
-: ""
-
-, "Name"
-: ""
-
-, "Email"
-: ""
-
-, "Type"
-: ""
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: ""
-
-, "{0} more..."
-: ""
-
 , "private classification"
 : ""
 
+, "recurring event"
+: ""
+
+, "recurring event exception"
+: ""
+
 , "has alarm"
 : ""
 
@@ -692,60 +556,13 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
+, "Mini Calendar"
 : ""
 
-, "Click here to invite another attender..."
+, "WK"
 : ""
 
-, "User"
-: ""
-
-, "Group"
-: ""
-
-, "Resource, Resources"
-: [
-  ""
-
-]
-, "Member of group"
-: ""
-
-, "This is the calendar where the attender has saved this event in"
-: ""
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: ""
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: ""
-
-, "External Attendee"
+, "{0} more..."
 : ""
 
 , "Resource Grant, Resource Grants"
@@ -765,6 +582,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -807,7 +627,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -837,100 +657,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: ""
+
+, "Role"
+: ""
+
+, "Select Role"
+: ""
+
+, "Status"
+: ""
+
+, "Select Status"
+: ""
+
+, "Adding {0} Attendee to event"
+: ""
+
 , "no events found"
 : ""
 
 , "Searching..."
 : ""
 
+, "Search Event"
+: ""
+
 , "Event, Events"
 : [
   ""
 
 ]
-, "Search Event"
+, "Additional Tags ..."
 : ""
 
-, "Switch to public poll"
+, "non-blocking"
 : ""
 
-, "Welcome {name}"
+, "Displayed in"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "No Information"
 : ""
 
-, "This poll is closed already"
+, "Event Location"
 : ""
 
-, "I am not {name}"
+, "From"
 : ""
 
-, "Login"
+, "until"
 : ""
 
-, "{headerDate, date, full} {headerDate, time, short}"
+, "Events"
 : ""
 
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: ""
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  ""
-
-]
 , "Calendars"
 : ""
 
@@ -964,6 +749,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -984,37 +781,237 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
   ""
 
 ]
+, "Resource, Resources"
+: [
+  ""
+
+]
+, "Resources"
+: ""
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
+, "Name"
 : ""
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: ""
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: ""
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: ""
+
+, "User"
+: ""
+
+, "Group"
+: ""
+
+, "Member of group"
+: ""
+
+, "This is the calendar where the attender has saved this event in"
+: ""
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: ""
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: ""
+
+, "External Attendee"
+: ""
+
+, "Originally"
+: ""
+
+, "Checking Calendar Data..."
+: ""
+
+, "Reply to Recurring Event"
+: ""
+
+, "You are responding to an recurring event. What would you like to do?"
+: ""
+
+, "Respond to whole series"
+: ""
+
+, "Do not respond"
+: ""
+
+, "The event of this message does not exist"
+: ""
+
+, "The sender is not authorised to update the event"
+: ""
+
+, "This message is already processed"
+: ""
+
+, "You are not an attendee of this event"
+: ""
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: ""
+
+, "This is an event invitation for someone else."
+: ""
+
+, "You have already replied to this event invitation."
+: ""
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: ""
+
+, "An invited attendee responded to the invitation."
+: ""
+
+, "Unsupported method"
+: ""
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : ""
 
 , "Grants"
 : ""
 
-, "Displayed in"
+, "This event is originally stored in a calendar you don't have access to."
 : ""
 
-, "Event not found"
+, "This event is originally stored in {0}"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "This event is additionally displayed in your personal calendar {0}"
 : ""
 
-, "GENDER_Attendee"
+, "Colors"
 : ""
 
-, "Select Attendee"
+, "Side bar color"
+: ""
+
+, "Color by Calendar"
+: ""
+
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: ""
+
+, "Saved in"
+: ""
+
+, "Enter description"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: ""
+
+, "End date must be after start date"
+: ""
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: ""
+
+, "Start date is not allowed to be before the configured time."
 : ""
 
 , "The summary must not be longer than 255 characters."
@@ -1029,126 +1026,142 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : ""
 
-, "Recurrances"
+, "Set This Date as Definite Event?"
 : ""
 
-, "No recurring rule defined"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "None"
+, "Attendee/Resources"
 : ""
 
-, "Exceptions of reccuring events can't have recurrences themselves."
+, "Additional Attendees ..."
 : ""
 
-, "at"
+, "Default Status"
 : ""
 
-, "never"
+, "No Access"
 : ""
 
-, "after {0} occurrences"
+, "All my events"
 : ""
 
-, "Except"
+, "Position on the left time axis, day and week view should start with"
 : ""
 
-, "during events in the calendars"
+, "Position on the left time axis, day and week view should end with"
 : ""
 
-, "End"
+, "Default Start Time"
 : ""
 
-, "Until has to be after event start"
+, "Scroll position on the left time axis, day and week view should start with"
 : ""
 
-, "The event is longer than the recurring interval"
+, "Visible Time"
 : ""
 
-, "Every {0}. Day"
+, "Time to be displayed at once"
 : ""
 
-, "Every {0}. Week at"
+, "Default Calendar"
 : ""
 
-, "Every {0}. Month"
+, "The default calendar for invitations and new events"
 : ""
 
-, "at the"
+, "Default Favorite"
 : ""
 
-, "first"
+, "The default favorite which is loaded on calendar startup"
 : ""
 
-, "second"
+, "Get Notification Emails"
 : ""
 
-, "third"
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
 : ""
 
-, "fourth"
+, "Send Notifications Emails of own Actions"
 : ""
 
-, "last"
+, "Get notifications emails for actions you did yourself"
 : ""
 
-, "Every {0}. Year"
+, "Send Notifications Emails of tentative events"
 : ""
 
-, "of"
+, "Get notifications emails of tentative events"
 : ""
 
-, "First name, ĺast name"
+, "Send Alarm Notifications Emails"
 : ""
 
-, "E-Mail address"
+, "Get event alarms via email"
 : ""
 
-, "Please wait..."
+, "Enable Standard Alarm"
 : ""
 
-, "General terms and conditions"
+, "New events get a standard alarm as defined below"
 : ""
 
-, "Relation, Relations"
-: [
-  ""
-
-]
-, "All events I attend"
+, "Standard Alarm Time"
 : ""
 
-, "Required"
+, "Minutes before the event starts"
 : ""
 
-, "Optional"
+, "Default Attendee Strategy"
 : ""
 
-, "No response"
+, "Default Attendee Strategy for new events"
 : ""
 
-, "Accepted"
+, "Time Increment"
 : ""
 
-, "Declined"
+, "Increment of event time steps"
 : ""
 
-, "Awaiting response"
+, "Default set Events to privat"
 : ""
 
-, "Events I have not yet responded to"
+, "If enabled every created event is always privat"
 : ""
 
-, "Declined events"
+, "First Day of Week"
 : ""
 
-, "Events I have declined"
+, "On what day the week should be starting"
 : ""
 
-, "I'm organizer"
+, "Default calendar strategy"
 : ""
 
-, "Events I'm the organizer of"
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: ""
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: ""
+
+, "On invitation and cancellation only"
+: ""
+
+, "On time changes"
+: ""
+
+, "On all updates but attendee responses"
+: ""
+
+, "On attendee responses too"
 : ""
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
@@ -1214,12 +1227,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: ""
+
+, "Accepted"
+: ""
+
+, "Declined"
+: ""
+
 , "Attendee Roles Available"
 : ""
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: ""
+
+, "Optional"
+: ""
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1229,6 +1260,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1271,6 +1332,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1322,6 +1386,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1361,94 +1428,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
+, "User Additional Filters"
 : ""
 
-, "Event invitation \"%1$s\" at %2$s"
+, "Group Additional Filters"
 : ""
 
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "Resource Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+, "%s's personal calendar"
 : ""
 
-, "Event \"%1$s\" at %2$s has been updated"
+, "Failed"
 : ""
 
-, "%1$s accepted event \"%2$s\" at %3$s"
+, "The right Resource Admin must be set once."
 : ""
 
-, "%1$s declined event \"%2$s\" at %3$s"
+, "Different Calendar"
 : ""
 
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+, "Exdate container move are not allowed"
 : ""
 
-, "No response from %1$s for event \"%2$s\" at %3$s"
+, "Invalid URL given"
 : ""
 
-, "Attendee changes for event \"%1$s\" at %2$s"
+, "The URL you used is invalid. Please use a valid one!"
 : ""
 
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Calendars to export"
 : ""
 
-, "Resource Management"
+, "Export target"
 : ""
 
-, "Polls for recurring events are not supported"
+, "VCalendar/ICS"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "Export visible events to ics file"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "Excel overview"
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Word event sheet"
 : ""
 
-, "Start"
+, "Export Events as Calendar Sheet"
 : ""
 
-, "Priority"
+, "VCalendar Report"
 : ""
 
-, "Url"
+, "Export multiple calendars to ics files"
 : ""
 
-, "Recurrance rule"
+, "OpenDocument all data"
 : ""
 
-, "Is all day event"
+, "Export event data into ods spreadsheet"
 : ""
 
-, "Organizer timezone"
+, "Word details"
 : ""
 
-, "No"
+, "Excel all data"
 : ""
 
-, "Yes"
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
 : ""
 
 , "unknown"
@@ -1508,34 +1584,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: ""
+
+, "Priority"
+: ""
+
+, "Url"
+: ""
+
+, "Recurrance rule"
+: ""
+
+, "Is all day event"
+: ""
+
+, "Organizer timezone"
+: ""
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
 : ""
 
-, "Excel overview"
+, "Event invitation \"%1$s\" at %2$s"
 : ""
 
-, "OpenDocument all data"
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Event \"%1$s\" at %2$s has been canceled"
 : ""
 
-, "Word event sheet"
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "Event \"%1$s\" at %2$s has been updated"
 : ""
 
-, "Excel all data"
+, "%1$s accepted event \"%2$s\" at %3$s"
 : ""
 
-, "Import iCal-files"
+, "%1$s declined event \"%2$s\" at %3$s"
+: ""
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+: ""
+
+, "No response from %1$s for event \"%2$s\" at %3$s"
+: ""
+
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
+: ""
+
+, "Attendee changes for event \"%1$s\" at %2$s"
+: ""
+
+, "Tentative event notification for event \"%1$s\" at %2$s"
+: ""
+
+, "Unknown action"
+: ""
+
+, "Resource Management"
+: ""
+
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+: ""
+
+, "Polls for recurring events are not supported"
+: ""
+
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1574,31 +1719,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : ""
 
-, "The poll \"%1$s\" has been closed."
+, "All events I attend"
 : ""
 
-, "The definite event is scheduled for \"%1$s\""
+, "Awaiting response"
 : ""
 
-, "You can review the poll results here:"
+, "Events I have not yet responded to"
 : ""
 
-, "Thank you for attendening the poll \"%1$s\""
+, "Declined events"
 : ""
 
-, "To review or edit your status please use your personal link:"
+, "Events I have declined"
 : ""
 
-, "Different Calendar"
+, "I'm organizer"
 : ""
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
+, "Events I'm the organizer of"
 : ""
 
 , "manage shared calendars"
@@ -1619,67 +1758,48 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : ""
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Do you really want to delete this event?"
-: ""
+, "Relation, Relations"
+: [
+  ""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
+, "Calendar"
+: ""
+
+, "Do you really want to delete this event?"
 : ""
 
 , "Resource Grant"
@@ -1688,10 +1808,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : ""
 
-, "Calendar"
+, "Attender"
 : ""
 
-, "Attender"
+, "Resource"
 : ""
 
 , "Relation"
