@@ -5,167 +5,249 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Calendar **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "%s's personal calendar"
-: "%s 的个人日历"
-
-, "Resources"
-: "资源"
-
-, "All my events"
+, "{0}, the {1}. of {2}"
 : ""
 
-, "Start Time"
-: "开始时间"
-
-, "Position on the left time axis, day and week view should start with"
+, "Recurrances"
 : ""
 
-, "End Time"
-: "结束时间"
-
-, "Position on the left time axis, day and week view should end with"
+, "No recurring rule defined"
 : ""
 
-, "Default Start Time"
+, "Details"
 : ""
 
-, "Scroll position on the left time axis, day and week view should start with"
+, "None"
 : ""
 
-, "Visible Time"
+, "Daily"
+: "每日"
+
+, "Weekly"
+: "每周"
+
+, "Monthly"
+: "每月"
+
+, "Yearly"
+: "每年"
+
+, "Exceptions of reccuring events can't have recurrences themselves."
 : ""
 
-, "Time to be displayed at once"
+, "at"
+: "在"
+
+, "never"
+: "从不"
+
+, "after {0} occurrences"
 : ""
 
-, "Default Calendar"
-: "缺省日历"
-
-, "The default calendar for invitations and new events"
-: "用于邀请和新事件的缺省日历"
-
-, "Default Favorite"
+, "Except"
 : ""
 
-, "The default favorite which is loaded on calendar startup"
+, "during events in the calendars"
 : ""
 
-, "Get Notification Emails"
-: "获得通知电子邮件"
+, "End"
+: "结束"
 
-, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
-: "你想要的通知动作级别。请注意组织者将获得所有更新包括参加者的答复，除非这个参数设置为 \"永不\""
-
-, "Send Notifications Emails of own Actions"
+, "Until has to be after event start"
 : ""
 
-, "Get notifications emails for actions you did yourself"
+, "The event is longer than the recurring interval"
 : ""
 
-, "Send Alarm Notifications Emails"
+, "Every {0}. Day"
 : ""
 
-, "Get event alarms via email"
+, "Every {0}. Week at"
 : ""
 
-, "Enable Standard Alarm"
+, "Every {0}. Month"
 : ""
 
-, "New events get a standard alarm as defined below"
+, "at the"
 : ""
 
-, "Standard Alarm Time"
+, "first"
+: "第一"
+
+, "second"
+: "第二"
+
+, "third"
+: "第三"
+
+, "fourth"
+: "第四"
+
+, "last"
+: "最后"
+
+, "Every {0}. Year"
 : ""
 
-, "Minutes before the event starts"
-: ""
-
-, "Default Attendee Strategy"
-: ""
-
-, "Default Attendee Strategy for new events"
-: ""
-
-, "Time Increment"
-: ""
-
-, "Increment of event time steps"
-: ""
-
-, "Default set Events to privat"
-: ""
-
-, "If enabled every created event is always privat"
-: ""
-
-, "First Day of Week"
-: ""
-
-, "On what day the week should be starting"
-: ""
-
-, "Default calendar strategy"
-: ""
-
-, "The calendar for new events if no container is selected"
-: ""
-
-, "Fixed Calendars"
-: "固定日历"
-
-, "Calendars always selected regardless of all filter parameters."
-: ""
-
-, "Never"
-: ""
-
-, "On invitation and cancellation only"
-: ""
-
-, "On time changes"
-: ""
-
-, "On all updates but attendee responses"
-: ""
-
-, "On attendee responses too"
-: ""
-
-, "Events"
-: "事件"
+, "of"
+: "的"
 
 , "Summary"
 : "摘要"
 
-, "Status"
-: "状态"
+, "Organizer"
+: "组织者"
 
-, "No Information"
-: "没有信息"
-
-, "recurring event"
-: ""
-
-, "recurring event exception"
-: ""
-
-, "Blocking"
-: ""
-
-, "Tentative"
-: "临时的"
+, "Description"
+: "描述"
 
 , "Location"
 : "位置"
 
-, "Organizer"
-: "组织者"
+, "Start Time"
+: "开始时间"
+
+, "End Time"
+: "结束时间"
 
 , "Attendee"
 : "参加者"
 
+, "whole day"
+: "整天"
+
+, "Week {0} :"
+: ""
+
+, "Poll, Polls"
+: [
+  ""
+
+]
+, "Options"
+: ""
+
+, "Alternative Dates"
+: ""
+
+, "Set as definite event"
+: ""
+
+, "Create Poll for this Event"
+: ""
+
+, "Name for poll"
+: ""
+
+, "Create scheduling suggestions and pick the best alternative based on user feedback."
+: ""
+
+, "Share the link below to poll for attendee status feedback."
+: ""
+
+, "Public URL"
+: ""
+
+, "Protect poll with a password"
+: ""
+
+, "Only invited attendee can reply"
+: ""
+
+, "Start Date"
+: ""
+
+, "Info"
+: ""
+
+, "loading alternative dates"
+: ""
+
+, "Select one Event Only"
+: ""
+
+, "You need to select exactly one event as the definite event."
+: ""
+
+, "Setting definite event"
+: ""
+
+, "New Event"
+: "新事件"
+
+, "Calendar, Calendars"
+: [
+  "日历"
+
+]
+, "Event not found"
+: ""
+
+, "The Event was deleted in the meantime or you don't have access rights to it."
+: ""
+
+, "Switch to public poll"
+: ""
+
+, "Welcome {name}"
+: ""
+
+, "This is a closed poll. No Attendee can be added."
+: ""
+
+, "This poll is closed already"
+: ""
+
+, "I am not {name}"
+: ""
+
+, "Login"
+: ""
+
+, "{headerDate, date, full} {headerDate, time, short}"
+: ""
+
+, "Cancel"
+: ""
+
+, "Save"
+: ""
+
+, "By using this service you agree to our terms and conditions"
+: ""
+
+, "Use your personal link please."
+: ""
+
+, "We have sent it to your E-Mail account again."
+: ""
+
+, "If you did not receive the link, please contact the organiser."
+: ""
+
+, "Password"
+: ""
+
+, "Submit"
+: ""
+
+, "Wrong password!"
+: ""
+
+, "Please log in"
+: ""
+
+, "User name"
+: ""
+
+, "Calendar of {name}"
+: ""
+
+, "An unexpected error occurred."
+: ""
+
 , "Add attendee"
 : ""
 
@@ -175,115 +257,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Check to filter for this attendee"
 : ""
 
-, "Attachments"
-: ""
-
-, "Private"
-: "私人"
-
-, "Tags"
-: "标签"
-
-, "whole day"
-: "整天"
-
-, "Description"
-: "描述"
-
-, "Attendee/Resources"
-: ""
-
-, "Additional Attendees ..."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "This event is originally stored in a calendar you don't have access to."
-: ""
-
-, "This event is originally stored in {0}"
-: ""
-
-, "This event is additionally displayed in your personal calendar {0}"
-: ""
-
-, "Set as definite event"
-: ""
-
-, "Set This Date as Definite Event?"
-: ""
-
-, "Do you want to close the poll and remove all other alternatives?"
-: ""
-
-, "Please choose the Event to add the contacts to"
-: ""
-
-, "Role"
-: "角色"
-
-, "Select Role"
-: "选择角色"
-
-, "Select Status"
-: "选择状态"
-
-, "Adding {0} Attendee to event"
-: ""
-
-, "Checking Calendar Data..."
-: "检验日历数据中…"
-
-, "Reply to Recurring Event"
-: ""
-
-, "You are responding to an recurring event. What would you like to do?"
-: ""
-
-, "Respond to whole series"
-: ""
-
-, "Do not respond"
-: ""
-
-, "The event of this message does not exist"
-: ""
-
-, "The sender is not authorised to update the event"
-: ""
-
-, "This message is already processed"
-: ""
-
-, "You are not an attendee of this event"
-: ""
-
-, "This event has been deleted by the organizer"
-: ""
-
-, "This event has been canceled."
-: ""
-
-, "Unsupported message"
-: ""
-
-, "This is an event invitation for someone else."
-: ""
-
-, "You have already replied to this event invitation."
-: ""
-
-, "You received an event invitation. Set your response to:"
-: ""
-
-, "An invited attendee responded to the invitation."
-: ""
-
-, "Unsupported method"
+, "Unavailable"
 : ""
 
 , "Loading events, please wait..."
@@ -325,6 +299,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Year"
 : ""
 
+, "Custom Selection"
+: ""
+
 , "Import Events"
 : ""
 
@@ -337,6 +314,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Copy {0}"
 : ""
 
+, "Set event status"
+: ""
+
 , "Updating event in the past"
 : ""
 
@@ -417,9 +397,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Cancel this action"
 : ""
 
+, "Update Status for all Attendee?"
+: ""
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: ""
+
 , "Manage Resources"
 : "管理资源"
 
+, "GENDER_Attendee"
+: ""
+
+, "Select Attendee"
+: "选择参加者"
+
+, "Attachments"
+: ""
+
+, "Private"
+: "私人"
+
+, "Tags"
+: "标签"
+
+, "Blocking"
+: ""
+
+, "Tentative"
+: "临时的"
+
 , "Import Definition Success!"
 : ""
 
@@ -456,9 +463,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Username"
 : ""
 
-, "Password"
-: ""
-
 , "Refresh time"
 : ""
 
@@ -510,7 +514,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Next"
 : ""
 
-, "Options"
+, "Ok"
 : ""
 
 , "Free Time Search"
@@ -534,155 +538,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Free Time Search Options"
 : ""
 
-, "View"
-: ""
-
-, "Details"
-: ""
-
-, "Saved in"
-: ""
-
-, "non-blocking"
-: ""
-
-, "Enter description"
-: "输入描述"
-
-, "Mute Notification"
-: ""
-
-, "Print Event"
-: ""
-
-, "End date is not valid"
-: "结束日期无效"
-
-, "End date must be after start date"
-: "结束日期必须在开始日期之后"
-
-, "End time is not allowed to be after the configured time."
-: ""
-
-, "Start date is not valid"
-: "开始日期无效"
-
-, "Start date is not allowed to be before the configured time."
-: ""
-
-, "Week {0} :"
-: ""
-
-, "Originally"
-: "原始的"
-
-, "Poll, Polls"
-: [
-  ""
-
-]
-, "Alternative Dates"
-: ""
-
-, "Create Poll for this Event"
-: ""
-
-, "Name for poll"
-: ""
-
-, "Create scheduling suggestions and pick the best alternative based on user feedback."
-: ""
-
-, "Share the link below to poll for attendee status feedback."
-: ""
-
-, "Public URL"
-: ""
-
-, "Protect poll with a password"
-: ""
-
-, "Only invited attendee can reply"
-: ""
-
-, "Start Date"
-: ""
-
-, "Info"
-: ""
-
-, "loading alternative dates"
-: ""
-
-, "Select one Event Only"
-: ""
-
-, "You need to select exactly one event as the definite event."
-: ""
-
-, "Setting definite event"
-: ""
-
-, "Event finder options"
-: ""
-
-, "Unavailable"
-: ""
-
-, "Edit Resource"
-: ""
-
-, "View Resource"
-: ""
-
-, "WK"
-: ""
-
-, "Rrule"
-: ""
-
-, "Daily"
-: "每日"
-
-, "Weekly"
-: "每周"
-
-, "Monthly"
-: "每月"
-
-, "Yearly"
-: "每年"
-
-, "Name"
-: "名字"
-
-, "Email"
-: "电子邮件"
-
-, "Type"
-: "类型"
-
-, "Maximum number of attendee"
-: ""
-
-, "Default Status"
-: ""
-
-, "Busy Type"
-: ""
-
-, "Additional Tags ..."
-: ""
-
-, "New Event"
-: "新事件"
-
-, "{0} more..."
-: ""
-
 , "private classification"
 : ""
 
+, "recurring event"
+: ""
+
+, "recurring event exception"
+: ""
+
 , "has alarm"
 : ""
 
@@ -692,60 +556,13 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "is part of an open poll"
 : ""
 
-, "{0}, the {1}. of {2}"
+, "Mini Calendar"
 : ""
 
-, "Click here to invite another attender..."
+, "WK"
 : ""
 
-, "User"
-: "用户"
-
-, "Group"
-: "组"
-
-, "Resource, Resources"
-: [
-  "资源"
-
-]
-, "Member of group"
-: ""
-
-, "This is the calendar where the attender has saved this event in"
-: ""
-
-, "Click icon to change"
-: ""
-
-, "Availability of Attendee"
-: ""
-
-, "Whole Group or each Member of Group"
-: ""
-
-, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
-: ""
-
-, "Member of Group"
-: ""
-
-, "Loading Groupmembers..."
-: ""
-
-, "Remove Attender"
-: "移除参加者"
-
-, "Compose email"
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "(as a group member)"
-: ""
-
-, "External Attendee"
+, "{0} more..."
 : ""
 
 , "Resource Grant, Resource Grants"
@@ -765,6 +582,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to read the resource itself"
 : ""
 
+, "Edit Resource"
+: ""
+
 , "The grant to edit the resource itself"
 : ""
 
@@ -807,7 +627,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Sync Events"
 : ""
 
-, "The grant to synchronise events from this resource calendar"
+, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
 : ""
 
 , "Events Free Busy"
@@ -837,100 +657,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "The grant to access events marked as private in this calendar"
 : ""
 
+, "Rrule"
+: ""
+
+, "Please choose the Event to add the contacts to"
+: ""
+
+, "Role"
+: "角色"
+
+, "Select Role"
+: "选择角色"
+
+, "Status"
+: "状态"
+
+, "Select Status"
+: "选择状态"
+
+, "Adding {0} Attendee to event"
+: ""
+
 , "no events found"
 : ""
 
 , "Searching..."
 : ""
 
+, "Search Event"
+: ""
+
 , "Event, Events"
 : [
   "事件"
 
 ]
-, "Search Event"
+, "Additional Tags ..."
 : ""
 
-, "Switch to public poll"
+, "non-blocking"
 : ""
 
-, "Welcome {name}"
+, "Displayed in"
 : ""
 
-, "This is a closed poll. No Attendee can be added."
+, "No Information"
+: "没有信息"
+
+, "Event Location"
 : ""
 
-, "This poll is closed already"
+, "From"
 : ""
 
-, "I am not {name}"
+, "until"
 : ""
 
-, "Login"
-: ""
+, "Events"
+: "事件"
 
-, "{headerDate, date, full} {headerDate, time, short}"
-: ""
-
-, "Cancle"
-: ""
-
-, "Save"
-: ""
-
-, "By using this service you agree to our terms and conditions"
-: ""
-
-, "Use your personal link please."
-: ""
-
-, "We have send it to your E-Mail account again."
-: ""
-
-, "If you did not receive the link, please contact the organiser."
-: ""
-
-, "Submit"
-: ""
-
-, "Wrong password!"
-: ""
-
-, "Plase log in"
-: ""
-
-, "User name"
-: ""
-
-, "Calendar of {name}"
-: ""
-
-, "An unexpected error occurred."
-: ""
-
-, "Mini Calendar"
-: ""
-
-, "Colors"
-: ""
-
-, "Color by Organizer Calendar"
-: ""
-
-, "Color by Attendee Calendar"
-: ""
-
-, "Color by Tags"
-: ""
-
-, "Color by Attendee Role"
-: ""
-
-, "Calendar, Calendars"
-: [
-  "日历"
-
-]
 , "Calendars"
 : "日历"
 
@@ -964,6 +749,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "GENDER_Classification"
 : ""
 
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Created By"
+: ""
+
 , "Unknown date"
 : ""
 
@@ -984,38 +781,238 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
   "参加者"
 
 ]
+, "Resource, Resources"
+: [
+  "资源"
+
+]
+, "Resources"
+: "资源"
+
 , "Anyone"
 : ""
 
-, "Default attendee status"
-: ""
+, "Name"
+: "名字"
 
 , "Calendar Hierarchy/Name"
 : ""
 
+, "Email"
+: "电子邮件"
+
+, "Maximum number of attendee"
+: ""
+
+, "Type"
+: "类型"
+
+, "Default attendee status"
+: ""
+
+, "Busy Type"
+: ""
+
+, "Event finder options"
+: ""
+
+, "Click here to invite another attender..."
+: ""
+
+, "User"
+: "用户"
+
+, "Group"
+: "组"
+
+, "Member of group"
+: ""
+
+, "This is the calendar where the attender has saved this event in"
+: ""
+
+, "Click icon to change"
+: ""
+
+, "Availability of Attendee"
+: ""
+
+, "Whole Group or each Member of Group"
+: ""
+
+, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
+: ""
+
+, "Member of Group"
+: ""
+
+, "Loading Groupmembers..."
+: ""
+
+, "Remove Attender"
+: "移除参加者"
+
+, "Compose email"
+: ""
+
+, "Poll URL: {0}"
+: ""
+
+, "View Resource"
+: ""
+
+, "(as a group member)"
+: ""
+
+, "External Attendee"
+: ""
+
+, "Originally"
+: "原始的"
+
+, "Checking Calendar Data..."
+: "检验日历数据中…"
+
+, "Reply to Recurring Event"
+: ""
+
+, "You are responding to an recurring event. What would you like to do?"
+: ""
+
+, "Respond to whole series"
+: ""
+
+, "Do not respond"
+: ""
+
+, "The event of this message does not exist"
+: ""
+
+, "The sender is not authorised to update the event"
+: ""
+
+, "This message is already processed"
+: ""
+
+, "You are not an attendee of this event"
+: ""
+
+, "This event has been deleted by the organizer"
+: ""
+
+, "This event has been canceled."
+: ""
+
+, "Unsupported message"
+: ""
+
+, "This is an event invitation for someone else."
+: ""
+
+, "You have already replied to this event invitation."
+: ""
+
+, "The event got rescheduled. Set your response to:"
+: ""
+
+, "You received an event invitation. Set your response to:"
+: ""
+
+, "An invited attendee responded to the invitation."
+: ""
+
+, "Unsupported method"
+: ""
+
 , "Suppress notification"
 : ""
 
+, "Color"
+: ""
+
 , "Enter description..."
 : "输入描述 ..."
 
 , "Grants"
 : ""
 
-, "Displayed in"
+, "This event is originally stored in a calendar you don't have access to."
 : ""
 
-, "Event not found"
+, "This event is originally stored in {0}"
 : ""
 
-, "The Event was deleted in the meantime or you don't have access rights to it."
+, "This event is additionally displayed in your personal calendar {0}"
 : ""
 
-, "GENDER_Attendee"
+, "Colors"
 : ""
 
-, "Select Attendee"
-: "选择参加者"
+, "Side bar color"
+: ""
+
+, "Color by Calendar"
+: ""
+
+, "Color by Attendee Calendar"
+: ""
+
+, "Color by Tags"
+: ""
+
+, "Color by Attendee Role"
+: ""
+
+, "Colors by response"
+: ""
+
+, "Colors by tags"
+: ""
+
+, "Colors by attendee"
+: ""
+
+, "Colors by resource"
+: ""
+
+, "View"
+: ""
+
+, "Saved in"
+: ""
+
+, "Enter description"
+: "输入描述"
+
+, "Notifications are disabled"
+: ""
+
+, "Notifications are enabled"
+: ""
+
+, "Print Event"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "End date is not valid"
+: "结束日期无效"
+
+, "End date must be after start date"
+: "结束日期必须在开始日期之后"
+
+, "End time is not allowed to be after the configured time."
+: ""
+
+, "Start date is not valid"
+: "开始日期无效"
+
+, "Start date is not allowed to be before the configured time."
+: ""
 
 , "The summary must not be longer than 255 characters."
 : ""
@@ -1029,126 +1026,142 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Summary too Short"
 : ""
 
-, "Recurrances"
+, "Set This Date as Definite Event?"
 : ""
 
-, "No recurring rule defined"
+, "Do you want to close the poll and remove all other alternatives?"
 : ""
 
-, "None"
+, "Attendee/Resources"
 : ""
 
-, "Exceptions of reccuring events can't have recurrences themselves."
+, "Additional Attendees ..."
 : ""
 
-, "at"
-: "在"
-
-, "never"
-: "从不"
-
-, "after {0} occurrences"
+, "Default Status"
 : ""
 
-, "Except"
+, "No Access"
 : ""
 
-, "during events in the calendars"
+, "All my events"
 : ""
 
-, "End"
-: "结束"
-
-, "Until has to be after event start"
+, "Position on the left time axis, day and week view should start with"
 : ""
 
-, "The event is longer than the recurring interval"
+, "Position on the left time axis, day and week view should end with"
 : ""
 
-, "Every {0}. Day"
+, "Default Start Time"
 : ""
 
-, "Every {0}. Week at"
+, "Scroll position on the left time axis, day and week view should start with"
 : ""
 
-, "Every {0}. Month"
+, "Visible Time"
 : ""
 
-, "at the"
+, "Time to be displayed at once"
 : ""
 
-, "first"
-: "第一"
+, "Default Calendar"
+: "缺省日历"
 
-, "second"
-: "第二"
+, "The default calendar for invitations and new events"
+: "用于邀请和新事件的缺省日历"
 
-, "third"
-: "第三"
-
-, "fourth"
-: "第四"
-
-, "last"
-: "最后"
-
-, "Every {0}. Year"
+, "Default Favorite"
 : ""
 
-, "of"
-: "的"
-
-, "First name, ĺast name"
+, "The default favorite which is loaded on calendar startup"
 : ""
 
-, "E-Mail address"
+, "Get Notification Emails"
+: "获得通知电子邮件"
+
+, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
+: "你想要的通知动作级别。请注意组织者将获得所有更新包括参加者的答复，除非这个参数设置为 \"永不\""
+
+, "Send Notifications Emails of own Actions"
 : ""
 
-, "Please wait..."
+, "Get notifications emails for actions you did yourself"
 : ""
 
-, "General terms and conditions"
+, "Send Notifications Emails of tentative events"
 : ""
 
-, "Relation, Relations"
-: [
-  ""
-
-]
-, "All events I attend"
+, "Get notifications emails of tentative events"
 : ""
 
-, "Required"
-: "要求的"
-
-, "Optional"
-: "可选的"
-
-, "No response"
-: "没有响应"
-
-, "Accepted"
-: "被接受"
-
-, "Declined"
-: "被拒绝"
-
-, "Awaiting response"
+, "Send Alarm Notifications Emails"
 : ""
 
-, "Events I have not yet responded to"
+, "Get event alarms via email"
 : ""
 
-, "Declined events"
+, "Enable Standard Alarm"
 : ""
 
-, "Events I have declined"
+, "New events get a standard alarm as defined below"
 : ""
 
-, "I'm organizer"
+, "Standard Alarm Time"
 : ""
 
-, "Events I'm the organizer of"
+, "Minutes before the event starts"
+: ""
+
+, "Default Attendee Strategy"
+: ""
+
+, "Default Attendee Strategy for new events"
+: ""
+
+, "Time Increment"
+: ""
+
+, "Increment of event time steps"
+: ""
+
+, "Default set Events to privat"
+: ""
+
+, "If enabled every created event is always privat"
+: ""
+
+, "First Day of Week"
+: ""
+
+, "On what day the week should be starting"
+: ""
+
+, "Default calendar strategy"
+: ""
+
+, "The calendar for new events if no container is selected"
+: ""
+
+, "Fixed Calendars"
+: "固定日历"
+
+, "Calendars always selected regardless of all filter parameters."
+: ""
+
+, "Never"
+: ""
+
+, "On invitation and cancellation only"
+: ""
+
+, "On time changes"
+: ""
+
+, "On all updates but attendee responses"
+: ""
+
+, "On attendee responses too"
 : ""
 
 , "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
@@ -1214,12 +1227,30 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
 : ""
 
+, "No response"
+: "没有响应"
+
+, "Accepted"
+: "被接受"
+
+, "Declined"
+: "被拒绝"
+
 , "Attendee Roles Available"
 : ""
 
 , "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
 : ""
 
+, "Required"
+: "要求的"
+
+, "Optional"
+: "可选的"
+
+, "Organizer has implicit edit grant"
+: ""
+
 , "Resource Types Available"
 : ""
 
@@ -1229,6 +1260,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Room"
 : ""
 
+, "Board"
+: ""
+
+, "Cable"
+: ""
+
+, "Car"
+: ""
+
+, "Coffee"
+: ""
+
+, "Homeoffice"
+: ""
+
+, "Lamp"
+: ""
+
+, "Laptop"
+: ""
+
+, "Material"
+: ""
+
+, "Projector"
+: ""
+
+, "Travel"
+: ""
+
 , "Free/Busy Types Available"
 : ""
 
@@ -1271,6 +1332,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Disable iMIP for external organizers"
 : ""
 
+, "Disable notification for external organizers"
+: ""
+
 , "(CalDAV) Skip double events from personal or shared calendar"
 : ""
 
@@ -1322,6 +1386,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Create alternative Events and let users as well as externals vote for the best option."
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Send Tentative Notifications"
 : ""
 
@@ -1361,95 +1428,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "only date & time"
 : ""
 
-, "and calendar"
-: ""
-
 , "and organizer"
 : ""
 
 , "and resources"
 : ""
 
+, "and calendar"
+: ""
+
 , "and other attendees"
 : ""
 
-, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+, "Search Attenders Additional Filters"
 : ""
 
-, "Alarm for event \"%1$s\" at %2$s"
+, "User Additional Filters"
 : ""
 
-, "Event invitation \"%1$s\" at %2$s"
-: "事件邀请 \"%1$s\" at %2$s"
-
-, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
+, "Group Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been canceled"
-: "事件 \"%1$s\" at %2$s 被取消"
-
-, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
+, "Resource Additional Filters"
 : ""
 
-, "Event \"%1$s\" at %2$s has been updated"
-: "事件 \"%1$s\" at %2$s 被更新"
-
-, "%1$s accepted event \"%2$s\" at %3$s"
-: "%1$s 接受了事件 \"%2$s\" at %3$s"
-
-, "%1$s declined event \"%2$s\" at %3$s"
-: "%1$s 拒绝了事件 \"%2$s\" at %3$s"
-
-, "Tentative response from %1$s for event \"%2$s\" at %3$s"
+, "Assign organizer meeting status on editGrant"
 : ""
 
-, "No response from %1$s for event \"%2$s\" at %3$s"
+, "%s's personal calendar"
+: "%s 的个人日历"
+
+, "Failed"
 : ""
 
-, "Attendee changes for event \"%1$s\" at %2$s"
+, "The right Resource Admin must be set once."
 : ""
 
-, "Tentative event notification for event \"%1$s\" at %2$s"
+, "Different Calendar"
 : ""
 
-, "Resource Management"
+, "Exdate container move are not allowed"
 : ""
 
-, "Polls for recurring events are not supported"
+, "Invalid URL given"
 : ""
 
-, "This contact has been automatically added by the system as a poll attendee"
+, "The URL you used is invalid. Please use a valid one!"
 : ""
 
-, "Attendance Confirmation for Poll \"%1$s\""
+, "Calendars to export"
 : ""
 
-, "%1$s is scheduled for %2$s"
+, "Export target"
 : ""
 
-, "Start"
-: "开始"
-
-, "Priority"
+, "VCalendar/ICS"
 : ""
 
-, "Url"
+, "Export visible events to ics file"
 : ""
 
-, "Recurrance rule"
+, "Excel overview"
 : ""
 
-, "Is all day event"
-: "是整日事件"
+, "Word event sheet"
+: ""
 
-, "Organizer timezone"
-: "组织者时区"
+, "Export Events as Calendar Sheet"
+: ""
 
-, "No"
-: "不"
+, "VCalendar Report"
+: ""
 
-, "Yes"
-: "是"
+, "Export multiple calendars to ics files"
+: ""
+
+, "OpenDocument all data"
+: ""
+
+, "Export event data into ods spreadsheet"
+: ""
+
+, "Word details"
+: ""
+
+, "Excel all data"
+: ""
+
+, "Shared Calendar CSV"
+: ""
+
+, "Resource CSV"
+: ""
+
+, "You can not have more than one grants filter"
+: ""
+
+, "Import iCal-files"
+: ""
 
 , "unknown"
 : "不知道"
@@ -1508,34 +1584,103 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "th"
 : ""
 
+, "Start"
+: "开始"
+
+, "Priority"
+: ""
+
+, "Url"
+: ""
+
+, "Recurrance rule"
+: ""
+
+, "Is all day event"
+: "是整日事件"
+
+, "Organizer timezone"
+: "组织者时区"
+
 , "Locked"
 : ""
 
 , "Closed"
 : ""
 
-, "Word details"
+, "Alarm for event \"%1$s\" at %2$s"
 : ""
 
-, "Excel overview"
+, "Event invitation \"%1$s\" at %2$s"
+: "事件邀请 \"%1$s\" at %2$s"
+
+, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
 : ""
 
-, "OpenDocument all data"
+, "Event \"%1$s\" at %2$s has been canceled"
+: "事件 \"%1$s\" at %2$s 被取消"
+
+, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
 : ""
 
-, "Export event data into ods spreadsheet"
+, "Event \"%1$s\" at %2$s has been updated"
+: "事件 \"%1$s\" at %2$s 被更新"
+
+, "%1$s accepted event \"%2$s\" at %3$s"
+: "%1$s 接受了事件 \"%2$s\" at %3$s"
+
+, "%1$s declined event \"%2$s\" at %3$s"
+: "%1$s 拒绝了事件 \"%2$s\" at %3$s"
+
+, "Tentative response from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "Word event sheet"
+, "No response from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "Export Events as Calendar Sheet"
+, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
 : ""
 
-, "Excel all data"
+, "Attendee changes for event \"%1$s\" at %2$s"
 : ""
 
-, "Import iCal-files"
+, "Tentative event notification for event \"%1$s\" at %2$s"
+: ""
+
+, "Unknown action"
+: ""
+
+, "Resource Management"
+: ""
+
+, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
+: ""
+
+, "Polls for recurring events are not supported"
+: ""
+
+, "This contact has been automatically added by the system as a poll attendee"
+: ""
+
+, "Attendance Confirmation for Poll \"%1$s\""
+: ""
+
+, "%1$s is scheduled for %2$s"
+: ""
+
+, "The poll \"%1$s\" has been closed."
+: ""
+
+, "The definite event is scheduled for \"%1$s\""
+: ""
+
+, "You can review the poll results here:"
+: ""
+
+, "Thank you for attendening the poll \"%1$s\""
+: ""
+
+, "To review or edit your status please use your personal link:"
 : ""
 
 , "Updates"
@@ -1574,31 +1719,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event details"
 : "事件细节"
 
-, "The poll \"%1$s\" has been closed."
+, "All events I attend"
 : ""
 
-, "The definite event is scheduled for \"%1$s\""
+, "Awaiting response"
 : ""
 
-, "You can review the poll results here:"
+, "Events I have not yet responded to"
 : ""
 
-, "Thank you for attendening the poll \"%1$s\""
+, "Declined events"
 : ""
 
-, "To review or edit your status please use your personal link:"
+, "Events I have declined"
 : ""
 
-, "Different Calendar"
+, "I'm organizer"
 : ""
 
-, "Exdate container move are not allowed"
-: ""
-
-, "Invalid URL given"
-: ""
-
-, "The URL you used is invalid. Please use a valid one!"
+, "Events I'm the organizer of"
 : ""
 
 , "manage shared calendars"
@@ -1619,71 +1758,49 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "All Rights to administrate resources"
 : ""
 
-, "Send Notifications Emails of tentative events"
+, "Account"
 : ""
 
-, "Get notifications emails of tentative events"
+, "Exporttime"
 : ""
 
-, "No Access"
+, "First name, ĺast name"
 : ""
 
-, "Board"
+, "E-Mail address"
 : ""
 
-, "Car"
+, "Please wait..."
 : ""
 
-, "Coffee"
+, "General terms and conditions"
 : ""
 
-, "Homeoffice"
+, "0009326B"
 : ""
 
-, "Lamp"
+, "20"
 : ""
 
-, "Laptop"
+, "00B359B9"
 : ""
 
-, "Material"
+, "00997199"
 : ""
 
-, "Projector"
-: ""
-
-, "Travel"
-: ""
-
-, "Cable)"
-: ""
-
-, "Search Attenders Additional Filters"
-: ""
-
-, "User Additional Filters"
-: ""
-
-, "Group Additional Filters"
-: ""
-
-, "Resource Additional Filters"
-: ""
-
-, "Assign organizer meeting status on editGrant"
-: ""
-
-, "Is a location"
-: "是一个位置"
-
-, "Do you really want to delete this event?"
-: ""
+, "Relation, Relations"
+: [
+  ""
 
+]
 , "Poll"
 : ""
 
-, "Resource"
-: "资源"
+, "Calendar"
+: "日历"
+
+, "Do you really want to delete this event?"
+: ""
 
 , "Resource Grant"
 : ""
@@ -1691,12 +1808,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Event"
 : "事件"
 
-, "Calendar"
-: "日历"
-
 , "Attender"
 : "参加者"
 
+, "Resource"
+: "资源"
+
 , "Relation"
 : ""
 
