@@ -5,169 +5,13 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: ""
-
-, "Default Lead List"
-: ""
-
-, "The default list for new leads"
-: ""
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: ""
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: ""
-
-, "The default favorite which is loaded on crm startup"
-: ""
-
-, "New Lead"
-: ""
-
-, "Tags"
-: ""
-
-, "Lead name"
-: "Име на предложение"
-
-, "Responsible"
-: "Отговорник"
-
-, "Partner"
-: "Партньор/Съдружник"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Bulgarian (http://www.transifex.com/tine20/tine20/language/bg/)\nLanguage: bg\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : "Клиент"
 
-, "Leadstate"
-: "Статус на предложение"
-
-, "Leadtype"
-: "Тип на предложението"
-
-, "Leadsource"
-: "Източник на предложението"
-
-, "Probability"
-: "Вероятност"
-
-, "Turnover"
-: "Оборот"
-
-, "Estimated end"
-: "Пресметната продължителност"
-
-, "Probable Turnover"
-: ""
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: ""
-
-, "CRM Role"
-: ""
-
-, "Tasks"
-: "Задачи"
-
-, "No Tasks to display"
-: "Няма намерени задачи"
-
-, "Summary"
-: "Заключение"
-
-, "Add a task..."
-: "Добави задача"
-
-, "Due Date"
-: "Краен срок"
-
-, "Priority"
-: "Приоритет"
-
-, "Percent"
-: "Процент"
-
-, "Status"
-: "Статус"
-
-, "Organizer"
-: ""
-
-, "Add new {0}"
-: ""
-
-, "Unlink {0}"
-: ""
-
-, "Unlink selected {0}"
-: ""
-
-, "Edit {0}"
-: ""
-
-, "Edit selected {0}"
-: ""
-
-, "Please choose the Lead to add the contacts to"
-: ""
-
-, "Please select the attenders' role"
-: ""
-
-, "Lead, Leads"
-: [
-  ""
- ,""
-
-]
-, "Select Lead"
-: ""
-
-, "Role"
-: ""
-
-, "Select Role"
-: ""
-
-, "Adding {0} contacts to lead"
-: ""
+, "Partner"
+: "Партньор/Съдружник"
 
 , "Phone"
 : "Телефон"
@@ -193,57 +37,120 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: "Статус"
+
 , "Start"
 : "Старт"
 
-, "Change type to Customer"
-: "Сменя типа контакт с Клиент"
+, "Estimated end"
+: "Пресметната продължителност"
 
-, "Change type to Responsible"
-: "Сменя типа контакт с Отговорник"
+, "Leadtype"
+: "Тип на предложението"
 
-, "Change type to Partner"
-: "Сменя типа контакт с Партньор"
+, "Leadsource"
+: "Източник на предложението"
 
-, "Change contact type"
-: "Сменя контакт-тип"
-
-, "Search for Contacts to add ..."
-: "Търси да прибави контакти"
-
-, "Name"
-: "Име"
-
-, "Address"
-: "Адрес"
-
-, "Data"
+, "Tags"
 : ""
 
-, "Cellphone"
-: "Мобилен"
+, "Lead name"
+: "Име на предложение"
+
+, "Responsible"
+: "Отговорник"
+
+, "Leadstate"
+: "Статус на предложение"
+
+, "Probability"
+: "Вероятност"
+
+, "Turnover"
+: "Оборот"
 
 , "End"
 : "Крайна дата"
 
-, "You do not have the run right for the Tasks application or it is not activated."
+, "Probable Turnover"
+: ""
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: ""
+
+, "Unlink {0}"
+: ""
+
+, "Unlink selected {0}"
+: ""
+
+, "Edit {0}"
+: ""
+
+, "Edit selected {0}"
+: ""
+
+, "New Lead"
 : ""
 
 , "Products"
 : "Продукти"
 
+, "Product"
+: "Продукт"
+
+, "Description"
+: "Описание"
+
+, "Price"
+: "Цена"
+
+, "Quantity"
+: ""
+
+, "Search for Products to add ..."
+: ""
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: "Задачи"
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: ""
+
 , "You do not have the run right for the Sales application or it is not activated."
 : ""
 
+, "Lead, Leads"
+: [
+  ""
+ ,""
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : "Очакван оборот"
 
-, "Description"
-: "Описание"
-
 , "Enter description"
 : "Напиши описание"
 
@@ -274,37 +181,130 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
-: "Продукт"
-
-, "Price"
-: "Цена"
-
-, "Quantity"
+, "Contact"
 : ""
 
-, "Search for Products to add ..."
+, "CRM Role"
 : ""
 
-, "All leads I have read grants for"
+, "Change type to Customer"
+: "Сменя типа контакт с Клиент"
+
+, "Change type to Responsible"
+: "Сменя типа контакт с Отговорник"
+
+, "Change type to Partner"
+: "Сменя типа контакт с Партньор"
+
+, "Change contact type"
+: "Сменя контакт-тип"
+
+, "Search for Contacts to add ..."
+: "Търси да прибави контакти"
+
+, "Name"
+: "Име"
+
+, "Address"
+: "Адрес"
+
+, "Data"
 : ""
 
-, "Last modified by me"
+, "Cellphone"
+: "Мобилен"
+
+, "Role"
 : ""
 
-, "All leads that I have last modified"
+, "Please choose the Lead to add the contacts to"
 : ""
 
-, "My leads"
+, "Please select the attenders' role"
 : ""
 
-, "All leads that I am responsible for"
+, "Select Lead"
 : ""
 
-, "Leads with overdue tasks"
+, "Select Role"
+: ""
+
+, "Adding {0} contacts to lead"
+: ""
+
+, "No Tasks to display"
+: "Няма намерени задачи"
+
+, "Summary"
+: "Заключение"
+
+, "Add a task..."
+: "Добави задача"
+
+, "Due Date"
+: "Краен срок"
+
+, "Priority"
+: "Приоритет"
+
+, "Percent"
+: "Процент"
+
+, "Organizer"
+: ""
+
+, "All leads"
+: ""
+
+, "Default Lead List"
+: ""
+
+, "The default list for new leads"
+: ""
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: ""
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: ""
+
+, "The default favorite which is loaded on crm startup"
+: ""
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
 : ""
 
 , "Lead States Available"
@@ -355,6 +355,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -373,6 +376,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: "Данни за предложението"
+
+, "End Scheduled"
+: "Краен срок"
+
+, "Contacts"
+: "Контакти"
+
+, "Telephone"
+: "Телефон"
+
+, "Email"
+: "Имейл"
+
+, "low"
+: "ниска"
+
+, "normal"
+: "нормална"
+
+, "high"
+: "висока"
+
+, "urgent"
+: "важност"
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: ""
+
 , "State"
 : "Статус"
 
@@ -403,52 +463,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : ""
 
-, "Task"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "Lead Data"
-: "Данни за предложението"
-
-, "End Scheduled"
-: "Краен срок"
-
-, "Contacts"
-: "Контакти"
-
-, "Telephone"
-: "Телефон"
-
-, "Email"
-: "Имейл"
-
-, "low"
-: "ниска"
-
-, "normal"
-: "нормална"
-
-, "high"
-: "висока"
-
-, "urgent"
-: "важност"
-
-, "Lead CSV import"
+, "All leads I have read grants for"
 : ""
 
-, "Import list (###CURRENTDATE###)"
+, "Last modified by me"
 : ""
 
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+, "All leads that I have last modified"
 : ""
 
-, "Edit new lead"
+, "My leads"
 : ""
 
-, "The following leads have just been imported into lead list %s"
+, "All leads that I am responsible for"
 : ""
 
-, "%s new leads have been imported"
+, "Leads with overdue tasks"
 : ""
 
 , "manage shared lead folders"
