@@ -5,171 +5,13 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: "Všechny leady"
-
-, "Default Lead List"
-: ""
-
-, "The default list for new leads"
-: ""
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: "Úroveň činností o kterých chcete být informováni."
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: "Výchozí oblíbené položky CRM"
-
-, "The default favorite which is loaded on crm startup"
-: "Výchozí oblíbené položky, které jsou načteny při spuštění CRM."
-
-, "New Lead"
-: ""
-
-, "Tags"
-: "Štítky"
-
-, "Lead name"
-: "Jméno leadu"
-
-, "Responsible"
-: "Odpovědná osoba"
-
-, "Partner"
-: "Partner"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : "Zákazník"
 
-, "Leadstate"
-: "Stav leadu"
-
-, "Leadtype"
-: "Typ leadu"
-
-, "Leadsource"
-: "Zdroj leadu"
-
-, "Probability"
-: "Pravděpodobnost"
-
-, "Turnover"
-: "Obrat"
-
-, "Estimated end"
-: "Odhadovaný konec"
-
-, "Probable Turnover"
-: "Předpokládaný obrat"
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: "Kontakt"
-
-, "CRM Role"
-: "CRM role"
-
-, "Tasks"
-: "Úkoly"
-
-, "No Tasks to display"
-: "Žádné úkoly ke zobrazení"
-
-, "Summary"
-: "Přehled"
-
-, "Add a task..."
-: "Přidat úkol..."
-
-, "Due Date"
-: "Termín dokončení"
-
-, "Priority"
-: "Priorita"
-
-, "Percent"
-: "Procent"
-
-, "Status"
-: "Status"
-
-, "Organizer"
-: ""
-
-, "Add new {0}"
-: "Přidat nový {0}"
-
-, "Unlink {0}"
-: "Zrušit odkaz {0}"
-
-, "Unlink selected {0}"
-: "Zrušit odkaz(y) na vybraný/é {0}"
-
-, "Edit {0}"
-: "Editovat {0}"
-
-, "Edit selected {0}"
-: "Editovat vybraný/é {0}"
-
-, "Please choose the Lead to add the contacts to"
-: ""
-
-, "Please select the attenders' role"
-: ""
-
-, "Lead, Leads"
-: [
-  "Lead"
- ,"Leady"
- ,"Leadů"
- ,"Leadů"
-
-]
-, "Select Lead"
-: ""
-
-, "Role"
-: "Role"
-
-, "Select Role"
-: ""
-
-, "Adding {0} contacts to lead"
-: ""
+, "Partner"
+: "Partner"
 
 , "Phone"
 : "Telefon"
@@ -195,57 +37,122 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: "Status"
+
 , "Start"
 : "Začátek"
 
-, "Change type to Customer"
-: "Změnit typ na Zákazník"
+, "Estimated end"
+: "Odhadovaný konec"
 
-, "Change type to Responsible"
-: "Změnit typ na Odpovědná osoba"
+, "Leadtype"
+: "Typ leadu"
 
-, "Change type to Partner"
-: "Změnit typ na Partner"
+, "Leadsource"
+: "Zdroj leadu"
 
-, "Change contact type"
-: "Změnit typ kontaktu"
+, "Tags"
+: "Štítky"
 
-, "Search for Contacts to add ..."
-: "Hledat kontakty pro přidání"
+, "Lead name"
+: "Jméno leadu"
 
-, "Name"
-: "Jméno"
+, "Responsible"
+: "Odpovědná osoba"
 
-, "Address"
-: "Adresa"
+, "Leadstate"
+: "Stav leadu"
 
-, "Data"
-: "Data"
+, "Probability"
+: "Pravděpodobnost"
 
-, "Cellphone"
-: "Mobilní telefon"
+, "Turnover"
+: "Obrat"
 
 , "End"
 : "Konec"
 
-, "You do not have the run right for the Tasks application or it is not activated."
-: "Nemáte oprávnění ke spuštění aplikace Úkoly nebo aplikace není povolena."
+, "Probable Turnover"
+: "Předpokládaný obrat"
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: "Přidat nový {0}"
+
+, "Unlink {0}"
+: "Zrušit odkaz {0}"
+
+, "Unlink selected {0}"
+: "Zrušit odkaz(y) na vybraný/é {0}"
+
+, "Edit {0}"
+: "Editovat {0}"
+
+, "Edit selected {0}"
+: "Editovat vybraný/é {0}"
+
+, "New Lead"
+: ""
 
 , "Products"
 : "Produkty"
 
+, "Product"
+: "Produkt"
+
+, "Description"
+: "Popis"
+
+, "Price"
+: "Cena"
+
+, "Quantity"
+: "Množství"
+
+, "Search for Products to add ..."
+: "Hledat produkty pro přidání ..."
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: "Úkoly"
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: "Nemáte oprávnění ke spuštění aplikace Úkoly nebo aplikace není povolena."
+
 , "You do not have the run right for the Sales application or it is not activated."
 : "Nemáte oprávnění ke spuštění aplikace Prodej nebo aplikace není povolena."
 
+, "Lead, Leads"
+: [
+  "Lead"
+ ,"Leady"
+ ,"Leadů"
+ ,"Leadů"
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : "Očekávaný obrat"
 
-, "Description"
-: "Popis"
-
 , "Enter description"
 : "Zadejte popis"
 
@@ -278,37 +185,130 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
-: "Produkt"
+, "Contact"
+: "Kontakt"
 
-, "Price"
-: "Cena"
+, "CRM Role"
+: "CRM role"
 
-, "Quantity"
-: "Množství"
+, "Change type to Customer"
+: "Změnit typ na Zákazník"
 
-, "Search for Products to add ..."
-: "Hledat produkty pro přidání ..."
+, "Change type to Responsible"
+: "Změnit typ na Odpovědná osoba"
 
-, "All leads I have read grants for"
-: "Všechny leady, které jsem oprávněn číst"
+, "Change type to Partner"
+: "Změnit typ na Partner"
 
-, "Last modified by me"
+, "Change contact type"
+: "Změnit typ kontaktu"
+
+, "Search for Contacts to add ..."
+: "Hledat kontakty pro přidání"
+
+, "Name"
+: "Jméno"
+
+, "Address"
+: "Adresa"
+
+, "Data"
+: "Data"
+
+, "Cellphone"
+: "Mobilní telefon"
+
+, "Role"
+: "Role"
+
+, "Please choose the Lead to add the contacts to"
 : ""
 
-, "All leads that I have last modified"
+, "Please select the attenders' role"
 : ""
 
-, "My leads"
+, "Select Lead"
 : ""
 
-, "All leads that I am responsible for"
+, "Select Role"
 : ""
 
-, "Leads with overdue tasks"
+, "Adding {0} contacts to lead"
+: ""
+
+, "No Tasks to display"
+: "Žádné úkoly ke zobrazení"
+
+, "Summary"
+: "Přehled"
+
+, "Add a task..."
+: "Přidat úkol..."
+
+, "Due Date"
+: "Termín dokončení"
+
+, "Priority"
+: "Priorita"
+
+, "Percent"
+: "Procent"
+
+, "Organizer"
+: ""
+
+, "All leads"
+: "Všechny leady"
+
+, "Default Lead List"
+: ""
+
+, "The default list for new leads"
+: ""
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: "Úroveň činností o kterých chcete být informováni."
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: "Výchozí oblíbené položky CRM"
+
+, "The default favorite which is loaded on crm startup"
+: "Výchozí oblíbené položky, které jsou načteny při spuštění CRM."
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
 : ""
 
 , "Lead States Available"
@@ -359,6 +359,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -377,6 +380,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: "Data leadu"
+
+, "End Scheduled"
+: "Plánovaný konec"
+
+, "Contacts"
+: "Kontakty"
+
+, "Telephone"
+: "Telefon"
+
+, "Email"
+: "Email"
+
+, "low"
+: "nízká"
+
+, "normal"
+: "normální"
+
+, "high"
+: "vysoká"
+
+, "urgent"
+: "urgentní"
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: ""
+
 , "State"
 : "Status"
 
@@ -407,52 +467,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : ""
 
-, "Task"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "Lead Data"
-: "Data leadu"
+, "All leads I have read grants for"
+: "Všechny leady, které jsem oprávněn číst"
 
-, "End Scheduled"
-: "Plánovaný konec"
-
-, "Contacts"
-: "Kontakty"
-
-, "Telephone"
-: "Telefon"
-
-, "Email"
-: "Email"
-
-, "low"
-: "nízká"
-
-, "normal"
-: "normální"
-
-, "high"
-: "vysoká"
-
-, "urgent"
-: "urgentní"
-
-, "Lead CSV import"
+, "Last modified by me"
 : ""
 
-, "Import list (###CURRENTDATE###)"
+, "All leads that I have last modified"
 : ""
 
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+, "My leads"
 : ""
 
-, "Edit new lead"
+, "All leads that I am responsible for"
 : ""
 
-, "The following leads have just been imported into lead list %s"
-: ""
-
-, "%s new leads have been imported"
+, "Leads with overdue tasks"
 : ""
 
 , "manage shared lead folders"
