@@ -5,169 +5,13 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nLanguage: en_AU\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: "All leads"
-
-, "Default Lead List"
-: ""
-
-, "The default list for new leads"
-: ""
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: "The level of actions you want to be notified about."
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: "Default Favorite"
-
-, "The default favorite which is loaded on crm startup"
-: "The default favorite which is loaded on crm startup"
-
-, "New Lead"
-: "New Lead"
-
-, "Tags"
-: "Tags"
-
-, "Lead name"
-: "Lead name"
-
-, "Responsible"
-: "Responsible"
-
-, "Partner"
-: "Partner"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nLanguage: en_AU\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : "Customer"
 
-, "Leadstate"
-: "Leadstate"
-
-, "Leadtype"
-: "Leadtype"
-
-, "Leadsource"
-: "Leadsource"
-
-, "Probability"
-: "Probability"
-
-, "Turnover"
-: "Turnover"
-
-, "Estimated end"
-: "Estimated end"
-
-, "Probable Turnover"
-: "Probable Turnover"
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: "Contact"
-
-, "CRM Role"
-: "CRM Role"
-
-, "Tasks"
-: "Tasks"
-
-, "No Tasks to display"
-: "No Tasks to display"
-
-, "Summary"
-: "Summary"
-
-, "Add a task..."
-: "Add a task..."
-
-, "Due Date"
-: "Due Date"
-
-, "Priority"
-: "Priority"
-
-, "Percent"
-: "Percent"
-
-, "Status"
-: "Status"
-
-, "Organizer"
-: ""
-
-, "Add new {0}"
-: "Add new {0}"
-
-, "Unlink {0}"
-: "Unlink {0}"
-
-, "Unlink selected {0}"
-: "Unlink selected {0}"
-
-, "Edit {0}"
-: "Edit {0}"
-
-, "Edit selected {0}"
-: "Edit selected {0}"
-
-, "Please choose the Lead to add the contacts to"
-: "Please choose the Lead to add the contacts to"
-
-, "Please select the attenders' role"
-: "Please select the attenders' role"
-
-, "Lead, Leads"
-: [
-  "Lead"
- ,"Leads"
-
-]
-, "Select Lead"
-: "Select Lead"
-
-, "Role"
-: "Role"
-
-, "Select Role"
-: "Select Role"
-
-, "Adding {0} contacts to lead"
-: ""
+, "Partner"
+: "Partner"
 
 , "Phone"
 : "Phone"
@@ -193,57 +37,120 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: "Status"
+
 , "Start"
 : "Start"
 
-, "Change type to Customer"
-: "Change type to Customer"
+, "Estimated end"
+: "Estimated end"
 
-, "Change type to Responsible"
-: "Change type to Responsible"
+, "Leadtype"
+: "Leadtype"
 
-, "Change type to Partner"
-: "Change type to Partner"
+, "Leadsource"
+: "Leadsource"
 
-, "Change contact type"
-: "Change contact type"
+, "Tags"
+: "Tags"
 
-, "Search for Contacts to add ..."
-: "Search for Contacts to add ..."
+, "Lead name"
+: "Lead name"
 
-, "Name"
-: "Name"
+, "Responsible"
+: "Responsible"
 
-, "Address"
-: "Address"
+, "Leadstate"
+: "Leadstate"
 
-, "Data"
-: "Data"
+, "Probability"
+: "Probability"
 
-, "Cellphone"
-: "Cellphone"
+, "Turnover"
+: "Turnover"
 
 , "End"
 : "End"
 
-, "You do not have the run right for the Tasks application or it is not activated."
-: "You do not have the run right for the Tasks application or it is not activated."
+, "Probable Turnover"
+: "Probable Turnover"
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: "Add new {0}"
+
+, "Unlink {0}"
+: "Unlink {0}"
+
+, "Unlink selected {0}"
+: "Unlink selected {0}"
+
+, "Edit {0}"
+: "Edit {0}"
+
+, "Edit selected {0}"
+: "Edit selected {0}"
+
+, "New Lead"
+: "New Lead"
 
 , "Products"
 : "Products"
 
+, "Product"
+: "Product"
+
+, "Description"
+: "Description"
+
+, "Price"
+: "Price"
+
+, "Quantity"
+: "Quantity"
+
+, "Search for Products to add ..."
+: "Search for Products to add ..."
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: "Tasks"
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: "You do not have the run right for the Tasks application or it is not activated."
+
 , "You do not have the run right for the Sales application or it is not activated."
 : "You do not have the run right for the Sales application or it is not activated."
 
+, "Lead, Leads"
+: [
+  "Lead"
+ ,"Leads"
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : "Expected turnover"
 
-, "Description"
-: "Description"
-
 , "Enter description"
 : "Enter description"
 
@@ -274,38 +181,131 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
-: "Product"
+, "Contact"
+: "Contact"
 
-, "Price"
-: "Price"
+, "CRM Role"
+: "CRM Role"
 
-, "Quantity"
-: "Quantity"
+, "Change type to Customer"
+: "Change type to Customer"
 
-, "Search for Products to add ..."
-: "Search for Products to add ..."
+, "Change type to Responsible"
+: "Change type to Responsible"
 
-, "All leads I have read grants for"
-: "All leads I have read grants for"
+, "Change type to Partner"
+: "Change type to Partner"
 
-, "Last modified by me"
-: "Last modified by me"
+, "Change contact type"
+: "Change contact type"
 
-, "All leads that I have last modified"
-: "All leads that I have last modified"
+, "Search for Contacts to add ..."
+: "Search for Contacts to add ..."
 
-, "My leads"
-: "My leads"
+, "Name"
+: "Name"
 
-, "All leads that I am responsible for"
-: "All leads that I am responsible for"
+, "Address"
+: "Address"
 
-, "Leads with overdue tasks"
-: "Leads with overdue tasks"
+, "Data"
+: "Data"
+
+, "Cellphone"
+: "Cellphone"
+
+, "Role"
+: "Role"
+
+, "Please choose the Lead to add the contacts to"
+: "Please choose the Lead to add the contacts to"
+
+, "Please select the attenders' role"
+: "Please select the attenders' role"
+
+, "Select Lead"
+: "Select Lead"
+
+, "Select Role"
+: "Select Role"
+
+, "Adding {0} contacts to lead"
+: ""
+
+, "No Tasks to display"
+: "No Tasks to display"
+
+, "Summary"
+: "Summary"
+
+, "Add a task..."
+: "Add a task..."
+
+, "Due Date"
+: "Due Date"
+
+, "Priority"
+: "Priority"
+
+, "Percent"
+: "Percent"
+
+, "Organizer"
+: ""
+
+, "All leads"
+: "All leads"
+
+, "Default Lead List"
+: ""
+
+, "The default list for new leads"
+: ""
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: "The level of actions you want to be notified about."
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: "Default Favorite"
+
+, "The default favorite which is loaded on crm startup"
+: "The default favorite which is loaded on crm startup"
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
+: ""
 
 , "Lead States Available"
 : ""
@@ -355,6 +355,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -373,6 +376,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: "Lead Data"
+
+, "End Scheduled"
+: "End Scheduled"
+
+, "Contacts"
+: "Contacts"
+
+, "Telephone"
+: "Telephone"
+
+, "Email"
+: "Email"
+
+, "low"
+: "low"
+
+, "normal"
+: "normal"
+
+, "high"
+: "high"
+
+, "urgent"
+: "urgent"
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: ""
+
 , "State"
 : "State"
 
@@ -403,53 +463,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : "Lead %s has been created"
 
-, "Task"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "Lead Data"
-: "Lead Data"
+, "All leads I have read grants for"
+: "All leads I have read grants for"
 
-, "End Scheduled"
-: "End Scheduled"
+, "Last modified by me"
+: "Last modified by me"
 
-, "Contacts"
-: "Contacts"
+, "All leads that I have last modified"
+: "All leads that I have last modified"
 
-, "Telephone"
-: "Telephone"
+, "My leads"
+: "My leads"
 
-, "Email"
-: "Email"
+, "All leads that I am responsible for"
+: "All leads that I am responsible for"
 
-, "low"
-: "low"
-
-, "normal"
-: "normal"
-
-, "high"
-: "high"
-
-, "urgent"
-: "urgent"
-
-, "Lead CSV import"
-: ""
-
-, "Import list (###CURRENTDATE###)"
-: ""
-
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
-: ""
-
-, "Edit new lead"
-: ""
-
-, "The following leads have just been imported into lead list %s"
-: ""
-
-, "%s new leads have been imported"
-: ""
+, "Leads with overdue tasks"
+: "Leads with overdue tasks"
 
 , "manage shared lead folders"
 : "manage shared lead folders"
