@@ -5,169 +5,13 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: "Todas las iniciativas"
-
-, "Default Lead List"
-: "Lista de iniciativas por defecto"
-
-, "The default list for new leads"
-: "Lista por defecto para nuevas iniciativas"
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: "El nivel de las acciones a notificar."
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: "Favorito por defecto"
-
-, "The default favorite which is loaded on crm startup"
-: "El favorito por defecto que se carga al comienzo de CRM"
-
-, "New Lead"
-: "Nueva Iniciativa"
-
-, "Tags"
-: "Etiquetas"
-
-, "Lead name"
-: "Nombre de la Iniciativa"
-
-, "Responsible"
-: "Responsable"
-
-, "Partner"
-: "Socio"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : "Cliente"
 
-, "Leadstate"
-: "Estado Iniciativa"
-
-, "Leadtype"
-: "Tipo de Iniciativa"
-
-, "Leadsource"
-: "Fuente de la Iniciativa"
-
-, "Probability"
-: "Probabilidad"
-
-, "Turnover"
-: "Facturación"
-
-, "Estimated end"
-: "Estimación finaliza"
-
-, "Probable Turnover"
-: "Facturación Prevista"
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: "Contacto"
-
-, "CRM Role"
-: "Cargo CRM"
-
-, "Tasks"
-: "Tareas"
-
-, "No Tasks to display"
-: "No hay tareas que mostar"
-
-, "Summary"
-: "Resumen"
-
-, "Add a task..."
-: "Agregar una tarea..."
-
-, "Due Date"
-: "Fecha Apta"
-
-, "Priority"
-: "Prioridad"
-
-, "Percent"
-: "Porcentaje"
-
-, "Status"
-: "Estado"
-
-, "Organizer"
-: ""
-
-, "Add new {0}"
-: "Agregar nueva {0}"
-
-, "Unlink {0}"
-: "Desconectar {0}"
-
-, "Unlink selected {0}"
-: "Desconectar selecccionados {0}"
-
-, "Edit {0}"
-: "Editar {0}"
-
-, "Edit selected {0}"
-: "Editar seleccionados {0}"
-
-, "Please choose the Lead to add the contacts to"
-: "Ingresar referencia para agregar los contactos"
-
-, "Please select the attenders' role"
-: "Seleccione rol de asistentes"
-
-, "Lead, Leads"
-: [
-  "Iniciativa"
- ,"Iniciativas"
-
-]
-, "Select Lead"
-: "Seleccionar iniciativa"
-
-, "Role"
-: "Cargo"
-
-, "Select Role"
-: "Seleccionar Cargo"
-
-, "Adding {0} contacts to lead"
-: "Agregar {0} contactos a la iniciativa"
+, "Partner"
+: "Socio"
 
 , "Phone"
 : "Teléfono"
@@ -193,57 +37,120 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: "Estado"
+
 , "Start"
 : "Inicio"
 
-, "Change type to Customer"
-: "Cambiar de cliente"
+, "Estimated end"
+: "Estimación finaliza"
 
-, "Change type to Responsible"
-: "Cambiar de Responsable"
+, "Leadtype"
+: "Tipo de Iniciativa"
 
-, "Change type to Partner"
-: "Cambiar de Socio"
+, "Leadsource"
+: "Fuente de la Iniciativa"
 
-, "Change contact type"
-: "Cambiar tipo de contacto"
+, "Tags"
+: "Etiquetas"
 
-, "Search for Contacts to add ..."
-: "Buscar contactos para añadir... "
+, "Lead name"
+: "Nombre de la Iniciativa"
 
-, "Name"
-: "Nombre"
+, "Responsible"
+: "Responsable"
 
-, "Address"
-: "Dirección"
+, "Leadstate"
+: "Estado Iniciativa"
 
-, "Data"
-: "Fecha"
+, "Probability"
+: "Probabilidad"
 
-, "Cellphone"
-: "Teléfono móvil"
+, "Turnover"
+: "Facturación"
 
 , "End"
 : "Fin"
 
-, "You do not have the run right for the Tasks application or it is not activated."
-: "No tiene privilegios para ejecutar la aplicación Tareas o no esta activada."
+, "Probable Turnover"
+: "Facturación Prevista"
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: "Agregar nueva {0}"
+
+, "Unlink {0}"
+: "Desconectar {0}"
+
+, "Unlink selected {0}"
+: "Desconectar selecccionados {0}"
+
+, "Edit {0}"
+: "Editar {0}"
+
+, "Edit selected {0}"
+: "Editar seleccionados {0}"
+
+, "New Lead"
+: "Nueva Iniciativa"
 
 , "Products"
 : "Productos"
 
+, "Product"
+: "Producto"
+
+, "Description"
+: "Descripción"
+
+, "Price"
+: "Precio"
+
+, "Quantity"
+: "Cantidad"
+
+, "Search for Products to add ..."
+: "Buscar Productos para añadir ..."
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: "Tareas"
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: "No tiene privilegios para ejecutar la aplicación Tareas o no esta activada."
+
 , "You do not have the run right for the Sales application or it is not activated."
 : "No tiene privilegios para ejecutar la aplicación Ventas o no esta activada."
 
+, "Lead, Leads"
+: [
+  "Iniciativa"
+ ,"Iniciativas"
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : "Facturación anual"
 
-, "Description"
-: "Descripción"
-
 , "Enter description"
 : "Escribir descripción"
 
@@ -274,38 +181,131 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
-: "Producto"
+, "Contact"
+: "Contacto"
 
-, "Price"
-: "Precio"
+, "CRM Role"
+: "Cargo CRM"
 
-, "Quantity"
-: "Cantidad"
+, "Change type to Customer"
+: "Cambiar de cliente"
 
-, "Search for Products to add ..."
-: "Buscar Productos para añadir ..."
+, "Change type to Responsible"
+: "Cambiar de Responsable"
 
-, "All leads I have read grants for"
-: "Todas las iniciativas leídas aplican para"
+, "Change type to Partner"
+: "Cambiar de Socio"
 
-, "Last modified by me"
-: "Últimas modificadas por mi"
+, "Change contact type"
+: "Cambiar tipo de contacto"
 
-, "All leads that I have last modified"
-: "Todas las iniciativas modificadas últimamente"
+, "Search for Contacts to add ..."
+: "Buscar contactos para añadir... "
 
-, "My leads"
-: "Mis iniciativas"
+, "Name"
+: "Nombre"
 
-, "All leads that I am responsible for"
-: "Todas las iniciativas de mi responsabilidad para"
+, "Address"
+: "Dirección"
 
-, "Leads with overdue tasks"
-: "Iniciativas con retraso"
+, "Data"
+: "Fecha"
+
+, "Cellphone"
+: "Teléfono móvil"
+
+, "Role"
+: "Cargo"
+
+, "Please choose the Lead to add the contacts to"
+: "Ingresar referencia para agregar los contactos"
+
+, "Please select the attenders' role"
+: "Seleccione rol de asistentes"
+
+, "Select Lead"
+: "Seleccionar iniciativa"
+
+, "Select Role"
+: "Seleccionar Cargo"
+
+, "Adding {0} contacts to lead"
+: "Agregar {0} contactos a la iniciativa"
+
+, "No Tasks to display"
+: "No hay tareas que mostar"
+
+, "Summary"
+: "Resumen"
+
+, "Add a task..."
+: "Agregar una tarea..."
+
+, "Due Date"
+: "Fecha Apta"
+
+, "Priority"
+: "Prioridad"
+
+, "Percent"
+: "Porcentaje"
+
+, "Organizer"
+: ""
+
+, "All leads"
+: "Todas las iniciativas"
+
+, "Default Lead List"
+: "Lista de iniciativas por defecto"
+
+, "The default list for new leads"
+: "Lista por defecto para nuevas iniciativas"
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: "El nivel de las acciones a notificar."
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: "Favorito por defecto"
+
+, "The default favorite which is loaded on crm startup"
+: "El favorito por defecto que se carga al comienzo de CRM"
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
+: ""
 
 , "Lead States Available"
 : ""
@@ -355,6 +355,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -373,6 +376,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: "Fecha Iniciativa"
+
+, "End Scheduled"
+: "Programación Finalizada"
+
+, "Contacts"
+: "Contactos"
+
+, "Telephone"
+: "Teléfono"
+
+, "Email"
+: "Email"
+
+, "low"
+: "baja"
+
+, "normal"
+: "normal"
+
+, "high"
+: "alta"
+
+, "urgent"
+: "urgente"
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: "Tarea"
+
 , "State"
 : "Estado"
 
@@ -403,53 +463,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : "Iniciativa %s ha sido creada"
 
-, "Task"
-: "Tarea"
-
-, "Lead Data"
-: "Fecha Iniciativa"
-
-, "End Scheduled"
-: "Programación Finalizada"
-
-, "Contacts"
-: "Contactos"
-
-, "Telephone"
-: "Teléfono"
-
-, "Email"
-: "Email"
-
-, "low"
-: "baja"
-
-, "normal"
-: "normal"
-
-, "high"
-: "alta"
-
-, "urgent"
-: "urgente"
-
-, "Lead CSV import"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "Import list (###CURRENTDATE###)"
-: ""
+, "All leads I have read grants for"
+: "Todas las iniciativas leídas aplican para"
 
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
-: ""
+, "Last modified by me"
+: "Últimas modificadas por mi"
 
-, "Edit new lead"
-: ""
+, "All leads that I have last modified"
+: "Todas las iniciativas modificadas últimamente"
 
-, "The following leads have just been imported into lead list %s"
-: ""
+, "My leads"
+: "Mis iniciativas"
 
-, "%s new leads have been imported"
-: ""
+, "All leads that I am responsible for"
+: "Todas las iniciativas de mi responsabilidad para"
+
+, "Leads with overdue tasks"
+: "Iniciativas con retraso"
 
 , "manage shared lead folders"
 : "gestionar carpetas compartidas de iniciativas"
