@@ -5,170 +5,12 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Hebrew (Israel) (http://www.transifex.com/tine20/tine20/language/he_IL/)\nLanguage: he_IL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: ""
-
-, "Default Lead List"
-: ""
-
-, "The default list for new leads"
-: ""
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: ""
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: ""
-
-, "The default favorite which is loaded on crm startup"
-: ""
-
-, "New Lead"
-: ""
-
-, "Tags"
-: ""
-
-, "Lead name"
-: ""
-
-, "Responsible"
-: ""
-
-, "Partner"
-: ""
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hebrew (Israel) (http://www.transifex.com/tine20/tine20/language/he_IL/)\nLanguage: he_IL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : ""
 
-, "Leadstate"
-: ""
-
-, "Leadtype"
-: ""
-
-, "Leadsource"
-: ""
-
-, "Probability"
-: ""
-
-, "Turnover"
-: ""
-
-, "Estimated end"
-: ""
-
-, "Probable Turnover"
-: ""
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: ""
-
-, "CRM Role"
-: ""
-
-, "Tasks"
-: ""
-
-, "No Tasks to display"
-: ""
-
-, "Summary"
-: ""
-
-, "Add a task..."
-: ""
-
-, "Due Date"
-: ""
-
-, "Priority"
-: ""
-
-, "Percent"
-: ""
-
-, "Status"
-: ""
-
-, "Organizer"
-: ""
-
-, "Add new {0}"
-: ""
-
-, "Unlink {0}"
-: ""
-
-, "Unlink selected {0}"
-: ""
-
-, "Edit {0}"
-: ""
-
-, "Edit selected {0}"
-: ""
-
-, "Please choose the Lead to add the contacts to"
-: ""
-
-, "Please select the attenders' role"
-: ""
-
-, "Lead, Leads"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Select Lead"
-: ""
-
-, "Role"
-: ""
-
-, "Select Role"
-: ""
-
-, "Adding {0} contacts to lead"
+, "Partner"
 : ""
 
 , "Phone"
@@ -195,57 +37,122 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: ""
+
 , "Start"
 : ""
 
-, "Change type to Customer"
+, "Estimated end"
 : ""
 
-, "Change type to Responsible"
+, "Leadtype"
 : ""
 
-, "Change type to Partner"
+, "Leadsource"
 : ""
 
-, "Change contact type"
+, "Tags"
 : ""
 
-, "Search for Contacts to add ..."
+, "Lead name"
 : ""
 
-, "Name"
+, "Responsible"
 : ""
 
-, "Address"
+, "Leadstate"
 : ""
 
-, "Data"
+, "Probability"
 : ""
 
-, "Cellphone"
+, "Turnover"
 : ""
 
 , "End"
 : ""
 
-, "You do not have the run right for the Tasks application or it is not activated."
+, "Probable Turnover"
+: ""
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: ""
+
+, "Unlink {0}"
+: ""
+
+, "Unlink selected {0}"
+: ""
+
+, "Edit {0}"
+: ""
+
+, "Edit selected {0}"
+: ""
+
+, "New Lead"
 : ""
 
 , "Products"
 : ""
 
+, "Product"
+: ""
+
+, "Description"
+: ""
+
+, "Price"
+: ""
+
+, "Quantity"
+: ""
+
+, "Search for Products to add ..."
+: ""
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: ""
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: ""
+
 , "You do not have the run right for the Sales application or it is not activated."
 : ""
 
+, "Lead, Leads"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : ""
 
-, "Description"
-: ""
-
 , "Enter description"
 : ""
 
@@ -278,37 +185,130 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
+, "Contact"
 : ""
 
-, "Price"
+, "CRM Role"
 : ""
 
-, "Quantity"
+, "Change type to Customer"
 : ""
 
-, "Search for Products to add ..."
+, "Change type to Responsible"
 : ""
 
-, "All leads I have read grants for"
+, "Change type to Partner"
 : ""
 
-, "Last modified by me"
+, "Change contact type"
 : ""
 
-, "All leads that I have last modified"
+, "Search for Contacts to add ..."
 : ""
 
-, "My leads"
+, "Name"
 : ""
 
-, "All leads that I am responsible for"
+, "Address"
 : ""
 
-, "Leads with overdue tasks"
+, "Data"
+: ""
+
+, "Cellphone"
+: ""
+
+, "Role"
+: ""
+
+, "Please choose the Lead to add the contacts to"
+: ""
+
+, "Please select the attenders' role"
+: ""
+
+, "Select Lead"
+: ""
+
+, "Select Role"
+: ""
+
+, "Adding {0} contacts to lead"
+: ""
+
+, "No Tasks to display"
+: ""
+
+, "Summary"
+: ""
+
+, "Add a task..."
+: ""
+
+, "Due Date"
+: ""
+
+, "Priority"
+: ""
+
+, "Percent"
+: ""
+
+, "Organizer"
+: ""
+
+, "All leads"
+: ""
+
+, "Default Lead List"
+: ""
+
+, "The default list for new leads"
+: ""
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: ""
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: ""
+
+, "The default favorite which is loaded on crm startup"
+: ""
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
 : ""
 
 , "Lead States Available"
@@ -359,6 +359,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -377,6 +380,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: ""
+
+, "End Scheduled"
+: ""
+
+, "Contacts"
+: ""
+
+, "Telephone"
+: ""
+
+, "Email"
+: ""
+
+, "low"
+: ""
+
+, "normal"
+: ""
+
+, "high"
+: ""
+
+, "urgent"
+: ""
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: ""
+
 , "State"
 : ""
 
@@ -407,52 +467,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : ""
 
-, "Task"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "Lead Data"
+, "All leads I have read grants for"
 : ""
 
-, "End Scheduled"
+, "Last modified by me"
 : ""
 
-, "Contacts"
+, "All leads that I have last modified"
 : ""
 
-, "Telephone"
+, "My leads"
 : ""
 
-, "Email"
+, "All leads that I am responsible for"
 : ""
 
-, "low"
-: ""
-
-, "normal"
-: ""
-
-, "high"
-: ""
-
-, "urgent"
-: ""
-
-, "Lead CSV import"
-: ""
-
-, "Import list (###CURRENTDATE###)"
-: ""
-
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
-: ""
-
-, "Edit new lead"
-: ""
-
-, "The following leads have just been imported into lead list %s"
-: ""
-
-, "%s new leads have been imported"
+, "Leads with overdue tasks"
 : ""
 
 , "manage shared lead folders"
