@@ -5,169 +5,13 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: "Tutti i leads"
-
-, "Default Lead List"
-: "Lista dei lead di default"
-
-, "The default list for new leads"
-: "Lista predefinita per clienti potenziali"
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: "Il livello di azioni per cui vuoi essere notificato."
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: "Preferito di Default"
-
-, "The default favorite which is loaded on crm startup"
-: "Il preferito di default che è caricato all'apertura del crm"
-
-, "New Lead"
-: "Nuovo Lead"
-
-, "Tags"
-: "Tag"
-
-, "Lead name"
-: "Nome cliente potenziale"
-
-, "Responsible"
-: "Responsabile"
-
-, "Partner"
-: "Partner"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : "Cliente"
 
-, "Leadstate"
-: "Stato cliente potenziale"
-
-, "Leadtype"
-: "Tipo cliente potenziale"
-
-, "Leadsource"
-: "Sorgente cliente potenziale"
-
-, "Probability"
-: "Probabilità"
-
-, "Turnover"
-: "Fatturato"
-
-, "Estimated end"
-: "Fine prevista"
-
-, "Probable Turnover"
-: "Fatturato probabile"
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: "Contatto"
-
-, "CRM Role"
-: "Ruolo CRM"
-
-, "Tasks"
-: "Compiti"
-
-, "No Tasks to display"
-: "Nessun compito da visualizzare"
-
-, "Summary"
-: "Sommario"
-
-, "Add a task..."
-: "Aggiungi un compito..."
-
-, "Due Date"
-: "Data prevista completamento"
-
-, "Priority"
-: "Priorità"
-
-, "Percent"
-: "Percentuale"
-
-, "Status"
-: "Stato"
-
-, "Organizer"
-: ""
-
-, "Add new {0}"
-: "Aggiungi nuovo {0}"
-
-, "Unlink {0}"
-: "Togli collegamento {0}"
-
-, "Unlink selected {0}"
-: "Togli collegamento selezionato {0}"
-
-, "Edit {0}"
-: "Modifica {0}"
-
-, "Edit selected {0}"
-: "Modifica {0} selezionato"
-
-, "Please choose the Lead to add the contacts to"
-: "Si prega di scegliere il Lead da aggiungere ai contatti"
-
-, "Please select the attenders' role"
-: "Prego seleziona il ruolo del partecipante"
-
-, "Lead, Leads"
-: [
-  "Cliente potenziale"
- ,"Clienti potenziali"
-
-]
-, "Select Lead"
-: "Seleziona Lead"
-
-, "Role"
-: "Ruolo"
-
-, "Select Role"
-: "Seleziona Ruolo"
-
-, "Adding {0} contacts to lead"
-: "Aggiunti {0} contatti al lead"
+, "Partner"
+: "Partner"
 
 , "Phone"
 : "Telefono"
@@ -193,57 +37,120 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: "Stato"
+
 , "Start"
 : "Inizio"
 
-, "Change type to Customer"
-: "Cambia tipo al Cliente"
+, "Estimated end"
+: "Fine prevista"
 
-, "Change type to Responsible"
-: "Cambia tipo al Responsabile"
+, "Leadtype"
+: "Tipo cliente potenziale"
 
-, "Change type to Partner"
-: "Cambia tipo al Partner"
+, "Leadsource"
+: "Sorgente cliente potenziale"
 
-, "Change contact type"
-: "Cambia tipo contatto"
+, "Tags"
+: "Tag"
 
-, "Search for Contacts to add ..."
-: "Ricerca Contatti da aggiungere..."
+, "Lead name"
+: "Nome cliente potenziale"
 
-, "Name"
-: "Nome"
+, "Responsible"
+: "Responsabile"
 
-, "Address"
-: "Indirizzo"
+, "Leadstate"
+: "Stato cliente potenziale"
 
-, "Data"
-: "Data"
+, "Probability"
+: "Probabilità"
 
-, "Cellphone"
-: "Cellulare"
+, "Turnover"
+: "Fatturato"
 
 , "End"
 : "Fine"
 
-, "You do not have the run right for the Tasks application or it is not activated."
-: "Non si ha il diritto di esecuzione per l'applicazione Attività o non è attivato."
+, "Probable Turnover"
+: "Fatturato probabile"
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: "Aggiungi nuovo {0}"
+
+, "Unlink {0}"
+: "Togli collegamento {0}"
+
+, "Unlink selected {0}"
+: "Togli collegamento selezionato {0}"
+
+, "Edit {0}"
+: "Modifica {0}"
+
+, "Edit selected {0}"
+: "Modifica {0} selezionato"
+
+, "New Lead"
+: "Nuovo Lead"
 
 , "Products"
 : "Prodotti"
 
+, "Product"
+: "Prodotto"
+
+, "Description"
+: "Descrizione"
+
+, "Price"
+: "Prezzo"
+
+, "Quantity"
+: "Quantità"
+
+, "Search for Products to add ..."
+: "Ricerca Prodotti da aggiungere..."
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: "Compiti"
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: "Non si ha il diritto di esecuzione per l'applicazione Attività o non è attivato."
+
 , "You do not have the run right for the Sales application or it is not activated."
 : "Non si ha il diritto di esecuzione per l'applicazione Vendite o non è attivato."
 
+, "Lead, Leads"
+: [
+  "Cliente potenziale"
+ ,"Clienti potenziali"
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : "Fatturato previsto"
 
-, "Description"
-: "Descrizione"
-
 , "Enter description"
 : "Inserisci descrizione"
 
@@ -274,38 +181,131 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
-: "Prodotto"
+, "Contact"
+: "Contatto"
 
-, "Price"
-: "Prezzo"
+, "CRM Role"
+: "Ruolo CRM"
 
-, "Quantity"
-: "Quantità"
+, "Change type to Customer"
+: "Cambia tipo al Cliente"
 
-, "Search for Products to add ..."
-: "Ricerca Prodotti da aggiungere..."
+, "Change type to Responsible"
+: "Cambia tipo al Responsabile"
 
-, "All leads I have read grants for"
-: "Tutti i potenziali di cui ho il permesso di lettura"
+, "Change type to Partner"
+: "Cambia tipo al Partner"
 
-, "Last modified by me"
-: "Ultimo modificato da me"
+, "Change contact type"
+: "Cambia tipo contatto"
 
-, "All leads that I have last modified"
-: "Tutti i leads che ho modificato"
+, "Search for Contacts to add ..."
+: "Ricerca Contatti da aggiungere..."
 
-, "My leads"
-: "Miei Leads"
+, "Name"
+: "Nome"
 
-, "All leads that I am responsible for"
-: "Tutti i leads di cui sono responsabile"
+, "Address"
+: "Indirizzo"
 
-, "Leads with overdue tasks"
-: "Leads con attività scadute"
+, "Data"
+: "Data"
+
+, "Cellphone"
+: "Cellulare"
+
+, "Role"
+: "Ruolo"
+
+, "Please choose the Lead to add the contacts to"
+: "Si prega di scegliere il Lead da aggiungere ai contatti"
+
+, "Please select the attenders' role"
+: "Prego seleziona il ruolo del partecipante"
+
+, "Select Lead"
+: "Seleziona Lead"
+
+, "Select Role"
+: "Seleziona Ruolo"
+
+, "Adding {0} contacts to lead"
+: "Aggiunti {0} contatti al lead"
+
+, "No Tasks to display"
+: "Nessun compito da visualizzare"
+
+, "Summary"
+: "Sommario"
+
+, "Add a task..."
+: "Aggiungi un compito..."
+
+, "Due Date"
+: "Data prevista completamento"
+
+, "Priority"
+: "Priorità"
+
+, "Percent"
+: "Percentuale"
+
+, "Organizer"
+: ""
+
+, "All leads"
+: "Tutti i leads"
+
+, "Default Lead List"
+: "Lista dei lead di default"
+
+, "The default list for new leads"
+: "Lista predefinita per clienti potenziali"
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: "Il livello di azioni per cui vuoi essere notificato."
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: "Preferito di Default"
+
+, "The default favorite which is loaded on crm startup"
+: "Il preferito di default che è caricato all'apertura del crm"
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
+: ""
 
 , "Lead States Available"
 : ""
@@ -355,6 +355,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -373,6 +376,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: "Dati cliente potenziale"
+
+, "End Scheduled"
+: "Fine schedulata"
+
+, "Contacts"
+: "Contatti"
+
+, "Telephone"
+: "Telefono"
+
+, "Email"
+: "Email"
+
+, "low"
+: "basso"
+
+, "normal"
+: "normale"
+
+, "high"
+: "alto"
+
+, "urgent"
+: "urgente"
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: "Attività"
+
 , "State"
 : "Stato"
 
@@ -403,53 +463,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : "Il lead %s è stato creato"
 
-, "Task"
-: "Attività"
-
-, "Lead Data"
-: "Dati cliente potenziale"
-
-, "End Scheduled"
-: "Fine schedulata"
-
-, "Contacts"
-: "Contatti"
-
-, "Telephone"
-: "Telefono"
-
-, "Email"
-: "Email"
-
-, "low"
-: "basso"
-
-, "normal"
-: "normale"
-
-, "high"
-: "alto"
-
-, "urgent"
-: "urgente"
-
-, "Lead CSV import"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "Import list (###CURRENTDATE###)"
-: ""
+, "All leads I have read grants for"
+: "Tutti i potenziali di cui ho il permesso di lettura"
 
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
-: ""
+, "Last modified by me"
+: "Ultimo modificato da me"
 
-, "Edit new lead"
-: ""
+, "All leads that I have last modified"
+: "Tutti i leads che ho modificato"
 
-, "The following leads have just been imported into lead list %s"
-: ""
+, "My leads"
+: "Miei Leads"
 
-, "%s new leads have been imported"
-: ""
+, "All leads that I am responsible for"
+: "Tutti i leads di cui sono responsabile"
+
+, "Leads with overdue tasks"
+: "Leads con attività scadute"
 
 , "manage shared lead folders"
 : "gestisci cartelle condivise dei clienti potenziali"
