@@ -5,168 +5,13 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Japanese (http://www.transifex.com/tine20/tine20/language/ja/)\nLanguage: ja\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: ""
-
-, "Default Lead List"
-: ""
-
-, "The default list for new leads"
-: ""
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: ""
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: ""
-
-, "The default favorite which is loaded on crm startup"
-: ""
-
-, "New Lead"
-: ""
-
-, "Tags"
-: ""
-
-, "Lead name"
-: "リード名"
-
-, "Responsible"
-: "責任"
-
-, "Partner"
-: "パートナ"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Japanese (http://www.transifex.com/tine20/tine20/language/ja/)\nLanguage: ja\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : "顧客"
 
-, "Leadstate"
-: "リードスタイル"
-
-, "Leadtype"
-: "リードタイプ"
-
-, "Leadsource"
-: "リードソース"
-
-, "Probability"
-: "確度"
-
-, "Turnover"
-: "取引高"
-
-, "Estimated end"
-: "終了予定"
-
-, "Probable Turnover"
-: ""
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: ""
-
-, "CRM Role"
-: ""
-
-, "Tasks"
-: "タスク"
-
-, "No Tasks to display"
-: "表示するタスクがありません"
-
-, "Summary"
-: "要約"
-
-, "Add a task..."
-: "タスクを追加しています..."
-
-, "Due Date"
-: "期日"
-
-, "Priority"
-: "重要度"
-
-, "Percent"
-: "パーセント"
-
-, "Status"
-: "ステータス"
-
-, "Organizer"
-: ""
-
-, "Add new {0}"
-: ""
-
-, "Unlink {0}"
-: ""
-
-, "Unlink selected {0}"
-: ""
-
-, "Edit {0}"
-: ""
-
-, "Edit selected {0}"
-: ""
-
-, "Please choose the Lead to add the contacts to"
-: ""
-
-, "Please select the attenders' role"
-: ""
-
-, "Lead, Leads"
-: [
-  ""
-
-]
-, "Select Lead"
-: ""
-
-, "Role"
-: ""
-
-, "Select Role"
-: ""
-
-, "Adding {0} contacts to lead"
-: ""
+, "Partner"
+: "パートナ"
 
 , "Phone"
 : "電話"
@@ -192,57 +37,119 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: "ステータス"
+
 , "Start"
 : "開始"
 
-, "Change type to Customer"
-: "顧客タイプの変更"
+, "Estimated end"
+: "終了予定"
 
-, "Change type to Responsible"
-: "責任者の変更"
+, "Leadtype"
+: "リードタイプ"
 
-, "Change type to Partner"
-: "パートナタイプの変更"
+, "Leadsource"
+: "リードソース"
 
-, "Change contact type"
-: "コンタクトタイプの編集"
-
-, "Search for Contacts to add ..."
-: "コンタクトの検索と追加"
-
-, "Name"
-: "名前"
-
-, "Address"
-: "住所"
-
-, "Data"
+, "Tags"
 : ""
 
-, "Cellphone"
-: "携帯電話"
+, "Lead name"
+: "リード名"
+
+, "Responsible"
+: "責任"
+
+, "Leadstate"
+: "リードスタイル"
+
+, "Probability"
+: "確度"
+
+, "Turnover"
+: "取引高"
 
 , "End"
 : "終了"
 
-, "You do not have the run right for the Tasks application or it is not activated."
+, "Probable Turnover"
+: ""
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: ""
+
+, "Unlink {0}"
+: ""
+
+, "Unlink selected {0}"
+: ""
+
+, "Edit {0}"
+: ""
+
+, "Edit selected {0}"
+: ""
+
+, "New Lead"
 : ""
 
 , "Products"
 : "プロダクト"
 
+, "Product"
+: ""
+
+, "Description"
+: "説明"
+
+, "Price"
+: "価格"
+
+, "Quantity"
+: ""
+
+, "Search for Products to add ..."
+: ""
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: "タスク"
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: ""
+
 , "You do not have the run right for the Sales application or it is not activated."
 : ""
 
+, "Lead, Leads"
+: [
+  ""
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : "概算売上見積"
 
-, "Description"
-: "説明"
-
 , "Enter description"
 : "説明を入力してください"
 
@@ -272,37 +179,130 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
+, "Contact"
 : ""
 
-, "Price"
-: "価格"
-
-, "Quantity"
+, "CRM Role"
 : ""
 
-, "Search for Products to add ..."
+, "Change type to Customer"
+: "顧客タイプの変更"
+
+, "Change type to Responsible"
+: "責任者の変更"
+
+, "Change type to Partner"
+: "パートナタイプの変更"
+
+, "Change contact type"
+: "コンタクトタイプの編集"
+
+, "Search for Contacts to add ..."
+: "コンタクトの検索と追加"
+
+, "Name"
+: "名前"
+
+, "Address"
+: "住所"
+
+, "Data"
 : ""
 
-, "All leads I have read grants for"
+, "Cellphone"
+: "携帯電話"
+
+, "Role"
 : ""
 
-, "Last modified by me"
+, "Please choose the Lead to add the contacts to"
 : ""
 
-, "All leads that I have last modified"
+, "Please select the attenders' role"
 : ""
 
-, "My leads"
+, "Select Lead"
 : ""
 
-, "All leads that I am responsible for"
+, "Select Role"
 : ""
 
-, "Leads with overdue tasks"
+, "Adding {0} contacts to lead"
+: ""
+
+, "No Tasks to display"
+: "表示するタスクがありません"
+
+, "Summary"
+: "要約"
+
+, "Add a task..."
+: "タスクを追加しています..."
+
+, "Due Date"
+: "期日"
+
+, "Priority"
+: "重要度"
+
+, "Percent"
+: "パーセント"
+
+, "Organizer"
+: ""
+
+, "All leads"
+: ""
+
+, "Default Lead List"
+: ""
+
+, "The default list for new leads"
+: ""
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: ""
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: ""
+
+, "The default favorite which is loaded on crm startup"
+: ""
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
 : ""
 
 , "Lead States Available"
@@ -353,6 +353,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -371,6 +374,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: "リードデータ"
+
+, "End Scheduled"
+: "スケジュールされた終了"
+
+, "Contacts"
+: "コンタクト"
+
+, "Telephone"
+: "電話番号"
+
+, "Email"
+: "Eメール"
+
+, "low"
+: "低"
+
+, "normal"
+: "波"
+
+, "high"
+: "高"
+
+, "urgent"
+: "緊急"
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: ""
+
 , "State"
 : "ステート"
 
@@ -401,52 +461,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : ""
 
-, "Task"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "Lead Data"
-: "リードデータ"
-
-, "End Scheduled"
-: "スケジュールされた終了"
-
-, "Contacts"
-: "コンタクト"
-
-, "Telephone"
-: "電話番号"
-
-, "Email"
-: "Eメール"
-
-, "low"
-: "低"
-
-, "normal"
-: "波"
-
-, "high"
-: "高"
-
-, "urgent"
-: "緊急"
-
-, "Lead CSV import"
+, "All leads I have read grants for"
 : ""
 
-, "Import list (###CURRENTDATE###)"
+, "Last modified by me"
 : ""
 
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+, "All leads that I have last modified"
 : ""
 
-, "Edit new lead"
+, "My leads"
 : ""
 
-, "The following leads have just been imported into lead list %s"
+, "All leads that I am responsible for"
 : ""
 
-, "%s new leads have been imported"
+, "Leads with overdue tasks"
 : ""
 
 , "manage shared lead folders"
