@@ -5,169 +5,13 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: ""
-
-, "Default Lead List"
-: ""
-
-, "The default list for new leads"
-: ""
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: ""
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: ""
-
-, "The default favorite which is loaded on crm startup"
-: ""
-
-, "New Lead"
-: ""
-
-, "Tags"
-: "Merker"
-
-, "Lead name"
-: "Mulighets navn"
-
-, "Responsible"
-: "Ansvarlig"
-
-, "Partner"
-: "Partner"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Norwegian Bokmål (http://www.transifex.com/tine20/tine20/language/nb/)\nLanguage: nb\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : "Kunde"
 
-, "Leadstate"
-: "Mulighets fylke"
-
-, "Leadtype"
-: "Mulighets type"
-
-, "Leadsource"
-: "Mulighets kilde"
-
-, "Probability"
-: "Sannsynlighet"
-
-, "Turnover"
-: "Omsetning"
-
-, "Estimated end"
-: "Forventet slutt"
-
-, "Probable Turnover"
-: ""
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: "Kontakt"
-
-, "CRM Role"
-: "CRM Rolle"
-
-, "Tasks"
-: "Oppgaver"
-
-, "No Tasks to display"
-: "Ingen Oppgaver å vise"
-
-, "Summary"
-: "Sammendrag"
-
-, "Add a task..."
-: "Legg til en oppgave..."
-
-, "Due Date"
-: "Ferdig Innen"
-
-, "Priority"
-: "Prioritet"
-
-, "Percent"
-: "Prosent"
-
-, "Status"
-: "Status"
-
-, "Organizer"
-: ""
-
-, "Add new {0}"
-: "Legg til ny {0}"
-
-, "Unlink {0}"
-: "Frakoble {0}"
-
-, "Unlink selected {0}"
-: "Frakoble valgte {0}"
-
-, "Edit {0}"
-: "Rediger {0}"
-
-, "Edit selected {0}"
-: "Rediger valgte {0}"
-
-, "Please choose the Lead to add the contacts to"
-: ""
-
-, "Please select the attenders' role"
-: ""
-
-, "Lead, Leads"
-: [
-  "Mulighet"
- ,"Muligheter"
-
-]
-, "Select Lead"
-: ""
-
-, "Role"
-: "Rolle"
-
-, "Select Role"
-: ""
-
-, "Adding {0} contacts to lead"
-: ""
+, "Partner"
+: "Partner"
 
 , "Phone"
 : "Telefon"
@@ -193,57 +37,120 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: "Status"
+
 , "Start"
 : "Start"
 
-, "Change type to Customer"
-: "Endre type til Kunde"
+, "Estimated end"
+: "Forventet slutt"
 
-, "Change type to Responsible"
-: "Endre type til Ansvarlig"
+, "Leadtype"
+: "Mulighets type"
 
-, "Change type to Partner"
-: "Endre type til Partner"
+, "Leadsource"
+: "Mulighets kilde"
 
-, "Change contact type"
-: "Endre kontakt type"
+, "Tags"
+: "Merker"
 
-, "Search for Contacts to add ..."
-: "Søk etter Kontaker å legge til ..."
+, "Lead name"
+: "Mulighets navn"
 
-, "Name"
-: "Navn"
+, "Responsible"
+: "Ansvarlig"
 
-, "Address"
-: "Adresse"
+, "Leadstate"
+: "Mulighets fylke"
 
-, "Data"
-: "Data"
+, "Probability"
+: "Sannsynlighet"
 
-, "Cellphone"
-: "Mobil"
+, "Turnover"
+: "Omsetning"
 
 , "End"
 : "Slutt"
 
-, "You do not have the run right for the Tasks application or it is not activated."
+, "Probable Turnover"
+: ""
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: "Legg til ny {0}"
+
+, "Unlink {0}"
+: "Frakoble {0}"
+
+, "Unlink selected {0}"
+: "Frakoble valgte {0}"
+
+, "Edit {0}"
+: "Rediger {0}"
+
+, "Edit selected {0}"
+: "Rediger valgte {0}"
+
+, "New Lead"
 : ""
 
 , "Products"
 : "Produkter"
 
+, "Product"
+: "Produkt"
+
+, "Description"
+: "Beskrivelse"
+
+, "Price"
+: "Pris"
+
+, "Quantity"
+: "Kvantum"
+
+, "Search for Products to add ..."
+: "Søk etter Produkter å legge til ..."
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: "Oppgaver"
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: ""
+
 , "You do not have the run right for the Sales application or it is not activated."
 : ""
 
+, "Lead, Leads"
+: [
+  "Mulighet"
+ ,"Muligheter"
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : "Forventet omsetning"
 
-, "Description"
-: "Beskrivelse"
-
 , "Enter description"
 : "Tast inn beskrivelse"
 
@@ -274,37 +181,130 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
-: "Produkt"
+, "Contact"
+: "Kontakt"
 
-, "Price"
-: "Pris"
+, "CRM Role"
+: "CRM Rolle"
 
-, "Quantity"
-: "Kvantum"
+, "Change type to Customer"
+: "Endre type til Kunde"
 
-, "Search for Products to add ..."
-: "Søk etter Produkter å legge til ..."
+, "Change type to Responsible"
+: "Endre type til Ansvarlig"
 
-, "All leads I have read grants for"
+, "Change type to Partner"
+: "Endre type til Partner"
+
+, "Change contact type"
+: "Endre kontakt type"
+
+, "Search for Contacts to add ..."
+: "Søk etter Kontaker å legge til ..."
+
+, "Name"
+: "Navn"
+
+, "Address"
+: "Adresse"
+
+, "Data"
+: "Data"
+
+, "Cellphone"
+: "Mobil"
+
+, "Role"
+: "Rolle"
+
+, "Please choose the Lead to add the contacts to"
 : ""
 
-, "Last modified by me"
+, "Please select the attenders' role"
 : ""
 
-, "All leads that I have last modified"
+, "Select Lead"
 : ""
 
-, "My leads"
+, "Select Role"
 : ""
 
-, "All leads that I am responsible for"
+, "Adding {0} contacts to lead"
 : ""
 
-, "Leads with overdue tasks"
+, "No Tasks to display"
+: "Ingen Oppgaver å vise"
+
+, "Summary"
+: "Sammendrag"
+
+, "Add a task..."
+: "Legg til en oppgave..."
+
+, "Due Date"
+: "Ferdig Innen"
+
+, "Priority"
+: "Prioritet"
+
+, "Percent"
+: "Prosent"
+
+, "Organizer"
+: ""
+
+, "All leads"
+: ""
+
+, "Default Lead List"
+: ""
+
+, "The default list for new leads"
+: ""
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: ""
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: ""
+
+, "The default favorite which is loaded on crm startup"
+: ""
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
 : ""
 
 , "Lead States Available"
@@ -355,6 +355,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -373,6 +376,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: "Mulighets Data"
+
+, "End Scheduled"
+: "Slutt Avatalt"
+
+, "Contacts"
+: "Kontakter"
+
+, "Telephone"
+: "Telefon"
+
+, "Email"
+: "E-post"
+
+, "low"
+: "lav"
+
+, "normal"
+: "normal"
+
+, "high"
+: "høy"
+
+, "urgent"
+: "viktig"
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: ""
+
 , "State"
 : "Fylke"
 
@@ -403,52 +463,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : ""
 
-, "Task"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "Lead Data"
-: "Mulighets Data"
-
-, "End Scheduled"
-: "Slutt Avatalt"
-
-, "Contacts"
-: "Kontakter"
-
-, "Telephone"
-: "Telefon"
-
-, "Email"
-: "E-post"
-
-, "low"
-: "lav"
-
-, "normal"
-: "normal"
-
-, "high"
-: "høy"
-
-, "urgent"
-: "viktig"
-
-, "Lead CSV import"
+, "All leads I have read grants for"
 : ""
 
-, "Import list (###CURRENTDATE###)"
+, "Last modified by me"
 : ""
 
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+, "All leads that I have last modified"
 : ""
 
-, "Edit new lead"
+, "My leads"
 : ""
 
-, "The following leads have just been imported into lead list %s"
+, "All leads that I am responsible for"
 : ""
 
-, "%s new leads have been imported"
+, "Leads with overdue tasks"
 : ""
 
 , "manage shared lead folders"
