@@ -5,170 +5,13 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nLanguage: ro_RO\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: ""
-
-, "Default Lead List"
-: ""
-
-, "The default list for new leads"
-: ""
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: ""
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: "Favorite Implicit"
-
-, "The default favorite which is loaded on crm startup"
-: ""
-
-, "New Lead"
-: ""
-
-, "Tags"
-: "Taguri"
-
-, "Lead name"
-: ""
-
-, "Responsible"
-: "Responsabil"
-
-, "Partner"
-: "Partener"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nLanguage: ro_RO\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : "Client"
 
-, "Leadstate"
-: ""
-
-, "Leadtype"
-: ""
-
-, "Leadsource"
-: ""
-
-, "Probability"
-: "Probabilitate"
-
-, "Turnover"
-: "Cifra de afaceri"
-
-, "Estimated end"
-: ""
-
-, "Probable Turnover"
-: ""
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: "Contact"
-
-, "CRM Role"
-: "Rol CRM"
-
-, "Tasks"
-: "Taskuri"
-
-, "No Tasks to display"
-: "Niciun Task de afişat"
-
-, "Summary"
-: "Sumar"
-
-, "Add a task..."
-: "Adaugă un task..."
-
-, "Due Date"
-: ""
-
-, "Priority"
-: "Prioritate"
-
-, "Percent"
-: "Procent"
-
-, "Status"
-: "Status"
-
-, "Organizer"
-: "Organizează"
-
-, "Add new {0}"
-: "Adaugă Nou {0}"
-
-, "Unlink {0}"
-: ""
-
-, "Unlink selected {0}"
-: ""
-
-, "Edit {0}"
-: "Editează {0}"
-
-, "Edit selected {0}"
-: "Editează selectat {0}"
-
-, "Please choose the Lead to add the contacts to"
-: ""
-
-, "Please select the attenders' role"
-: ""
-
-, "Lead, Leads"
-: [
-  ""
- ,""
- ,""
-
-]
-, "Select Lead"
-: ""
-
-, "Role"
-: "Rol"
-
-, "Select Role"
-: "Selectează Rol"
-
-, "Adding {0} contacts to lead"
-: ""
+, "Partner"
+: "Partener"
 
 , "Phone"
 : "Telefon"
@@ -194,57 +37,121 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: "Status"
+
 , "Start"
 : "Start"
 
-, "Change type to Customer"
-: "Schimbă tip la Client"
+, "Estimated end"
+: ""
 
-, "Change type to Responsible"
-: "Schimbă tip la Responsabil"
+, "Leadtype"
+: ""
 
-, "Change type to Partner"
-: "Schimbă tip la Partener"
+, "Leadsource"
+: ""
 
-, "Change contact type"
-: "Schimbă tip contact"
+, "Tags"
+: "Taguri"
 
-, "Search for Contacts to add ..."
-: "Caută Contacte pentru adăugare ..."
+, "Lead name"
+: ""
 
-, "Name"
-: "Nume"
+, "Responsible"
+: "Responsabil"
 
-, "Address"
-: "Addresă"
+, "Leadstate"
+: ""
 
-, "Data"
-: "Data"
+, "Probability"
+: "Probabilitate"
 
-, "Cellphone"
-: "Celular"
+, "Turnover"
+: "Cifra de afaceri"
 
 , "End"
 : "Final"
 
-, "You do not have the run right for the Tasks application or it is not activated."
+, "Probable Turnover"
+: ""
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: "Adaugă Nou {0}"
+
+, "Unlink {0}"
+: ""
+
+, "Unlink selected {0}"
+: ""
+
+, "Edit {0}"
+: "Editează {0}"
+
+, "Edit selected {0}"
+: "Editează selectat {0}"
+
+, "New Lead"
 : ""
 
 , "Products"
 : "Produse"
 
+, "Product"
+: "Produs"
+
+, "Description"
+: "Descriere"
+
+, "Price"
+: "Preţ"
+
+, "Quantity"
+: "Cantitate"
+
+, "Search for Products to add ..."
+: ""
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: "Taskuri"
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: ""
+
 , "You do not have the run right for the Sales application or it is not activated."
 : ""
 
+, "Lead, Leads"
+: [
+  ""
+ ,""
+ ,""
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : ""
 
-, "Description"
-: "Descriere"
-
 , "Enter description"
 : ""
 
@@ -276,37 +183,130 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
-: "Produs"
+, "Contact"
+: "Contact"
 
-, "Price"
-: "Preţ"
+, "CRM Role"
+: "Rol CRM"
 
-, "Quantity"
-: "Cantitate"
+, "Change type to Customer"
+: "Schimbă tip la Client"
 
-, "Search for Products to add ..."
+, "Change type to Responsible"
+: "Schimbă tip la Responsabil"
+
+, "Change type to Partner"
+: "Schimbă tip la Partener"
+
+, "Change contact type"
+: "Schimbă tip contact"
+
+, "Search for Contacts to add ..."
+: "Caută Contacte pentru adăugare ..."
+
+, "Name"
+: "Nume"
+
+, "Address"
+: "Addresă"
+
+, "Data"
+: "Data"
+
+, "Cellphone"
+: "Celular"
+
+, "Role"
+: "Rol"
+
+, "Please choose the Lead to add the contacts to"
 : ""
 
-, "All leads I have read grants for"
+, "Please select the attenders' role"
 : ""
 
-, "Last modified by me"
-: "Ultima modificată de mine"
-
-, "All leads that I have last modified"
+, "Select Lead"
 : ""
 
-, "My leads"
+, "Select Role"
+: "Selectează Rol"
+
+, "Adding {0} contacts to lead"
 : ""
 
-, "All leads that I am responsible for"
+, "No Tasks to display"
+: "Niciun Task de afişat"
+
+, "Summary"
+: "Sumar"
+
+, "Add a task..."
+: "Adaugă un task..."
+
+, "Due Date"
 : ""
 
-, "Leads with overdue tasks"
+, "Priority"
+: "Prioritate"
+
+, "Percent"
+: "Procent"
+
+, "Organizer"
+: "Organizează"
+
+, "All leads"
+: ""
+
+, "Default Lead List"
+: ""
+
+, "The default list for new leads"
+: ""
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: ""
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: "Favorite Implicit"
+
+, "The default favorite which is loaded on crm startup"
+: ""
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
 : ""
 
 , "Lead States Available"
@@ -357,6 +357,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -375,6 +378,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: ""
+
+, "End Scheduled"
+: "Final Programat"
+
+, "Contacts"
+: "Contacte"
+
+, "Telephone"
+: "Telefon"
+
+, "Email"
+: "Email"
+
+, "low"
+: "scăzut"
+
+, "normal"
+: "normal"
+
+, "high"
+: "înalt"
+
+, "urgent"
+: "urgent"
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: "Task"
+
 , "State"
 : "Stat"
 
@@ -405,52 +465,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : ""
 
-, "Task"
-: "Task"
-
-, "Lead Data"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "End Scheduled"
-: "Final Programat"
-
-, "Contacts"
-: "Contacte"
-
-, "Telephone"
-: "Telefon"
-
-, "Email"
-: "Email"
-
-, "low"
-: "scăzut"
-
-, "normal"
-: "normal"
-
-, "high"
-: "înalt"
-
-, "urgent"
-: "urgent"
-
-, "Lead CSV import"
+, "All leads I have read grants for"
 : ""
 
-, "Import list (###CURRENTDATE###)"
+, "Last modified by me"
+: "Ultima modificată de mine"
+
+, "All leads that I have last modified"
 : ""
 
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+, "My leads"
 : ""
 
-, "Edit new lead"
+, "All leads that I am responsible for"
 : ""
 
-, "The following leads have just been imported into lead list %s"
-: ""
-
-, "%s new leads have been imported"
+, "Leads with overdue tasks"
 : ""
 
 , "manage shared lead folders"
