@@ -5,168 +5,13 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: ""
-
-, "Default Lead List"
-: ""
-
-, "The default list for new leads"
-: ""
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: "ระดับของการกระทำที่คุณต้องการรับทราบ"
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: "ค่าที่ชอบหลัก"
-
-, "The default favorite which is loaded on crm startup"
-: ""
-
-, "New Lead"
-: ""
-
-, "Tags"
-: "ป้ายกำกับ"
-
-, "Lead name"
-: ""
-
-, "Responsible"
-: "รับผิดชอบ"
-
-, "Partner"
-: "คู่หู"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : "ลูกค้า"
 
-, "Leadstate"
-: "สถานะดำเนินการ"
-
-, "Leadtype"
-: "ประเภทดำเนินการ"
-
-, "Leadsource"
-: "แหล่งดำเนินการ"
-
-, "Probability"
-: "ความน่าจะเป็น"
-
-, "Turnover"
-: ""
-
-, "Estimated end"
-: ""
-
-, "Probable Turnover"
-: ""
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: "การติดต่อ"
-
-, "CRM Role"
-: "หน้าที่ CRM"
-
-, "Tasks"
-: "หน้าที่"
-
-, "No Tasks to display"
-: "ไม่มีหน้าที่ให้แสดง"
-
-, "Summary"
-: "ข้อสรุป"
-
-, "Add a task..."
-: "เพิ่มหน้าที่..."
-
-, "Due Date"
-: "วันครบกำหนด"
-
-, "Priority"
-: "ลำดับความสำคัญ"
-
-, "Percent"
-: "เปอร์เซนต์"
-
-, "Status"
-: "สถานะ"
-
-, "Organizer"
-: ""
-
-, "Add new {0}"
-: "เพิ่ม {0} ใหม่"
-
-, "Unlink {0}"
-: "ยกเลิกการเชื่อมต่อ {0}"
-
-, "Unlink selected {0}"
-: ""
-
-, "Edit {0}"
-: "แก้ไข {0}"
-
-, "Edit selected {0}"
-: "แก้ไข {0} ที่เลือก"
-
-, "Please choose the Lead to add the contacts to"
-: ""
-
-, "Please select the attenders' role"
-: ""
-
-, "Lead, Leads"
-: [
-  ""
-
-]
-, "Select Lead"
-: ""
-
-, "Role"
-: "หน้าที่"
-
-, "Select Role"
-: "เลือก หน้าที่"
-
-, "Adding {0} contacts to lead"
-: ""
+, "Partner"
+: "คู่หู"
 
 , "Phone"
 : "โทรศัพท์"
@@ -192,57 +37,119 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: "สถานะ"
+
 , "Start"
 : "เริ่มต้น"
 
-, "Change type to Customer"
-: "เปลี่ยน ประเภทลูกค้า"
-
-, "Change type to Responsible"
+, "Estimated end"
 : ""
 
-, "Change type to Partner"
+, "Leadtype"
+: "ประเภทดำเนินการ"
+
+, "Leadsource"
+: "แหล่งดำเนินการ"
+
+, "Tags"
+: "ป้ายกำกับ"
+
+, "Lead name"
 : ""
 
-, "Change contact type"
-: "เปลี่ยนประเภทการติดต่อ"
+, "Responsible"
+: "รับผิดชอบ"
 
-, "Search for Contacts to add ..."
-: "ค้นหาการติดต่อเพื่อเพิ่ม ..."
+, "Leadstate"
+: "สถานะดำเนินการ"
 
-, "Name"
-: "ชื่อ"
+, "Probability"
+: "ความน่าจะเป็น"
 
-, "Address"
-: "ที่อยู่"
-
-, "Data"
-: "ข้อมูล"
-
-, "Cellphone"
-: "โทรศัพท์เคลื่อนที่"
+, "Turnover"
+: ""
 
 , "End"
 : "สิ้นสุด"
 
-, "You do not have the run right for the Tasks application or it is not activated."
+, "Probable Turnover"
+: ""
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: "เพิ่ม {0} ใหม่"
+
+, "Unlink {0}"
+: "ยกเลิกการเชื่อมต่อ {0}"
+
+, "Unlink selected {0}"
+: ""
+
+, "Edit {0}"
+: "แก้ไข {0}"
+
+, "Edit selected {0}"
+: "แก้ไข {0} ที่เลือก"
+
+, "New Lead"
 : ""
 
 , "Products"
 : "สินค้า"
 
+, "Product"
+: "สินค้า"
+
+, "Description"
+: "การอธิบาย"
+
+, "Price"
+: "ราคา"
+
+, "Quantity"
+: "จำนวน"
+
+, "Search for Products to add ..."
+: "ค้นหาสินค้าเพื่อเพิ่ม ..."
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: "หน้าที่"
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: ""
+
 , "You do not have the run right for the Sales application or it is not activated."
 : ""
 
+, "Lead, Leads"
+: [
+  ""
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : ""
 
-, "Description"
-: "การอธิบาย"
-
 , "Enter description"
 : "ใส่ คำอธิบาย"
 
@@ -272,37 +179,130 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
-: "สินค้า"
+, "Contact"
+: "การติดต่อ"
 
-, "Price"
-: "ราคา"
+, "CRM Role"
+: "หน้าที่ CRM"
 
-, "Quantity"
-: "จำนวน"
+, "Change type to Customer"
+: "เปลี่ยน ประเภทลูกค้า"
 
-, "Search for Products to add ..."
-: "ค้นหาสินค้าเพื่อเพิ่ม ..."
-
-, "All leads I have read grants for"
+, "Change type to Responsible"
 : ""
 
-, "Last modified by me"
-: "ปรับปรุงครั้งล่าสุด โดยฉัน"
-
-, "All leads that I have last modified"
+, "Change type to Partner"
 : ""
 
-, "My leads"
+, "Change contact type"
+: "เปลี่ยนประเภทการติดต่อ"
+
+, "Search for Contacts to add ..."
+: "ค้นหาการติดต่อเพื่อเพิ่ม ..."
+
+, "Name"
+: "ชื่อ"
+
+, "Address"
+: "ที่อยู่"
+
+, "Data"
+: "ข้อมูล"
+
+, "Cellphone"
+: "โทรศัพท์เคลื่อนที่"
+
+, "Role"
+: "หน้าที่"
+
+, "Please choose the Lead to add the contacts to"
 : ""
 
-, "All leads that I am responsible for"
+, "Please select the attenders' role"
 : ""
 
-, "Leads with overdue tasks"
+, "Select Lead"
+: ""
+
+, "Select Role"
+: "เลือก หน้าที่"
+
+, "Adding {0} contacts to lead"
+: ""
+
+, "No Tasks to display"
+: "ไม่มีหน้าที่ให้แสดง"
+
+, "Summary"
+: "ข้อสรุป"
+
+, "Add a task..."
+: "เพิ่มหน้าที่..."
+
+, "Due Date"
+: "วันครบกำหนด"
+
+, "Priority"
+: "ลำดับความสำคัญ"
+
+, "Percent"
+: "เปอร์เซนต์"
+
+, "Organizer"
+: ""
+
+, "All leads"
+: ""
+
+, "Default Lead List"
+: ""
+
+, "The default list for new leads"
+: ""
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: "ระดับของการกระทำที่คุณต้องการรับทราบ"
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: "ค่าที่ชอบหลัก"
+
+, "The default favorite which is loaded on crm startup"
+: ""
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
 : ""
 
 , "Lead States Available"
@@ -353,6 +353,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -371,6 +374,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: "ข้อมูลที่ดำเนินการ"
+
+, "End Scheduled"
+: ""
+
+, "Contacts"
+: "การติดต่อ"
+
+, "Telephone"
+: "โทรศัพท์"
+
+, "Email"
+: "อีเมล"
+
+, "low"
+: "ต่ำ"
+
+, "normal"
+: "ธรรมดา"
+
+, "high"
+: "สูง"
+
+, "urgent"
+: "ด่วน"
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: "หน้าที่"
+
 , "State"
 : ""
 
@@ -401,52 +461,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : ""
 
-, "Task"
-: "หน้าที่"
-
-, "Lead Data"
-: "ข้อมูลที่ดำเนินการ"
-
-, "End Scheduled"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "Contacts"
-: "การติดต่อ"
-
-, "Telephone"
-: "โทรศัพท์"
-
-, "Email"
-: "อีเมล"
-
-, "low"
-: "ต่ำ"
-
-, "normal"
-: "ธรรมดา"
-
-, "high"
-: "สูง"
-
-, "urgent"
-: "ด่วน"
-
-, "Lead CSV import"
+, "All leads I have read grants for"
 : ""
 
-, "Import list (###CURRENTDATE###)"
+, "Last modified by me"
+: "ปรับปรุงครั้งล่าสุด โดยฉัน"
+
+, "All leads that I have last modified"
 : ""
 
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+, "My leads"
 : ""
 
-, "Edit new lead"
+, "All leads that I am responsible for"
 : ""
 
-, "The following leads have just been imported into lead list %s"
-: ""
-
-, "%s new leads have been imported"
+, "Leads with overdue tasks"
 : ""
 
 , "manage shared lead folders"
