@@ -5,168 +5,13 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Crm **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "All leads"
-: ""
-
-, "Default Lead List"
-: ""
-
-, "The default list for new leads"
-: ""
-
-, "Get Notification E-mails"
-: ""
-
-, "The level of actions you want to be notified about."
-: ""
-
-, "Send Notifications e-mails for own actions"
-: ""
-
-, "Get notifications e-mails for actions you did yourself"
-: ""
-
-, "Send Notifications e-mails to responsible"
-: ""
-
-, "Get notifications e-mails for action to responsible"
-: ""
-
-, "Send Notifications e-mails to customer"
-: ""
-
-, "Get notifications e-mails for action to customer"
-: ""
-
-, "Send Notifications e-mails to partner"
-: ""
-
-, "Get notifications e-mails for action to partner"
-: ""
-
-, "Default Favorite"
-: ""
-
-, "The default favorite which is loaded on crm startup"
-: ""
-
-, "New Lead"
-: ""
-
-, "Tags"
-: ""
-
-, "Lead name"
-: "线索名"
-
-, "Responsible"
-: "负责人"
-
-, "Partner"
-: "伙伴"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Customer"
 : "客户"
 
-, "Leadstate"
-: "线索状态"
-
-, "Leadtype"
-: "线索类型"
-
-, "Leadsource"
-: "线索源"
-
-, "Probability"
-: "可能性"
-
-, "Turnover"
-: "周转"
-
-, "Estimated end"
-: "估计结束"
-
-, "Probable Turnover"
-: ""
-
-, "Resubmission Date"
-: ""
-
-, "Import leads"
-: ""
-
-, "Contact"
-: ""
-
-, "CRM Role"
-: ""
-
-, "Tasks"
-: "任务"
-
-, "No Tasks to display"
-: "没有任务要显示"
-
-, "Summary"
-: "摘要"
-
-, "Add a task..."
-: "添加任务..."
-
-, "Due Date"
-: "过期日期"
-
-, "Priority"
-: "优先"
-
-, "Percent"
-: "百分比"
-
-, "Status"
-: "状态"
-
-, "Organizer"
-: ""
-
-, "Add new {0}"
-: ""
-
-, "Unlink {0}"
-: ""
-
-, "Unlink selected {0}"
-: ""
-
-, "Edit {0}"
-: ""
-
-, "Edit selected {0}"
-: ""
-
-, "Please choose the Lead to add the contacts to"
-: ""
-
-, "Please select the attenders' role"
-: ""
-
-, "Lead, Leads"
-: [
-  ""
-
-]
-, "Select Lead"
-: ""
-
-, "Role"
-: "职务"
-
-, "Select Role"
-: ""
-
-, "Adding {0} contacts to lead"
-: ""
+, "Partner"
+: "伙伴"
 
 , "Phone"
 : "电话"
@@ -192,57 +37,119 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "City"
 : ""
 
+, "Status"
+: "状态"
+
 , "Start"
 : "开始"
 
-, "Change type to Customer"
-: "修改客户类型"
+, "Estimated end"
+: "估计结束"
 
-, "Change type to Responsible"
-: "修改负责人类型"
+, "Leadtype"
+: "线索类型"
 
-, "Change type to Partner"
-: "修改伙伴类型"
+, "Leadsource"
+: "线索源"
 
-, "Change contact type"
-: "修改联系人类型"
-
-, "Search for Contacts to add ..."
-: "搜索联系人添加到 ..."
-
-, "Name"
-: "姓名"
-
-, "Address"
-: "地址"
-
-, "Data"
+, "Tags"
 : ""
 
-, "Cellphone"
-: "手机"
+, "Lead name"
+: "线索名"
+
+, "Responsible"
+: "负责人"
+
+, "Leadstate"
+: "线索状态"
+
+, "Probability"
+: "可能性"
+
+, "Turnover"
+: "周转"
 
 , "End"
 : "结束"
 
-, "You do not have the run right for the Tasks application or it is not activated."
+, "Probable Turnover"
+: ""
+
+, "Resubmission Date"
+: ""
+
+, "Import leads"
+: ""
+
+, "Add new {0}"
+: ""
+
+, "Unlink {0}"
+: ""
+
+, "Unlink selected {0}"
+: ""
+
+, "Edit {0}"
+: ""
+
+, "Edit selected {0}"
+: ""
+
+, "New Lead"
 : ""
 
 , "Products"
 : "产品"
 
+, "Product"
+: ""
+
+, "Description"
+: "描述"
+
+, "Price"
+: "价格"
+
+, "Quantity"
+: ""
+
+, "Search for Products to add ..."
+: ""
+
+, "1"
+: ""
+
+, "Notifications are disabled"
+: ""
+
+, "Send Notification?"
+: ""
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: ""
+
+, "Tasks"
+: "任务"
+
+, "You do not have the run right for the Tasks application or it is not activated."
+: ""
+
 , "You do not have the run right for the Sales application or it is not activated."
 : ""
 
+, "Lead, Leads"
+: [
+  ""
+
+]
 , "Enter lead name"
 : ""
 
 , "Expected turnover"
 : "期望的周转"
 
-, "Description"
-: "描述"
-
 , "Enter description"
 : "输入描述"
 
@@ -272,37 +179,130 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "X Lead"
 : ""
 
+, "read-only"
+: ""
+
 , "Archived"
 : ""
 
-, "Product"
+, "Contact"
 : ""
 
-, "Price"
-: "价格"
-
-, "Quantity"
+, "CRM Role"
 : ""
 
-, "Search for Products to add ..."
+, "Change type to Customer"
+: "修改客户类型"
+
+, "Change type to Responsible"
+: "修改负责人类型"
+
+, "Change type to Partner"
+: "修改伙伴类型"
+
+, "Change contact type"
+: "修改联系人类型"
+
+, "Search for Contacts to add ..."
+: "搜索联系人添加到 ..."
+
+, "Name"
+: "姓名"
+
+, "Address"
+: "地址"
+
+, "Data"
 : ""
 
-, "All leads I have read grants for"
+, "Cellphone"
+: "手机"
+
+, "Role"
+: "职务"
+
+, "Please choose the Lead to add the contacts to"
 : ""
 
-, "Last modified by me"
+, "Please select the attenders' role"
 : ""
 
-, "All leads that I have last modified"
+, "Select Lead"
 : ""
 
-, "My leads"
+, "Select Role"
 : ""
 
-, "All leads that I am responsible for"
+, "Adding {0} contacts to lead"
 : ""
 
-, "Leads with overdue tasks"
+, "No Tasks to display"
+: "没有任务要显示"
+
+, "Summary"
+: "摘要"
+
+, "Add a task..."
+: "添加任务..."
+
+, "Due Date"
+: "过期日期"
+
+, "Priority"
+: "优先"
+
+, "Percent"
+: "百分比"
+
+, "Organizer"
+: ""
+
+, "All leads"
+: ""
+
+, "Default Lead List"
+: ""
+
+, "The default list for new leads"
+: ""
+
+, "Get Notification E-mails"
+: ""
+
+, "The level of actions you want to be notified about."
+: ""
+
+, "Send Notifications e-mails for own actions"
+: ""
+
+, "Get notifications e-mails for actions you did yourself"
+: ""
+
+, "Default Favorite"
+: ""
+
+, "The default favorite which is loaded on crm startup"
+: ""
+
+, "controls sending notification of Leads"
+: ""
+
+, "send notification)description"
+: ""
+
+, "send notification to all access container"
+: ""
+
+, "send notification to responsible"
+: ""
+
+, "send notification to responsible)description"
+: ""
+
+, "send notification to customer"
+: ""
+
+, "send notification to partner"
 : ""
 
 , "Lead States Available"
@@ -353,6 +353,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead Import"
 : ""
 
+, "Lead Notification Confirmation"
+: ""
+
 , "Add new task on lead import"
 : ""
 
@@ -371,6 +374,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
 : ""
 
+, "Lead Data"
+: "线索数据"
+
+, "End Scheduled"
+: "预计的结束"
+
+, "Contacts"
+: "联系人"
+
+, "Telephone"
+: "电话"
+
+, "Email"
+: "电子邮件"
+
+, "low"
+: "低"
+
+, "normal"
+: "正常"
+
+, "high"
+: "高"
+
+, "urgent"
+: "紧急"
+
+, "CSV all data"
+: ""
+
+, "Lead CSV import"
+: ""
+
+, "Import list (###CURRENTDATE###)"
+: ""
+
+, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+: ""
+
+, "Edit new lead"
+: ""
+
+, "The following leads have just been imported into lead list %s"
+: ""
+
+, "%s new leads have been imported"
+: ""
+
+, "GENDER_Lead"
+: ""
+
+, "Show Closed"
+: ""
+
+, "Task"
+: ""
+
 , "State"
 : "情形"
 
@@ -401,52 +461,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "Lead %s has been created"
 : "潜在客户 %s 已被创建"
 
-, "Task"
+, "This Lead state is set to read-only therefore updating this Lead is not possible."
 : ""
 
-, "Lead Data"
-: "线索数据"
-
-, "End Scheduled"
-: "预计的结束"
-
-, "Contacts"
-: "联系人"
-
-, "Telephone"
-: "电话"
-
-, "Email"
-: "电子邮件"
-
-, "low"
-: "低"
-
-, "normal"
-: "正常"
-
-, "high"
-: "高"
-
-, "urgent"
-: "紧急"
-
-, "Lead CSV import"
+, "All leads I have read grants for"
 : ""
 
-, "Import list (###CURRENTDATE###)"
+, "Last modified by me"
 : ""
 
-, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
+, "All leads that I have last modified"
 : ""
 
-, "Edit new lead"
+, "My leads"
 : ""
 
-, "The following leads have just been imported into lead list %s"
+, "All leads that I am responsible for"
 : ""
 
-, "%s new leads have been imported"
+, "Leads with overdue tasks"
 : ""
 
 , "manage shared lead folders"
