@@ -5,79 +5,28 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Felamimail **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "All inboxes"
+, "Can not combine \"allow external\" and \"allow only members\""
 : ""
 
-, "Default Email Account"
-: "Compte de correu electrònic per defecte"
+, "Delete"
+: "Elimina"
 
-, "The default email account to use when sending mails."
-: "Compte de correu electrònic a utilitzar per defecte per a l'enviament de correus."
+, "Reply"
+: "Respon"
 
-, "Mark Email Automatically As Read"
-: ""
+, "Reply To All"
+: "Respon a tots"
 
-, "Is email marked as read automatically or by user action"
-: ""
+, "Forward"
+: "Reenvia"
 
-, "Email Update Interval"
-: "Interval d'actualització de correu electrònic"
+, "Print Message"
+: "Imprimeix el missatge"
 
-, "How often should Felamimail check for new Emails (in minutes)."
-: ""
-
-, "Use for mailto links"
-: ""
-
-, "Use Felamimail in mailto links, otherwise use the default desktop client."
-: ""
-
-, "Use for NOTES"
-: "Utilitzeu per a NOTES"
-
-, "Save Note default Value."
-: "Desa el valor per defecte Nota."
-
-, "Confirm Delete"
-: "Confirma l'eliminació"
-
-, "Show confirmation dialog when deleting mails."
-: "Mostra un diàleg de confirmació quan s'eliminin correus electrònics."
-
-, ".eml file Attachment in forwarded mails"
-: ""
-
-, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
-: ""
-
-, "Message not available."
-: ""
-
-, "File Message"
-: ""
-
-, "Filemanager ..."
-: ""
-
-, "Attachment"
-: ""
-
-, "Download"
-: ""
-
-, "{messageCount, plural, one {Message was filed} other {# messages where filed}}"
-: ""
-
-, "Success"
-: ""
-
-, "Error"
-: ""
-
-, "File Messages as Attachment"
-: ""
+, "Print Preview"
+: "Previsualitza la impressió"
 
 , "Add New Account"
 : ""
@@ -85,6 +34,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Permissions"
 : ""
 
+, "Rules"
+: ""
+
+, "Vacation, Vacations"
+: [
+  ""
+ ,""
+
+]
 , "Account, Accounts"
 : [
   "Compte"
@@ -94,7 +52,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Account Name"
 : "Nom de compte"
 
-, "Account Type"
+, "Type"
+: ""
+
+, "Migration Approved"
+: ""
+
+, "Approve Migration"
+: ""
+
+, "Do you want to approve the migration of this account?"
 : ""
 
 , "User"
@@ -145,6 +112,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password"
 : "Contrasenya"
 
+, "Test IMAP Connection"
+: ""
+
 , "SMTP"
 : "SMTP"
 
@@ -166,6 +136,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password (optional)"
 : "Contrasenya (opcional)"
 
+, "Test SMTP Connection"
+: ""
+
 , "Sieve"
 : ""
 
@@ -175,6 +148,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Notification Email"
 : ""
 
+, "Auto-move notifications"
+: ""
+
+, "Auto-move notifications folder"
+: ""
+
 , "Other Settings"
 : "Altres paràmetres"
 
@@ -217,16 +196,22 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Reply-To Email"
 : ""
 
-, "Shared System Account"
+, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
 : ""
 
-, "Additional Personal System Account"
+, "Migration has not been approved."
 : ""
 
-, "Additional Personal External Account"
+, "It is not possible to convert the account to this type."
 : ""
 
-, "Default Personal System Account"
+, "System accounts cannot be created manually."
+: ""
+
+, "Mailinglist accounts cannot be created manually."
+: ""
+
+, "Account type change not possible"
 : ""
 
 , "E-Mail account needs a password"
@@ -244,52 +229,172 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "The grant edit the shared email account"
 : ""
 
-, "Click here to set To/CC/BCC."
+, "Send Mails"
 : ""
 
-, "To:"
-: "A:"
+, "The grant to send mails via the email account"
+: ""
 
-, "Cc:"
-: "Cc:"
+, "Warning"
+: ""
 
-, "Bcc:"
-: "Bcc:"
+, "Server connection failed. Do you still want to save this setting and exit?"
+: ""
 
-, "Remove"
-: "Elimina"
+, "Connection succeed"
+: ""
 
-, "Compose email"
+, "Connecting to {0} server..."
+: ""
+
+, "Connection failed"
+: ""
+
+, "{server} Connection Status"
+: ""
+
+, "Save Message as"
+: ""
+
+, "File (in Filemanager) ..."
+: ""
+
+, "Attachment (of Record)"
+: ""
+
+, "Download"
+: ""
+
+, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
+: ""
+
+, "Success"
+: ""
+
+, "Error"
+: ""
+
+, "Save Messages as Attachment"
+: ""
+
+, "No Messages found."
+: ""
+
+, "It is SPAM"
+: ""
+
+, "It is not SPAM"
+: ""
+
+, "Compose"
+: ""
+
+, "Toggle highlighting"
+: ""
+
+, "Mark read/unread"
+: "Marca com a llegit/no llegit"
+
+, "Move"
+: ""
+
+, "Copy"
+: ""
+
+, "Import Messages"
+: ""
+
+, "Add Account"
+: "Afegeix un compte"
+
+, "No target folder selected"
+: ""
+
+, "You need to select a target folder for the messages."
+: ""
+
+, "Wrong File Type"
+: ""
+
+, "Files of type eml allowed only."
+: ""
+
+, "Importing Messages..."
+: ""
+
+, "Id"
+: "Identificador"
+
+, "Attachments"
+: "Adjunts"
+
+, "Flags"
+: ""
+
+, "Subject"
+: "Assumpte"
+
+, "From (Email)"
+: ""
+
+, "From (Name)"
+: ""
+
+, "Sender"
 : ""
 
 , "To"
 : "A"
 
-, "CC"
+, "Sent"
+: "Enviat"
+
+, "Received"
+: "Rebut"
+
+, "Folder, Folders"
+: [
+  "Carpeta"
+ ,"Carpetes"
+
+]
+, "Size"
+: "Mida"
+
+, "Answered"
+: "Contestat"
+
+, "Forwarded"
+: "Reenviat"
+
+, "This message might be SPAM"
 : ""
 
-, "BCC"
+, "Tine20"
 : ""
 
-, "Mass Mailing"
+, "Encrypted Message"
 : ""
 
-, "Signatures"
+, "Filed as:"
 : ""
 
-, "Name"
+, "Select Message File Location"
 : ""
 
-, "Is Default"
+, "Filing Messages"
 : ""
 
-, "Add Signature"
+, "Error Filing Message"
 : ""
 
-, "Edit Signature"
+, "Could not file message."
 : ""
 
-, "Delete Signature"
+, "Send Reading Confirmation"
+: ""
+
+, "Do you want to send a reading confirmation message?"
 : ""
 
 , "Empty Folder"
@@ -301,12 +406,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "New {0}"
 : "Nou {0}"
 
-, "Folder, Folders"
-: [
-  "Carpeta"
- ,"Carpetes"
-
-]
 , "Please enter the name of the new {0}:"
 : "Introduïu el nom del nou {0}:"
 
@@ -340,27 +439,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Update Folder List"
 : ""
 
-, "Add as \"To\""
+, "Message not available."
 : ""
 
-, "Add as \"Cc\""
+, "Cancel"
 : ""
 
-, "Add as \"Bcc\""
+, "Ok"
 : ""
 
-, "Remove from recipients"
+, "Folders of account {0}"
 : ""
 
-, "Loading Mail Addresses"
+, "Folders of all accounts"
+: ""
+
+, "Compose email"
+: ""
+
+, "CC"
+: ""
+
+, "BCC"
+: ""
+
+, "Mass Mailing"
 : ""
 
 , "Open in Felamimail"
 : ""
 
-, "Subject"
-: "Assumpte"
-
 , "From"
 : "Des de"
 
@@ -376,12 +484,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Show or hide header information"
 : "Mostra o amaga la informació de capçalera"
 
-, "Attachments"
-: "Adjunts"
-
 , "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
 : ""
 
+, "Open"
+: ""
+
+, "Save As"
+: ""
+
+, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
+: ""
+
+, "Save as Record Attachment"
+: ""
+
+, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
+: ""
+
+, "Confirm SPAM Suspicion"
+: ""
+
+, "Yes, it is SPAM"
+: ""
+
+, "No, it is not"
+: ""
+
+, "(new message)"
+: ""
+
+, "Select recipients for \"{0}\""
+: ""
+
+, "Signatures"
+: ""
+
+, "Name"
+: ""
+
+, "Is Default"
+: ""
+
+, "Add Signature"
+: ""
+
+, "Edit Signature"
+: ""
+
+, "Delete Signature"
+: ""
+
 , "Recipient filter"
 : ""
 
@@ -391,105 +544,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "\"{0}\" recipients"
 : ""
 
-, "Total Messages:"
+, "Attachment"
 : ""
 
-, "Unread Messages:"
+, "Filemanager (Download link)"
 : ""
 
-, "Name on Server:"
+, "Filemanager (Download link, password)"
 : ""
 
-, "Last update:"
+, "Filemanager (Systemlink)"
 : ""
 
-, "Fetching messages... ({0} done)"
+, "Attachment Type"
 : ""
 
-, "{0} unread message, {0} unread messages"
-: [
-  ""
- ,""
-
-]
-, "(new message)"
+, "Click icon to change"
 : ""
 
-, "Select recipients for \"{0}\""
+, "name"
 : ""
 
-, "Mailvelope decryption Error [{0}]"
+, "size"
 : ""
 
-, "To decrypt this message please install {0} with API support enabled"
+, "type"
 : ""
 
-, "PGP encrypted Message"
+, "Vacation Message for {0}"
 : ""
 
-, "Delete"
-: "Elimina"
-
-, "Reply"
-: "Respon"
-
-, "Reply To All"
-: "Respon a tots"
-
-, "Forward"
-: "Reenvia"
-
-, "Print Message"
-: "Imprimeix el missatge"
-
-, "Print Preview"
-: "Previsualitza la impressió"
-
 , "Notification for {0}"
 : ""
 
-, "Edit Filter Rule"
-: ""
-
-, "Apply filter if"
-: ""
-
-, "all conditions match"
-: ""
-
-, "any condition matches"
-: ""
-
-, "Do this action:"
-: ""
-
-, "Keep a copy"
-: ""
-
-, "Move mail to folder"
-: ""
-
-, "Redirect mail to address"
-: ""
-
-, "Reject mail with this text"
-: ""
-
-, "Discard mail"
-: ""
-
-, "Auto-Reply mail with this text"
-: ""
-
-, "Keep mail"
-: ""
-
-, "Sieve Filter Rules"
-: ""
-
-, "Sieve Filter Rules for {0}"
-: ""
-
 , "Move up"
 : ""
 
@@ -511,6 +598,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Action"
 : ""
 
+, "Keep a copy"
+: ""
+
 , "is greater than"
 : ""
 
@@ -523,7 +613,64 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Header \"{0}\" matches \"{1}\""
 : ""
 
-, "Vacation Message for {0}"
+, "Sieve Filter Rules"
+: ""
+
+, "Sieve Filter Rules for {0}"
+: ""
+
+, "From (Email and Name)"
+: ""
+
+, "To (Email)"
+: ""
+
+, "To (Email CC)"
+: ""
+
+, "Header contains"
+: ""
+
+, "Header name"
+: ""
+
+, "Header value"
+: ""
+
+, "Header regex"
+: ""
+
+, "Edit Filter Rule"
+: ""
+
+, "Apply filter if"
+: ""
+
+, "all conditions match"
+: ""
+
+, "any condition matches"
+: ""
+
+, "Do this action:"
+: ""
+
+, "Move mail to folder"
+: ""
+
+, "Redirect mail to address"
+: ""
+
+, "Reject mail with this text"
+: ""
+
+, "Discard mail"
+: ""
+
+, "Auto-Reply mail with this text"
+: ""
+
+, "Keep mail"
 : ""
 
 , "General"
@@ -577,63 +724,189 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Choose Template ..."
 : ""
 
-, "From (Email)"
+, "Mailvelope decryption Error [{0}]"
 : ""
 
-, "From (Email and Name)"
+, "To decrypt this message please install {0} with API support enabled"
 : ""
 
-, "To (Email)"
+, "PGP encrypted Message"
 : ""
 
-, "To (Email CC)"
+, "GENDER_Message"
 : ""
 
-, "Size"
-: "Mida"
+, "Message, Messages"
+: [
+  "Missatge"
+ ,"Missatges"
 
-, "Header contains"
+]
+, "Subject/From"
+: "Assumpte/Des de"
+
+, "Cc"
+: "Cc"
+
+, "Bcc"
+: "Bcc"
+
+, "INBOX"
 : ""
 
-, "Header name"
+, "Drafts"
 : ""
 
-, "Header value"
+, "Templates"
 : ""
 
-, "Header regex"
+, "Junk"
 : ""
 
-, "Filemanager (Download link)"
+, "Trash"
 : ""
 
-, "Filemanager (Download link, password)"
+, "GENDER_Folder"
 : ""
 
-, "Filemanager (Systemlink)"
+, "record list, record lists"
+: [
+  "llista de registres"
+ ,"llistes de registres"
+
+]
+, "Rule, Rules"
+: [
+  ""
+ ,""
+
+]
+, "Flag, Flags"
+: [
+  ""
+ ,""
+
+]
+, "Flag list, Flag lists"
+: [
+  ""
+ ,""
+
+]
+, "Total Messages:"
 : ""
 
-, "Attachment Type"
+, "Unread Messages:"
 : ""
 
-, "Click icon to change"
+, "Name on Server:"
 : ""
 
-, "name"
+, "Last update:"
 : ""
 
-, "size"
+, "Fetching messages... ({0} done)"
 : ""
 
-, "type"
+, "{0} unread message, {0} unread messages"
+: [
+  ""
+ ,""
+
+]
+, "New Mail"
 : ""
 
-, "Failure"
+, "Email"
+: "Correu electrònic"
+
+, "Active Vacation Message"
 : ""
 
-, "This file is already attached to this record."
+, "Email account \"{0}\" has an active vacation message."
 : ""
 
+, "Poll URL: {0}"
+: ""
+
+, "{0} as default mailer"
+: ""
+
+, "New mails"
+: "Nous correus"
+
+, "You got {0} new mail(s) in folder {1} ({2})."
+: ""
+
+, "IMAP Credentials for {0}"
+: "Credencials IMAP per a {0}"
+
+, "Credentials"
+: "Credencials"
+
+, "IMAP Error"
+: ""
+
+, "No connection to IMAP server."
+: "Sense connexió amb el servidor IMAP."
+
+, "IMAP Credentials Error"
+: ""
+
+, "Your email credentials are wrong. Please contact your administrator"
+: ""
+
+, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
+: ""
+
+, "SMTP Error"
+: ""
+
+, "No connection to SMTP server."
+: ""
+
+, "Sieve Error"
+: ""
+
+, "No connection to Sieve server."
+: ""
+
+, "Save Sieve Script Error"
+: ""
+
+, "Could not save script on Sieve server."
+: ""
+
+, "Add as \"To\""
+: ""
+
+, "Add as \"Cc\""
+: ""
+
+, "Add as \"Bcc\""
+: ""
+
+, "Remove from recipients"
+: ""
+
+, "Loading Mail Addresses"
+: ""
+
+, "Click here to set To/CC/BCC."
+: ""
+
+, "To:"
+: "A:"
+
+, "Cc:"
+: "Cc:"
+
+, "Bcc:"
+: "Bcc:"
+
+, "Remove"
+: "Elimina"
+
 , "Send"
 : "Envia"
 
@@ -714,13 +987,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 
 , "Signature, Signatures"
 : [
-  "Signatura"
- ,"Signatura"
+  ""
+ ,""
 
 ]
-, "Warning"
-: ""
-
 , "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
 : ""
 
@@ -736,229 +1006,82 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "No recipients set."
 : ""
 
+, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
+: ""
+
 , "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
 : ""
 
-, "Message, Messages"
-: [
-  "Missatge"
- ,"Missatges"
-
-]
-, "Subject/From"
-: "Assumpte/Des de"
-
-, "From (Name)"
+, "All inboxes"
 : ""
 
-, "Cc"
-: "Cc"
+, "Default Email Account"
+: "Compte de correu electrònic per defecte"
 
-, "Bcc"
-: "Bcc"
+, "The default email account to use when sending mails."
+: "Compte de correu electrònic a utilitzar per defecte per a l'enviament de correus."
 
-, "Flags"
+, "Mark Email Automatically As Read"
 : ""
 
-, "Received"
-: "Rebut"
-
-, "INBOX"
+, "Is email marked as read automatically or by user action"
 : ""
 
-, "Drafts"
+, "Email Update Interval"
+: "Interval d'actualització de correu electrònic"
+
+, "How often should Felamimail check for new Emails (in minutes)."
 : ""
 
-, "Sent"
-: "Enviat"
-
-, "Templates"
+, "Use for mailto links"
 : ""
 
-, "Junk"
+, "Use Felamimail in mailto links, otherwise use the default desktop client."
 : ""
 
-, "Trash"
+, "Use for NOTES"
+: "Utilitzeu per a NOTES"
+
+, "Save Note default Value."
+: "Desa el valor per defecte Nota."
+
+, "Confirm Delete"
+: "Confirma l'eliminació"
+
+, "Show confirmation dialog when deleting mails."
+: "Mostra un diàleg de confirmació quan s'eliminin correus electrònics."
+
+, ".eml file Attachment in forwarded mails"
 : ""
 
-, "record list, record lists"
-: [
-  "llista de registres"
- ,"llistes de registres"
-
-]
-, "Vacation, Vacations"
-: [
-  ""
- ,""
-
-]
-, "Rule, Rules"
-: [
-  ""
- ,""
-
-]
-, "Flag, Flags"
-: [
-  ""
- ,""
-
-]
-, "Flag list, Flag lists"
-: [
-  ""
- ,""
-
-]
-, "No Messages found."
+, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
 : ""
 
-, "Compose"
+, "Default Font"
 : ""
 
-, "Toggle highlighting"
+, "Setting the default font in the E-Mail app"
 : ""
 
-, "Mark read/unread"
-: "Marca com a llegit/no llegit"
-
-, "Move"
+, "Mail Type"
 : ""
 
-, "Add Account"
-: "Afegeix un compte"
-
-, "Id"
-: "Identificador"
-
-, "Sender"
+, "Possible mail types."
 : ""
 
-, "Answered"
-: "Contestat"
-
-, "Forwarded"
-: "Reenviat"
-
-, "Tine20"
+, "Additional Personal External Account"
 : ""
 
-, "Filed as:"
+, "Shared System Account"
 : ""
 
-, "Select Message File Location"
+, "Additional Personal System Account"
 : ""
 
-, "Filing Messages"
+, "Default Personal System Account"
 : ""
 
-, "Error Filing Message"
-: ""
-
-, "Could not file message."
-: ""
-
-, "Send Reading Confirmation"
-: ""
-
-, "Do you want to send a reading confirmation message?"
-: ""
-
-, "New Mail"
-: ""
-
-, "Email"
-: "Correu electrònic"
-
-, "Active Vacation Message"
-: ""
-
-, "Email account \"{0}\" has an active vacation message."
-: ""
-
-, "Poll URL: {0}"
-: ""
-
-, "{0} as default mailer"
-: ""
-
-, "New mails"
-: "Nous correus"
-
-, "You got {0} new mail(s) in folder {1} ({2})."
-: ""
-
-, "IMAP Credentials for {0}"
-: "Credencials IMAP per a {0}"
-
-, "Credentials"
-: "Credencials"
-
-, "IMAP Error"
-: ""
-
-, "No connection to IMAP server."
-: "Sense connexió amb el servidor IMAP."
-
-, "IMAP Credentials Error"
-: ""
-
-, "Your email credentials are wrong. Please contact your administrator"
-: ""
-
-, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
-: ""
-
-, "SMTP Error"
-: ""
-
-, "No connection to SMTP server."
-: ""
-
-, "Sieve Error"
-: ""
-
-, "No connection to Sieve server."
-: ""
-
-, "Save Sieve Script Error"
-: ""
-
-, "Could not save script on Sieve server."
-: ""
-
-, "Cancel"
-: ""
-
-, "Ok"
-: ""
-
-, "Folders of account {0}"
-: ""
-
-, "Folders of all accounts"
-: ""
-
-, "All inboxes of my email accounts"
-: ""
-
-, "All unread mail"
-: ""
-
-, "All unread mail of my email accounts"
-: ""
-
-, "All highlighted mail"
-: ""
-
-, "All highlighted mail of my email accounts"
-: ""
-
-, "All drafts"
-: ""
-
-, "All mails with the draft flag"
+, "Mailinglist"
 : ""
 
 , "Mailinglist Reject Reason"
@@ -988,12 +1111,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Delete Archived Mail"
 : ""
 
+, "Prevent copying mails in the same account"
+: ""
+
 , "Enabled Features"
 : ""
 
 , "Enabled Features in Felamimail Application."
 : ""
 
+, "Account Migration"
+: ""
+
+, "Shows context menu for system accounts to approve migration"
+: ""
+
+, "Move notifications"
+: ""
+
+, "Move notifications to a subfolder via sieve"
+: ""
+
+, "Auto-Save Drafts"
+: ""
+
+, "Save drafts automatically while editing an email"
+: ""
+
+, "Only password download link"
+: ""
+
+, "Allow only password download link"
+: ""
+
 , "Tine 2.0 Flag"
 : ""
 
@@ -1012,6 +1162,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create template, trash, sent, draft and junks folders for system accounts"
 : ""
 
+, "Enable Spam Suspicion Strategy"
+: ""
+
+, "SEnable pam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy Config"
+: ""
+
+, "Spam User Processing Pipeline"
+: ""
+
+, "Confirm SPAM Suspicion Message"
+: ""
+
+, "Message for users when they press the info button in a SPAM suspicion toolbar."
+: ""
+
 , "Filter E-Mail URIs"
 : ""
 
@@ -1054,91 +1225,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "shared / adb_list accounts need to have a password set"
 : ""
 
-, "shared / adb_list accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an user_id set"
-: ""
-
-, "Seen"
-: ""
-
-, "Deleted"
-: ""
-
-, "Draft"
-: ""
-
-, "Flagged"
-: ""
-
-, "Bad recipient address syntax"
-: ""
-
-, "Recipient address rejected"
-: ""
-
-, "Invalid address format"
-: ""
-
-, "Error: %s"
-: ""
-
-, "Could not send message"
-: ""
-
-, "My Mail Download Links"
-: ""
-
-, "Out of Office reply from %1$s"
-: ""
-
-, "You have new mail from "
-: ""
-
-, "Can not combine \"allow external\" and \"allow only members\""
-: ""
-
-, "Message File Suggestion, Message File Suggestions"
-: [
-  ""
- ,""
-
-]
-, "Message File Suggestions"
-: ""
-
-, "Message File Location, Message File Locations"
-: [
-  ""
- ,""
-
-]
-, "Message File Locations"
-: ""
-
-, "Message ID Hash"
-: ""
-
-, "Message ID"
-: ""
-
-, "Model"
-: ""
-
-, "Record ID"
-: ""
-
-, "Record Title"
-: ""
-
-, "Node ID"
-: ""
-
-, "Type"
+, "Is default"
 : ""
 
 , "Email Account, Email Accounts"
@@ -1213,7 +1300,163 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "on"
 : ""
 
-, "Is default"
+, "Message File Location, Message File Locations"
+: [
+  ""
+ ,""
+
+]
+, "Message File Locations"
+: ""
+
+, "Message ID Hash"
+: ""
+
+, "Message ID"
+: ""
+
+, "Model"
+: ""
+
+, "Record ID"
+: ""
+
+, "Record Title"
+: ""
+
+, "Node ID"
+: ""
+
+, "Message File Suggestion, Message File Suggestions"
+: [
+  ""
+ ,""
+
+]
+, "Message File Suggestions"
+: ""
+
+, "Out of Office reply from %1$s"
+: ""
+
+, "It is not allowed to redirect emails to self! Please change the recipient."
+: ""
+
+, "Redirects to external email domains are not allowed."
+: ""
+
+, "You have new mail from "
+: ""
+
+, "shared / adb_list accounts need to have an email set"
+: ""
+
+, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
+: ""
+
+, "userInternal accounts need to have an email set"
+: ""
+
+, "userInternal accounts need to have an user_id set"
+: ""
+
+, "Please choose a new email address for userInternal accounts"
+: ""
+
+, "system account for user does not exist"
+: ""
+
+, "Account type cannot be changed from {0} to {1}"
+: ""
+
+, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
+: ""
+
+, "Migration of this account has not been approved!"
+: ""
+
+, "Could not find email user xprops!"
+: ""
+
+, "Internal user accounts need a valid user"
+: ""
+
+, "System account of user is missing"
+: ""
+
+, "Bad recipient address syntax"
+: ""
+
+, "Recipient address rejected"
+: ""
+
+, "Original message not found, email was moved or deleted"
+: ""
+
+, "Invalid address format"
+: ""
+
+, "Error: %s"
+: ""
+
+, "Could not send message"
+: ""
+
+, "My Mail Download Links"
+: ""
+
+, "Seen"
+: ""
+
+, "Deleted"
+: ""
+
+, "Draft"
+: ""
+
+, "Flagged"
+: ""
+
+, "It is not allowed to copy e-mails in the same account."
+: ""
+
+, "Folder with name {0} already exists!"
+: ""
+
+, "Failure on create folder"
+: ""
+
+, "All inboxes of my email accounts"
+: ""
+
+, "All unread mail"
+: ""
+
+, "All unread mail of my email accounts"
+: ""
+
+, "All highlighted mail"
+: ""
+
+, "All highlighted mail of my email accounts"
+: ""
+
+, "All drafts"
+: ""
+
+, "All mails with the draft flag"
+: ""
+
+, "IMAP Hostname missing"
+: ""
+
+, "IMAP Credentials missing"
+: ""
+
+, "SMTP Hostname missing"
+: ""
+
+, "SMTP Credentials missing"
 : ""
 
 , "manage email accounts"
@@ -1228,6 +1471,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create new email accounts"
 : "Crea noves comptes de correu electrònic"
 
+, "Vacation"
+: ""
 
 , "Account"
 : "Compte"
@@ -1235,21 +1480,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Folder"
 : "Carpeta"
 
-, "{0} unread message"
-: ""
-
-, "Signature"
-: "Signatura"
-
 , "Message"
 : "Missatge"
 
 , "record list"
 : "llista de registres"
 
-, "Vacation"
-: ""
-
 , "Rule"
 : ""
 
@@ -1259,15 +1495,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Flag list"
 : ""
 
-, "Message File Suggestion"
+, "{0} unread message"
 : ""
 
-, "Message File Location"
+, "Signature"
 : ""
 
 , "Email Account"
 : ""
 
+, "Message File Location"
+: ""
+
+, "Message File Suggestion"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
