@@ -20,10 +20,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 : "Gemeinsame Konten benötigen eine E-Mail-Adresse"
 
 , "userInternal accounts need to have an email set"
-: "Das persönliche Systemkonto benötigen eine E-Mail-Adresse"
+: "Das persönliche Systemkonto benötigt eine E-Mail-Adresse"
 
-, "userInternal accounts need to have an user_id set"
-: "Das persönliche Systemkonto benötigen eine User-ID"
+, "Internal user accounts need a valid user"
+: "Das persönliche Systemkonto benötigt einen validen Benutzer"
 
 , "Migration of this account has not been approved!"
 : "Die Migration dieses Kontos wurde nicht freigegeben!"
@@ -796,6 +796,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "User Name (From)"
 : "E-Mail Absender"
 
+, "User Name (From) cannot contain a comma."
+: "E-Mail Absender darf kein Komma enthalten"
+
 , "Signature position"
 : "Signaturposition"
 
@@ -1288,8 +1291,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Save as Record Attachment"
 : "Als Datensatz Anhang speichern"
 
-, "Folder with this name already exists!"
-: "Ordner mit dem Namen ist bereits vorhanden!"
+, "Folder with name {0} already exists!"
+: "Ordner mit dem Namen {0} ist bereits vorhanden!"
 
 , "Failure on create folder"
 : "Fehler beim anlegen des Ordners"
@@ -1393,24 +1396,84 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Your %1$s Team"
 : "Ihr %1$s Team"
 
-, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
-: "Massen-Mails werden nicht an die eingetragenen CC und/oder BCC Empfänger geschickt. Bitte entfernen Sie diese."
+, "Internal user accounts need an email address"
+: "Interne Benutzerkonten brauchen eine E-Mail-Adresse"
 
-, "Internal user accounts need a valid user"
-: "Das persönliche Systemkonto benötigt einen validen Benutzer"
+, "Internal user accounts need to be assigned to a user"
+: "Interne Benutzerkonten müssen einer Nutzer:in zugeordnet sein"
 
-, "IMAP Credentials missing"
-: "IMAP Zugangsdaten fehlen"
+, "Import Messages"
+: "Nachrichten importieren"
 
-, "SMTP Credentials missing"
-: "SMTP Zugangsdaten fehlen"
+, "No target folder selected"
+: "Kein Zielordner ausgewählt"
+
+, "You need to select a target folder for the messages."
+: "Sie müssen einen Zielordner für die Nachrichten auswählen."
+
+, "Wrong File Type"
+: "Falscher Dateityp"
+
+, "Files of type eml allowed only."
+: "Nur Dateien vom Typ eml sind erlaubt."
+
+, "Importing Messages..."
+: "Importiere Nachrichten..."
+
+, "Attachment"
+: "Anhang"
+
+, "GENDER_Folder"
+: "male"
+
+, "Attention"
+: "Achtung"
+
+, "The from-address for this mail got changed to {0} , as you don't have the send mail right for the account {1}."
+: "Die Absender-Adresse für diese Mail wurde auf : {0} geändert, \n da sie für das Konto : {1} nicht das E-Mail Versenden Recht haben."
+
+, "Only password download link"
+: "Nur passwortgeschützter Download Link"
+
+, "userInternal accounts need to have an user_id set"
+: "Das persönliche Systemkonto benötigen eine User-ID"
+
+, "Original message not found, email was moved or deleted"
+: "Die ursprüngliche Nachricht wurde nicht gefunden, die E-Mail wurde verschoben oder gelöscht."
 
 , "IMAP Hostname missing"
 : "IMAP Hostname fehlt"
 
+, "IMAP Credentials missing"
+: "IMAP Zugangsdaten fehlen"
+
 , "SMTP Hostname missing"
 : "SMTP Hostname fehlt"
 
+, "SMTP Credentials missing"
+: "SMTP Zugangsdaten fehlen"
+
+, "Allow only password download links"
+: "Nur passwortgeschützter Download Link erlaubt"
+
+, "Folder with this name already exists!"
+: "Ordner mit dem Namen ist bereits vorhanden!"
+
+, "Manage personal email accounts"
+: "Persönliche Konten verwalten"
+
+, "Edit and delete personal email accounts"
+: "Bearbeiten und Löschen von persönlichen Konten"
+
+, "Add personal email accounts"
+: "Persönliche Konten hinzufügen"
+
+, "Create new personal email accounts"
+: "Neue persönliche Konten hinzufügen"
+
+, "Explore Sieve script"
+: "Sieve-Skript anzeigen"
+
 , "Signature"
 : "Signatur"
 
