@@ -5,79 +5,28 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Felamimail **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "All inboxes"
-: "Todas las Bandejas de Entrada"
-
-, "Default Email Account"
-: "Dirección de correo por defecto"
-
-, "The default email account to use when sending mails."
-: "La Cuenta de Correo por defecto a utilizar para el envío de correos."
-
-, "Mark Email Automatically As Read"
+, "Can not combine \"allow external\" and \"allow only members\""
 : ""
 
-, "Is email marked as read automatically or by user action"
-: ""
+, "Delete"
+: "Borrar"
 
-, "Email Update Interval"
-: "Intervalo de actualización del Email"
+, "Reply"
+: "Contestar"
 
-, "How often should Felamimail check for new Emails (in minutes)."
-: "Frecuencia para comprobar nuevos correos (en minutos)."
+, "Reply To All"
+: "Contestar a todos"
 
-, "Use for mailto links"
-: "Usar para enlaces mailto"
+, "Forward"
+: "Reenviar"
 
-, "Use Felamimail in mailto links, otherwise use the default desktop client."
-: ""
+, "Print Message"
+: "Imprimir Mensaje"
 
-, "Use for NOTES"
-: "Usar para Notas"
-
-, "Save Note default Value."
-: "Guardar Valor por defecto de la Nota."
-
-, "Confirm Delete"
-: "Confirmar Borrado"
-
-, "Show confirmation dialog when deleting mails."
-: "Mostrar diálogo de confirmación al Eliminar correos"
-
-, ".eml file Attachment in forwarded mails"
-: ""
-
-, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
-: ""
-
-, "Message not available."
-: "Mensaje no disponible"
-
-, "File Message"
-: ""
-
-, "Filemanager ..."
-: ""
-
-, "Attachment"
-: ""
-
-, "Download"
-: ""
-
-, "{messageCount, plural, one {Message was filed} other {# messages where filed}}"
-: ""
-
-, "Success"
-: ""
-
-, "Error"
-: ""
-
-, "File Messages as Attachment"
-: ""
+, "Print Preview"
+: "Imprimir previsualización"
 
 , "Add New Account"
 : ""
@@ -85,6 +34,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Permissions"
 : ""
 
+, "Rules"
+: ""
+
+, "Vacation, Vacations"
+: [
+  "Vacaciones"
+ ,"Vacaciones"
+
+]
 , "Account, Accounts"
 : [
   "Cuenta"
@@ -94,7 +52,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Account Name"
 : "Nombre de la Cuenta"
 
-, "Account Type"
+, "Type"
+: ""
+
+, "Migration Approved"
+: ""
+
+, "Approve Migration"
+: ""
+
+, "Do you want to approve the migration of this account?"
 : ""
 
 , "User"
@@ -145,6 +112,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password"
 : "Contraseña"
 
+, "Test IMAP Connection"
+: ""
+
 , "SMTP"
 : "SMTP"
 
@@ -166,6 +136,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password (optional)"
 : "Contraseña (opcional)"
 
+, "Test SMTP Connection"
+: ""
+
 , "Sieve"
 : "Umbral"
 
@@ -175,6 +148,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Notification Email"
 : ""
 
+, "Auto-move notifications"
+: ""
+
+, "Auto-move notifications folder"
+: ""
+
 , "Other Settings"
 : "Otras Preferencias"
 
@@ -217,16 +196,22 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Reply-To Email"
 : ""
 
-, "Shared System Account"
+, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
 : ""
 
-, "Additional Personal System Account"
+, "Migration has not been approved."
 : ""
 
-, "Additional Personal External Account"
+, "It is not possible to convert the account to this type."
 : ""
 
-, "Default Personal System Account"
+, "System accounts cannot be created manually."
+: ""
+
+, "Mailinglist accounts cannot be created manually."
+: ""
+
+, "Account type change not possible"
 : ""
 
 , "E-Mail account needs a password"
@@ -244,53 +229,173 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "The grant edit the shared email account"
 : ""
 
-, "Click here to set To/CC/BCC."
-: "Click aquí para configurar Para/Cc/Cco"
+, "Send Mails"
+: ""
 
-, "To:"
-: "Para:"
+, "The grant to send mails via the email account"
+: ""
 
-, "Cc:"
-: "Cc:"
+, "Warning"
+: ""
 
-, "Bcc:"
-: "Bcc:"
+, "Server connection failed. Do you still want to save this setting and exit?"
+: ""
 
-, "Remove"
-: "Eliminar"
+, "Connection succeed"
+: ""
 
-, "Compose email"
-: "Redactar email"
+, "Connecting to {0} server..."
+: ""
+
+, "Connection failed"
+: ""
+
+, "{server} Connection Status"
+: ""
+
+, "Save Message as"
+: ""
+
+, "File (in Filemanager) ..."
+: ""
+
+, "Attachment (of Record)"
+: ""
+
+, "Download"
+: ""
+
+, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
+: ""
+
+, "Success"
+: ""
+
+, "Error"
+: ""
+
+, "Save Messages as Attachment"
+: ""
+
+, "No Messages found."
+: ""
+
+, "It is SPAM"
+: ""
+
+, "It is not SPAM"
+: ""
+
+, "Compose"
+: "Redactar"
+
+, "Toggle highlighting"
+: "Cambiar seleccion"
+
+, "Mark read/unread"
+: "Marcar leído/no leído"
+
+, "Move"
+: ""
+
+, "Copy"
+: ""
+
+, "Import Messages"
+: ""
+
+, "Add Account"
+: "Añadir Cuenta"
+
+, "No target folder selected"
+: ""
+
+, "You need to select a target folder for the messages."
+: ""
+
+, "Wrong File Type"
+: ""
+
+, "Files of type eml allowed only."
+: ""
+
+, "Importing Messages..."
+: ""
+
+, "Id"
+: "Id"
+
+, "Attachments"
+: "Adjuntos"
+
+, "Flags"
+: "Banderas"
+
+, "Subject"
+: "Asunto"
+
+, "From (Email)"
+: "De (Email)"
+
+, "From (Name)"
+: "De (Nombre)"
+
+, "Sender"
+: "Remitente"
 
 , "To"
 : "Para"
 
-, "CC"
+, "Sent"
+: "Enviado"
+
+, "Received"
+: "Recibido"
+
+, "Folder, Folders"
+: [
+  "Carpeta"
+ ,"Carpetas"
+
+]
+, "Size"
+: "Tamaño"
+
+, "Answered"
+: "Contestado"
+
+, "Forwarded"
+: "Reenviado"
+
+, "This message might be SPAM"
 : ""
 
-, "BCC"
+, "Tine20"
 : ""
 
-, "Mass Mailing"
+, "Encrypted Message"
 : ""
 
-, "Signatures"
+, "Filed as:"
 : ""
 
-, "Name"
+, "Select Message File Location"
 : ""
 
-, "Is Default"
+, "Filing Messages"
 : ""
 
-, "Add Signature"
+, "Error Filing Message"
 : ""
 
-, "Edit Signature"
+, "Could not file message."
 : ""
 
-, "Delete Signature"
-: ""
+, "Send Reading Confirmation"
+: "Enviar Confirmación de Lectura"
+
+, "Do you want to send a reading confirmation message?"
+: "¿Desea enviar un mensaje de confirmación de lectura?"
 
 , "Empty Folder"
 : "Vaciar Carpeta"
@@ -301,12 +406,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "New {0}"
 : "Nueva {0}"
 
-, "Folder, Folders"
-: [
-  "Carpeta"
- ,"Carpetas"
-
-]
 , "Please enter the name of the new {0}:"
 : "Ingresar el nombre del nuevo {0}:"
 
@@ -340,27 +439,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Update Folder List"
 : "Actualizar lista de carpetas"
 
-, "Add as \"To\""
-: "Agregar a \"Para\""
+, "Message not available."
+: "Mensaje no disponible"
 
-, "Add as \"Cc\""
-: "Agregar a \"Cc\""
+, "Cancel"
+: "Cancelar"
 
-, "Add as \"Bcc\""
-: "Agregar a \"Cco\""
+, "Ok"
+: "Aceptar"
 
-, "Remove from recipients"
-: "Eliminar de destinatarios"
+, "Folders of account {0}"
+: "Carpetas de la Cuenta {0}"
 
-, "Loading Mail Addresses"
-: "Cargando Dirección de Correo"
+, "Folders of all accounts"
+: "Carpetas de todas las Cuentas"
+
+, "Compose email"
+: "Redactar email"
+
+, "CC"
+: ""
+
+, "BCC"
+: ""
+
+, "Mass Mailing"
+: ""
 
 , "Open in Felamimail"
 : ""
 
-, "Subject"
-: "Asunto"
-
 , "From"
 : "De"
 
@@ -376,12 +484,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Show or hide header information"
 : "Mostrar / Ocultar la información del Encabezado"
 
-, "Attachments"
-: "Adjuntos"
-
 , "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
 : ""
 
+, "Open"
+: ""
+
+, "Save As"
+: ""
+
+, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
+: ""
+
+, "Save as Record Attachment"
+: ""
+
+, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
+: ""
+
+, "Confirm SPAM Suspicion"
+: ""
+
+, "Yes, it is SPAM"
+: ""
+
+, "No, it is not"
+: ""
+
+, "(new message)"
+: "(nuevo mensaje)"
+
+, "Select recipients for \"{0}\""
+: "Selecionar destinaratios para \"{0}\""
+
+, "Signatures"
+: ""
+
+, "Name"
+: ""
+
+, "Is Default"
+: ""
+
+, "Add Signature"
+: ""
+
+, "Edit Signature"
+: ""
+
+, "Delete Signature"
+: ""
+
 , "Recipient filter"
 : "Filtro de Destinatarios"
 
@@ -391,105 +544,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "\"{0}\" recipients"
 : "\"{0}\" Destinatarios"
 
-, "Total Messages:"
-: "Total de Mensajes:"
-
-, "Unread Messages:"
-: "Mensajes sin leer:"
-
-, "Name on Server:"
-: "Nombre en el Servidor:"
-
-, "Last update:"
-: "Última actualización:"
-
-, "Fetching messages... ({0} done)"
+, "Attachment"
 : ""
 
-, "{0} unread message, {0} unread messages"
-: [
-  "{0} mensaje Sin Leer"
- ,"{0} mensajes Sin Leer"
-
-]
-, "(new message)"
-: "(nuevo mensaje)"
-
-, "Select recipients for \"{0}\""
-: "Selecionar destinaratios para \"{0}\""
-
-, "Mailvelope decryption Error [{0}]"
+, "Filemanager (Download link)"
 : ""
 
-, "To decrypt this message please install {0} with API support enabled"
+, "Filemanager (Download link, password)"
 : ""
 
-, "PGP encrypted Message"
+, "Filemanager (Systemlink)"
 : ""
 
-, "Delete"
-: "Borrar"
+, "Attachment Type"
+: ""
 
-, "Reply"
-: "Contestar"
+, "Click icon to change"
+: ""
 
-, "Reply To All"
-: "Contestar a todos"
+, "name"
+: ""
 
-, "Forward"
-: "Reenviar"
+, "size"
+: ""
 
-, "Print Message"
-: "Imprimir Mensaje"
+, "type"
+: ""
 
-, "Print Preview"
-: "Imprimir previsualización"
+, "Vacation Message for {0}"
+: "Mensaje de Fuera de Oficina para {0}"
 
 , "Notification for {0}"
 : ""
 
-, "Edit Filter Rule"
-: "Editar Regla de Filtrado"
-
-, "Apply filter if"
-: "Aplicar filtro si"
-
-, "all conditions match"
-: ""
-
-, "any condition matches"
-: ""
-
-, "Do this action:"
-: "Realizar la siguiente acción:"
-
-, "Keep a copy"
-: ""
-
-, "Move mail to folder"
-: "Mover correo a la carpeta"
-
-, "Redirect mail to address"
-: "Reenviar correo a"
-
-, "Reject mail with this text"
-: "Rechazar correo con el siguiente texto"
-
-, "Discard mail"
-: "Descartar correo"
-
-, "Auto-Reply mail with this text"
-: ""
-
-, "Keep mail"
-: "Guardar correo"
-
-, "Sieve Filter Rules"
-: "Reglas de Filtrado "
-
-, "Sieve Filter Rules for {0}"
-: "Reglas de filtrado de correo para {0}"
-
 , "Move up"
 : "Mover arriba"
 
@@ -511,6 +598,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Action"
 : "Acción"
 
+, "Keep a copy"
+: ""
+
 , "is greater than"
 : "es mayor que"
 
@@ -523,8 +613,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Header \"{0}\" matches \"{1}\""
 : "Encabezado \"{0}\" coincide con \"{1}\""
 
-, "Vacation Message for {0}"
-: "Mensaje de Fuera de Oficina para {0}"
+, "Sieve Filter Rules"
+: "Reglas de Filtrado "
+
+, "Sieve Filter Rules for {0}"
+: "Reglas de filtrado de correo para {0}"
+
+, "From (Email and Name)"
+: "De (Email y Nombre)"
+
+, "To (Email)"
+: "Para (email)"
+
+, "To (Email CC)"
+: "CC"
+
+, "Header contains"
+: "Contenido del Encabezado"
+
+, "Header name"
+: "Nombre de Encabezado"
+
+, "Header value"
+: "Valor del Encabezado"
+
+, "Header regex"
+: "Encabezado regex"
+
+, "Edit Filter Rule"
+: "Editar Regla de Filtrado"
+
+, "Apply filter if"
+: "Aplicar filtro si"
+
+, "all conditions match"
+: ""
+
+, "any condition matches"
+: ""
+
+, "Do this action:"
+: "Realizar la siguiente acción:"
+
+, "Move mail to folder"
+: "Mover correo a la carpeta"
+
+, "Redirect mail to address"
+: "Reenviar correo a"
+
+, "Reject mail with this text"
+: "Rechazar correo con el siguiente texto"
+
+, "Discard mail"
+: "Descartar correo"
+
+, "Auto-Reply mail with this text"
+: ""
+
+, "Keep mail"
+: "Guardar correo"
 
 , "General"
 : "General"
@@ -577,62 +724,188 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Choose Template ..."
 : "Seleccionar Plantilla..."
 
-, "From (Email)"
-: "De (Email)"
-
-, "From (Email and Name)"
-: "De (Email y Nombre)"
-
-, "To (Email)"
-: "Para (email)"
-
-, "To (Email CC)"
-: "CC"
-
-, "Size"
-: "Tamaño"
-
-, "Header contains"
-: "Contenido del Encabezado"
-
-, "Header name"
-: "Nombre de Encabezado"
-
-, "Header value"
-: "Valor del Encabezado"
-
-, "Header regex"
-: "Encabezado regex"
-
-, "Filemanager (Download link)"
+, "Mailvelope decryption Error [{0}]"
 : ""
 
-, "Filemanager (Download link, password)"
+, "To decrypt this message please install {0} with API support enabled"
 : ""
 
-, "Filemanager (Systemlink)"
+, "PGP encrypted Message"
 : ""
 
-, "Attachment Type"
+, "GENDER_Message"
 : ""
 
-, "Click icon to change"
+, "Message, Messages"
+: [
+  "Mensaje"
+ ,"Mensajes"
+
+]
+, "Subject/From"
+: "Asunto/De"
+
+, "Cc"
+: "Cc"
+
+, "Bcc"
+: "Bcc"
+
+, "INBOX"
+: "Bandeja de Entrada"
+
+, "Drafts"
+: "Borradores"
+
+, "Templates"
+: "Plantillas"
+
+, "Junk"
+: "Basura"
+
+, "Trash"
+: "Papelera"
+
+, "GENDER_Folder"
 : ""
 
-, "name"
+, "record list, record lists"
+: [
+  "lista de registros"
+ ,"listado de registros"
+
+]
+, "Rule, Rules"
+: [
+  "Regla"
+ ,"Reglas"
+
+]
+, "Flag, Flags"
+: [
+  "Bandera"
+ ,"Banderas"
+
+]
+, "Flag list, Flag lists"
+: [
+  "Lista de banderas"
+ ,"Listados de Banderas"
+
+]
+, "Total Messages:"
+: "Total de Mensajes:"
+
+, "Unread Messages:"
+: "Mensajes sin leer:"
+
+, "Name on Server:"
+: "Nombre en el Servidor:"
+
+, "Last update:"
+: "Última actualización:"
+
+, "Fetching messages... ({0} done)"
 : ""
 
-, "size"
+, "{0} unread message, {0} unread messages"
+: [
+  "{0} mensaje Sin Leer"
+ ,"{0} mensajes Sin Leer"
+
+]
+, "New Mail"
+: "Nuevo Correo"
+
+, "Email"
+: "Email"
+
+, "Active Vacation Message"
+: "Activar Mensaje de Fuera de Oficina"
+
+, "Email account \"{0}\" has an active vacation message."
+: "Cuenta de correo \"{0}\" tiene activado Mensaje Fuera de Oficina"
+
+, "Poll URL: {0}"
 : ""
 
-, "type"
+, "{0} as default mailer"
 : ""
 
-, "Failure"
-: ""
+, "New mails"
+: "Nuevos correos"
 
-, "This file is already attached to this record."
-: ""
+, "You got {0} new mail(s) in folder {1} ({2})."
+: "Usted tiene {0} nuevo(s) mensaje(s) en {1} ({2})."
+
+, "IMAP Credentials for {0}"
+: "Credenciales IMAP para {0}"
+
+, "Credentials"
+: "Credenciales"
+
+, "IMAP Error"
+: "IMAP Error"
+
+, "No connection to IMAP server."
+: "Sin conexión con servidor IMAP."
+
+, "IMAP Credentials Error"
+: "IMAP Error de credenciales"
+
+, "Your email credentials are wrong. Please contact your administrator"
+: "Sus credenciales no son correctas. Favor de contactar al administrador."
+
+, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
+: "Hay una carpeta que fue eliminada o renombrada por otro usuaro. Favor de actualizar la lista de carpetas."
+
+, "SMTP Error"
+: "SMTP Error"
+
+, "No connection to SMTP server."
+: "Sin conexión con servidor SMTP"
+
+, "Sieve Error"
+: "Error de Filtro"
+
+, "No connection to Sieve server."
+: "Sin conexión al Servidor de Filtros"
+
+, "Save Sieve Script Error"
+: "Guardar error del script de filtro"
+
+, "Could not save script on Sieve server."
+: "No se pudo escribir el script en el Servidor de Filtrado"
+
+, "Add as \"To\""
+: "Agregar a \"Para\""
+
+, "Add as \"Cc\""
+: "Agregar a \"Cc\""
+
+, "Add as \"Bcc\""
+: "Agregar a \"Cco\""
+
+, "Remove from recipients"
+: "Eliminar de destinatarios"
+
+, "Loading Mail Addresses"
+: "Cargando Dirección de Correo"
+
+, "Click here to set To/CC/BCC."
+: "Click aquí para configurar Para/Cc/Cco"
+
+, "To:"
+: "Para:"
+
+, "Cc:"
+: "Cc:"
+
+, "Bcc:"
+: "Bcc:"
+
+, "Remove"
+: "Eliminar"
 
 , "Send"
 : "Enviar"
@@ -714,13 +987,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 
 , "Signature, Signatures"
 : [
-  "Firma"
- ,"Firma"
+  ""
+ ,""
 
 ]
-, "Warning"
-: ""
-
 , "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
 : ""
 
@@ -736,230 +1006,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "No recipients set."
 : "No hay Destinatarios"
 
+, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
+: ""
+
 , "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
 : ""
 
-, "Message, Messages"
-: [
-  "Mensaje"
- ,"Mensajes"
+, "All inboxes"
+: "Todas las Bandejas de Entrada"
 
-]
-, "Subject/From"
-: "Asunto/De"
+, "Default Email Account"
+: "Dirección de correo por defecto"
 
-, "From (Name)"
-: "De (Nombre)"
+, "The default email account to use when sending mails."
+: "La Cuenta de Correo por defecto a utilizar para el envío de correos."
 
-, "Cc"
-: "Cc"
-
-, "Bcc"
-: "Bcc"
-
-, "Flags"
-: "Banderas"
-
-, "Received"
-: "Recibido"
-
-, "INBOX"
-: "Bandeja de Entrada"
-
-, "Drafts"
-: "Borradores"
-
-, "Sent"
-: "Enviado"
-
-, "Templates"
-: "Plantillas"
-
-, "Junk"
-: "Basura"
-
-, "Trash"
-: "Papelera"
-
-, "record list, record lists"
-: [
-  "lista de registros"
- ,"listado de registros"
-
-]
-, "Vacation, Vacations"
-: [
-  "Vacaciones"
- ,"Vacaciones"
-
-]
-, "Rule, Rules"
-: [
-  "Regla"
- ,"Reglas"
-
-]
-, "Flag, Flags"
-: [
-  "Bandera"
- ,"Banderas"
-
-]
-, "Flag list, Flag lists"
-: [
-  "Lista de banderas"
- ,"Listados de Banderas"
-
-]
-, "No Messages found."
+, "Mark Email Automatically As Read"
 : ""
 
-, "Compose"
-: "Redactar"
-
-, "Toggle highlighting"
-: "Cambiar seleccion"
-
-, "Mark read/unread"
-: "Marcar leído/no leído"
-
-, "Move"
+, "Is email marked as read automatically or by user action"
 : ""
 
-, "Add Account"
-: "Añadir Cuenta"
+, "Email Update Interval"
+: "Intervalo de actualización del Email"
 
-, "Id"
-: "Id"
+, "How often should Felamimail check for new Emails (in minutes)."
+: "Frecuencia para comprobar nuevos correos (en minutos)."
 
-, "Sender"
-: "Remitente"
+, "Use for mailto links"
+: "Usar para enlaces mailto"
 
-, "Answered"
-: "Contestado"
-
-, "Forwarded"
-: "Reenviado"
-
-, "Tine20"
+, "Use Felamimail in mailto links, otherwise use the default desktop client."
 : ""
 
-, "Filed as:"
+, "Use for NOTES"
+: "Usar para Notas"
+
+, "Save Note default Value."
+: "Guardar Valor por defecto de la Nota."
+
+, "Confirm Delete"
+: "Confirmar Borrado"
+
+, "Show confirmation dialog when deleting mails."
+: "Mostrar diálogo de confirmación al Eliminar correos"
+
+, ".eml file Attachment in forwarded mails"
 : ""
 
-, "Select Message File Location"
+, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
 : ""
 
-, "Filing Messages"
+, "Default Font"
 : ""
 
-, "Error Filing Message"
+, "Setting the default font in the E-Mail app"
 : ""
 
-, "Could not file message."
+, "Mail Type"
 : ""
 
-, "Send Reading Confirmation"
-: "Enviar Confirmación de Lectura"
-
-, "Do you want to send a reading confirmation message?"
-: "¿Desea enviar un mensaje de confirmación de lectura?"
-
-, "New Mail"
-: "Nuevo Correo"
-
-, "Email"
-: "Email"
-
-, "Active Vacation Message"
-: "Activar Mensaje de Fuera de Oficina"
-
-, "Email account \"{0}\" has an active vacation message."
-: "Cuenta de correo \"{0}\" tiene activado Mensaje Fuera de Oficina"
-
-, "Poll URL: {0}"
+, "Possible mail types."
 : ""
 
-, "{0} as default mailer"
+, "Additional Personal External Account"
 : ""
 
-, "New mails"
-: "Nuevos correos"
+, "Shared System Account"
+: ""
 
-, "You got {0} new mail(s) in folder {1} ({2})."
-: "Usted tiene {0} nuevo(s) mensaje(s) en {1} ({2})."
+, "Additional Personal System Account"
+: ""
 
-, "IMAP Credentials for {0}"
-: "Credenciales IMAP para {0}"
+, "Default Personal System Account"
+: ""
 
-, "Credentials"
-: "Credenciales"
-
-, "IMAP Error"
-: "IMAP Error"
-
-, "No connection to IMAP server."
-: "Sin conexión con servidor IMAP."
-
-, "IMAP Credentials Error"
-: "IMAP Error de credenciales"
-
-, "Your email credentials are wrong. Please contact your administrator"
-: "Sus credenciales no son correctas. Favor de contactar al administrador."
-
-, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
-: "Hay una carpeta que fue eliminada o renombrada por otro usuaro. Favor de actualizar la lista de carpetas."
-
-, "SMTP Error"
-: "SMTP Error"
-
-, "No connection to SMTP server."
-: "Sin conexión con servidor SMTP"
-
-, "Sieve Error"
-: "Error de Filtro"
-
-, "No connection to Sieve server."
-: "Sin conexión al Servidor de Filtros"
-
-, "Save Sieve Script Error"
-: "Guardar error del script de filtro"
-
-, "Could not save script on Sieve server."
-: "No se pudo escribir el script en el Servidor de Filtrado"
-
-, "Cancel"
-: "Cancelar"
-
-, "Ok"
-: "Aceptar"
-
-, "Folders of account {0}"
-: "Carpetas de la Cuenta {0}"
-
-, "Folders of all accounts"
-: "Carpetas de todas las Cuentas"
-
-, "All inboxes of my email accounts"
-: "Todas las Bandejas de Entrada de mis Cuentas de Correo"
-
-, "All unread mail"
-: "Todos los mensajes No leídos"
-
-, "All unread mail of my email accounts"
-: "Tods los Correos Sin Leer de mis Cuentas de Correo"
-
-, "All highlighted mail"
-: "Todos los correos Destacados"
-
-, "All highlighted mail of my email accounts"
-: "Todo correo seleccionado en mi/s cuenta/s de correo"
-
-, "All drafts"
-: "Todos los Borradores"
-
-, "All mails with the draft flag"
-: "Todos los correos marcados como Borradores"
+, "Mailinglist"
+: ""
 
 , "Mailinglist Reject Reason"
 : ""
@@ -988,12 +1111,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Delete Archived Mail"
 : ""
 
+, "Prevent copying mails in the same account"
+: ""
+
 , "Enabled Features"
 : ""
 
 , "Enabled Features in Felamimail Application."
 : ""
 
+, "Account Migration"
+: ""
+
+, "Shows context menu for system accounts to approve migration"
+: ""
+
+, "Move notifications"
+: ""
+
+, "Move notifications to a subfolder via sieve"
+: ""
+
+, "Auto-Save Drafts"
+: ""
+
+, "Save drafts automatically while editing an email"
+: ""
+
+, "Only password download link"
+: ""
+
+, "Allow only password download link"
+: ""
+
 , "Tine 2.0 Flag"
 : ""
 
@@ -1012,6 +1162,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create template, trash, sent, draft and junks folders for system accounts"
 : ""
 
+, "Enable Spam Suspicion Strategy"
+: ""
+
+, "SEnable pam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy Config"
+: ""
+
+, "Spam User Processing Pipeline"
+: ""
+
+, "Confirm SPAM Suspicion Message"
+: ""
+
+, "Message for users when they press the info button in a SPAM suspicion toolbar."
+: ""
+
 , "Filter E-Mail URIs"
 : ""
 
@@ -1054,91 +1225,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "shared / adb_list accounts need to have a password set"
 : ""
 
-, "shared / adb_list accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an user_id set"
-: ""
-
-, "Seen"
-: "Visto"
-
-, "Deleted"
-: "Eliminado"
-
-, "Draft"
-: "Borrador"
-
-, "Flagged"
-: "Marcado"
-
-, "Bad recipient address syntax"
-: ""
-
-, "Recipient address rejected"
-: ""
-
-, "Invalid address format"
-: ""
-
-, "Error: %s"
-: "Error: %s"
-
-, "Could not send message"
-: "No se pudo enviar el mensaje"
-
-, "My Mail Download Links"
-: ""
-
-, "Out of Office reply from %1$s"
-: "Respuesta Fuera de Oficina desde %1$s"
-
-, "You have new mail from "
-: ""
-
-, "Can not combine \"allow external\" and \"allow only members\""
-: ""
-
-, "Message File Suggestion, Message File Suggestions"
-: [
-  ""
- ,""
-
-]
-, "Message File Suggestions"
-: ""
-
-, "Message File Location, Message File Locations"
-: [
-  ""
- ,""
-
-]
-, "Message File Locations"
-: ""
-
-, "Message ID Hash"
-: ""
-
-, "Message ID"
-: ""
-
-, "Model"
-: ""
-
-, "Record ID"
-: ""
-
-, "Record Title"
-: ""
-
-, "Node ID"
-: ""
-
-, "Type"
+, "Is default"
 : ""
 
 , "Email Account, Email Accounts"
@@ -1213,7 +1300,163 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "on"
 : "Activado"
 
-, "Is default"
+, "Message File Location, Message File Locations"
+: [
+  ""
+ ,""
+
+]
+, "Message File Locations"
+: ""
+
+, "Message ID Hash"
+: ""
+
+, "Message ID"
+: ""
+
+, "Model"
+: ""
+
+, "Record ID"
+: ""
+
+, "Record Title"
+: ""
+
+, "Node ID"
+: ""
+
+, "Message File Suggestion, Message File Suggestions"
+: [
+  ""
+ ,""
+
+]
+, "Message File Suggestions"
+: ""
+
+, "Out of Office reply from %1$s"
+: "Respuesta Fuera de Oficina desde %1$s"
+
+, "It is not allowed to redirect emails to self! Please change the recipient."
+: ""
+
+, "Redirects to external email domains are not allowed."
+: ""
+
+, "You have new mail from "
+: ""
+
+, "shared / adb_list accounts need to have an email set"
+: ""
+
+, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
+: ""
+
+, "userInternal accounts need to have an email set"
+: ""
+
+, "userInternal accounts need to have an user_id set"
+: ""
+
+, "Please choose a new email address for userInternal accounts"
+: ""
+
+, "system account for user does not exist"
+: ""
+
+, "Account type cannot be changed from {0} to {1}"
+: ""
+
+, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
+: ""
+
+, "Migration of this account has not been approved!"
+: ""
+
+, "Could not find email user xprops!"
+: ""
+
+, "Internal user accounts need a valid user"
+: ""
+
+, "System account of user is missing"
+: ""
+
+, "Bad recipient address syntax"
+: ""
+
+, "Recipient address rejected"
+: ""
+
+, "Original message not found, email was moved or deleted"
+: ""
+
+, "Invalid address format"
+: ""
+
+, "Error: %s"
+: "Error: %s"
+
+, "Could not send message"
+: "No se pudo enviar el mensaje"
+
+, "My Mail Download Links"
+: ""
+
+, "Seen"
+: "Visto"
+
+, "Deleted"
+: "Eliminado"
+
+, "Draft"
+: "Borrador"
+
+, "Flagged"
+: "Marcado"
+
+, "It is not allowed to copy e-mails in the same account."
+: ""
+
+, "Folder with name {0} already exists!"
+: ""
+
+, "Failure on create folder"
+: ""
+
+, "All inboxes of my email accounts"
+: "Todas las Bandejas de Entrada de mis Cuentas de Correo"
+
+, "All unread mail"
+: "Todos los mensajes No leídos"
+
+, "All unread mail of my email accounts"
+: "Tods los Correos Sin Leer de mis Cuentas de Correo"
+
+, "All highlighted mail"
+: "Todos los correos Destacados"
+
+, "All highlighted mail of my email accounts"
+: "Todo correo seleccionado en mi/s cuenta/s de correo"
+
+, "All drafts"
+: "Todos los Borradores"
+
+, "All mails with the draft flag"
+: "Todos los correos marcados como Borradores"
+
+, "IMAP Hostname missing"
+: ""
+
+, "IMAP Credentials missing"
+: ""
+
+, "SMTP Hostname missing"
+: ""
+
+, "SMTP Credentials missing"
 : ""
 
 , "manage email accounts"
@@ -1228,10 +1471,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create new email accounts"
 : "Crear nueva cuenta de correo"
 
-
-
-
-
+, "Vacation"
+: "Vacaciones"
 
 , "Account"
 : "Cuenta"
@@ -1239,21 +1480,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Folder"
 : "Carpeta"
 
-, "{0} unread message"
-: "{0} mensaje Sin Leer"
-
-, "Signature"
-: "Firma"
-
 , "Message"
 : "Mensaje"
 
 , "record list"
 : "lista de registros"
 
-, "Vacation"
-: "Vacaciones"
-
 , "Rule"
 : "Regla"
 
@@ -1263,15 +1495,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Flag list"
 : "Lista de banderas"
 
-, "Message File Suggestion"
-: ""
+, "{0} unread message"
+: "{0} mensaje Sin Leer"
 
-, "Message File Location"
+, "Signature"
 : ""
 
 , "Email Account"
 : ""
 
+, "Message File Location"
+: ""
+
+, "Message File Suggestion"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
