@@ -5,79 +5,28 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Felamimail **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "All inboxes"
-: "Tous les boîtes de réception"
-
-, "Default Email Account"
-: "Compte messagerie par défaut"
-
-, "The default email account to use when sending mails."
-: "Compte par défaut pour l'envoi des messages."
-
-, "Mark Email Automatically As Read"
+, "Can not combine \"allow external\" and \"allow only members\""
 : ""
 
-, "Is email marked as read automatically or by user action"
-: ""
+, "Delete"
+: "Effacer"
 
-, "Email Update Interval"
-: "Intervalle de mise à jour des messages"
+, "Reply"
+: "Répondre"
 
-, "How often should Felamimail check for new Emails (in minutes)."
-: "Felamimail récupèrera les nouveaux messages automatiquement (toutes les x minutes)."
+, "Reply To All"
+: "Répondre à tous"
 
-, "Use for mailto links"
-: ""
+, "Forward"
+: "Transférer"
 
-, "Use Felamimail in mailto links, otherwise use the default desktop client."
-: ""
+, "Print Message"
+: "Imprimer le message"
 
-, "Use for NOTES"
-: "Utiliser dans les Notes"
-
-, "Save Note default Value."
-: "Sauvegarde dans les Notes par défaut"
-
-, "Confirm Delete"
-: "Confirmer la suppression"
-
-, "Show confirmation dialog when deleting mails."
-: "Demander confirmation avant de supprimer des messages."
-
-, ".eml file Attachment in forwarded mails"
-: ""
-
-, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
-: ""
-
-, "Message not available."
-: "Message indisponible"
-
-, "File Message"
-: ""
-
-, "Filemanager ..."
-: ""
-
-, "Attachment"
-: ""
-
-, "Download"
-: ""
-
-, "{messageCount, plural, one {Message was filed} other {# messages where filed}}"
-: ""
-
-, "Success"
-: ""
-
-, "Error"
-: ""
-
-, "File Messages as Attachment"
-: ""
+, "Print Preview"
+: "Aperçu avant impression"
 
 , "Add New Account"
 : ""
@@ -85,6 +34,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Permissions"
 : ""
 
+, "Rules"
+: ""
+
+, "Vacation, Vacations"
+: [
+  "Absence"
+ ,"Absences"
+
+]
 , "Account, Accounts"
 : [
   "Compte"
@@ -94,7 +52,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Account Name"
 : "Nom du compte"
 
-, "Account Type"
+, "Type"
+: ""
+
+, "Migration Approved"
+: ""
+
+, "Approve Migration"
+: ""
+
+, "Do you want to approve the migration of this account?"
 : ""
 
 , "User"
@@ -145,6 +112,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password"
 : "Mot de passe"
 
+, "Test IMAP Connection"
+: ""
+
 , "SMTP"
 : "SMTP"
 
@@ -166,6 +136,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password (optional)"
 : "Mot de passe (facultatif)"
 
+, "Test SMTP Connection"
+: ""
+
 , "Sieve"
 : "Sieve"
 
@@ -175,6 +148,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Notification Email"
 : ""
 
+, "Auto-move notifications"
+: ""
+
+, "Auto-move notifications folder"
+: ""
+
 , "Other Settings"
 : "Autre"
 
@@ -217,16 +196,22 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Reply-To Email"
 : ""
 
-, "Shared System Account"
+, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
 : ""
 
-, "Additional Personal System Account"
+, "Migration has not been approved."
 : ""
 
-, "Additional Personal External Account"
+, "It is not possible to convert the account to this type."
 : ""
 
-, "Default Personal System Account"
+, "System accounts cannot be created manually."
+: ""
+
+, "Mailinglist accounts cannot be created manually."
+: ""
+
+, "Account type change not possible"
 : ""
 
 , "E-Mail account needs a password"
@@ -244,53 +229,173 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "The grant edit the shared email account"
 : ""
 
-, "Click here to set To/CC/BCC."
-: "Cliquer ici pour définir le type de destinataire"
+, "Send Mails"
+: ""
 
-, "To:"
-: "À :"
+, "The grant to send mails via the email account"
+: ""
 
-, "Cc:"
-: "Cc:"
+, "Warning"
+: ""
 
-, "Bcc:"
-: "Bcc:"
+, "Server connection failed. Do you still want to save this setting and exit?"
+: ""
 
-, "Remove"
-: "Retirer"
+, "Connection succeed"
+: ""
 
-, "Compose email"
-: "Écrire un message"
+, "Connecting to {0} server..."
+: ""
+
+, "Connection failed"
+: ""
+
+, "{server} Connection Status"
+: ""
+
+, "Save Message as"
+: ""
+
+, "File (in Filemanager) ..."
+: ""
+
+, "Attachment (of Record)"
+: ""
+
+, "Download"
+: ""
+
+, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
+: ""
+
+, "Success"
+: ""
+
+, "Error"
+: ""
+
+, "Save Messages as Attachment"
+: ""
+
+, "No Messages found."
+: ""
+
+, "It is SPAM"
+: ""
+
+, "It is not SPAM"
+: ""
+
+, "Compose"
+: "Écrire"
+
+, "Toggle highlighting"
+: "Important"
+
+, "Mark read/unread"
+: "Marquer comme lu / non-lu"
+
+, "Move"
+: ""
+
+, "Copy"
+: ""
+
+, "Import Messages"
+: ""
+
+, "Add Account"
+: "Ajouter un compte"
+
+, "No target folder selected"
+: ""
+
+, "You need to select a target folder for the messages."
+: ""
+
+, "Wrong File Type"
+: ""
+
+, "Files of type eml allowed only."
+: ""
+
+, "Importing Messages..."
+: ""
+
+, "Id"
+: "Id"
+
+, "Attachments"
+: "P.J."
+
+, "Flags"
+: "Marqueurs"
+
+, "Subject"
+: "Sujet"
+
+, "From (Email)"
+: "De (adresse)"
+
+, "From (Name)"
+: "Expéditeur"
+
+, "Sender"
+: "Envoyé par"
 
 , "To"
 : "Destinataire"
 
-, "CC"
+, "Sent"
+: "Envoyés"
+
+, "Received"
+: "Reçu"
+
+, "Folder, Folders"
+: [
+  "un dossier"
+ ,"des dossiers"
+
+]
+, "Size"
+: "Taille"
+
+, "Answered"
+: "Répondu"
+
+, "Forwarded"
+: "Transféré"
+
+, "This message might be SPAM"
 : ""
 
-, "BCC"
+, "Tine20"
 : ""
 
-, "Mass Mailing"
+, "Encrypted Message"
 : ""
 
-, "Signatures"
+, "Filed as:"
 : ""
 
-, "Name"
+, "Select Message File Location"
 : ""
 
-, "Is Default"
+, "Filing Messages"
 : ""
 
-, "Add Signature"
+, "Error Filing Message"
 : ""
 
-, "Edit Signature"
+, "Could not file message."
 : ""
 
-, "Delete Signature"
-: ""
+, "Send Reading Confirmation"
+: "Envoyer un accusé de réception"
+
+, "Do you want to send a reading confirmation message?"
+: "Voulez vous envoyer un accusé de réception ?"
 
 , "Empty Folder"
 : "Vider le dossier"
@@ -301,12 +406,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "New {0}"
 : "Nouveau {0}"
 
-, "Folder, Folders"
-: [
-  "un dossier"
- ,"des dossiers"
-
-]
 , "Please enter the name of the new {0}:"
 : "Saisissez le nom du nouveau {0} :"
 
@@ -340,27 +439,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Update Folder List"
 : "Mettre à jour la liste des dossiers"
 
-, "Add as \"To\""
-: "Ajouter au(x) destinataire(s)"
+, "Message not available."
+: "Message indisponible"
 
-, "Add as \"Cc\""
-: "Ajouter en copie conforme"
+, "Cancel"
+: "Annuler"
 
-, "Add as \"Bcc\""
-: "Ajouter en copie cachée"
+, "Ok"
+: "Ok"
 
-, "Remove from recipients"
-: "Supprimer des destinataires"
+, "Folders of account {0}"
+: "Dossiers du compte {0}"
 
-, "Loading Mail Addresses"
-: "Chargement des adresses électroniques"
+, "Folders of all accounts"
+: "Dossiers de tous les comptes"
+
+, "Compose email"
+: "Écrire un message"
+
+, "CC"
+: ""
+
+, "BCC"
+: ""
+
+, "Mass Mailing"
+: ""
 
 , "Open in Felamimail"
 : ""
 
-, "Subject"
-: "Sujet"
-
 , "From"
 : "De"
 
@@ -376,12 +484,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Show or hide header information"
 : "Afficher/Masquer l'entête de message"
 
-, "Attachments"
-: "P.J."
-
 , "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
 : ""
 
+, "Open"
+: ""
+
+, "Save As"
+: ""
+
+, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
+: ""
+
+, "Save as Record Attachment"
+: ""
+
+, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
+: ""
+
+, "Confirm SPAM Suspicion"
+: ""
+
+, "Yes, it is SPAM"
+: ""
+
+, "No, it is not"
+: ""
+
+, "(new message)"
+: "(nouveau message)"
+
+, "Select recipients for \"{0}\""
+: "Sélectionner le destinataire pour \"{0}\""
+
+, "Signatures"
+: ""
+
+, "Name"
+: ""
+
+, "Is Default"
+: ""
+
+, "Add Signature"
+: ""
+
+, "Edit Signature"
+: ""
+
+, "Delete Signature"
+: ""
+
 , "Recipient filter"
 : "Filtre destinataire"
 
@@ -391,105 +544,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "\"{0}\" recipients"
 : "\"{0}\" destinataires"
 
-, "Total Messages:"
-: "Total des messages :"
-
-, "Unread Messages:"
-: "Messages non lus :"
-
-, "Name on Server:"
-: "Nom sur le serveur :"
-
-, "Last update:"
-: "Dernière modification"
-
-, "Fetching messages... ({0} done)"
+, "Attachment"
 : ""
 
-, "{0} unread message, {0} unread messages"
-: [
-  "{0} message non lu"
- ,"{0} messages non lus"
-
-]
-, "(new message)"
-: "(nouveau message)"
-
-, "Select recipients for \"{0}\""
-: "Sélectionner le destinataire pour \"{0}\""
-
-, "Mailvelope decryption Error [{0}]"
+, "Filemanager (Download link)"
 : ""
 
-, "To decrypt this message please install {0} with API support enabled"
+, "Filemanager (Download link, password)"
 : ""
 
-, "PGP encrypted Message"
+, "Filemanager (Systemlink)"
 : ""
 
-, "Delete"
-: "Effacer"
+, "Attachment Type"
+: ""
 
-, "Reply"
-: "Répondre"
+, "Click icon to change"
+: ""
 
-, "Reply To All"
-: "Répondre à tous"
+, "name"
+: ""
 
-, "Forward"
-: "Transférer"
+, "size"
+: ""
 
-, "Print Message"
-: "Imprimer le message"
+, "type"
+: ""
 
-, "Print Preview"
-: "Aperçu avant impression"
+, "Vacation Message for {0}"
+: "Message d'absence pour {0}"
 
 , "Notification for {0}"
 : ""
 
-, "Edit Filter Rule"
-: "Éditer la règle de filtrage"
-
-, "Apply filter if"
-: ""
-
-, "all conditions match"
-: ""
-
-, "any condition matches"
-: ""
-
-, "Do this action:"
-: "Effectuer cette action :"
-
-, "Keep a copy"
-: ""
-
-, "Move mail to folder"
-: "Déplacer le message dans le dossier"
-
-, "Redirect mail to address"
-: "Rediriger le message vers l'adresse"
-
-, "Reject mail with this text"
-: "Rejeter le message avec ce message"
-
-, "Discard mail"
-: "Refuser le message"
-
-, "Auto-Reply mail with this text"
-: ""
-
-, "Keep mail"
-: "Garder le message"
-
-, "Sieve Filter Rules"
-: "Enregistrer les règles Sieve"
-
-, "Sieve Filter Rules for {0}"
-: "Règles de filtrage Sieve pour {0}"
-
 , "Move up"
 : "Monter"
 
@@ -511,6 +598,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Action"
 : "Action"
 
+, "Keep a copy"
+: ""
+
 , "is greater than"
 : "est supérieur à"
 
@@ -523,8 +613,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Header \"{0}\" matches \"{1}\""
 : "En-tête \"{0}\" correspond à \"{1}\""
 
-, "Vacation Message for {0}"
-: "Message d'absence pour {0}"
+, "Sieve Filter Rules"
+: "Enregistrer les règles Sieve"
+
+, "Sieve Filter Rules for {0}"
+: "Règles de filtrage Sieve pour {0}"
+
+, "From (Email and Name)"
+: "De (adresse et nom)"
+
+, "To (Email)"
+: "Destinataire (adresse)"
+
+, "To (Email CC)"
+: ""
+
+, "Header contains"
+: "L'entête contient"
+
+, "Header name"
+: "Nom d'en-tête"
+
+, "Header value"
+: "Header value"
+
+, "Header regex"
+: "Header regex"
+
+, "Edit Filter Rule"
+: "Éditer la règle de filtrage"
+
+, "Apply filter if"
+: ""
+
+, "all conditions match"
+: ""
+
+, "any condition matches"
+: ""
+
+, "Do this action:"
+: "Effectuer cette action :"
+
+, "Move mail to folder"
+: "Déplacer le message dans le dossier"
+
+, "Redirect mail to address"
+: "Rediriger le message vers l'adresse"
+
+, "Reject mail with this text"
+: "Rejeter le message avec ce message"
+
+, "Discard mail"
+: "Refuser le message"
+
+, "Auto-Reply mail with this text"
+: ""
+
+, "Keep mail"
+: "Garder le message"
 
 , "General"
 : "Général"
@@ -577,62 +724,188 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Choose Template ..."
 : "Choisir le modèle ..."
 
-, "From (Email)"
-: "De (adresse)"
-
-, "From (Email and Name)"
-: "De (adresse et nom)"
-
-, "To (Email)"
-: "Destinataire (adresse)"
-
-, "To (Email CC)"
+, "Mailvelope decryption Error [{0}]"
 : ""
 
-, "Size"
-: "Taille"
-
-, "Header contains"
-: "L'entête contient"
-
-, "Header name"
-: "Nom d'en-tête"
-
-, "Header value"
-: "Header value"
-
-, "Header regex"
-: "Header regex"
-
-, "Filemanager (Download link)"
+, "To decrypt this message please install {0} with API support enabled"
 : ""
 
-, "Filemanager (Download link, password)"
+, "PGP encrypted Message"
 : ""
 
-, "Filemanager (Systemlink)"
+, "GENDER_Message"
 : ""
 
-, "Attachment Type"
+, "Message, Messages"
+: [
+  "Message"
+ ,"Messages"
+
+]
+, "Subject/From"
+: "Sujet/De"
+
+, "Cc"
+: "Cc"
+
+, "Bcc"
+: "Bcc"
+
+, "INBOX"
+: "Boîte de réception"
+
+, "Drafts"
+: "Brouillons"
+
+, "Templates"
+: "Modèles"
+
+, "Junk"
+: "Indésirables"
+
+, "Trash"
+: "Corbeille"
+
+, "GENDER_Folder"
 : ""
 
-, "Click icon to change"
+, "record list, record lists"
+: [
+  "liste d'enregistrement"
+ ,"listes d'enregistrements"
+
+]
+, "Rule, Rules"
+: [
+  "Règle"
+ ,"Règles"
+
+]
+, "Flag, Flags"
+: [
+  "Indicateur"
+ ,"Indicateurs"
+
+]
+, "Flag list, Flag lists"
+: [
+  "Liste d'indicateurs"
+ ,"Listes d'indicateurs"
+
+]
+, "Total Messages:"
+: "Total des messages :"
+
+, "Unread Messages:"
+: "Messages non lus :"
+
+, "Name on Server:"
+: "Nom sur le serveur :"
+
+, "Last update:"
+: "Dernière modification"
+
+, "Fetching messages... ({0} done)"
 : ""
 
-, "name"
+, "{0} unread message, {0} unread messages"
+: [
+  "{0} message non lu"
+ ,"{0} messages non lus"
+
+]
+, "New Mail"
+: "Nouveau message"
+
+, "Email"
+: "Messagerie"
+
+, "Active Vacation Message"
+: "Message d'absence actuel"
+
+, "Email account \"{0}\" has an active vacation message."
+: "L'alerte absence est activée sur le compte messagerie \"{0}\"."
+
+, "Poll URL: {0}"
 : ""
 
-, "size"
+, "{0} as default mailer"
 : ""
 
-, "type"
-: ""
+, "New mails"
+: "Nouveaux messages"
 
-, "Failure"
-: ""
+, "You got {0} new mail(s) in folder {1} ({2})."
+: "Vous avez {0} nouveau(x) message(s) dans le dossier {1} ({2})."
 
-, "This file is already attached to this record."
-: ""
+, "IMAP Credentials for {0}"
+: "Authentification IMAP de {0}"
+
+, "Credentials"
+: "Identifiants"
+
+, "IMAP Error"
+: "Erreur IMAP"
+
+, "No connection to IMAP server."
+: "Pas de connexion au serveur IMAP."
+
+, "IMAP Credentials Error"
+: "Erreur dans les identifiants IMAP"
+
+, "Your email credentials are wrong. Please contact your administrator"
+: "Vos identifiants sont invalides. Merci de contacter votre administrateur."
+
+, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
+: "La structure des dossiers a été modifiée par un autre programme et doit être mise à jour."
+
+, "SMTP Error"
+: "Erreur SMTP"
+
+, "No connection to SMTP server."
+: "Pas de connexion au serveur SMTP."
+
+, "Sieve Error"
+: "Erreur Sieve"
+
+, "No connection to Sieve server."
+: "Pas de connexion au serveur Sieve."
+
+, "Save Sieve Script Error"
+: "Enregistrer les erreurs de script Sieve"
+
+, "Could not save script on Sieve server."
+: "Impossible d'enregistrer le script Sieve"
+
+, "Add as \"To\""
+: "Ajouter au(x) destinataire(s)"
+
+, "Add as \"Cc\""
+: "Ajouter en copie conforme"
+
+, "Add as \"Bcc\""
+: "Ajouter en copie cachée"
+
+, "Remove from recipients"
+: "Supprimer des destinataires"
+
+, "Loading Mail Addresses"
+: "Chargement des adresses électroniques"
+
+, "Click here to set To/CC/BCC."
+: "Cliquer ici pour définir le type de destinataire"
+
+, "To:"
+: "À :"
+
+, "Cc:"
+: "Cc:"
+
+, "Bcc:"
+: "Bcc:"
+
+, "Remove"
+: "Retirer"
 
 , "Send"
 : "Envoyer"
@@ -714,13 +987,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 
 , "Signature, Signatures"
 : [
-  "Signature"
- ,"Signature"
+  ""
+ ,""
 
 ]
-, "Warning"
-: ""
-
 , "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
 : ""
 
@@ -736,230 +1006,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "No recipients set."
 : "Pas de destinataire"
 
+, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
+: ""
+
 , "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
 : ""
 
-, "Message, Messages"
-: [
-  "Message"
- ,"Messages"
+, "All inboxes"
+: "Tous les boîtes de réception"
 
-]
-, "Subject/From"
-: "Sujet/De"
+, "Default Email Account"
+: "Compte messagerie par défaut"
 
-, "From (Name)"
-: "Expéditeur"
+, "The default email account to use when sending mails."
+: "Compte par défaut pour l'envoi des messages."
 
-, "Cc"
-: "Cc"
-
-, "Bcc"
-: "Bcc"
-
-, "Flags"
-: "Marqueurs"
-
-, "Received"
-: "Reçu"
-
-, "INBOX"
-: "Boîte de réception"
-
-, "Drafts"
-: "Brouillons"
-
-, "Sent"
-: "Envoyés"
-
-, "Templates"
-: "Modèles"
-
-, "Junk"
-: "Indésirables"
-
-, "Trash"
-: "Corbeille"
-
-, "record list, record lists"
-: [
-  "liste d'enregistrement"
- ,"listes d'enregistrements"
-
-]
-, "Vacation, Vacations"
-: [
-  "Absence"
- ,"Absences"
-
-]
-, "Rule, Rules"
-: [
-  "Règle"
- ,"Règles"
-
-]
-, "Flag, Flags"
-: [
-  "Indicateur"
- ,"Indicateurs"
-
-]
-, "Flag list, Flag lists"
-: [
-  "Liste d'indicateurs"
- ,"Listes d'indicateurs"
-
-]
-, "No Messages found."
+, "Mark Email Automatically As Read"
 : ""
 
-, "Compose"
-: "Écrire"
-
-, "Toggle highlighting"
-: "Important"
-
-, "Mark read/unread"
-: "Marquer comme lu / non-lu"
-
-, "Move"
+, "Is email marked as read automatically or by user action"
 : ""
 
-, "Add Account"
-: "Ajouter un compte"
+, "Email Update Interval"
+: "Intervalle de mise à jour des messages"
 
-, "Id"
-: "Id"
+, "How often should Felamimail check for new Emails (in minutes)."
+: "Felamimail récupèrera les nouveaux messages automatiquement (toutes les x minutes)."
 
-, "Sender"
-: "Envoyé par"
-
-, "Answered"
-: "Répondu"
-
-, "Forwarded"
-: "Transféré"
-
-, "Tine20"
+, "Use for mailto links"
 : ""
 
-, "Filed as:"
+, "Use Felamimail in mailto links, otherwise use the default desktop client."
 : ""
 
-, "Select Message File Location"
+, "Use for NOTES"
+: "Utiliser dans les Notes"
+
+, "Save Note default Value."
+: "Sauvegarde dans les Notes par défaut"
+
+, "Confirm Delete"
+: "Confirmer la suppression"
+
+, "Show confirmation dialog when deleting mails."
+: "Demander confirmation avant de supprimer des messages."
+
+, ".eml file Attachment in forwarded mails"
 : ""
 
-, "Filing Messages"
+, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
 : ""
 
-, "Error Filing Message"
+, "Default Font"
 : ""
 
-, "Could not file message."
+, "Setting the default font in the E-Mail app"
 : ""
 
-, "Send Reading Confirmation"
-: "Envoyer un accusé de réception"
-
-, "Do you want to send a reading confirmation message?"
-: "Voulez vous envoyer un accusé de réception ?"
-
-, "New Mail"
-: "Nouveau message"
-
-, "Email"
-: "Messagerie"
-
-, "Active Vacation Message"
-: "Message d'absence actuel"
-
-, "Email account \"{0}\" has an active vacation message."
-: "L'alerte absence est activée sur le compte messagerie \"{0}\"."
-
-, "Poll URL: {0}"
+, "Mail Type"
 : ""
 
-, "{0} as default mailer"
+, "Possible mail types."
 : ""
 
-, "New mails"
-: "Nouveaux messages"
+, "Additional Personal External Account"
+: ""
 
-, "You got {0} new mail(s) in folder {1} ({2})."
-: "Vous avez {0} nouveau(x) message(s) dans le dossier {1} ({2})."
+, "Shared System Account"
+: ""
 
-, "IMAP Credentials for {0}"
-: "Authentification IMAP de {0}"
+, "Additional Personal System Account"
+: ""
 
-, "Credentials"
-: "Identifiants"
+, "Default Personal System Account"
+: ""
 
-, "IMAP Error"
-: "Erreur IMAP"
-
-, "No connection to IMAP server."
-: "Pas de connexion au serveur IMAP."
-
-, "IMAP Credentials Error"
-: "Erreur dans les identifiants IMAP"
-
-, "Your email credentials are wrong. Please contact your administrator"
-: "Vos identifiants sont invalides. Merci de contacter votre administrateur."
-
-, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
-: "La structure des dossiers a été modifiée par un autre programme et doit être mise à jour."
-
-, "SMTP Error"
-: "Erreur SMTP"
-
-, "No connection to SMTP server."
-: "Pas de connexion au serveur SMTP."
-
-, "Sieve Error"
-: "Erreur Sieve"
-
-, "No connection to Sieve server."
-: "Pas de connexion au serveur Sieve."
-
-, "Save Sieve Script Error"
-: "Enregistrer les erreurs de script Sieve"
-
-, "Could not save script on Sieve server."
-: "Impossible d'enregistrer le script Sieve"
-
-, "Cancel"
-: "Annuler"
-
-, "Ok"
-: "Ok"
-
-, "Folders of account {0}"
-: "Dossiers du compte {0}"
-
-, "Folders of all accounts"
-: "Dossiers de tous les comptes"
-
-, "All inboxes of my email accounts"
-: "Tous les boîtes de réception de mes comptes"
-
-, "All unread mail"
-: "Tous les messages non lus"
-
-, "All unread mail of my email accounts"
-: "Tous les messages non lus de mes comptes"
-
-, "All highlighted mail"
-: "Tous les messages importants"
-
-, "All highlighted mail of my email accounts"
-: "Tous les messages importants de mes comptes"
-
-, "All drafts"
-: "Tous les brouillons"
-
-, "All mails with the draft flag"
-: "Tous les brouillons"
+, "Mailinglist"
+: ""
 
 , "Mailinglist Reject Reason"
 : ""
@@ -988,12 +1111,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Delete Archived Mail"
 : ""
 
+, "Prevent copying mails in the same account"
+: ""
+
 , "Enabled Features"
 : ""
 
 , "Enabled Features in Felamimail Application."
 : ""
 
+, "Account Migration"
+: ""
+
+, "Shows context menu for system accounts to approve migration"
+: ""
+
+, "Move notifications"
+: ""
+
+, "Move notifications to a subfolder via sieve"
+: ""
+
+, "Auto-Save Drafts"
+: ""
+
+, "Save drafts automatically while editing an email"
+: ""
+
+, "Only password download link"
+: ""
+
+, "Allow only password download link"
+: ""
+
 , "Tine 2.0 Flag"
 : ""
 
@@ -1012,6 +1162,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create template, trash, sent, draft and junks folders for system accounts"
 : ""
 
+, "Enable Spam Suspicion Strategy"
+: ""
+
+, "SEnable pam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy Config"
+: ""
+
+, "Spam User Processing Pipeline"
+: ""
+
+, "Confirm SPAM Suspicion Message"
+: ""
+
+, "Message for users when they press the info button in a SPAM suspicion toolbar."
+: ""
+
 , "Filter E-Mail URIs"
 : ""
 
@@ -1054,91 +1225,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "shared / adb_list accounts need to have a password set"
 : ""
 
-, "shared / adb_list accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an user_id set"
-: ""
-
-, "Seen"
-: "Vu"
-
-, "Deleted"
-: "Supprimé"
-
-, "Draft"
-: "Brouillon"
-
-, "Flagged"
-: "Marqué"
-
-, "Bad recipient address syntax"
-: ""
-
-, "Recipient address rejected"
-: ""
-
-, "Invalid address format"
-: ""
-
-, "Error: %s"
-: "Erreur : %s"
-
-, "Could not send message"
-: "Impossible d'envoyer le message"
-
-, "My Mail Download Links"
-: ""
-
-, "Out of Office reply from %1$s"
-: "Réponse \"Je suis absent\" de %1$s"
-
-, "You have new mail from "
-: ""
-
-, "Can not combine \"allow external\" and \"allow only members\""
-: ""
-
-, "Message File Suggestion, Message File Suggestions"
-: [
-  ""
- ,""
-
-]
-, "Message File Suggestions"
-: ""
-
-, "Message File Location, Message File Locations"
-: [
-  ""
- ,""
-
-]
-, "Message File Locations"
-: ""
-
-, "Message ID Hash"
-: ""
-
-, "Message ID"
-: ""
-
-, "Model"
-: ""
-
-, "Record ID"
-: ""
-
-, "Record Title"
-: ""
-
-, "Node ID"
-: ""
-
-, "Type"
+, "Is default"
 : ""
 
 , "Email Account, Email Accounts"
@@ -1213,7 +1300,163 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "on"
 : "le"
 
-, "Is default"
+, "Message File Location, Message File Locations"
+: [
+  ""
+ ,""
+
+]
+, "Message File Locations"
+: ""
+
+, "Message ID Hash"
+: ""
+
+, "Message ID"
+: ""
+
+, "Model"
+: ""
+
+, "Record ID"
+: ""
+
+, "Record Title"
+: ""
+
+, "Node ID"
+: ""
+
+, "Message File Suggestion, Message File Suggestions"
+: [
+  ""
+ ,""
+
+]
+, "Message File Suggestions"
+: ""
+
+, "Out of Office reply from %1$s"
+: "Réponse \"Je suis absent\" de %1$s"
+
+, "It is not allowed to redirect emails to self! Please change the recipient."
+: ""
+
+, "Redirects to external email domains are not allowed."
+: ""
+
+, "You have new mail from "
+: ""
+
+, "shared / adb_list accounts need to have an email set"
+: ""
+
+, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
+: ""
+
+, "userInternal accounts need to have an email set"
+: ""
+
+, "userInternal accounts need to have an user_id set"
+: ""
+
+, "Please choose a new email address for userInternal accounts"
+: ""
+
+, "system account for user does not exist"
+: ""
+
+, "Account type cannot be changed from {0} to {1}"
+: ""
+
+, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
+: ""
+
+, "Migration of this account has not been approved!"
+: ""
+
+, "Could not find email user xprops!"
+: ""
+
+, "Internal user accounts need a valid user"
+: ""
+
+, "System account of user is missing"
+: ""
+
+, "Bad recipient address syntax"
+: ""
+
+, "Recipient address rejected"
+: ""
+
+, "Original message not found, email was moved or deleted"
+: ""
+
+, "Invalid address format"
+: ""
+
+, "Error: %s"
+: "Erreur : %s"
+
+, "Could not send message"
+: "Impossible d'envoyer le message"
+
+, "My Mail Download Links"
+: ""
+
+, "Seen"
+: "Vu"
+
+, "Deleted"
+: "Supprimé"
+
+, "Draft"
+: "Brouillon"
+
+, "Flagged"
+: "Marqué"
+
+, "It is not allowed to copy e-mails in the same account."
+: ""
+
+, "Folder with name {0} already exists!"
+: ""
+
+, "Failure on create folder"
+: ""
+
+, "All inboxes of my email accounts"
+: "Tous les boîtes de réception de mes comptes"
+
+, "All unread mail"
+: "Tous les messages non lus"
+
+, "All unread mail of my email accounts"
+: "Tous les messages non lus de mes comptes"
+
+, "All highlighted mail"
+: "Tous les messages importants"
+
+, "All highlighted mail of my email accounts"
+: "Tous les messages importants de mes comptes"
+
+, "All drafts"
+: "Tous les brouillons"
+
+, "All mails with the draft flag"
+: "Tous les brouillons"
+
+, "IMAP Hostname missing"
+: ""
+
+, "IMAP Credentials missing"
+: ""
+
+, "SMTP Hostname missing"
+: ""
+
+, "SMTP Credentials missing"
 : ""
 
 , "manage email accounts"
@@ -1228,10 +1471,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create new email accounts"
 : "Créer de nouveaux comptes messagerie"
 
-
-
-
-
+, "Vacation"
+: "Absence"
 
 , "Account"
 : "Compte"
@@ -1239,21 +1480,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Folder"
 : "un dossier"
 
-, "{0} unread message"
-: "{0} message non lu"
-
-, "Signature"
-: "Signature"
-
 , "Message"
 : "Message"
 
 , "record list"
 : "liste d'enregistrement"
 
-, "Vacation"
-: "Absence"
-
 , "Rule"
 : "Règle"
 
@@ -1263,15 +1495,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Flag list"
 : "Liste d'indicateurs"
 
-, "Message File Suggestion"
-: ""
+, "{0} unread message"
+: "{0} message non lu"
 
-, "Message File Location"
+, "Signature"
 : ""
 
 , "Email Account"
 : ""
 
+, "Message File Location"
+: ""
+
+, "Message File Suggestion"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
