@@ -5,79 +5,28 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Felamimail **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "All inboxes"
-: "Összes beérkezett üzenetek mappa"
-
-, "Default Email Account"
-: "Alapértelmezett email fiók"
-
-, "The default email account to use when sending mails."
-: "Alapértelmezett email fiók üzenetek küldéséhez."
-
-, "Mark Email Automatically As Read"
+, "Can not combine \"allow external\" and \"allow only members\""
 : ""
 
-, "Is email marked as read automatically or by user action"
-: ""
+, "Delete"
+: "Törlés"
 
-, "Email Update Interval"
-: "Email frissítés intervalluma"
+, "Reply"
+: "Válasz"
 
-, "How often should Felamimail check for new Emails (in minutes)."
-: ""
+, "Reply To All"
+: "Válasz mindenkinek"
 
-, "Use for mailto links"
-: ""
+, "Forward"
+: "Továbbítás"
 
-, "Use Felamimail in mailto links, otherwise use the default desktop client."
-: ""
+, "Print Message"
+: "Üzenet nyomtatása"
 
-, "Use for NOTES"
-: "Használja MEGJEGYZÉSKÉNT"
-
-, "Save Note default Value."
-: "Alapértelmezett Megjegyzés érték mentése."
-
-, "Confirm Delete"
-: "Törlés megerősítése"
-
-, "Show confirmation dialog when deleting mails."
-: "Megerősítés ablak mutatása üzenetek törlésekor."
-
-, ".eml file Attachment in forwarded mails"
-: ""
-
-, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
-: ""
-
-, "Message not available."
-: ""
-
-, "File Message"
-: ""
-
-, "Filemanager ..."
-: ""
-
-, "Attachment"
-: ""
-
-, "Download"
-: ""
-
-, "{messageCount, plural, one {Message was filed} other {# messages where filed}}"
-: ""
-
-, "Success"
-: ""
-
-, "Error"
-: ""
-
-, "File Messages as Attachment"
-: ""
+, "Print Preview"
+: "Nyomtatási nézet"
 
 , "Add New Account"
 : ""
@@ -85,6 +34,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Permissions"
 : ""
 
+, "Rules"
+: ""
+
+, "Vacation, Vacations"
+: [
+  "Szabadság"
+ ,"Szabadságok"
+
+]
 , "Account, Accounts"
 : [
   "Fiók"
@@ -94,7 +52,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Account Name"
 : "Fiók neve"
 
-, "Account Type"
+, "Type"
+: ""
+
+, "Migration Approved"
+: ""
+
+, "Approve Migration"
+: ""
+
+, "Do you want to approve the migration of this account?"
 : ""
 
 , "User"
@@ -145,6 +112,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password"
 : "Jelszó"
 
+, "Test IMAP Connection"
+: ""
+
 , "SMTP"
 : "SMTP"
 
@@ -166,6 +136,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password (optional)"
 : "Jelszó (opcionális)"
 
+, "Test SMTP Connection"
+: ""
+
 , "Sieve"
 : "Sieve"
 
@@ -175,6 +148,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Notification Email"
 : ""
 
+, "Auto-move notifications"
+: ""
+
+, "Auto-move notifications folder"
+: ""
+
 , "Other Settings"
 : "Egyéb beállítások"
 
@@ -217,16 +196,22 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Reply-To Email"
 : ""
 
-, "Shared System Account"
+, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
 : ""
 
-, "Additional Personal System Account"
+, "Migration has not been approved."
 : ""
 
-, "Additional Personal External Account"
+, "It is not possible to convert the account to this type."
 : ""
 
-, "Default Personal System Account"
+, "System accounts cannot be created manually."
+: ""
+
+, "Mailinglist accounts cannot be created manually."
+: ""
+
+, "Account type change not possible"
 : ""
 
 , "E-Mail account needs a password"
@@ -244,52 +229,172 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "The grant edit the shared email account"
 : ""
 
-, "Click here to set To/CC/BCC."
-: "Kattints ide a Címzett/Másolat/Titkos Másolat beállításához."
+, "Send Mails"
+: ""
 
-, "To:"
-: "Címzett:"
+, "The grant to send mails via the email account"
+: ""
 
-, "Cc:"
-: "Másolat:"
+, "Warning"
+: ""
 
-, "Bcc:"
-: "Titkos másolat:"
+, "Server connection failed. Do you still want to save this setting and exit?"
+: ""
 
-, "Remove"
-: "Eltávolítás"
+, "Connection succeed"
+: ""
 
-, "Compose email"
-: "Email írása"
+, "Connecting to {0} server..."
+: ""
+
+, "Connection failed"
+: ""
+
+, "{server} Connection Status"
+: ""
+
+, "Save Message as"
+: ""
+
+, "File (in Filemanager) ..."
+: ""
+
+, "Attachment (of Record)"
+: ""
+
+, "Download"
+: ""
+
+, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
+: ""
+
+, "Success"
+: ""
+
+, "Error"
+: ""
+
+, "Save Messages as Attachment"
+: ""
+
+, "No Messages found."
+: ""
+
+, "It is SPAM"
+: ""
+
+, "It is not SPAM"
+: ""
+
+, "Compose"
+: "Írás"
+
+, "Toggle highlighting"
+: "Megjelölés váltása"
+
+, "Mark read/unread"
+: "Olvasott/olvasatlan jelölés"
+
+, "Move"
+: ""
+
+, "Copy"
+: ""
+
+, "Import Messages"
+: ""
+
+, "Add Account"
+: "Fiók hozzáadása"
+
+, "No target folder selected"
+: ""
+
+, "You need to select a target folder for the messages."
+: ""
+
+, "Wrong File Type"
+: ""
+
+, "Files of type eml allowed only."
+: ""
+
+, "Importing Messages..."
+: ""
+
+, "Id"
+: "Id"
+
+, "Attachments"
+: "Mellékletek"
+
+, "Flags"
+: "Zászlók"
+
+, "Subject"
+: "Tárgy"
+
+, "From (Email)"
+: "Feladó (Email)"
+
+, "From (Name)"
+: "Feladó (Név)"
+
+, "Sender"
+: "Küldő"
 
 , "To"
 : "Címzett"
 
-, "CC"
+, "Sent"
+: "Elküldött"
+
+, "Received"
+: "Beérkezett"
+
+, "Folder, Folders"
+: [
+  "Mappa"
+ ,"Mappák"
+
+]
+, "Size"
+: "Méret"
+
+, "Answered"
+: "Megválaszolt"
+
+, "Forwarded"
+: "Továbbított"
+
+, "This message might be SPAM"
 : ""
 
-, "BCC"
+, "Tine20"
 : ""
 
-, "Mass Mailing"
+, "Encrypted Message"
 : ""
 
-, "Signatures"
+, "Filed as:"
 : ""
 
-, "Name"
+, "Select Message File Location"
 : ""
 
-, "Is Default"
+, "Filing Messages"
 : ""
 
-, "Add Signature"
+, "Error Filing Message"
 : ""
 
-, "Edit Signature"
+, "Could not file message."
 : ""
 
-, "Delete Signature"
+, "Send Reading Confirmation"
+: ""
+
+, "Do you want to send a reading confirmation message?"
 : ""
 
 , "Empty Folder"
@@ -301,12 +406,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "New {0}"
 : "Új {0}"
 
-, "Folder, Folders"
-: [
-  "Mappa"
- ,"Mappák"
-
-]
 , "Please enter the name of the new {0}:"
 : "Kérem adja meg az új {0} nevét:"
 
@@ -340,27 +439,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Update Folder List"
 : "Mappa lista újratöltése"
 
-, "Add as \"To\""
-: "Hozzáadás \"To\"-ként"
+, "Message not available."
+: ""
 
-, "Add as \"Cc\""
-: "Hozzáadás \"Cc\"-ként"
+, "Cancel"
+: "Mégse"
 
-, "Add as \"Bcc\""
-: "Hozzáadás \"Bcc\"-ként"
+, "Ok"
+: "Rendben"
 
-, "Remove from recipients"
-: "Eltávolítás a címzettek kzül"
+, "Folders of account {0}"
+: "{0} fiók mappái"
 
-, "Loading Mail Addresses"
-: "Üzenet címek betöltése"
+, "Folders of all accounts"
+: "Összes fiók mappái"
+
+, "Compose email"
+: "Email írása"
+
+, "CC"
+: ""
+
+, "BCC"
+: ""
+
+, "Mass Mailing"
+: ""
 
 , "Open in Felamimail"
 : ""
 
-, "Subject"
-: "Tárgy"
-
 , "From"
 : "Feladó"
 
@@ -376,12 +484,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Show or hide header information"
 : "Fejléc információinak megjelenítése vagy elrejtése"
 
-, "Attachments"
-: "Mellékletek"
-
 , "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
 : ""
 
+, "Open"
+: ""
+
+, "Save As"
+: ""
+
+, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
+: ""
+
+, "Save as Record Attachment"
+: ""
+
+, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
+: ""
+
+, "Confirm SPAM Suspicion"
+: ""
+
+, "Yes, it is SPAM"
+: ""
+
+, "No, it is not"
+: ""
+
+, "(new message)"
+: "(új üzenet)"
+
+, "Select recipients for \"{0}\""
+: "Válassz ki címzetteket ehhez: \"{0}\""
+
+, "Signatures"
+: ""
+
+, "Name"
+: ""
+
+, "Is Default"
+: ""
+
+, "Add Signature"
+: ""
+
+, "Edit Signature"
+: ""
+
+, "Delete Signature"
+: ""
+
 , "Recipient filter"
 : "Címzettek szűrése"
 
@@ -391,105 +544,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "\"{0}\" recipients"
 : "\"{0}\" címzettek"
 
-, "Total Messages:"
-: "Összes üzenet:"
-
-, "Unread Messages:"
-: "Olvasatlan üzenet:"
-
-, "Name on Server:"
-: "Név a szerveren:"
-
-, "Last update:"
-: "Utolsó frissítés:"
-
-, "Fetching messages... ({0} done)"
+, "Attachment"
 : ""
 
-, "{0} unread message, {0} unread messages"
-: [
-  "{0} olvasatlan levél"
- ,"{0} olvasatlan levél"
-
-]
-, "(new message)"
-: "(új üzenet)"
-
-, "Select recipients for \"{0}\""
-: "Válassz ki címzetteket ehhez: \"{0}\""
-
-, "Mailvelope decryption Error [{0}]"
+, "Filemanager (Download link)"
 : ""
 
-, "To decrypt this message please install {0} with API support enabled"
+, "Filemanager (Download link, password)"
 : ""
 
-, "PGP encrypted Message"
+, "Filemanager (Systemlink)"
 : ""
 
-, "Delete"
-: "Törlés"
+, "Attachment Type"
+: ""
 
-, "Reply"
-: "Válasz"
+, "Click icon to change"
+: ""
 
-, "Reply To All"
-: "Válasz mindenkinek"
+, "name"
+: ""
 
-, "Forward"
-: "Továbbítás"
+, "size"
+: ""
 
-, "Print Message"
-: "Üzenet nyomtatása"
+, "type"
+: ""
 
-, "Print Preview"
-: "Nyomtatási nézet"
+, "Vacation Message for {0}"
+: "Szabadság üzenet ehhez: {0}"
 
 , "Notification for {0}"
 : ""
 
-, "Edit Filter Rule"
-: "Szűrő szabály szerkesztése"
-
-, "Apply filter if"
-: ""
-
-, "all conditions match"
-: ""
-
-, "any condition matches"
-: ""
-
-, "Do this action:"
-: "Tegye ezt a műveletet:"
-
-, "Keep a copy"
-: ""
-
-, "Move mail to folder"
-: "Levél áthelyezése mappába"
-
-, "Redirect mail to address"
-: "Levél továbbküldése"
-
-, "Reject mail with this text"
-: "Levél visszaküldése ezzel a szöveggel"
-
-, "Discard mail"
-: "Levél eldobása"
-
-, "Auto-Reply mail with this text"
-: ""
-
-, "Keep mail"
-: "Levél megtartása"
-
-, "Sieve Filter Rules"
-: "Sieve szűrő szabályok"
-
-, "Sieve Filter Rules for {0}"
-: "Sieve szűrő feltételek ehhez:{0}"
-
 , "Move up"
 : "Mozgatás le"
 
@@ -511,6 +598,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Action"
 : "Művelet"
 
+, "Keep a copy"
+: ""
+
 , "is greater than"
 : "nagyobb, mint"
 
@@ -523,8 +613,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Header \"{0}\" matches \"{1}\""
 : "Fejléc \"{0}\" \"{1}\" tartalmaz"
 
-, "Vacation Message for {0}"
-: "Szabadság üzenet ehhez: {0}"
+, "Sieve Filter Rules"
+: "Sieve szűrő szabályok"
+
+, "Sieve Filter Rules for {0}"
+: "Sieve szűrő feltételek ehhez:{0}"
+
+, "From (Email and Name)"
+: "Feladó (Email és Név)"
+
+, "To (Email)"
+: "Címzett (Email)"
+
+, "To (Email CC)"
+: ""
+
+, "Header contains"
+: "Feljéc tartalmaz"
+
+, "Header name"
+: "Fejléc neve"
+
+, "Header value"
+: "Fejléc érték"
+
+, "Header regex"
+: "Fejléc regex"
+
+, "Edit Filter Rule"
+: "Szűrő szabály szerkesztése"
+
+, "Apply filter if"
+: ""
+
+, "all conditions match"
+: ""
+
+, "any condition matches"
+: ""
+
+, "Do this action:"
+: "Tegye ezt a műveletet:"
+
+, "Move mail to folder"
+: "Levél áthelyezése mappába"
+
+, "Redirect mail to address"
+: "Levél továbbküldése"
+
+, "Reject mail with this text"
+: "Levél visszaküldése ezzel a szöveggel"
+
+, "Discard mail"
+: "Levél eldobása"
+
+, "Auto-Reply mail with this text"
+: ""
+
+, "Keep mail"
+: "Levél megtartása"
 
 , "General"
 : "Általános"
@@ -577,62 +724,188 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Choose Template ..."
 : ""
 
-, "From (Email)"
-: "Feladó (Email)"
-
-, "From (Email and Name)"
-: "Feladó (Email és Név)"
-
-, "To (Email)"
-: "Címzett (Email)"
-
-, "To (Email CC)"
+, "Mailvelope decryption Error [{0}]"
 : ""
 
-, "Size"
-: "Méret"
-
-, "Header contains"
-: "Feljéc tartalmaz"
-
-, "Header name"
-: "Fejléc neve"
-
-, "Header value"
-: "Fejléc érték"
-
-, "Header regex"
-: "Fejléc regex"
-
-, "Filemanager (Download link)"
+, "To decrypt this message please install {0} with API support enabled"
 : ""
 
-, "Filemanager (Download link, password)"
+, "PGP encrypted Message"
 : ""
 
-, "Filemanager (Systemlink)"
+, "GENDER_Message"
 : ""
 
-, "Attachment Type"
+, "Message, Messages"
+: [
+  "Üzenet"
+ ,"Üzenetek"
+
+]
+, "Subject/From"
+: "Tárgy/Feladó"
+
+, "Cc"
+: "Másolat"
+
+, "Bcc"
+: "Titkos másolat"
+
+, "INBOX"
+: "BEJÖVŐ ÜZENTEK"
+
+, "Drafts"
+: "Piszkozatok"
+
+, "Templates"
+: "Sablonok"
+
+, "Junk"
+: "Szemét"
+
+, "Trash"
+: "Törölt elemek"
+
+, "GENDER_Folder"
 : ""
 
-, "Click icon to change"
+, "record list, record lists"
+: [
+  "adat lista"
+ ,"adat listák"
+
+]
+, "Rule, Rules"
+: [
+  "Szabály"
+ ,"Szabályok"
+
+]
+, "Flag, Flags"
+: [
+  "Zászló"
+ ,"Zászlók"
+
+]
+, "Flag list, Flag lists"
+: [
+  "Zászló lista"
+ ,"Zászló listák"
+
+]
+, "Total Messages:"
+: "Összes üzenet:"
+
+, "Unread Messages:"
+: "Olvasatlan üzenet:"
+
+, "Name on Server:"
+: "Név a szerveren:"
+
+, "Last update:"
+: "Utolsó frissítés:"
+
+, "Fetching messages... ({0} done)"
 : ""
 
-, "name"
+, "{0} unread message, {0} unread messages"
+: [
+  "{0} olvasatlan levél"
+ ,"{0} olvasatlan levél"
+
+]
+, "New Mail"
+: "Új levél"
+
+, "Email"
+: "Email"
+
+, "Active Vacation Message"
+: "Aktív szabadság üzenet"
+
+, "Email account \"{0}\" has an active vacation message."
+: "Email fiók \"{0}\" rendelkezik aktív szabadság üzenettel."
+
+, "Poll URL: {0}"
 : ""
 
-, "size"
+, "{0} as default mailer"
 : ""
 
-, "type"
-: ""
+, "New mails"
+: "Új levelek"
 
-, "Failure"
-: ""
+, "You got {0} new mail(s) in folder {1} ({2})."
+: "{0} új üzeneted van a {1} mappában ({2})."
 
-, "This file is already attached to this record."
-: ""
+, "IMAP Credentials for {0}"
+: "{0} IMAP belépési adatai"
+
+, "Credentials"
+: "Belépési adatok"
+
+, "IMAP Error"
+: "IMAP hiba"
+
+, "No connection to IMAP server."
+: "Nincs kapcsolat az IMAP szerverrel."
+
+, "IMAP Credentials Error"
+: "IMAP belépési adatok hibásak"
+
+, "Your email credentials are wrong. Please contact your administrator"
+: "Az email belépési adataid rosszak. Lépj kapcsolatba a rendszergazdával."
+
+, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
+: "Az egyik mappádat egy másik kliens törölte vagy átnevezte. Kérlek frissítsd a mappa listát."
+
+, "SMTP Error"
+: "SMTP hiba"
+
+, "No connection to SMTP server."
+: "Nincs kapcsolat az SMTP szerverrel."
+
+, "Sieve Error"
+: "Sieve hiba"
+
+, "No connection to Sieve server."
+: "Nincs kapcsolat a Sieve szerverrel."
+
+, "Save Sieve Script Error"
+: "Sieve script hiba mentése"
+
+, "Could not save script on Sieve server."
+: "Nem menthető  script a Sieve szerveren."
+
+, "Add as \"To\""
+: "Hozzáadás \"To\"-ként"
+
+, "Add as \"Cc\""
+: "Hozzáadás \"Cc\"-ként"
+
+, "Add as \"Bcc\""
+: "Hozzáadás \"Bcc\"-ként"
+
+, "Remove from recipients"
+: "Eltávolítás a címzettek kzül"
+
+, "Loading Mail Addresses"
+: "Üzenet címek betöltése"
+
+, "Click here to set To/CC/BCC."
+: "Kattints ide a Címzett/Másolat/Titkos Másolat beállításához."
+
+, "To:"
+: "Címzett:"
+
+, "Cc:"
+: "Másolat:"
+
+, "Bcc:"
+: "Titkos másolat:"
+
+, "Remove"
+: "Eltávolítás"
 
 , "Send"
 : "Küldés"
@@ -714,13 +987,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 
 , "Signature, Signatures"
 : [
-  "Aláírás"
- ,"Aláírás"
+  ""
+ ,""
 
 ]
-, "Warning"
-: ""
-
 , "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
 : ""
 
@@ -736,230 +1006,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "No recipients set."
 : "Nincsenek címzettek beállítva."
 
+, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
+: ""
+
 , "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
 : ""
 
-, "Message, Messages"
-: [
-  "Üzenet"
- ,"Üzenetek"
+, "All inboxes"
+: "Összes beérkezett üzenetek mappa"
 
-]
-, "Subject/From"
-: "Tárgy/Feladó"
+, "Default Email Account"
+: "Alapértelmezett email fiók"
 
-, "From (Name)"
-: "Feladó (Név)"
+, "The default email account to use when sending mails."
+: "Alapértelmezett email fiók üzenetek küldéséhez."
 
-, "Cc"
-: "Másolat"
-
-, "Bcc"
-: "Titkos másolat"
-
-, "Flags"
-: "Zászlók"
-
-, "Received"
-: "Beérkezett"
-
-, "INBOX"
-: "BEJÖVŐ ÜZENTEK"
-
-, "Drafts"
-: "Piszkozatok"
-
-, "Sent"
-: "Elküldött"
-
-, "Templates"
-: "Sablonok"
-
-, "Junk"
-: "Szemét"
-
-, "Trash"
-: "Törölt elemek"
-
-, "record list, record lists"
-: [
-  "adat lista"
- ,"adat listák"
-
-]
-, "Vacation, Vacations"
-: [
-  "Szabadság"
- ,"Szabadságok"
-
-]
-, "Rule, Rules"
-: [
-  "Szabály"
- ,"Szabályok"
-
-]
-, "Flag, Flags"
-: [
-  "Zászló"
- ,"Zászlók"
-
-]
-, "Flag list, Flag lists"
-: [
-  "Zászló lista"
- ,"Zászló listák"
-
-]
-, "No Messages found."
+, "Mark Email Automatically As Read"
 : ""
 
-, "Compose"
-: "Írás"
-
-, "Toggle highlighting"
-: "Megjelölés váltása"
-
-, "Mark read/unread"
-: "Olvasott/olvasatlan jelölés"
-
-, "Move"
+, "Is email marked as read automatically or by user action"
 : ""
 
-, "Add Account"
-: "Fiók hozzáadása"
+, "Email Update Interval"
+: "Email frissítés intervalluma"
 
-, "Id"
-: "Id"
-
-, "Sender"
-: "Küldő"
-
-, "Answered"
-: "Megválaszolt"
-
-, "Forwarded"
-: "Továbbított"
-
-, "Tine20"
+, "How often should Felamimail check for new Emails (in minutes)."
 : ""
 
-, "Filed as:"
+, "Use for mailto links"
 : ""
 
-, "Select Message File Location"
+, "Use Felamimail in mailto links, otherwise use the default desktop client."
 : ""
 
-, "Filing Messages"
+, "Use for NOTES"
+: "Használja MEGJEGYZÉSKÉNT"
+
+, "Save Note default Value."
+: "Alapértelmezett Megjegyzés érték mentése."
+
+, "Confirm Delete"
+: "Törlés megerősítése"
+
+, "Show confirmation dialog when deleting mails."
+: "Megerősítés ablak mutatása üzenetek törlésekor."
+
+, ".eml file Attachment in forwarded mails"
 : ""
 
-, "Error Filing Message"
+, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
 : ""
 
-, "Could not file message."
+, "Default Font"
 : ""
 
-, "Send Reading Confirmation"
+, "Setting the default font in the E-Mail app"
 : ""
 
-, "Do you want to send a reading confirmation message?"
+, "Mail Type"
 : ""
 
-, "New Mail"
-: "Új levél"
-
-, "Email"
-: "Email"
-
-, "Active Vacation Message"
-: "Aktív szabadság üzenet"
-
-, "Email account \"{0}\" has an active vacation message."
-: "Email fiók \"{0}\" rendelkezik aktív szabadság üzenettel."
-
-, "Poll URL: {0}"
+, "Possible mail types."
 : ""
 
-, "{0} as default mailer"
+, "Additional Personal External Account"
 : ""
 
-, "New mails"
-: "Új levelek"
+, "Shared System Account"
+: ""
 
-, "You got {0} new mail(s) in folder {1} ({2})."
-: "{0} új üzeneted van a {1} mappában ({2})."
+, "Additional Personal System Account"
+: ""
 
-, "IMAP Credentials for {0}"
-: "{0} IMAP belépési adatai"
+, "Default Personal System Account"
+: ""
 
-, "Credentials"
-: "Belépési adatok"
-
-, "IMAP Error"
-: "IMAP hiba"
-
-, "No connection to IMAP server."
-: "Nincs kapcsolat az IMAP szerverrel."
-
-, "IMAP Credentials Error"
-: "IMAP belépési adatok hibásak"
-
-, "Your email credentials are wrong. Please contact your administrator"
-: "Az email belépési adataid rosszak. Lépj kapcsolatba a rendszergazdával."
-
-, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
-: "Az egyik mappádat egy másik kliens törölte vagy átnevezte. Kérlek frissítsd a mappa listát."
-
-, "SMTP Error"
-: "SMTP hiba"
-
-, "No connection to SMTP server."
-: "Nincs kapcsolat az SMTP szerverrel."
-
-, "Sieve Error"
-: "Sieve hiba"
-
-, "No connection to Sieve server."
-: "Nincs kapcsolat a Sieve szerverrel."
-
-, "Save Sieve Script Error"
-: "Sieve script hiba mentése"
-
-, "Could not save script on Sieve server."
-: "Nem menthető  script a Sieve szerveren."
-
-, "Cancel"
-: "Mégse"
-
-, "Ok"
-: "Rendben"
-
-, "Folders of account {0}"
-: "{0} fiók mappái"
-
-, "Folders of all accounts"
-: "Összes fiók mappái"
-
-, "All inboxes of my email accounts"
-: "Email fiókjaim összes beérkezett üzenetek mappája"
-
-, "All unread mail"
-: "Összes olvasatlan levél"
-
-, "All unread mail of my email accounts"
-: "Email fiókajim összes olvasatlan levele"
-
-, "All highlighted mail"
-: "Összes megjelelölt levél"
-
-, "All highlighted mail of my email accounts"
-: "Email fiókjaim összes megjelelölt levele"
-
-, "All drafts"
-: "Összes piszkozat"
-
-, "All mails with the draft flag"
-: "Összes levél piszkozat zászlóval"
+, "Mailinglist"
+: ""
 
 , "Mailinglist Reject Reason"
 : ""
@@ -988,12 +1111,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Delete Archived Mail"
 : ""
 
+, "Prevent copying mails in the same account"
+: ""
+
 , "Enabled Features"
 : ""
 
 , "Enabled Features in Felamimail Application."
 : ""
 
+, "Account Migration"
+: ""
+
+, "Shows context menu for system accounts to approve migration"
+: ""
+
+, "Move notifications"
+: ""
+
+, "Move notifications to a subfolder via sieve"
+: ""
+
+, "Auto-Save Drafts"
+: ""
+
+, "Save drafts automatically while editing an email"
+: ""
+
+, "Only password download link"
+: ""
+
+, "Allow only password download link"
+: ""
+
 , "Tine 2.0 Flag"
 : ""
 
@@ -1012,6 +1162,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create template, trash, sent, draft and junks folders for system accounts"
 : ""
 
+, "Enable Spam Suspicion Strategy"
+: ""
+
+, "SEnable pam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy Config"
+: ""
+
+, "Spam User Processing Pipeline"
+: ""
+
+, "Confirm SPAM Suspicion Message"
+: ""
+
+, "Message for users when they press the info button in a SPAM suspicion toolbar."
+: ""
+
 , "Filter E-Mail URIs"
 : ""
 
@@ -1054,91 +1225,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "shared / adb_list accounts need to have a password set"
 : ""
 
-, "shared / adb_list accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an user_id set"
-: ""
-
-, "Seen"
-: "Olvasott"
-
-, "Deleted"
-: "Törölt"
-
-, "Draft"
-: "Piszkozat"
-
-, "Flagged"
-: "Zászlóval jelölt"
-
-, "Bad recipient address syntax"
-: ""
-
-, "Recipient address rejected"
-: ""
-
-, "Invalid address format"
-: ""
-
-, "Error: %s"
-: ""
-
-, "Could not send message"
-: ""
-
-, "My Mail Download Links"
-: ""
-
-, "Out of Office reply from %1$s"
-: "Házon kívül válasz érkezett: %1$s"
-
-, "You have new mail from "
-: ""
-
-, "Can not combine \"allow external\" and \"allow only members\""
-: ""
-
-, "Message File Suggestion, Message File Suggestions"
-: [
-  ""
- ,""
-
-]
-, "Message File Suggestions"
-: ""
-
-, "Message File Location, Message File Locations"
-: [
-  ""
- ,""
-
-]
-, "Message File Locations"
-: ""
-
-, "Message ID Hash"
-: ""
-
-, "Message ID"
-: ""
-
-, "Model"
-: ""
-
-, "Record ID"
-: ""
-
-, "Record Title"
-: ""
-
-, "Node ID"
-: ""
-
-, "Type"
+, "Is default"
 : ""
 
 , "Email Account, Email Accounts"
@@ -1213,7 +1300,163 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "on"
 : ""
 
-, "Is default"
+, "Message File Location, Message File Locations"
+: [
+  ""
+ ,""
+
+]
+, "Message File Locations"
+: ""
+
+, "Message ID Hash"
+: ""
+
+, "Message ID"
+: ""
+
+, "Model"
+: ""
+
+, "Record ID"
+: ""
+
+, "Record Title"
+: ""
+
+, "Node ID"
+: ""
+
+, "Message File Suggestion, Message File Suggestions"
+: [
+  ""
+ ,""
+
+]
+, "Message File Suggestions"
+: ""
+
+, "Out of Office reply from %1$s"
+: "Házon kívül válasz érkezett: %1$s"
+
+, "It is not allowed to redirect emails to self! Please change the recipient."
+: ""
+
+, "Redirects to external email domains are not allowed."
+: ""
+
+, "You have new mail from "
+: ""
+
+, "shared / adb_list accounts need to have an email set"
+: ""
+
+, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
+: ""
+
+, "userInternal accounts need to have an email set"
+: ""
+
+, "userInternal accounts need to have an user_id set"
+: ""
+
+, "Please choose a new email address for userInternal accounts"
+: ""
+
+, "system account for user does not exist"
+: ""
+
+, "Account type cannot be changed from {0} to {1}"
+: ""
+
+, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
+: ""
+
+, "Migration of this account has not been approved!"
+: ""
+
+, "Could not find email user xprops!"
+: ""
+
+, "Internal user accounts need a valid user"
+: ""
+
+, "System account of user is missing"
+: ""
+
+, "Bad recipient address syntax"
+: ""
+
+, "Recipient address rejected"
+: ""
+
+, "Original message not found, email was moved or deleted"
+: ""
+
+, "Invalid address format"
+: ""
+
+, "Error: %s"
+: ""
+
+, "Could not send message"
+: ""
+
+, "My Mail Download Links"
+: ""
+
+, "Seen"
+: "Olvasott"
+
+, "Deleted"
+: "Törölt"
+
+, "Draft"
+: "Piszkozat"
+
+, "Flagged"
+: "Zászlóval jelölt"
+
+, "It is not allowed to copy e-mails in the same account."
+: ""
+
+, "Folder with name {0} already exists!"
+: ""
+
+, "Failure on create folder"
+: ""
+
+, "All inboxes of my email accounts"
+: "Email fiókjaim összes beérkezett üzenetek mappája"
+
+, "All unread mail"
+: "Összes olvasatlan levél"
+
+, "All unread mail of my email accounts"
+: "Email fiókajim összes olvasatlan levele"
+
+, "All highlighted mail"
+: "Összes megjelelölt levél"
+
+, "All highlighted mail of my email accounts"
+: "Email fiókjaim összes megjelelölt levele"
+
+, "All drafts"
+: "Összes piszkozat"
+
+, "All mails with the draft flag"
+: "Összes levél piszkozat zászlóval"
+
+, "IMAP Hostname missing"
+: ""
+
+, "IMAP Credentials missing"
+: ""
+
+, "SMTP Hostname missing"
+: ""
+
+, "SMTP Credentials missing"
 : ""
 
 , "manage email accounts"
@@ -1228,10 +1471,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create new email accounts"
 : "Új email fiókok létrehozása"
 
-
-
-
-
+, "Vacation"
+: "Szabadság"
 
 , "Account"
 : "Fiók"
@@ -1239,21 +1480,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Folder"
 : "Mappa"
 
-, "{0} unread message"
-: "{0} olvasatlan levél"
-
-, "Signature"
-: "Aláírás"
-
 , "Message"
 : "Üzenet"
 
 , "record list"
 : "adat lista"
 
-, "Vacation"
-: "Szabadság"
-
 , "Rule"
 : "Szabály"
 
@@ -1263,15 +1495,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Flag list"
 : "Zászló lista"
 
-, "Message File Suggestion"
-: ""
+, "{0} unread message"
+: "{0} olvasatlan levél"
 
-, "Message File Location"
+, "Signature"
 : ""
 
 , "Email Account"
 : ""
 
+, "Message File Location"
+: ""
+
+, "Message File Suggestion"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
