@@ -5,79 +5,28 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Felamimail **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "All inboxes"
-: "Todas as caixas de entrada"
-
-, "Default Email Account"
-: "Conta de Email Padrão"
-
-, "The default email account to use when sending mails."
-: "A conta de email padrão a ser usada quando enviar correio."
-
-, "Mark Email Automatically As Read"
+, "Can not combine \"allow external\" and \"allow only members\""
 : ""
 
-, "Is email marked as read automatically or by user action"
-: ""
+, "Delete"
+: "Apagar"
 
-, "Email Update Interval"
-: "Intervalo de Atualização de Email"
+, "Reply"
+: "Responder"
 
-, "How often should Felamimail check for new Emails (in minutes)."
-: "Com que frequência Felamimail deve verificar por novas mensagens (em minutos)."
+, "Reply To All"
+: "Responder para Todos"
 
-, "Use for mailto links"
-: ""
+, "Forward"
+: "Encaminhar"
 
-, "Use Felamimail in mailto links, otherwise use the default desktop client."
-: ""
+, "Print Message"
+: "Imprimir Mensagem"
 
-, "Use for NOTES"
-: "Usar para NOTAS"
-
-, "Save Note default Value."
-: "Salvar Valor padrão para Nota."
-
-, "Confirm Delete"
-: "Confirmar Apagar"
-
-, "Show confirmation dialog when deleting mails."
-: "Exibir diálogo de confirmação quando apagar correios."
-
-, ".eml file Attachment in forwarded mails"
-: ""
-
-, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
-: ""
-
-, "Message not available."
-: "Mensagem não disponível."
-
-, "File Message"
-: ""
-
-, "Filemanager ..."
-: ""
-
-, "Attachment"
-: ""
-
-, "Download"
-: ""
-
-, "{messageCount, plural, one {Message was filed} other {# messages where filed}}"
-: ""
-
-, "Success"
-: ""
-
-, "Error"
-: ""
-
-, "File Messages as Attachment"
-: ""
+, "Print Preview"
+: "Impressão Prévia"
 
 , "Add New Account"
 : ""
@@ -85,6 +34,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Permissions"
 : ""
 
+, "Rules"
+: ""
+
+, "Vacation, Vacations"
+: [
+  "Férias"
+ ,"Férias"
+
+]
 , "Account, Accounts"
 : [
   "Conta"
@@ -94,7 +52,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Account Name"
 : "Nome da Conta"
 
-, "Account Type"
+, "Type"
+: ""
+
+, "Migration Approved"
+: ""
+
+, "Approve Migration"
+: ""
+
+, "Do you want to approve the migration of this account?"
 : ""
 
 , "User"
@@ -145,6 +112,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password"
 : "Senha"
 
+, "Test IMAP Connection"
+: ""
+
 , "SMTP"
 : "SMTP"
 
@@ -166,6 +136,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password (optional)"
 : "Senha (opcional)"
 
+, "Test SMTP Connection"
+: ""
+
 , "Sieve"
 : "Filtrar"
 
@@ -175,6 +148,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Notification Email"
 : ""
 
+, "Auto-move notifications"
+: ""
+
+, "Auto-move notifications folder"
+: ""
+
 , "Other Settings"
 : "Outros Parâmetros"
 
@@ -217,16 +196,22 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Reply-To Email"
 : ""
 
-, "Shared System Account"
+, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
 : ""
 
-, "Additional Personal System Account"
+, "Migration has not been approved."
 : ""
 
-, "Additional Personal External Account"
+, "It is not possible to convert the account to this type."
 : ""
 
-, "Default Personal System Account"
+, "System accounts cannot be created manually."
+: ""
+
+, "Mailinglist accounts cannot be created manually."
+: ""
+
+, "Account type change not possible"
 : ""
 
 , "E-Mail account needs a password"
@@ -244,53 +229,173 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "The grant edit the shared email account"
 : ""
 
-, "Click here to set To/CC/BCC."
-: "Clique aqui para assinalar Para/CC/CCO."
+, "Send Mails"
+: ""
 
-, "To:"
-: "Para"
+, "The grant to send mails via the email account"
+: ""
 
-, "Cc:"
-: "Cc"
+, "Warning"
+: ""
 
-, "Bcc:"
-: "Cco"
+, "Server connection failed. Do you still want to save this setting and exit?"
+: ""
 
-, "Remove"
-: "Remover"
+, "Connection succeed"
+: ""
 
-, "Compose email"
-: "Escrever email"
+, "Connecting to {0} server..."
+: ""
+
+, "Connection failed"
+: ""
+
+, "{server} Connection Status"
+: ""
+
+, "Save Message as"
+: ""
+
+, "File (in Filemanager) ..."
+: ""
+
+, "Attachment (of Record)"
+: ""
+
+, "Download"
+: ""
+
+, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
+: ""
+
+, "Success"
+: ""
+
+, "Error"
+: ""
+
+, "Save Messages as Attachment"
+: ""
+
+, "No Messages found."
+: ""
+
+, "It is SPAM"
+: ""
+
+, "It is not SPAM"
+: ""
+
+, "Compose"
+: "Escrever"
+
+, "Toggle highlighting"
+: "Alternar destaque"
+
+, "Mark read/unread"
+: "Marcar como lida/não lida"
+
+, "Move"
+: ""
+
+, "Copy"
+: ""
+
+, "Import Messages"
+: ""
+
+, "Add Account"
+: "Adicionar Conta"
+
+, "No target folder selected"
+: ""
+
+, "You need to select a target folder for the messages."
+: ""
+
+, "Wrong File Type"
+: ""
+
+, "Files of type eml allowed only."
+: ""
+
+, "Importing Messages..."
+: ""
+
+, "Id"
+: "Id"
+
+, "Attachments"
+: "Anexos"
+
+, "Flags"
+: "Margadores"
+
+, "Subject"
+: "Assunto"
+
+, "From (Email)"
+: "De (email)"
+
+, "From (Name)"
+: "De (Nome)"
+
+, "Sender"
+: "Remetente"
 
 , "To"
 : "Para"
 
-, "CC"
+, "Sent"
+: "Enviado"
+
+, "Received"
+: "Recebido"
+
+, "Folder, Folders"
+: [
+  "Pasta"
+ ,"Pastas"
+
+]
+, "Size"
+: "Tamanho"
+
+, "Answered"
+: "Respondido"
+
+, "Forwarded"
+: "Encaminhado"
+
+, "This message might be SPAM"
 : ""
 
-, "BCC"
+, "Tine20"
 : ""
 
-, "Mass Mailing"
+, "Encrypted Message"
 : ""
 
-, "Signatures"
+, "Filed as:"
 : ""
 
-, "Name"
+, "Select Message File Location"
 : ""
 
-, "Is Default"
+, "Filing Messages"
 : ""
 
-, "Add Signature"
+, "Error Filing Message"
 : ""
 
-, "Edit Signature"
+, "Could not file message."
 : ""
 
-, "Delete Signature"
-: ""
+, "Send Reading Confirmation"
+: "Enviar Confirmação de Leitura"
+
+, "Do you want to send a reading confirmation message?"
+: "Você quer enviar a confirmação de leitura da mensagem ?"
 
 , "Empty Folder"
 : "Pasta Vazia"
@@ -301,12 +406,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "New {0}"
 : "Novo {0}"
 
-, "Folder, Folders"
-: [
-  "Pasta"
- ,"Pastas"
-
-]
 , "Please enter the name of the new {0}:"
 : "Favor informar o nome do novo {0}:"
 
@@ -340,27 +439,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Update Folder List"
 : "Atualizar Lista de Pastas"
 
-, "Add as \"To\""
-: "Adicionar como \"Para\""
+, "Message not available."
+: "Mensagem não disponível."
 
-, "Add as \"Cc\""
-: "Adicionar como \"Cc\""
+, "Cancel"
+: "Cancelar"
 
-, "Add as \"Bcc\""
-: "Adicionar como \"Cco\""
+, "Ok"
+: "Ok"
 
-, "Remove from recipients"
-: "Remover dos beneficiários"
+, "Folders of account {0}"
+: "Pastas da conta {0}"
 
-, "Loading Mail Addresses"
-: "Carregando Endereço de Correio"
+, "Folders of all accounts"
+: "Pastas de todas as contas"
+
+, "Compose email"
+: "Escrever email"
+
+, "CC"
+: ""
+
+, "BCC"
+: ""
+
+, "Mass Mailing"
+: ""
 
 , "Open in Felamimail"
 : ""
 
-, "Subject"
-: "Assunto"
-
 , "From"
 : "De"
 
@@ -376,12 +484,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Show or hide header information"
 : "Exibir ou ocultar o cabeçalho da informação"
 
-, "Attachments"
-: "Anexos"
-
 , "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
 : ""
 
+, "Open"
+: ""
+
+, "Save As"
+: ""
+
+, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
+: ""
+
+, "Save as Record Attachment"
+: ""
+
+, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
+: ""
+
+, "Confirm SPAM Suspicion"
+: ""
+
+, "Yes, it is SPAM"
+: ""
+
+, "No, it is not"
+: ""
+
+, "(new message)"
+: "(nova mensagem)"
+
+, "Select recipients for \"{0}\""
+: "Selecionar destinatários para \"{0}\""
+
+, "Signatures"
+: ""
+
+, "Name"
+: ""
+
+, "Is Default"
+: ""
+
+, "Add Signature"
+: ""
+
+, "Edit Signature"
+: ""
+
+, "Delete Signature"
+: ""
+
 , "Recipient filter"
 : "Filtro do destinatário"
 
@@ -391,105 +544,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "\"{0}\" recipients"
 : "\"{0}\" destinatários"
 
-, "Total Messages:"
-: "Total de Mensagens:"
-
-, "Unread Messages:"
-: "Mensagens não Lidas:"
-
-, "Name on Server:"
-: "Nome no Servidor:"
-
-, "Last update:"
-: "Última atualização:"
-
-, "Fetching messages... ({0} done)"
+, "Attachment"
 : ""
 
-, "{0} unread message, {0} unread messages"
-: [
-  "mensagem não lida"
- ,"mensagens não lidas"
-
-]
-, "(new message)"
-: "(nova mensagem)"
-
-, "Select recipients for \"{0}\""
-: "Selecionar destinatários para \"{0}\""
-
-, "Mailvelope decryption Error [{0}]"
+, "Filemanager (Download link)"
 : ""
 
-, "To decrypt this message please install {0} with API support enabled"
+, "Filemanager (Download link, password)"
 : ""
 
-, "PGP encrypted Message"
+, "Filemanager (Systemlink)"
 : ""
 
-, "Delete"
-: "Apagar"
+, "Attachment Type"
+: ""
 
-, "Reply"
-: "Responder"
+, "Click icon to change"
+: ""
 
-, "Reply To All"
-: "Responder para Todos"
+, "name"
+: ""
 
-, "Forward"
-: "Encaminhar"
+, "size"
+: ""
 
-, "Print Message"
-: "Imprimir Mensagem"
+, "type"
+: ""
 
-, "Print Preview"
-: "Impressão Prévia"
+, "Vacation Message for {0}"
+: "Mensagem de Férias para {0}"
 
 , "Notification for {0}"
 : ""
 
-, "Edit Filter Rule"
-: "Editar Regra de Filtro"
-
-, "Apply filter if"
-: ""
-
-, "all conditions match"
-: ""
-
-, "any condition matches"
-: ""
-
-, "Do this action:"
-: "Faça esta ação:"
-
-, "Keep a copy"
-: ""
-
-, "Move mail to folder"
-: "Mover correio para a pasta"
-
-, "Redirect mail to address"
-: "Redirecionar correio para o endereço"
-
-, "Reject mail with this text"
-: "Rejeitar correio com este texto"
-
-, "Discard mail"
-: "Descartar correio"
-
-, "Auto-Reply mail with this text"
-: ""
-
-, "Keep mail"
-: "Guardar correio"
-
-, "Sieve Filter Rules"
-: "Regras para aplicar o filtro"
-
-, "Sieve Filter Rules for {0}"
-: "Regras para aplicar o Filtro por {0}"
-
 , "Move up"
 : "Mover-se"
 
@@ -511,6 +598,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Action"
 : "Ação"
 
+, "Keep a copy"
+: ""
+
 , "is greater than"
 : "é maior que"
 
@@ -523,8 +613,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Header \"{0}\" matches \"{1}\""
 : "Cabeçalho \"{0}\" matches \"{1}\""
 
-, "Vacation Message for {0}"
-: "Mensagem de Férias para {0}"
+, "Sieve Filter Rules"
+: "Regras para aplicar o filtro"
+
+, "Sieve Filter Rules for {0}"
+: "Regras para aplicar o Filtro por {0}"
+
+, "From (Email and Name)"
+: "De (Email e Nome)"
+
+, "To (Email)"
+: "Para (Email)"
+
+, "To (Email CC)"
+: ""
+
+, "Header contains"
+: "Cabeçalho contém"
+
+, "Header name"
+: "Nome do cabeçalho"
+
+, "Header value"
+: "Valor do cabeçalho"
+
+, "Header regex"
+: "Valor do cabeçalho"
+
+, "Edit Filter Rule"
+: "Editar Regra de Filtro"
+
+, "Apply filter if"
+: ""
+
+, "all conditions match"
+: ""
+
+, "any condition matches"
+: ""
+
+, "Do this action:"
+: "Faça esta ação:"
+
+, "Move mail to folder"
+: "Mover correio para a pasta"
+
+, "Redirect mail to address"
+: "Redirecionar correio para o endereço"
+
+, "Reject mail with this text"
+: "Rejeitar correio com este texto"
+
+, "Discard mail"
+: "Descartar correio"
+
+, "Auto-Reply mail with this text"
+: ""
+
+, "Keep mail"
+: "Guardar correio"
 
 , "General"
 : "Geral"
@@ -577,62 +724,188 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Choose Template ..."
 : "Escolher Modelo ..."
 
-, "From (Email)"
-: "De (email)"
-
-, "From (Email and Name)"
-: "De (Email e Nome)"
-
-, "To (Email)"
-: "Para (Email)"
-
-, "To (Email CC)"
+, "Mailvelope decryption Error [{0}]"
 : ""
 
-, "Size"
-: "Tamanho"
-
-, "Header contains"
-: "Cabeçalho contém"
-
-, "Header name"
-: "Nome do cabeçalho"
-
-, "Header value"
-: "Valor do cabeçalho"
-
-, "Header regex"
-: "Valor do cabeçalho"
-
-, "Filemanager (Download link)"
+, "To decrypt this message please install {0} with API support enabled"
 : ""
 
-, "Filemanager (Download link, password)"
+, "PGP encrypted Message"
 : ""
 
-, "Filemanager (Systemlink)"
+, "GENDER_Message"
 : ""
 
-, "Attachment Type"
+, "Message, Messages"
+: [
+  "Mensagem"
+ ,"Mensagens"
+
+]
+, "Subject/From"
+: "Assunto/De"
+
+, "Cc"
+: "Cc"
+
+, "Bcc"
+: "Cco"
+
+, "INBOX"
+: "Caixa de Entrada"
+
+, "Drafts"
+: "Rascunhos"
+
+, "Templates"
+: "Modelos"
+
+, "Junk"
+: "Lixo"
+
+, "Trash"
+: "Lixeira"
+
+, "GENDER_Folder"
 : ""
 
-, "Click icon to change"
+, "record list, record lists"
+: [
+  "lista de registro"
+ ,"listas de registros"
+
+]
+, "Rule, Rules"
+: [
+  "Regra"
+ ,"Regras"
+
+]
+, "Flag, Flags"
+: [
+  "Marcador"
+ ,"Marcadores"
+
+]
+, "Flag list, Flag lists"
+: [
+  "Lista de marcadores"
+ ,"Listas de marcadores"
+
+]
+, "Total Messages:"
+: "Total de Mensagens:"
+
+, "Unread Messages:"
+: "Mensagens não Lidas:"
+
+, "Name on Server:"
+: "Nome no Servidor:"
+
+, "Last update:"
+: "Última atualização:"
+
+, "Fetching messages... ({0} done)"
 : ""
 
-, "name"
+, "{0} unread message, {0} unread messages"
+: [
+  "mensagem não lida"
+ ,"mensagens não lidas"
+
+]
+, "New Mail"
+: "Novo Correio"
+
+, "Email"
+: "Email"
+
+, "Active Vacation Message"
+: "Ativar Mensagem de Férias"
+
+, "Email account \"{0}\" has an active vacation message."
+: "Conta de Email \"{0}\" tem mensagem de férias ativa."
+
+, "Poll URL: {0}"
 : ""
 
-, "size"
+, "{0} as default mailer"
 : ""
 
-, "type"
-: ""
+, "New mails"
+: "Novos correios"
 
-, "Failure"
-: ""
+, "You got {0} new mail(s) in folder {1} ({2})."
+: "Você tem {0} novo(s) correio(s) na pasta {1} ({2})."
 
-, "This file is already attached to this record."
-: ""
+, "IMAP Credentials for {0}"
+: "Credenciais de IMAP para {0}"
+
+, "Credentials"
+: "Credenciais"
+
+, "IMAP Error"
+: "Erro IMAP"
+
+, "No connection to IMAP server."
+: "Sem conexão para o servidor IMAP."
+
+, "IMAP Credentials Error"
+: "Erro de Credenciais no IMAP"
+
+, "Your email credentials are wrong. Please contact your administrator"
+: "Suas credenciais de email estão erradas. Favor contactar seu administrador"
+
+, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
+: "Uma das suas pastas foi apagada ou renomeada por outro cliente. Favor atualize a lista de pastas desta conta."
+
+, "SMTP Error"
+: "Erro SMTP"
+
+, "No connection to SMTP server."
+: "Nenhuma conexão com o servidor SMTP."
+
+, "Sieve Error"
+: "Erro "
+
+, "No connection to Sieve server."
+: "Nenhuma conexão ao servidor de filtragem"
+
+, "Save Sieve Script Error"
+: "Erro ao salvar o script de filtragem"
+
+, "Could not save script on Sieve server."
+: "O script não pode ser salvo no servidor de filtragem"
+
+, "Add as \"To\""
+: "Adicionar como \"Para\""
+
+, "Add as \"Cc\""
+: "Adicionar como \"Cc\""
+
+, "Add as \"Bcc\""
+: "Adicionar como \"Cco\""
+
+, "Remove from recipients"
+: "Remover dos beneficiários"
+
+, "Loading Mail Addresses"
+: "Carregando Endereço de Correio"
+
+, "Click here to set To/CC/BCC."
+: "Clique aqui para assinalar Para/CC/CCO."
+
+, "To:"
+: "Para"
+
+, "Cc:"
+: "Cc"
+
+, "Bcc:"
+: "Cco"
+
+, "Remove"
+: "Remover"
 
 , "Send"
 : "Enviar"
@@ -714,13 +987,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 
 , "Signature, Signatures"
 : [
-  "Assinatura"
- ,"Assinatura"
+  ""
+ ,""
 
 ]
-, "Warning"
-: ""
-
 , "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
 : ""
 
@@ -736,230 +1006,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "No recipients set."
 : "Nenhum destinatário selecionado."
 
+, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
+: ""
+
 , "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
 : ""
 
-, "Message, Messages"
-: [
-  "Mensagem"
- ,"Mensagens"
+, "All inboxes"
+: "Todas as caixas de entrada"
 
-]
-, "Subject/From"
-: "Assunto/De"
+, "Default Email Account"
+: "Conta de Email Padrão"
 
-, "From (Name)"
-: "De (Nome)"
+, "The default email account to use when sending mails."
+: "A conta de email padrão a ser usada quando enviar correio."
 
-, "Cc"
-: "Cc"
-
-, "Bcc"
-: "Cco"
-
-, "Flags"
-: "Margadores"
-
-, "Received"
-: "Recebido"
-
-, "INBOX"
-: "Caixa de Entrada"
-
-, "Drafts"
-: "Rascunhos"
-
-, "Sent"
-: "Enviado"
-
-, "Templates"
-: "Modelos"
-
-, "Junk"
-: "Lixo"
-
-, "Trash"
-: "Lixeira"
-
-, "record list, record lists"
-: [
-  "lista de registro"
- ,"listas de registros"
-
-]
-, "Vacation, Vacations"
-: [
-  "Férias"
- ,"Férias"
-
-]
-, "Rule, Rules"
-: [
-  "Regra"
- ,"Regras"
-
-]
-, "Flag, Flags"
-: [
-  "Marcador"
- ,"Marcadores"
-
-]
-, "Flag list, Flag lists"
-: [
-  "Lista de marcadores"
- ,"Listas de marcadores"
-
-]
-, "No Messages found."
+, "Mark Email Automatically As Read"
 : ""
 
-, "Compose"
-: "Escrever"
-
-, "Toggle highlighting"
-: "Alternar destaque"
-
-, "Mark read/unread"
-: "Marcar como lida/não lida"
-
-, "Move"
+, "Is email marked as read automatically or by user action"
 : ""
 
-, "Add Account"
-: "Adicionar Conta"
+, "Email Update Interval"
+: "Intervalo de Atualização de Email"
 
-, "Id"
-: "Id"
+, "How often should Felamimail check for new Emails (in minutes)."
+: "Com que frequência Felamimail deve verificar por novas mensagens (em minutos)."
 
-, "Sender"
-: "Remetente"
-
-, "Answered"
-: "Respondido"
-
-, "Forwarded"
-: "Encaminhado"
-
-, "Tine20"
+, "Use for mailto links"
 : ""
 
-, "Filed as:"
+, "Use Felamimail in mailto links, otherwise use the default desktop client."
 : ""
 
-, "Select Message File Location"
+, "Use for NOTES"
+: "Usar para NOTAS"
+
+, "Save Note default Value."
+: "Salvar Valor padrão para Nota."
+
+, "Confirm Delete"
+: "Confirmar Apagar"
+
+, "Show confirmation dialog when deleting mails."
+: "Exibir diálogo de confirmação quando apagar correios."
+
+, ".eml file Attachment in forwarded mails"
 : ""
 
-, "Filing Messages"
+, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
 : ""
 
-, "Error Filing Message"
+, "Default Font"
 : ""
 
-, "Could not file message."
+, "Setting the default font in the E-Mail app"
 : ""
 
-, "Send Reading Confirmation"
-: "Enviar Confirmação de Leitura"
-
-, "Do you want to send a reading confirmation message?"
-: "Você quer enviar a confirmação de leitura da mensagem ?"
-
-, "New Mail"
-: "Novo Correio"
-
-, "Email"
-: "Email"
-
-, "Active Vacation Message"
-: "Ativar Mensagem de Férias"
-
-, "Email account \"{0}\" has an active vacation message."
-: "Conta de Email \"{0}\" tem mensagem de férias ativa."
-
-, "Poll URL: {0}"
+, "Mail Type"
 : ""
 
-, "{0} as default mailer"
+, "Possible mail types."
 : ""
 
-, "New mails"
-: "Novos correios"
+, "Additional Personal External Account"
+: ""
 
-, "You got {0} new mail(s) in folder {1} ({2})."
-: "Você tem {0} novo(s) correio(s) na pasta {1} ({2})."
+, "Shared System Account"
+: ""
 
-, "IMAP Credentials for {0}"
-: "Credenciais de IMAP para {0}"
+, "Additional Personal System Account"
+: ""
 
-, "Credentials"
-: "Credenciais"
+, "Default Personal System Account"
+: ""
 
-, "IMAP Error"
-: "Erro IMAP"
-
-, "No connection to IMAP server."
-: "Sem conexão para o servidor IMAP."
-
-, "IMAP Credentials Error"
-: "Erro de Credenciais no IMAP"
-
-, "Your email credentials are wrong. Please contact your administrator"
-: "Suas credenciais de email estão erradas. Favor contactar seu administrador"
-
-, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
-: "Uma das suas pastas foi apagada ou renomeada por outro cliente. Favor atualize a lista de pastas desta conta."
-
-, "SMTP Error"
-: "Erro SMTP"
-
-, "No connection to SMTP server."
-: "Nenhuma conexão com o servidor SMTP."
-
-, "Sieve Error"
-: "Erro "
-
-, "No connection to Sieve server."
-: "Nenhuma conexão ao servidor de filtragem"
-
-, "Save Sieve Script Error"
-: "Erro ao salvar o script de filtragem"
-
-, "Could not save script on Sieve server."
-: "O script não pode ser salvo no servidor de filtragem"
-
-, "Cancel"
-: "Cancelar"
-
-, "Ok"
-: "Ok"
-
-, "Folders of account {0}"
-: "Pastas da conta {0}"
-
-, "Folders of all accounts"
-: "Pastas de todas as contas"
-
-, "All inboxes of my email accounts"
-: "Todas as caixas de entrada de minhas contas de email"
-
-, "All unread mail"
-: "Todos os emails não lidos"
-
-, "All unread mail of my email accounts"
-: "Todos os emails não lidos das minhas contas de email"
-
-, "All highlighted mail"
-: "Todos os correios importantes"
-
-, "All highlighted mail of my email accounts"
-: "Todos os correios importantes das minhas contas de email"
-
-, "All drafts"
-: "Todos os rascunhos"
-
-, "All mails with the draft flag"
-: "Todos os correios marcados como rascunho"
+, "Mailinglist"
+: ""
 
 , "Mailinglist Reject Reason"
 : ""
@@ -988,12 +1111,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Delete Archived Mail"
 : ""
 
+, "Prevent copying mails in the same account"
+: ""
+
 , "Enabled Features"
 : ""
 
 , "Enabled Features in Felamimail Application."
 : ""
 
+, "Account Migration"
+: ""
+
+, "Shows context menu for system accounts to approve migration"
+: ""
+
+, "Move notifications"
+: ""
+
+, "Move notifications to a subfolder via sieve"
+: ""
+
+, "Auto-Save Drafts"
+: ""
+
+, "Save drafts automatically while editing an email"
+: ""
+
+, "Only password download link"
+: ""
+
+, "Allow only password download link"
+: ""
+
 , "Tine 2.0 Flag"
 : ""
 
@@ -1012,6 +1162,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create template, trash, sent, draft and junks folders for system accounts"
 : ""
 
+, "Enable Spam Suspicion Strategy"
+: ""
+
+, "SEnable pam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy Config"
+: ""
+
+, "Spam User Processing Pipeline"
+: ""
+
+, "Confirm SPAM Suspicion Message"
+: ""
+
+, "Message for users when they press the info button in a SPAM suspicion toolbar."
+: ""
+
 , "Filter E-Mail URIs"
 : ""
 
@@ -1054,91 +1225,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "shared / adb_list accounts need to have a password set"
 : ""
 
-, "shared / adb_list accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an user_id set"
-: ""
-
-, "Seen"
-: "Visto"
-
-, "Deleted"
-: "Apagado"
-
-, "Draft"
-: "Rascunho"
-
-, "Flagged"
-: "Marcado"
-
-, "Bad recipient address syntax"
-: ""
-
-, "Recipient address rejected"
-: ""
-
-, "Invalid address format"
-: ""
-
-, "Error: %s"
-: ""
-
-, "Could not send message"
-: ""
-
-, "My Mail Download Links"
-: ""
-
-, "Out of Office reply from %1$s"
-: "Fora do escritório responder de %1$s"
-
-, "You have new mail from "
-: ""
-
-, "Can not combine \"allow external\" and \"allow only members\""
-: ""
-
-, "Message File Suggestion, Message File Suggestions"
-: [
-  ""
- ,""
-
-]
-, "Message File Suggestions"
-: ""
-
-, "Message File Location, Message File Locations"
-: [
-  ""
- ,""
-
-]
-, "Message File Locations"
-: ""
-
-, "Message ID Hash"
-: ""
-
-, "Message ID"
-: ""
-
-, "Model"
-: ""
-
-, "Record ID"
-: ""
-
-, "Record Title"
-: ""
-
-, "Node ID"
-: ""
-
-, "Type"
+, "Is default"
 : ""
 
 , "Email Account, Email Accounts"
@@ -1213,7 +1300,163 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "on"
 : "em"
 
-, "Is default"
+, "Message File Location, Message File Locations"
+: [
+  ""
+ ,""
+
+]
+, "Message File Locations"
+: ""
+
+, "Message ID Hash"
+: ""
+
+, "Message ID"
+: ""
+
+, "Model"
+: ""
+
+, "Record ID"
+: ""
+
+, "Record Title"
+: ""
+
+, "Node ID"
+: ""
+
+, "Message File Suggestion, Message File Suggestions"
+: [
+  ""
+ ,""
+
+]
+, "Message File Suggestions"
+: ""
+
+, "Out of Office reply from %1$s"
+: "Fora do escritório responder de %1$s"
+
+, "It is not allowed to redirect emails to self! Please change the recipient."
+: ""
+
+, "Redirects to external email domains are not allowed."
+: ""
+
+, "You have new mail from "
+: ""
+
+, "shared / adb_list accounts need to have an email set"
+: ""
+
+, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
+: ""
+
+, "userInternal accounts need to have an email set"
+: ""
+
+, "userInternal accounts need to have an user_id set"
+: ""
+
+, "Please choose a new email address for userInternal accounts"
+: ""
+
+, "system account for user does not exist"
+: ""
+
+, "Account type cannot be changed from {0} to {1}"
+: ""
+
+, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
+: ""
+
+, "Migration of this account has not been approved!"
+: ""
+
+, "Could not find email user xprops!"
+: ""
+
+, "Internal user accounts need a valid user"
+: ""
+
+, "System account of user is missing"
+: ""
+
+, "Bad recipient address syntax"
+: ""
+
+, "Recipient address rejected"
+: ""
+
+, "Original message not found, email was moved or deleted"
+: ""
+
+, "Invalid address format"
+: ""
+
+, "Error: %s"
+: ""
+
+, "Could not send message"
+: ""
+
+, "My Mail Download Links"
+: ""
+
+, "Seen"
+: "Visto"
+
+, "Deleted"
+: "Apagado"
+
+, "Draft"
+: "Rascunho"
+
+, "Flagged"
+: "Marcado"
+
+, "It is not allowed to copy e-mails in the same account."
+: ""
+
+, "Folder with name {0} already exists!"
+: ""
+
+, "Failure on create folder"
+: ""
+
+, "All inboxes of my email accounts"
+: "Todas as caixas de entrada de minhas contas de email"
+
+, "All unread mail"
+: "Todos os emails não lidos"
+
+, "All unread mail of my email accounts"
+: "Todos os emails não lidos das minhas contas de email"
+
+, "All highlighted mail"
+: "Todos os correios importantes"
+
+, "All highlighted mail of my email accounts"
+: "Todos os correios importantes das minhas contas de email"
+
+, "All drafts"
+: "Todos os rascunhos"
+
+, "All mails with the draft flag"
+: "Todos os correios marcados como rascunho"
+
+, "IMAP Hostname missing"
+: ""
+
+, "IMAP Credentials missing"
+: ""
+
+, "SMTP Hostname missing"
+: ""
+
+, "SMTP Credentials missing"
 : ""
 
 , "manage email accounts"
@@ -1228,10 +1471,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create new email accounts"
 : "Criar novas contas de email"
 
-
-
-
-
+, "Vacation"
+: "Férias"
 
 , "Account"
 : "Conta"
@@ -1239,21 +1480,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Folder"
 : "Pasta"
 
-, "{0} unread message"
-: "mensagem não lida"
-
-, "Signature"
-: "Assinatura"
-
 , "Message"
 : "Mensagem"
 
 , "record list"
 : "lista de registro"
 
-, "Vacation"
-: "Férias"
-
 , "Rule"
 : "Regra"
 
@@ -1263,15 +1495,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Flag list"
 : "Lista de marcadores"
 
-, "Message File Suggestion"
-: ""
+, "{0} unread message"
+: "mensagem não lida"
 
-, "Message File Location"
+, "Signature"
 : ""
 
 , "Email Account"
 : ""
 
+, "Message File Location"
+: ""
+
+, "Message File Suggestion"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
