@@ -5,79 +5,28 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Felamimail **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "All inboxes"
-: "Të gjitha postat hyrëse"
-
-, "Default Email Account"
-: "Llogaria E-Postë e paracaktuar"
-
-, "The default email account to use when sending mails."
-: "Llogaria E-poste e paracaktuar për tu përdorur kur dërgohet postë"
-
-, "Mark Email Automatically As Read"
+, "Can not combine \"allow external\" and \"allow only members\""
 : ""
 
-, "Is email marked as read automatically or by user action"
-: ""
+, "Delete"
+: "Fshij"
 
-, "Email Update Interval"
-: "Intervali i Përditësimit të E-Postës"
+, "Reply"
+: "Përgjigju"
 
-, "How often should Felamimail check for new Emails (in minutes)."
-: "Sa shpesh duhet të kërkoje Felamimail për E-postë të re (në minuta)"
+, "Reply To All"
+: "Përgjigju të gjithëve"
 
-, "Use for mailto links"
-: ""
+, "Forward"
+: "Përpara"
 
-, "Use Felamimail in mailto links, otherwise use the default desktop client."
-: ""
+, "Print Message"
+: "Mesazhi Printimit"
 
-, "Use for NOTES"
-: "Përdore për SHËNIME"
-
-, "Save Note default Value."
-: "Vlera e paracaktuar e shënimit të ruajtjes"
-
-, "Confirm Delete"
-: "Konfirmo Fshirjen"
-
-, "Show confirmation dialog when deleting mails."
-: "Trego dialogun e konfirmimit kur fshij postë"
-
-, ".eml file Attachment in forwarded mails"
-: ""
-
-, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
-: ""
-
-, "Message not available."
-: "Mesazhi i pa disponueshëm"
-
-, "File Message"
-: ""
-
-, "Filemanager ..."
-: ""
-
-, "Attachment"
-: ""
-
-, "Download"
-: ""
-
-, "{messageCount, plural, one {Message was filed} other {# messages where filed}}"
-: ""
-
-, "Success"
-: ""
-
-, "Error"
-: ""
-
-, "File Messages as Attachment"
-: ""
+, "Print Preview"
+: "Premiera Printimit"
 
 , "Add New Account"
 : ""
@@ -85,6 +34,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Permissions"
 : ""
 
+, "Rules"
+: ""
+
+, "Vacation, Vacations"
+: [
+  "Pushim"
+ ,"Pushime"
+
+]
 , "Account, Accounts"
 : [
   "Llogari"
@@ -94,7 +52,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Account Name"
 : "Emri Llogarisë"
 
-, "Account Type"
+, "Type"
+: ""
+
+, "Migration Approved"
+: ""
+
+, "Approve Migration"
+: ""
+
+, "Do you want to approve the migration of this account?"
 : ""
 
 , "User"
@@ -145,6 +112,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password"
 : "Fjalëkalim"
 
+, "Test IMAP Connection"
+: ""
+
 , "SMTP"
 : "SMTP"
 
@@ -166,6 +136,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password (optional)"
 : "Fjalëkalim (opsional)"
 
+, "Test SMTP Connection"
+: ""
+
 , "Sieve"
 : "Sieve"
 
@@ -175,6 +148,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Notification Email"
 : ""
 
+, "Auto-move notifications"
+: ""
+
+, "Auto-move notifications folder"
+: ""
+
 , "Other Settings"
 : "Konfigurime të tjera"
 
@@ -217,16 +196,22 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Reply-To Email"
 : ""
 
-, "Shared System Account"
+, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
 : ""
 
-, "Additional Personal System Account"
+, "Migration has not been approved."
 : ""
 
-, "Additional Personal External Account"
+, "It is not possible to convert the account to this type."
 : ""
 
-, "Default Personal System Account"
+, "System accounts cannot be created manually."
+: ""
+
+, "Mailinglist accounts cannot be created manually."
+: ""
+
+, "Account type change not possible"
 : ""
 
 , "E-Mail account needs a password"
@@ -244,53 +229,173 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "The grant edit the shared email account"
 : ""
 
-, "Click here to set To/CC/BCC."
-: "Kliko këtu për të vendosur Drejt/CC/BCC."
+, "Send Mails"
+: ""
 
-, "To:"
-: "Drejt"
+, "The grant to send mails via the email account"
+: ""
 
-, "Cc:"
-: "Cc"
+, "Warning"
+: ""
 
-, "Bcc:"
-: "Bcc"
+, "Server connection failed. Do you still want to save this setting and exit?"
+: ""
 
-, "Remove"
-: "Hiq"
+, "Connection succeed"
+: ""
 
-, "Compose email"
-: "Krijo E-Postë"
+, "Connecting to {0} server..."
+: ""
+
+, "Connection failed"
+: ""
+
+, "{server} Connection Status"
+: ""
+
+, "Save Message as"
+: ""
+
+, "File (in Filemanager) ..."
+: ""
+
+, "Attachment (of Record)"
+: ""
+
+, "Download"
+: ""
+
+, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
+: ""
+
+, "Success"
+: ""
+
+, "Error"
+: ""
+
+, "Save Messages as Attachment"
+: ""
+
+, "No Messages found."
+: ""
+
+, "It is SPAM"
+: ""
+
+, "It is not SPAM"
+: ""
+
+, "Compose"
+: "Krijo"
+
+, "Toggle highlighting"
+: "Nyjëzo(toggle)Theksimet"
+
+, "Mark read/unread"
+: "Shëno lexuar/i palexuar"
+
+, "Move"
+: ""
+
+, "Copy"
+: ""
+
+, "Import Messages"
+: ""
+
+, "Add Account"
+: "Shto Llogari"
+
+, "No target folder selected"
+: ""
+
+, "You need to select a target folder for the messages."
+: ""
+
+, "Wrong File Type"
+: ""
+
+, "Files of type eml allowed only."
+: ""
+
+, "Importing Messages..."
+: ""
+
+, "Id"
+: "Id"
+
+, "Attachments"
+: "Bashkangjitje"
+
+, "Flags"
+: "Flamuj"
+
+, "Subject"
+: "Subjekti"
+
+, "From (Email)"
+: "Nga (E-Postë)"
+
+, "From (Name)"
+: "Nga (Emër)"
+
+, "Sender"
+: "Dërgues"
 
 , "To"
 : "Drejt"
 
-, "CC"
+, "Sent"
+: "Dërgo"
+
+, "Received"
+: "Marrë"
+
+, "Folder, Folders"
+: [
+  "Dosje"
+ ,"Dosje"
+
+]
+, "Size"
+: "Madhësi"
+
+, "Answered"
+: "Përgjigjur"
+
+, "Forwarded"
+: "Ridrejtuar"
+
+, "This message might be SPAM"
 : ""
 
-, "BCC"
+, "Tine20"
 : ""
 
-, "Mass Mailing"
+, "Encrypted Message"
 : ""
 
-, "Signatures"
+, "Filed as:"
 : ""
 
-, "Name"
+, "Select Message File Location"
 : ""
 
-, "Is Default"
+, "Filing Messages"
 : ""
 
-, "Add Signature"
+, "Error Filing Message"
 : ""
 
-, "Edit Signature"
+, "Could not file message."
 : ""
 
-, "Delete Signature"
-: ""
+, "Send Reading Confirmation"
+: "Dërgo konfirmimin e leximit"
+
+, "Do you want to send a reading confirmation message?"
+: "Doni të dërgoni një mesazh konfimimi të leximit?"
 
 , "Empty Folder"
 : "Boshatis Dosjen"
@@ -301,12 +406,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "New {0}"
 : "E re {0}"
 
-, "Folder, Folders"
-: [
-  "Dosje"
- ,"Dosje"
-
-]
 , "Please enter the name of the new {0}:"
 : "Ju lutem vendosni emrin e {0} së re"
 
@@ -340,27 +439,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Update Folder List"
 : "Përditëso Listen e Dosjes"
 
-, "Add as \"To\""
-: "Shtoje si \"To\""
+, "Message not available."
+: "Mesazhi i pa disponueshëm"
 
-, "Add as \"Cc\""
-: "Shtoje si \"Cc\""
+, "Cancel"
+: "Anullo"
 
-, "Add as \"Bcc\""
-: "Shtoje si \"Bcc\""
+, "Ok"
+: "Ok"
 
-, "Remove from recipients"
-: "Hiqe nga marrësit"
+, "Folders of account {0}"
+: "Dosjet e llogarisë {0}"
 
-, "Loading Mail Addresses"
-: "Duke ngarkuar adresat e postës"
+, "Folders of all accounts"
+: "Dosje të tëgjithë llogarive"
+
+, "Compose email"
+: "Krijo E-Postë"
+
+, "CC"
+: ""
+
+, "BCC"
+: ""
+
+, "Mass Mailing"
+: ""
 
 , "Open in Felamimail"
 : ""
 
-, "Subject"
-: "Subjekti"
-
 , "From"
 : "Nga"
 
@@ -376,12 +484,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Show or hide header information"
 : "Trego ose fshih informacionin e Kokës(header)"
 
-, "Attachments"
-: "Bashkangjitje"
-
 , "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
 : ""
 
+, "Open"
+: ""
+
+, "Save As"
+: ""
+
+, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
+: ""
+
+, "Save as Record Attachment"
+: ""
+
+, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
+: ""
+
+, "Confirm SPAM Suspicion"
+: ""
+
+, "Yes, it is SPAM"
+: ""
+
+, "No, it is not"
+: ""
+
+, "(new message)"
+: "(mesazh i ri)"
+
+, "Select recipients for \"{0}\""
+: "Zgjidhni marrësin për \"{0}\""
+
+, "Signatures"
+: ""
+
+, "Name"
+: ""
+
+, "Is Default"
+: ""
+
+, "Add Signature"
+: ""
+
+, "Edit Signature"
+: ""
+
+, "Delete Signature"
+: ""
+
 , "Recipient filter"
 : "Flitri i marrësit"
 
@@ -391,105 +544,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "\"{0}\" recipients"
 : "\"{0}\" marrës"
 
-, "Total Messages:"
-: "Mesazhe Gjithsej:"
-
-, "Unread Messages:"
-: "Mesazhe të pa lexuara"
-
-, "Name on Server:"
-: "Emri në Server"
-
-, "Last update:"
-: "Përditësimi i fundit"
-
-, "Fetching messages... ({0} done)"
+, "Attachment"
 : ""
 
-, "{0} unread message, {0} unread messages"
-: [
-  "{0} mesazh i palexuar"
- ,"{0} mesazhe të palexuara"
-
-]
-, "(new message)"
-: "(mesazh i ri)"
-
-, "Select recipients for \"{0}\""
-: "Zgjidhni marrësin për \"{0}\""
-
-, "Mailvelope decryption Error [{0}]"
+, "Filemanager (Download link)"
 : ""
 
-, "To decrypt this message please install {0} with API support enabled"
+, "Filemanager (Download link, password)"
 : ""
 
-, "PGP encrypted Message"
+, "Filemanager (Systemlink)"
 : ""
 
-, "Delete"
-: "Fshij"
+, "Attachment Type"
+: ""
 
-, "Reply"
-: "Përgjigju"
+, "Click icon to change"
+: ""
 
-, "Reply To All"
-: "Përgjigju të gjithëve"
+, "name"
+: ""
 
-, "Forward"
-: "Përpara"
+, "size"
+: ""
 
-, "Print Message"
-: "Mesazhi Printimit"
+, "type"
+: ""
 
-, "Print Preview"
-: "Premiera Printimit"
+, "Vacation Message for {0}"
+: "Mesazh Pushimesh për {0}"
 
 , "Notification for {0}"
 : ""
 
-, "Edit Filter Rule"
-: "Modifiko Rregullin e Filtruesit"
-
-, "Apply filter if"
-: ""
-
-, "all conditions match"
-: ""
-
-, "any condition matches"
-: ""
-
-, "Do this action:"
-: "Kryej këtë veprim:"
-
-, "Keep a copy"
-: ""
-
-, "Move mail to folder"
-: "Lëviz postën në dosje"
-
-, "Redirect mail to address"
-: "Ridrejto postën tek adresa"
-
-, "Reject mail with this text"
-: "Refuzo postën me këtë tekst"
-
-, "Discard mail"
-: "Skarco postën"
-
-, "Auto-Reply mail with this text"
-: ""
-
-, "Keep mail"
-: "Mbaj postën"
-
-, "Sieve Filter Rules"
-: "Rregullat fitruese të Sieve"
-
-, "Sieve Filter Rules for {0}"
-: "Rregullat filtruese të sieve për {0}"
-
 , "Move up"
 : "Lëviz lartë"
 
@@ -511,6 +598,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Action"
 : "Veprim"
 
+, "Keep a copy"
+: ""
+
 , "is greater than"
 : "është më e madhe se"
 
@@ -523,8 +613,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Header \"{0}\" matches \"{1}\""
 : "Koka(header) \"{0}\" përputhet me \"{1}\""
 
-, "Vacation Message for {0}"
-: "Mesazh Pushimesh për {0}"
+, "Sieve Filter Rules"
+: "Rregullat fitruese të Sieve"
+
+, "Sieve Filter Rules for {0}"
+: "Rregullat filtruese të sieve për {0}"
+
+, "From (Email and Name)"
+: "Nga (E-Postë dhe Emër)"
+
+, "To (Email)"
+: "Drejt (E-Postë)"
+
+, "To (Email CC)"
+: ""
+
+, "Header contains"
+: "Koka (header) përmban"
+
+, "Header name"
+: "Emri i kokës (header)"
+
+, "Header value"
+: "Vlera e Kokës(header)"
+
+, "Header regex"
+: "Modeli i Kokës (header regex)"
+
+, "Edit Filter Rule"
+: "Modifiko Rregullin e Filtruesit"
+
+, "Apply filter if"
+: ""
+
+, "all conditions match"
+: ""
+
+, "any condition matches"
+: ""
+
+, "Do this action:"
+: "Kryej këtë veprim:"
+
+, "Move mail to folder"
+: "Lëviz postën në dosje"
+
+, "Redirect mail to address"
+: "Ridrejto postën tek adresa"
+
+, "Reject mail with this text"
+: "Refuzo postën me këtë tekst"
+
+, "Discard mail"
+: "Skarco postën"
+
+, "Auto-Reply mail with this text"
+: ""
+
+, "Keep mail"
+: "Mbaj postën"
 
 , "General"
 : "I Përgjithshëm"
@@ -577,62 +724,188 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Choose Template ..."
 : "Zgjidh Shabllonin"
 
-, "From (Email)"
-: "Nga (E-Postë)"
-
-, "From (Email and Name)"
-: "Nga (E-Postë dhe Emër)"
-
-, "To (Email)"
-: "Drejt (E-Postë)"
-
-, "To (Email CC)"
+, "Mailvelope decryption Error [{0}]"
 : ""
 
-, "Size"
-: "Madhësi"
-
-, "Header contains"
-: "Koka (header) përmban"
-
-, "Header name"
-: "Emri i kokës (header)"
-
-, "Header value"
-: "Vlera e Kokës(header)"
-
-, "Header regex"
-: "Modeli i Kokës (header regex)"
-
-, "Filemanager (Download link)"
+, "To decrypt this message please install {0} with API support enabled"
 : ""
 
-, "Filemanager (Download link, password)"
+, "PGP encrypted Message"
 : ""
 
-, "Filemanager (Systemlink)"
+, "GENDER_Message"
 : ""
 
-, "Attachment Type"
+, "Message, Messages"
+: [
+  "Mesazh"
+ ,"Mesazhe"
+
+]
+, "Subject/From"
+: "Subjekt/Nga"
+
+, "Cc"
+: "Cc"
+
+, "Bcc"
+: "Bcc"
+
+, "INBOX"
+: "Posta Hyrëse"
+
+, "Drafts"
+: "Drafte"
+
+, "Templates"
+: "Shabllone"
+
+, "Junk"
+: "Hedhurina"
+
+, "Trash"
+: "Plehëra"
+
+, "GENDER_Folder"
 : ""
 
-, "Click icon to change"
+, "record list, record lists"
+: [
+  "lista e të dhënave"
+ ,"listat e të dhënave"
+
+]
+, "Rule, Rules"
+: [
+  "Rregull"
+ ,"Rregulla"
+
+]
+, "Flag, Flags"
+: [
+  "Flamur"
+ ,"Flamuj"
+
+]
+, "Flag list, Flag lists"
+: [
+  "Lista e Flamujve"
+ ,"Listat e Flamujve"
+
+]
+, "Total Messages:"
+: "Mesazhe Gjithsej:"
+
+, "Unread Messages:"
+: "Mesazhe të pa lexuara"
+
+, "Name on Server:"
+: "Emri në Server"
+
+, "Last update:"
+: "Përditësimi i fundit"
+
+, "Fetching messages... ({0} done)"
 : ""
 
-, "name"
+, "{0} unread message, {0} unread messages"
+: [
+  "{0} mesazh i palexuar"
+ ,"{0} mesazhe të palexuara"
+
+]
+, "New Mail"
+: "Postë e Re"
+
+, "Email"
+: "E-Postë"
+
+, "Active Vacation Message"
+: "Mesazh Aktiv Pushimesh "
+
+, "Email account \"{0}\" has an active vacation message."
+: "Llogaria e E-Postës  \"{0}\" ka një mesazh aktiv pushimesh"
+
+, "Poll URL: {0}"
 : ""
 
-, "size"
+, "{0} as default mailer"
 : ""
 
-, "type"
-: ""
+, "New mails"
+: "Posta të reja"
 
-, "Failure"
-: ""
+, "You got {0} new mail(s) in folder {1} ({2})."
+: "Ju keni {0} postë të re në dosjen {1} ({2})."
 
-, "This file is already attached to this record."
-: ""
+, "IMAP Credentials for {0}"
+: "kredencialet IMAP për {0}"
+
+, "Credentials"
+: "Kredencialet"
+
+, "IMAP Error"
+: "Gabim IMAP"
+
+, "No connection to IMAP server."
+: "Nuk ka lidhje tek serveri IMAP"
+
+, "IMAP Credentials Error"
+: "Gabim kredencialesh IMAP"
+
+, "Your email credentials are wrong. Please contact your administrator"
+: "Kredencialet tuaja të E-Postës janë gabim. Ju lutem kontaktoni administratorin tuaj"
+
+, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
+: "Një nga dosjet tuaja është fshirë ose riemëruar nga një klient tjetër. Ju lutem përditësonilistën e dosjeve për këtë llogari"
+
+, "SMTP Error"
+: "Gabim SMTP"
+
+, "No connection to SMTP server."
+: "Nuk ka lidhje tek serveri SMTP"
+
+, "Sieve Error"
+: "Gabim Sieve"
+
+, "No connection to Sieve server."
+: "Nuk ka lidhje tek servieri Sieve"
+
+, "Save Sieve Script Error"
+: "Ruaj gabimin e dorëshkrimit të Sieve "
+
+, "Could not save script on Sieve server."
+: "Nuk mund të ruhej dorëshkrimi në serverin e Sieve"
+
+, "Add as \"To\""
+: "Shtoje si \"To\""
+
+, "Add as \"Cc\""
+: "Shtoje si \"Cc\""
+
+, "Add as \"Bcc\""
+: "Shtoje si \"Bcc\""
+
+, "Remove from recipients"
+: "Hiqe nga marrësit"
+
+, "Loading Mail Addresses"
+: "Duke ngarkuar adresat e postës"
+
+, "Click here to set To/CC/BCC."
+: "Kliko këtu për të vendosur Drejt/CC/BCC."
+
+, "To:"
+: "Drejt"
+
+, "Cc:"
+: "Cc"
+
+, "Bcc:"
+: "Bcc"
+
+, "Remove"
+: "Hiq"
 
 , "Send"
 : "Dërgo"
@@ -714,13 +987,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 
 , "Signature, Signatures"
 : [
-  "Nënshkrim"
- ,"Nënshkrim"
+  ""
+ ,""
 
 ]
-, "Warning"
-: ""
-
 , "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
 : ""
 
@@ -736,230 +1006,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "No recipients set."
 : "Nuk janë vendosur marrës"
 
+, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
+: ""
+
 , "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
 : ""
 
-, "Message, Messages"
-: [
-  "Mesazh"
- ,"Mesazhe"
+, "All inboxes"
+: "Të gjitha postat hyrëse"
 
-]
-, "Subject/From"
-: "Subjekt/Nga"
+, "Default Email Account"
+: "Llogaria E-Postë e paracaktuar"
 
-, "From (Name)"
-: "Nga (Emër)"
+, "The default email account to use when sending mails."
+: "Llogaria E-poste e paracaktuar për tu përdorur kur dërgohet postë"
 
-, "Cc"
-: "Cc"
-
-, "Bcc"
-: "Bcc"
-
-, "Flags"
-: "Flamuj"
-
-, "Received"
-: "Marrë"
-
-, "INBOX"
-: "Posta Hyrëse"
-
-, "Drafts"
-: "Drafte"
-
-, "Sent"
-: "Dërgo"
-
-, "Templates"
-: "Shabllone"
-
-, "Junk"
-: "Hedhurina"
-
-, "Trash"
-: "Plehëra"
-
-, "record list, record lists"
-: [
-  "lista e të dhënave"
- ,"listat e të dhënave"
-
-]
-, "Vacation, Vacations"
-: [
-  "Pushim"
- ,"Pushime"
-
-]
-, "Rule, Rules"
-: [
-  "Rregull"
- ,"Rregulla"
-
-]
-, "Flag, Flags"
-: [
-  "Flamur"
- ,"Flamuj"
-
-]
-, "Flag list, Flag lists"
-: [
-  "Lista e Flamujve"
- ,"Listat e Flamujve"
-
-]
-, "No Messages found."
+, "Mark Email Automatically As Read"
 : ""
 
-, "Compose"
-: "Krijo"
-
-, "Toggle highlighting"
-: "Nyjëzo(toggle)Theksimet"
-
-, "Mark read/unread"
-: "Shëno lexuar/i palexuar"
-
-, "Move"
+, "Is email marked as read automatically or by user action"
 : ""
 
-, "Add Account"
-: "Shto Llogari"
+, "Email Update Interval"
+: "Intervali i Përditësimit të E-Postës"
 
-, "Id"
-: "Id"
+, "How often should Felamimail check for new Emails (in minutes)."
+: "Sa shpesh duhet të kërkoje Felamimail për E-postë të re (në minuta)"
 
-, "Sender"
-: "Dërgues"
-
-, "Answered"
-: "Përgjigjur"
-
-, "Forwarded"
-: "Ridrejtuar"
-
-, "Tine20"
+, "Use for mailto links"
 : ""
 
-, "Filed as:"
+, "Use Felamimail in mailto links, otherwise use the default desktop client."
 : ""
 
-, "Select Message File Location"
+, "Use for NOTES"
+: "Përdore për SHËNIME"
+
+, "Save Note default Value."
+: "Vlera e paracaktuar e shënimit të ruajtjes"
+
+, "Confirm Delete"
+: "Konfirmo Fshirjen"
+
+, "Show confirmation dialog when deleting mails."
+: "Trego dialogun e konfirmimit kur fshij postë"
+
+, ".eml file Attachment in forwarded mails"
 : ""
 
-, "Filing Messages"
+, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
 : ""
 
-, "Error Filing Message"
+, "Default Font"
 : ""
 
-, "Could not file message."
+, "Setting the default font in the E-Mail app"
 : ""
 
-, "Send Reading Confirmation"
-: "Dërgo konfirmimin e leximit"
-
-, "Do you want to send a reading confirmation message?"
-: "Doni të dërgoni një mesazh konfimimi të leximit?"
-
-, "New Mail"
-: "Postë e Re"
-
-, "Email"
-: "E-Postë"
-
-, "Active Vacation Message"
-: "Mesazh Aktiv Pushimesh "
-
-, "Email account \"{0}\" has an active vacation message."
-: "Llogaria e E-Postës  \"{0}\" ka një mesazh aktiv pushimesh"
-
-, "Poll URL: {0}"
+, "Mail Type"
 : ""
 
-, "{0} as default mailer"
+, "Possible mail types."
 : ""
 
-, "New mails"
-: "Posta të reja"
+, "Additional Personal External Account"
+: ""
 
-, "You got {0} new mail(s) in folder {1} ({2})."
-: "Ju keni {0} postë të re në dosjen {1} ({2})."
+, "Shared System Account"
+: ""
 
-, "IMAP Credentials for {0}"
-: "kredencialet IMAP për {0}"
+, "Additional Personal System Account"
+: ""
 
-, "Credentials"
-: "Kredencialet"
+, "Default Personal System Account"
+: ""
 
-, "IMAP Error"
-: "Gabim IMAP"
-
-, "No connection to IMAP server."
-: "Nuk ka lidhje tek serveri IMAP"
-
-, "IMAP Credentials Error"
-: "Gabim kredencialesh IMAP"
-
-, "Your email credentials are wrong. Please contact your administrator"
-: "Kredencialet tuaja të E-Postës janë gabim. Ju lutem kontaktoni administratorin tuaj"
-
-, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
-: "Një nga dosjet tuaja është fshirë ose riemëruar nga një klient tjetër. Ju lutem përditësonilistën e dosjeve për këtë llogari"
-
-, "SMTP Error"
-: "Gabim SMTP"
-
-, "No connection to SMTP server."
-: "Nuk ka lidhje tek serveri SMTP"
-
-, "Sieve Error"
-: "Gabim Sieve"
-
-, "No connection to Sieve server."
-: "Nuk ka lidhje tek servieri Sieve"
-
-, "Save Sieve Script Error"
-: "Ruaj gabimin e dorëshkrimit të Sieve "
-
-, "Could not save script on Sieve server."
-: "Nuk mund të ruhej dorëshkrimi në serverin e Sieve"
-
-, "Cancel"
-: "Anullo"
-
-, "Ok"
-: "Ok"
-
-, "Folders of account {0}"
-: "Dosjet e llogarisë {0}"
-
-, "Folders of all accounts"
-: "Dosje të tëgjithë llogarive"
-
-, "All inboxes of my email accounts"
-: "Të gjithë Postat Hyrëse për llogaritë e mia E-Postë"
-
-, "All unread mail"
-: "Të gjithë postat e palexuara"
-
-, "All unread mail of my email accounts"
-: "Të gjithë postat e palexuara të llogarive të mia E-Postë"
-
-, "All highlighted mail"
-: "Të gjithë postat e Theksuara"
-
-, "All highlighted mail of my email accounts"
-: "Të gjithë postat e theksuara të llogarive të mia E-Postë"
-
-, "All drafts"
-: "Gjithë draftet"
-
-, "All mails with the draft flag"
-: "Gjithë postat me shënimin Draft"
+, "Mailinglist"
+: ""
 
 , "Mailinglist Reject Reason"
 : ""
@@ -988,12 +1111,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Delete Archived Mail"
 : ""
 
+, "Prevent copying mails in the same account"
+: ""
+
 , "Enabled Features"
 : ""
 
 , "Enabled Features in Felamimail Application."
 : ""
 
+, "Account Migration"
+: ""
+
+, "Shows context menu for system accounts to approve migration"
+: ""
+
+, "Move notifications"
+: ""
+
+, "Move notifications to a subfolder via sieve"
+: ""
+
+, "Auto-Save Drafts"
+: ""
+
+, "Save drafts automatically while editing an email"
+: ""
+
+, "Only password download link"
+: ""
+
+, "Allow only password download link"
+: ""
+
 , "Tine 2.0 Flag"
 : ""
 
@@ -1012,6 +1162,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create template, trash, sent, draft and junks folders for system accounts"
 : ""
 
+, "Enable Spam Suspicion Strategy"
+: ""
+
+, "SEnable pam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy Config"
+: ""
+
+, "Spam User Processing Pipeline"
+: ""
+
+, "Confirm SPAM Suspicion Message"
+: ""
+
+, "Message for users when they press the info button in a SPAM suspicion toolbar."
+: ""
+
 , "Filter E-Mail URIs"
 : ""
 
@@ -1054,91 +1225,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "shared / adb_list accounts need to have a password set"
 : ""
 
-, "shared / adb_list accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an user_id set"
-: ""
-
-, "Seen"
-: "Parë"
-
-, "Deleted"
-: "Fshirë"
-
-, "Draft"
-: "Draft"
-
-, "Flagged"
-: "Shënuar"
-
-, "Bad recipient address syntax"
-: ""
-
-, "Recipient address rejected"
-: ""
-
-, "Invalid address format"
-: ""
-
-, "Error: %s"
-: "Gabim: %s"
-
-, "Could not send message"
-: "Nuk mund të dërgohej mesazhi"
-
-, "My Mail Download Links"
-: ""
-
-, "Out of Office reply from %1$s"
-: "Përgjigje 'Jashtë Zyre' nga %1$s"
-
-, "You have new mail from "
-: ""
-
-, "Can not combine \"allow external\" and \"allow only members\""
-: ""
-
-, "Message File Suggestion, Message File Suggestions"
-: [
-  ""
- ,""
-
-]
-, "Message File Suggestions"
-: ""
-
-, "Message File Location, Message File Locations"
-: [
-  ""
- ,""
-
-]
-, "Message File Locations"
-: ""
-
-, "Message ID Hash"
-: ""
-
-, "Message ID"
-: ""
-
-, "Model"
-: ""
-
-, "Record ID"
-: ""
-
-, "Record Title"
-: ""
-
-, "Node ID"
-: ""
-
-, "Type"
+, "Is default"
 : ""
 
 , "Email Account, Email Accounts"
@@ -1213,7 +1300,163 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "on"
 : "në"
 
-, "Is default"
+, "Message File Location, Message File Locations"
+: [
+  ""
+ ,""
+
+]
+, "Message File Locations"
+: ""
+
+, "Message ID Hash"
+: ""
+
+, "Message ID"
+: ""
+
+, "Model"
+: ""
+
+, "Record ID"
+: ""
+
+, "Record Title"
+: ""
+
+, "Node ID"
+: ""
+
+, "Message File Suggestion, Message File Suggestions"
+: [
+  ""
+ ,""
+
+]
+, "Message File Suggestions"
+: ""
+
+, "Out of Office reply from %1$s"
+: "Përgjigje 'Jashtë Zyre' nga %1$s"
+
+, "It is not allowed to redirect emails to self! Please change the recipient."
+: ""
+
+, "Redirects to external email domains are not allowed."
+: ""
+
+, "You have new mail from "
+: ""
+
+, "shared / adb_list accounts need to have an email set"
+: ""
+
+, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
+: ""
+
+, "userInternal accounts need to have an email set"
+: ""
+
+, "userInternal accounts need to have an user_id set"
+: ""
+
+, "Please choose a new email address for userInternal accounts"
+: ""
+
+, "system account for user does not exist"
+: ""
+
+, "Account type cannot be changed from {0} to {1}"
+: ""
+
+, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
+: ""
+
+, "Migration of this account has not been approved!"
+: ""
+
+, "Could not find email user xprops!"
+: ""
+
+, "Internal user accounts need a valid user"
+: ""
+
+, "System account of user is missing"
+: ""
+
+, "Bad recipient address syntax"
+: ""
+
+, "Recipient address rejected"
+: ""
+
+, "Original message not found, email was moved or deleted"
+: ""
+
+, "Invalid address format"
+: ""
+
+, "Error: %s"
+: "Gabim: %s"
+
+, "Could not send message"
+: "Nuk mund të dërgohej mesazhi"
+
+, "My Mail Download Links"
+: ""
+
+, "Seen"
+: "Parë"
+
+, "Deleted"
+: "Fshirë"
+
+, "Draft"
+: "Draft"
+
+, "Flagged"
+: "Shënuar"
+
+, "It is not allowed to copy e-mails in the same account."
+: ""
+
+, "Folder with name {0} already exists!"
+: ""
+
+, "Failure on create folder"
+: ""
+
+, "All inboxes of my email accounts"
+: "Të gjithë Postat Hyrëse për llogaritë e mia E-Postë"
+
+, "All unread mail"
+: "Të gjithë postat e palexuara"
+
+, "All unread mail of my email accounts"
+: "Të gjithë postat e palexuara të llogarive të mia E-Postë"
+
+, "All highlighted mail"
+: "Të gjithë postat e Theksuara"
+
+, "All highlighted mail of my email accounts"
+: "Të gjithë postat e theksuara të llogarive të mia E-Postë"
+
+, "All drafts"
+: "Gjithë draftet"
+
+, "All mails with the draft flag"
+: "Gjithë postat me shënimin Draft"
+
+, "IMAP Hostname missing"
+: ""
+
+, "IMAP Credentials missing"
+: ""
+
+, "SMTP Hostname missing"
+: ""
+
+, "SMTP Credentials missing"
 : ""
 
 , "manage email accounts"
@@ -1228,10 +1471,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create new email accounts"
 : "Krijo llogari të re E-Poste"
 
-
-
-
-
+, "Vacation"
+: "Pushim"
 
 , "Account"
 : "Llogari"
@@ -1239,21 +1480,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Folder"
 : "Dosje"
 
-, "{0} unread message"
-: "{0} mesazh i palexuar"
-
-, "Signature"
-: "Nënshkrim"
-
 , "Message"
 : "Mesazh"
 
 , "record list"
 : "lista e të dhënave"
 
-, "Vacation"
-: "Pushim"
-
 , "Rule"
 : "Rregull"
 
@@ -1263,15 +1495,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Flag list"
 : "Lista e Flamujve"
 
-, "Message File Suggestion"
-: ""
+, "{0} unread message"
+: "{0} mesazh i palexuar"
 
-, "Message File Location"
+, "Signature"
 : ""
 
 , "Email Account"
 : ""
 
+, "Message File Location"
+: ""
+
+, "Message File Suggestion"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
