@@ -5,79 +5,28 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Felamimail **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:17+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "All inboxes"
-: "Alla inkorgar"
-
-, "Default Email Account"
-: "Standard e-postkonto"
-
-, "The default email account to use when sending mails."
-: "Den förvalda e-post kontot för att använda när du skickar e-post."
-
-, "Mark Email Automatically As Read"
+, "Can not combine \"allow external\" and \"allow only members\""
 : ""
 
-, "Is email marked as read automatically or by user action"
-: ""
+, "Delete"
+: "Radera"
 
-, "Email Update Interval"
-: "E-post Updaterings Intervall"
+, "Reply"
+: "Svara"
 
-, "How often should Felamimail check for new Emails (in minutes)."
-: ""
+, "Reply To All"
+: "Svara till alla"
 
-, "Use for mailto links"
-: ""
+, "Forward"
+: "Vidarebefodra"
 
-, "Use Felamimail in mailto links, otherwise use the default desktop client."
-: ""
+, "Print Message"
+: "Utskrifts Meddelande"
 
-, "Use for NOTES"
-: "Använd för NOTERINGAR"
-
-, "Save Note default Value."
-: "Spara Notifiering standard värde"
-
-, "Confirm Delete"
-: "bekräfta borttagning"
-
-, "Show confirmation dialog when deleting mails."
-: "Visa bekräftelseruta när du tar bort e-post."
-
-, ".eml file Attachment in forwarded mails"
-: ""
-
-, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
-: ""
-
-, "Message not available."
-: "Meddelande är inte tillgängligt."
-
-, "File Message"
-: ""
-
-, "Filemanager ..."
-: ""
-
-, "Attachment"
-: ""
-
-, "Download"
-: ""
-
-, "{messageCount, plural, one {Message was filed} other {# messages where filed}}"
-: ""
-
-, "Success"
-: ""
-
-, "Error"
-: ""
-
-, "File Messages as Attachment"
-: ""
+, "Print Preview"
+: "Förhandsvisa"
 
 , "Add New Account"
 : "Lägg till nytt konto"
@@ -85,6 +34,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Permissions"
 : ""
 
+, "Rules"
+: ""
+
+, "Vacation, Vacations"
+: [
+  "Semester"
+ ,"Semestrar"
+
+]
 , "Account, Accounts"
 : [
   "Konto"
@@ -94,7 +52,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Account Name"
 : "Kontonamn"
 
-, "Account Type"
+, "Type"
+: ""
+
+, "Migration Approved"
+: ""
+
+, "Approve Migration"
+: ""
+
+, "Do you want to approve the migration of this account?"
 : ""
 
 , "User"
@@ -145,6 +112,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password"
 : "Lösenord"
 
+, "Test IMAP Connection"
+: ""
+
 , "SMTP"
 : "SMTP"
 
@@ -166,6 +136,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password (optional)"
 : "Lösenord (tillval)"
 
+, "Test SMTP Connection"
+: ""
+
 , "Sieve"
 : "Filter"
 
@@ -175,6 +148,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Notification Email"
 : ""
 
+, "Auto-move notifications"
+: ""
+
+, "Auto-move notifications folder"
+: ""
+
 , "Other Settings"
 : "Andra Inställningar"
 
@@ -217,16 +196,22 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Reply-To Email"
 : ""
 
-, "Shared System Account"
+, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
 : ""
 
-, "Additional Personal System Account"
+, "Migration has not been approved."
 : ""
 
-, "Additional Personal External Account"
+, "It is not possible to convert the account to this type."
 : ""
 
-, "Default Personal System Account"
+, "System accounts cannot be created manually."
+: ""
+
+, "Mailinglist accounts cannot be created manually."
+: ""
+
+, "Account type change not possible"
 : ""
 
 , "E-Mail account needs a password"
@@ -244,52 +229,172 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "The grant edit the shared email account"
 : ""
 
-, "Click here to set To/CC/BCC."
-: "Klicka här för att ställa in / CC / BCC."
+, "Send Mails"
+: ""
 
-, "To:"
-: "Till:"
+, "The grant to send mails via the email account"
+: ""
 
-, "Cc:"
-: "Cc:"
+, "Warning"
+: ""
 
-, "Bcc:"
-: "Bcc:"
+, "Server connection failed. Do you still want to save this setting and exit?"
+: ""
 
-, "Remove"
-: "Flytta"
+, "Connection succeed"
+: ""
 
-, "Compose email"
-: "Skriv mail"
+, "Connecting to {0} server..."
+: ""
+
+, "Connection failed"
+: ""
+
+, "{server} Connection Status"
+: ""
+
+, "Save Message as"
+: ""
+
+, "File (in Filemanager) ..."
+: ""
+
+, "Attachment (of Record)"
+: ""
+
+, "Download"
+: ""
+
+, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
+: ""
+
+, "Success"
+: ""
+
+, "Error"
+: ""
+
+, "Save Messages as Attachment"
+: ""
+
+, "No Messages found."
+: ""
+
+, "It is SPAM"
+: ""
+
+, "It is not SPAM"
+: ""
+
+, "Compose"
+: "Skapa nytt mail"
+
+, "Toggle highlighting"
+: "Växla markering"
+
+, "Mark read/unread"
+: "Markera läst/oläst"
+
+, "Move"
+: ""
+
+, "Copy"
+: ""
+
+, "Import Messages"
+: ""
+
+, "Add Account"
+: "Lägg till användare"
+
+, "No target folder selected"
+: ""
+
+, "You need to select a target folder for the messages."
+: ""
+
+, "Wrong File Type"
+: ""
+
+, "Files of type eml allowed only."
+: ""
+
+, "Importing Messages..."
+: ""
+
+, "Id"
+: "Id"
+
+, "Attachments"
+: "Bifogade"
+
+, "Flags"
+: "Flaggor"
+
+, "Subject"
+: "Ämne"
+
+, "From (Email)"
+: "Från (E-post)"
+
+, "From (Name)"
+: "Från (Namn)"
+
+, "Sender"
+: "Sändare"
 
 , "To"
 : "Till"
 
-, "CC"
+, "Sent"
+: "Skickat"
+
+, "Received"
+: "Mottaget"
+
+, "Folder, Folders"
+: [
+  "Mapp"
+ ,"Mappar"
+
+]
+, "Size"
+: "Storlek"
+
+, "Answered"
+: "Svarad"
+
+, "Forwarded"
+: "Vidarebefodrat"
+
+, "This message might be SPAM"
 : ""
 
-, "BCC"
+, "Tine20"
 : ""
 
-, "Mass Mailing"
+, "Encrypted Message"
 : ""
 
-, "Signatures"
+, "Filed as:"
 : ""
 
-, "Name"
+, "Select Message File Location"
 : ""
 
-, "Is Default"
+, "Filing Messages"
 : ""
 
-, "Add Signature"
+, "Error Filing Message"
 : ""
 
-, "Edit Signature"
+, "Could not file message."
 : ""
 
-, "Delete Signature"
+, "Send Reading Confirmation"
+: ""
+
+, "Do you want to send a reading confirmation message?"
 : ""
 
 , "Empty Folder"
@@ -301,12 +406,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "New {0}"
 : "Ny {0}"
 
-, "Folder, Folders"
-: [
-  "Mapp"
- ,"Mappar"
-
-]
 , "Please enter the name of the new {0}:"
 : "Ange namnet på den nya {0}:"
 
@@ -340,27 +439,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Update Folder List"
 : "Uppdatera mapp lista"
 
-, "Add as \"To\""
-: "Lägg till som \"Till\""
+, "Message not available."
+: "Meddelande är inte tillgängligt."
 
-, "Add as \"Cc\""
-: "Lägg till som \"Cc\""
+, "Cancel"
+: "Avbryt"
 
-, "Add as \"Bcc\""
-: "Lägg till som \"Bcc\""
+, "Ok"
+: "Ok"
 
-, "Remove from recipients"
-: "Ta bort från mottagarna"
+, "Folders of account {0}"
+: "Mappar av konto {0}"
 
-, "Loading Mail Addresses"
-: "Laddar mailadresser"
+, "Folders of all accounts"
+: "Mappar av alla konton"
+
+, "Compose email"
+: "Skriv mail"
+
+, "CC"
+: ""
+
+, "BCC"
+: ""
+
+, "Mass Mailing"
+: ""
 
 , "Open in Felamimail"
 : ""
 
-, "Subject"
-: "Ämne"
-
 , "From"
 : "Från"
 
@@ -376,12 +484,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Show or hide header information"
 : "Visa eller dölj rubrik-information"
 
-, "Attachments"
-: "Bifogade"
-
 , "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
 : ""
 
+, "Open"
+: ""
+
+, "Save As"
+: ""
+
+, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
+: ""
+
+, "Save as Record Attachment"
+: ""
+
+, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
+: ""
+
+, "Confirm SPAM Suspicion"
+: ""
+
+, "Yes, it is SPAM"
+: ""
+
+, "No, it is not"
+: ""
+
+, "(new message)"
+: "(nytt meddelande)"
+
+, "Select recipients for \"{0}\""
+: "Välj mottagare för \"{0}\""
+
+, "Signatures"
+: ""
+
+, "Name"
+: ""
+
+, "Is Default"
+: ""
+
+, "Add Signature"
+: ""
+
+, "Edit Signature"
+: ""
+
+, "Delete Signature"
+: ""
+
 , "Recipient filter"
 : "Motaggar filter"
 
@@ -391,105 +544,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "\"{0}\" recipients"
 : "\"{0}\" mottagare"
 
-, "Total Messages:"
-: "Totala Meddelanden: "
-
-, "Unread Messages:"
-: "Olästa Meddelanden:"
-
-, "Name on Server:"
-: "Namn på Server:"
-
-, "Last update:"
-: "Senaste uppdatering:"
-
-, "Fetching messages... ({0} done)"
+, "Attachment"
 : ""
 
-, "{0} unread message, {0} unread messages"
-: [
-  "{0} oläst meddelande"
- ,"{0} olästa meddelanden"
-
-]
-, "(new message)"
-: "(nytt meddelande)"
-
-, "Select recipients for \"{0}\""
-: "Välj mottagare för \"{0}\""
-
-, "Mailvelope decryption Error [{0}]"
+, "Filemanager (Download link)"
 : ""
 
-, "To decrypt this message please install {0} with API support enabled"
+, "Filemanager (Download link, password)"
 : ""
 
-, "PGP encrypted Message"
+, "Filemanager (Systemlink)"
 : ""
 
-, "Delete"
-: "Radera"
+, "Attachment Type"
+: ""
 
-, "Reply"
-: "Svara"
+, "Click icon to change"
+: ""
 
-, "Reply To All"
-: "Svara till alla"
+, "name"
+: ""
 
-, "Forward"
-: "Vidarebefodra"
+, "size"
+: ""
 
-, "Print Message"
-: "Utskrifts Meddelande"
+, "type"
+: ""
 
-, "Print Preview"
-: "Förhandsvisa"
+, "Vacation Message for {0}"
+: "Semester Meddelande för {0}"
 
 , "Notification for {0}"
 : ""
 
-, "Edit Filter Rule"
-: "Ändra Filter Regel"
-
-, "Apply filter if"
-: ""
-
-, "all conditions match"
-: ""
-
-, "any condition matches"
-: ""
-
-, "Do this action:"
-: "Gör denna åtgärd:"
-
-, "Keep a copy"
-: ""
-
-, "Move mail to folder"
-: "Flytta mail till mapp"
-
-, "Redirect mail to address"
-: "Omdirigera e-post till adress"
-
-, "Reject mail with this text"
-: "Avvisa post med denna text"
-
-, "Discard mail"
-: "kassera post"
-
-, "Auto-Reply mail with this text"
-: ""
-
-, "Keep mail"
-: "Behåll epost"
-
-, "Sieve Filter Rules"
-: "Sieve Filter Rules"
-
-, "Sieve Filter Rules for {0}"
-: "Sålla filter regler för {0}"
-
 , "Move up"
 : "Flytta upp"
 
@@ -511,6 +598,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Action"
 : "Handling"
 
+, "Keep a copy"
+: ""
+
 , "is greater than"
 : "är större än"
 
@@ -523,8 +613,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Header \"{0}\" matches \"{1}\""
 : "Huvudrubrik \"{0}\" matchar \"{1}\""
 
-, "Vacation Message for {0}"
-: "Semester Meddelande för {0}"
+, "Sieve Filter Rules"
+: "Sieve Filter Rules"
+
+, "Sieve Filter Rules for {0}"
+: "Sålla filter regler för {0}"
+
+, "From (Email and Name)"
+: "Från (Mail och Namn)"
+
+, "To (Email)"
+: "Till (Mail)"
+
+, "To (Email CC)"
+: ""
+
+, "Header contains"
+: "Huvudrubriks innehåll"
+
+, "Header name"
+: "Huvudrubrik namn"
+
+, "Header value"
+: "Huvudrubrik värde"
+
+, "Header regex"
+: "Huvudrubrik regex"
+
+, "Edit Filter Rule"
+: "Ändra Filter Regel"
+
+, "Apply filter if"
+: ""
+
+, "all conditions match"
+: ""
+
+, "any condition matches"
+: ""
+
+, "Do this action:"
+: "Gör denna åtgärd:"
+
+, "Move mail to folder"
+: "Flytta mail till mapp"
+
+, "Redirect mail to address"
+: "Omdirigera e-post till adress"
+
+, "Reject mail with this text"
+: "Avvisa post med denna text"
+
+, "Discard mail"
+: "kassera post"
+
+, "Auto-Reply mail with this text"
+: ""
+
+, "Keep mail"
+: "Behåll epost"
 
 , "General"
 : "Ällmän"
@@ -577,62 +724,188 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Choose Template ..."
 : "Välj mall"
 
-, "From (Email)"
-: "Från (E-post)"
-
-, "From (Email and Name)"
-: "Från (Mail och Namn)"
-
-, "To (Email)"
-: "Till (Mail)"
-
-, "To (Email CC)"
+, "Mailvelope decryption Error [{0}]"
 : ""
 
-, "Size"
-: "Storlek"
-
-, "Header contains"
-: "Huvudrubriks innehåll"
-
-, "Header name"
-: "Huvudrubrik namn"
-
-, "Header value"
-: "Huvudrubrik värde"
-
-, "Header regex"
-: "Huvudrubrik regex"
-
-, "Filemanager (Download link)"
+, "To decrypt this message please install {0} with API support enabled"
 : ""
 
-, "Filemanager (Download link, password)"
+, "PGP encrypted Message"
 : ""
 
-, "Filemanager (Systemlink)"
+, "GENDER_Message"
 : ""
 
-, "Attachment Type"
+, "Message, Messages"
+: [
+  "Meddelande"
+ ,"Meddelanden"
+
+]
+, "Subject/From"
+: "Ämne/Form"
+
+, "Cc"
+: "Cc"
+
+, "Bcc"
+: "Bcc"
+
+, "INBOX"
+: "INKORG"
+
+, "Drafts"
+: "utkast"
+
+, "Templates"
+: "mallar"
+
+, "Junk"
+: "Skräppost"
+
+, "Trash"
+: "Skräp"
+
+, "GENDER_Folder"
 : ""
 
-, "Click icon to change"
+, "record list, record lists"
+: [
+  "postlista"
+ ,"postlistor"
+
+]
+, "Rule, Rules"
+: [
+  "Regel"
+ ,"Regler"
+
+]
+, "Flag, Flags"
+: [
+  "Flagga"
+ ,"Flaggar"
+
+]
+, "Flag list, Flag lists"
+: [
+  "Flagg lista"
+ ,"Flagg listor"
+
+]
+, "Total Messages:"
+: "Totala Meddelanden: "
+
+, "Unread Messages:"
+: "Olästa Meddelanden:"
+
+, "Name on Server:"
+: "Namn på Server:"
+
+, "Last update:"
+: "Senaste uppdatering:"
+
+, "Fetching messages... ({0} done)"
 : ""
 
-, "name"
+, "{0} unread message, {0} unread messages"
+: [
+  "{0} oläst meddelande"
+ ,"{0} olästa meddelanden"
+
+]
+, "New Mail"
+: "Nytt Mail"
+
+, "Email"
+: "Mail"
+
+, "Active Vacation Message"
+: "Aktuellt semestermeddelande"
+
+, "Email account \"{0}\" has an active vacation message."
+: "E-postkonto \"{0}\" har ett aktivt semestermeddelande."
+
+, "Poll URL: {0}"
 : ""
 
-, "size"
+, "{0} as default mailer"
 : ""
 
-, "type"
-: ""
+, "New mails"
+: "nya mail"
 
-, "Failure"
-: ""
+, "You got {0} new mail(s) in folder {1} ({2})."
+: "Du har {0} ny mail(s) i mappen {1} ({2})."
 
-, "This file is already attached to this record."
-: ""
+, "IMAP Credentials for {0}"
+: "IMAP Referenser för {0}"
+
+, "Credentials"
+: "Inloggningsuppgifter"
+
+, "IMAP Error"
+: "IMAP Fel"
+
+, "No connection to IMAP server."
+: "Ingen anslutning till IMAP server."
+
+, "IMAP Credentials Error"
+: "Fel på IMAP inloggningsuppgifter"
+
+, "Your email credentials are wrong. Please contact your administrator"
+: "Dina mail-inloggningsuppgifter är felaktiga. Vänligen kontakta din administratör"
+
+, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
+: "En av dina mappar har tagits bort eller har bytts namn på av någon annan klient. Uppdatera mapplistan av detta konto."
+
+, "SMTP Error"
+: "SMTP-fel"
+
+, "No connection to SMTP server."
+: "Ingen anslutning till SMTP server"
+
+, "Sieve Error"
+: "Filterfel"
+
+, "No connection to Sieve server."
+: "Ingen anslutning till Filterserver"
+
+, "Save Sieve Script Error"
+: "Fel vid sparning av filter-skript"
+
+, "Could not save script on Sieve server."
+: "Kunde inte spara skriptet på Filterserver."
+
+, "Add as \"To\""
+: "Lägg till som \"Till\""
+
+, "Add as \"Cc\""
+: "Lägg till som \"Cc\""
+
+, "Add as \"Bcc\""
+: "Lägg till som \"Bcc\""
+
+, "Remove from recipients"
+: "Ta bort från mottagarna"
+
+, "Loading Mail Addresses"
+: "Laddar mailadresser"
+
+, "Click here to set To/CC/BCC."
+: "Klicka här för att ställa in / CC / BCC."
+
+, "To:"
+: "Till:"
+
+, "Cc:"
+: "Cc:"
+
+, "Bcc:"
+: "Bcc:"
+
+, "Remove"
+: "Flytta"
 
 , "Send"
 : "Skicka"
@@ -714,13 +987,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 
 , "Signature, Signatures"
 : [
-  "Signatur"
- ,"Signatur"
+  ""
+ ,""
 
 ]
-, "Warning"
-: ""
-
 , "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
 : ""
 
@@ -736,230 +1006,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "No recipients set."
 : "Inga mottagare inställd."
 
+, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
+: ""
+
 , "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
 : ""
 
-, "Message, Messages"
-: [
-  "Meddelande"
- ,"Meddelanden"
+, "All inboxes"
+: "Alla inkorgar"
 
-]
-, "Subject/From"
-: "Ämne/Form"
+, "Default Email Account"
+: "Standard e-postkonto"
 
-, "From (Name)"
-: "Från (Namn)"
+, "The default email account to use when sending mails."
+: "Den förvalda e-post kontot för att använda när du skickar e-post."
 
-, "Cc"
-: "Cc"
-
-, "Bcc"
-: "Bcc"
-
-, "Flags"
-: "Flaggor"
-
-, "Received"
-: "Mottaget"
-
-, "INBOX"
-: "INKORG"
-
-, "Drafts"
-: "utkast"
-
-, "Sent"
-: "Skickat"
-
-, "Templates"
-: "mallar"
-
-, "Junk"
-: "Skräppost"
-
-, "Trash"
-: "Skräp"
-
-, "record list, record lists"
-: [
-  "postlista"
- ,"postlistor"
-
-]
-, "Vacation, Vacations"
-: [
-  "Semester"
- ,"Semestrar"
-
-]
-, "Rule, Rules"
-: [
-  "Regel"
- ,"Regler"
-
-]
-, "Flag, Flags"
-: [
-  "Flagga"
- ,"Flaggar"
-
-]
-, "Flag list, Flag lists"
-: [
-  "Flagg lista"
- ,"Flagg listor"
-
-]
-, "No Messages found."
+, "Mark Email Automatically As Read"
 : ""
 
-, "Compose"
-: "Skapa nytt mail"
-
-, "Toggle highlighting"
-: "Växla markering"
-
-, "Mark read/unread"
-: "Markera läst/oläst"
-
-, "Move"
+, "Is email marked as read automatically or by user action"
 : ""
 
-, "Add Account"
-: "Lägg till användare"
+, "Email Update Interval"
+: "E-post Updaterings Intervall"
 
-, "Id"
-: "Id"
-
-, "Sender"
-: "Sändare"
-
-, "Answered"
-: "Svarad"
-
-, "Forwarded"
-: "Vidarebefodrat"
-
-, "Tine20"
+, "How often should Felamimail check for new Emails (in minutes)."
 : ""
 
-, "Filed as:"
+, "Use for mailto links"
 : ""
 
-, "Select Message File Location"
+, "Use Felamimail in mailto links, otherwise use the default desktop client."
 : ""
 
-, "Filing Messages"
+, "Use for NOTES"
+: "Använd för NOTERINGAR"
+
+, "Save Note default Value."
+: "Spara Notifiering standard värde"
+
+, "Confirm Delete"
+: "bekräfta borttagning"
+
+, "Show confirmation dialog when deleting mails."
+: "Visa bekräftelseruta när du tar bort e-post."
+
+, ".eml file Attachment in forwarded mails"
 : ""
 
-, "Error Filing Message"
+, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
 : ""
 
-, "Could not file message."
+, "Default Font"
 : ""
 
-, "Send Reading Confirmation"
+, "Setting the default font in the E-Mail app"
 : ""
 
-, "Do you want to send a reading confirmation message?"
+, "Mail Type"
 : ""
 
-, "New Mail"
-: "Nytt Mail"
-
-, "Email"
-: "Mail"
-
-, "Active Vacation Message"
-: "Aktuellt semestermeddelande"
-
-, "Email account \"{0}\" has an active vacation message."
-: "E-postkonto \"{0}\" har ett aktivt semestermeddelande."
-
-, "Poll URL: {0}"
+, "Possible mail types."
 : ""
 
-, "{0} as default mailer"
+, "Additional Personal External Account"
 : ""
 
-, "New mails"
-: "nya mail"
+, "Shared System Account"
+: ""
 
-, "You got {0} new mail(s) in folder {1} ({2})."
-: "Du har {0} ny mail(s) i mappen {1} ({2})."
+, "Additional Personal System Account"
+: ""
 
-, "IMAP Credentials for {0}"
-: "IMAP Referenser för {0}"
+, "Default Personal System Account"
+: ""
 
-, "Credentials"
-: "Inloggningsuppgifter"
-
-, "IMAP Error"
-: "IMAP Fel"
-
-, "No connection to IMAP server."
-: "Ingen anslutning till IMAP server."
-
-, "IMAP Credentials Error"
-: "Fel på IMAP inloggningsuppgifter"
-
-, "Your email credentials are wrong. Please contact your administrator"
-: "Dina mail-inloggningsuppgifter är felaktiga. Vänligen kontakta din administratör"
-
-, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
-: "En av dina mappar har tagits bort eller har bytts namn på av någon annan klient. Uppdatera mapplistan av detta konto."
-
-, "SMTP Error"
-: "SMTP-fel"
-
-, "No connection to SMTP server."
-: "Ingen anslutning till SMTP server"
-
-, "Sieve Error"
-: "Filterfel"
-
-, "No connection to Sieve server."
-: "Ingen anslutning till Filterserver"
-
-, "Save Sieve Script Error"
-: "Fel vid sparning av filter-skript"
-
-, "Could not save script on Sieve server."
-: "Kunde inte spara skriptet på Filterserver."
-
-, "Cancel"
-: "Avbryt"
-
-, "Ok"
-: "Ok"
-
-, "Folders of account {0}"
-: "Mappar av konto {0}"
-
-, "Folders of all accounts"
-: "Mappar av alla konton"
-
-, "All inboxes of my email accounts"
-: "Alla inkorgar av mina e-postkonton"
-
-, "All unread mail"
-: "Alla olästa mail"
-
-, "All unread mail of my email accounts"
-: "Alla olästa mail av mina e-postkonton"
-
-, "All highlighted mail"
-: "Alla markerade mail"
-
-, "All highlighted mail of my email accounts"
-: "Alla markerade mail av mina e-post konton"
-
-, "All drafts"
-: "Alla utkast"
-
-, "All mails with the draft flag"
-: "Alla brev med utkast flaggning"
+, "Mailinglist"
+: ""
 
 , "Mailinglist Reject Reason"
 : ""
@@ -988,12 +1111,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Delete Archived Mail"
 : ""
 
+, "Prevent copying mails in the same account"
+: ""
+
 , "Enabled Features"
 : ""
 
 , "Enabled Features in Felamimail Application."
 : ""
 
+, "Account Migration"
+: ""
+
+, "Shows context menu for system accounts to approve migration"
+: ""
+
+, "Move notifications"
+: ""
+
+, "Move notifications to a subfolder via sieve"
+: ""
+
+, "Auto-Save Drafts"
+: ""
+
+, "Save drafts automatically while editing an email"
+: ""
+
+, "Only password download link"
+: ""
+
+, "Allow only password download link"
+: ""
+
 , "Tine 2.0 Flag"
 : ""
 
@@ -1012,6 +1162,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create template, trash, sent, draft and junks folders for system accounts"
 : ""
 
+, "Enable Spam Suspicion Strategy"
+: ""
+
+, "SEnable pam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy Config"
+: ""
+
+, "Spam User Processing Pipeline"
+: ""
+
+, "Confirm SPAM Suspicion Message"
+: ""
+
+, "Message for users when they press the info button in a SPAM suspicion toolbar."
+: ""
+
 , "Filter E-Mail URIs"
 : ""
 
@@ -1054,91 +1225,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "shared / adb_list accounts need to have a password set"
 : ""
 
-, "shared / adb_list accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an user_id set"
-: ""
-
-, "Seen"
-: "Sett"
-
-, "Deleted"
-: "Borttagen"
-
-, "Draft"
-: "utkast"
-
-, "Flagged"
-: "Markerad"
-
-, "Bad recipient address syntax"
-: ""
-
-, "Recipient address rejected"
-: ""
-
-, "Invalid address format"
-: ""
-
-, "Error: %s"
-: ""
-
-, "Could not send message"
-: ""
-
-, "My Mail Download Links"
-: ""
-
-, "Out of Office reply from %1$s"
-: "Frånvarande svar från %1$s"
-
-, "You have new mail from "
-: ""
-
-, "Can not combine \"allow external\" and \"allow only members\""
-: ""
-
-, "Message File Suggestion, Message File Suggestions"
-: [
-  ""
- ,""
-
-]
-, "Message File Suggestions"
-: ""
-
-, "Message File Location, Message File Locations"
-: [
-  ""
- ,""
-
-]
-, "Message File Locations"
-: ""
-
-, "Message ID Hash"
-: ""
-
-, "Message ID"
-: ""
-
-, "Model"
-: ""
-
-, "Record ID"
-: ""
-
-, "Record Title"
-: ""
-
-, "Node ID"
-: ""
-
-, "Type"
+, "Is default"
 : ""
 
 , "Email Account, Email Accounts"
@@ -1213,7 +1300,163 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "on"
 : ""
 
-, "Is default"
+, "Message File Location, Message File Locations"
+: [
+  ""
+ ,""
+
+]
+, "Message File Locations"
+: ""
+
+, "Message ID Hash"
+: ""
+
+, "Message ID"
+: ""
+
+, "Model"
+: ""
+
+, "Record ID"
+: ""
+
+, "Record Title"
+: ""
+
+, "Node ID"
+: ""
+
+, "Message File Suggestion, Message File Suggestions"
+: [
+  ""
+ ,""
+
+]
+, "Message File Suggestions"
+: ""
+
+, "Out of Office reply from %1$s"
+: "Frånvarande svar från %1$s"
+
+, "It is not allowed to redirect emails to self! Please change the recipient."
+: ""
+
+, "Redirects to external email domains are not allowed."
+: ""
+
+, "You have new mail from "
+: ""
+
+, "shared / adb_list accounts need to have an email set"
+: ""
+
+, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
+: ""
+
+, "userInternal accounts need to have an email set"
+: ""
+
+, "userInternal accounts need to have an user_id set"
+: ""
+
+, "Please choose a new email address for userInternal accounts"
+: ""
+
+, "system account for user does not exist"
+: ""
+
+, "Account type cannot be changed from {0} to {1}"
+: ""
+
+, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
+: ""
+
+, "Migration of this account has not been approved!"
+: ""
+
+, "Could not find email user xprops!"
+: ""
+
+, "Internal user accounts need a valid user"
+: ""
+
+, "System account of user is missing"
+: ""
+
+, "Bad recipient address syntax"
+: ""
+
+, "Recipient address rejected"
+: ""
+
+, "Original message not found, email was moved or deleted"
+: ""
+
+, "Invalid address format"
+: ""
+
+, "Error: %s"
+: ""
+
+, "Could not send message"
+: ""
+
+, "My Mail Download Links"
+: ""
+
+, "Seen"
+: "Sett"
+
+, "Deleted"
+: "Borttagen"
+
+, "Draft"
+: "utkast"
+
+, "Flagged"
+: "Markerad"
+
+, "It is not allowed to copy e-mails in the same account."
+: ""
+
+, "Folder with name {0} already exists!"
+: ""
+
+, "Failure on create folder"
+: ""
+
+, "All inboxes of my email accounts"
+: "Alla inkorgar av mina e-postkonton"
+
+, "All unread mail"
+: "Alla olästa mail"
+
+, "All unread mail of my email accounts"
+: "Alla olästa mail av mina e-postkonton"
+
+, "All highlighted mail"
+: "Alla markerade mail"
+
+, "All highlighted mail of my email accounts"
+: "Alla markerade mail av mina e-post konton"
+
+, "All drafts"
+: "Alla utkast"
+
+, "All mails with the draft flag"
+: "Alla brev med utkast flaggning"
+
+, "IMAP Hostname missing"
+: ""
+
+, "IMAP Credentials missing"
+: ""
+
+, "SMTP Hostname missing"
+: ""
+
+, "SMTP Credentials missing"
 : ""
 
 , "manage email accounts"
@@ -1228,10 +1471,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create new email accounts"
 : "Skapa nya email konton"
 
-
-
-
-
+, "Vacation"
+: "Semester"
 
 , "Account"
 : "Konto"
@@ -1239,21 +1480,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Folder"
 : "Mapp"
 
-, "{0} unread message"
-: "{0} oläst meddelande"
-
-, "Signature"
-: "Signatur"
-
 , "Message"
 : "Meddelande"
 
 , "record list"
 : "postlista"
 
-, "Vacation"
-: "Semester"
-
 , "Rule"
 : "Regel"
 
@@ -1263,15 +1495,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Flag list"
 : "Flagg lista"
 
-, "Message File Suggestion"
-: ""
+, "{0} unread message"
+: "{0} oläst meddelande"
 
-, "Message File Location"
+, "Signature"
 : ""
 
 , "Email Account"
 : ""
 
+, "Message File Location"
+: ""
+
+, "Message File Suggestion"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
