@@ -5,79 +5,28 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Felamimail **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "All inboxes"
-: "กล่องข้อความเข้าทั้งหมด"
-
-, "Default Email Account"
-: "บัญชีอีเมลหลัก"
-
-, "The default email account to use when sending mails."
-: "บัญชีอีเมลหลักที่ใช้ส่งอีเมล"
-
-, "Mark Email Automatically As Read"
+, "Can not combine \"allow external\" and \"allow only members\""
 : ""
 
-, "Is email marked as read automatically or by user action"
-: ""
+, "Delete"
+: "ลบ"
 
-, "Email Update Interval"
-: "ความถี่ในการอัพเดทอีเมล"
+, "Reply"
+: "ตอบ"
 
-, "How often should Felamimail check for new Emails (in minutes)."
-: "ต้องการให้ Felamimail เช็คอีเมลใหม่ บ่อยแค่ไหน (เป็นนาที)"
+, "Reply To All"
+: "ตอบทุกคน"
 
-, "Use for mailto links"
-: "ใช้สำหรับเชื่อมต่อ เมลไปยัง"
+, "Forward"
+: "ส่งต่อ"
 
-, "Use Felamimail in mailto links, otherwise use the default desktop client."
-: "ใช้ Felamimail ในการเชื่อมต่อเมลไปยัง หรือไม่ก็ใช้ค่าหลักที่ลูกค้าตั้งไว้บนเดสก์ท็อป"
+, "Print Message"
+: "พิมพ์ข้อความ"
 
-, "Use for NOTES"
-: "ใช้สำหรับบันทึก"
-
-, "Save Note default Value."
-: "ค่าหลักของบันทึกโน๊ต"
-
-, "Confirm Delete"
-: "ยืนยันการลบ"
-
-, "Show confirmation dialog when deleting mails."
-: "แสดงข้อความยืนยันเมื่อกำลังลบเมล"
-
-, ".eml file Attachment in forwarded mails"
-: ""
-
-, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
-: ""
-
-, "Message not available."
-: "ข้อความไม่มีอยู่ "
-
-, "File Message"
-: ""
-
-, "Filemanager ..."
-: ""
-
-, "Attachment"
-: ""
-
-, "Download"
-: ""
-
-, "{messageCount, plural, one {Message was filed} other {# messages where filed}}"
-: ""
-
-, "Success"
-: ""
-
-, "Error"
-: ""
-
-, "File Messages as Attachment"
-: ""
+, "Print Preview"
+: "พิมพ์หน้าพรีวิว"
 
 , "Add New Account"
 : ""
@@ -85,6 +34,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Permissions"
 : ""
 
+, "Rules"
+: ""
+
+, "Vacation, Vacations"
+: [
+  "พักร้อน"
+
+]
 , "Account, Accounts"
 : [
   "บัญชี"
@@ -93,7 +50,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Account Name"
 : "ชื่อบัญชี"
 
-, "Account Type"
+, "Type"
+: ""
+
+, "Migration Approved"
+: ""
+
+, "Approve Migration"
+: ""
+
+, "Do you want to approve the migration of this account?"
 : ""
 
 , "User"
@@ -144,6 +110,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password"
 : "รหัสผ่าน"
 
+, "Test IMAP Connection"
+: ""
+
 , "SMTP"
 : "SMTP"
 
@@ -165,6 +134,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password (optional)"
 : "รหัสผ่าน (ไม่บังคับ)"
 
+, "Test SMTP Connection"
+: ""
+
 , "Sieve"
 : "กรอง"
 
@@ -174,6 +146,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Notification Email"
 : ""
 
+, "Auto-move notifications"
+: ""
+
+, "Auto-move notifications folder"
+: ""
+
 , "Other Settings"
 : "ค่าติดตั้งอื่น ๆ"
 
@@ -216,16 +194,22 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Reply-To Email"
 : ""
 
-, "Shared System Account"
+, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
 : ""
 
-, "Additional Personal System Account"
+, "Migration has not been approved."
 : ""
 
-, "Additional Personal External Account"
+, "It is not possible to convert the account to this type."
 : ""
 
-, "Default Personal System Account"
+, "System accounts cannot be created manually."
+: ""
+
+, "Mailinglist accounts cannot be created manually."
+: ""
+
+, "Account type change not possible"
 : ""
 
 , "E-Mail account needs a password"
@@ -243,53 +227,172 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "The grant edit the shared email account"
 : ""
 
-, "Click here to set To/CC/BCC."
-: "กดที่นี่เพื่อตั้งเป็น To/CC/BCC"
+, "Send Mails"
+: ""
 
-, "To:"
-: "To:"
+, "The grant to send mails via the email account"
+: ""
 
-, "Cc:"
-: "Cc:"
+, "Warning"
+: ""
 
-, "Bcc:"
-: "Bcc:"
+, "Server connection failed. Do you still want to save this setting and exit?"
+: ""
 
-, "Remove"
-: "เอาออก"
+, "Connection succeed"
+: ""
 
-, "Compose email"
-: "เขียนอีเมล"
+, "Connecting to {0} server..."
+: ""
+
+, "Connection failed"
+: ""
+
+, "{server} Connection Status"
+: ""
+
+, "Save Message as"
+: ""
+
+, "File (in Filemanager) ..."
+: ""
+
+, "Attachment (of Record)"
+: ""
+
+, "Download"
+: ""
+
+, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
+: ""
+
+, "Success"
+: ""
+
+, "Error"
+: ""
+
+, "Save Messages as Attachment"
+: ""
+
+, "No Messages found."
+: ""
+
+, "It is SPAM"
+: ""
+
+, "It is not SPAM"
+: ""
+
+, "Compose"
+: "เขียน"
+
+, "Toggle highlighting"
+: "เปิดปิดการเน้นให้เด่น"
+
+, "Mark read/unread"
+: "ทำเครื่องหมาย อ่านแล้ว/ ยังไม่ได้อ่าน"
+
+, "Move"
+: ""
+
+, "Copy"
+: ""
+
+, "Import Messages"
+: ""
+
+, "Add Account"
+: "เพิ่มบัญชี"
+
+, "No target folder selected"
+: ""
+
+, "You need to select a target folder for the messages."
+: ""
+
+, "Wrong File Type"
+: ""
+
+, "Files of type eml allowed only."
+: ""
+
+, "Importing Messages..."
+: ""
+
+, "Id"
+: "รหัส"
+
+, "Attachments"
+: "สิ่งที่แนบมาด้วย"
+
+, "Flags"
+: "ป้าย"
+
+, "Subject"
+: "หัวเรื่อง"
+
+, "From (Email)"
+: "จาก (อีเมล)"
+
+, "From (Name)"
+: "จาก (ชื่อ)"
+
+, "Sender"
+: "ผู้ส่ง"
 
 , "To"
 : "ถึง"
 
-, "CC"
+, "Sent"
+: "ส่งแล้ว"
+
+, "Received"
+: "ได้รับแล้ว"
+
+, "Folder, Folders"
+: [
+  "แฟ้มเอกสาร"
+
+]
+, "Size"
+: "ขนาด"
+
+, "Answered"
+: "ตอบแล้ว"
+
+, "Forwarded"
+: "ส่งต่อแล้ว"
+
+, "This message might be SPAM"
 : ""
 
-, "BCC"
+, "Tine20"
 : ""
 
-, "Mass Mailing"
+, "Encrypted Message"
 : ""
 
-, "Signatures"
+, "Filed as:"
 : ""
 
-, "Name"
+, "Select Message File Location"
 : ""
 
-, "Is Default"
+, "Filing Messages"
 : ""
 
-, "Add Signature"
+, "Error Filing Message"
 : ""
 
-, "Edit Signature"
+, "Could not file message."
 : ""
 
-, "Delete Signature"
-: ""
+, "Send Reading Confirmation"
+: "ส่งการยืนยันการอ่าน"
+
+, "Do you want to send a reading confirmation message?"
+: "คุณต้องการส่งข้อความยืนยันการอ่านหรือไม่?"
 
 , "Empty Folder"
 : "ล้างแฟ้ม"
@@ -300,11 +403,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "New {0}"
 : "ใหม่ {0}"
 
-, "Folder, Folders"
-: [
-  "แฟ้มเอกสาร"
-
-]
 , "Please enter the name of the new {0}:"
 : "กรุณาใส่ชื่อของ {0} ใหม่:"
 
@@ -338,27 +436,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Update Folder List"
 : "ปรับปรุงรายชื่อแฟ้ม"
 
-, "Add as \"To\""
-: "เพิ่มเป็น \"To\""
+, "Message not available."
+: "ข้อความไม่มีอยู่ "
 
-, "Add as \"Cc\""
-: "เพิ่มเป็น \"Cc\""
+, "Cancel"
+: "ยกเลิก"
 
-, "Add as \"Bcc\""
-: "เพิ่มเป็น \"Bcc\""
+, "Ok"
+: "ตกลง"
 
-, "Remove from recipients"
-: "เอาออกจากผู้รับ"
+, "Folders of account {0}"
+: "แฟ้มของบัญชี {0}"
 
-, "Loading Mail Addresses"
-: "กำลังโหลดที่อยู่อีเมล"
+, "Folders of all accounts"
+: "แฟ้มของทุกบัญชี"
+
+, "Compose email"
+: "เขียนอีเมล"
+
+, "CC"
+: ""
+
+, "BCC"
+: ""
+
+, "Mass Mailing"
+: ""
 
 , "Open in Felamimail"
 : ""
 
-, "Subject"
-: "หัวเรื่อง"
-
 , "From"
 : "จาก"
 
@@ -374,12 +481,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Show or hide header information"
 : "แสดงหรือซ่อนหัวข้อของข้อมูล"
 
-, "Attachments"
-: "สิ่งที่แนบมาด้วย"
-
 , "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
 : ""
 
+, "Open"
+: ""
+
+, "Save As"
+: ""
+
+, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
+: ""
+
+, "Save as Record Attachment"
+: ""
+
+, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
+: ""
+
+, "Confirm SPAM Suspicion"
+: ""
+
+, "Yes, it is SPAM"
+: ""
+
+, "No, it is not"
+: ""
+
+, "(new message)"
+: "(ข้อความใหม่)"
+
+, "Select recipients for \"{0}\""
+: "เลือกผู้รับสำหรับ \"{0}\""
+
+, "Signatures"
+: ""
+
+, "Name"
+: ""
+
+, "Is Default"
+: ""
+
+, "Add Signature"
+: ""
+
+, "Edit Signature"
+: ""
+
+, "Delete Signature"
+: ""
+
 , "Recipient filter"
 : "ตัวกรองผู้รับ"
 
@@ -389,104 +541,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "\"{0}\" recipients"
 : "\"{0}\" ผู้รับ"
 
-, "Total Messages:"
-: "ข้อความทั้งหมด:"
-
-, "Unread Messages:"
-: "ข้อความที่ยังไม่ได้อ่าน:"
-
-, "Name on Server:"
-: "ชื่อบนเซิร์ฟเวอร์:"
-
-, "Last update:"
-: "ปรับปรุงล่าสุด:"
-
-, "Fetching messages... ({0} done)"
+, "Attachment"
 : ""
 
-, "{0} unread message, {0} unread messages"
-: [
-  "{0} ข้อความที่ยังไม่ได้อ่าน"
-
-]
-, "(new message)"
-: "(ข้อความใหม่)"
-
-, "Select recipients for \"{0}\""
-: "เลือกผู้รับสำหรับ \"{0}\""
-
-, "Mailvelope decryption Error [{0}]"
+, "Filemanager (Download link)"
 : ""
 
-, "To decrypt this message please install {0} with API support enabled"
+, "Filemanager (Download link, password)"
 : ""
 
-, "PGP encrypted Message"
+, "Filemanager (Systemlink)"
 : ""
 
-, "Delete"
-: "ลบ"
+, "Attachment Type"
+: ""
 
-, "Reply"
-: "ตอบ"
+, "Click icon to change"
+: ""
 
-, "Reply To All"
-: "ตอบทุกคน"
+, "name"
+: ""
 
-, "Forward"
-: "ส่งต่อ"
+, "size"
+: ""
 
-, "Print Message"
-: "พิมพ์ข้อความ"
+, "type"
+: ""
 
-, "Print Preview"
-: "พิมพ์หน้าพรีวิว"
+, "Vacation Message for {0}"
+: "ข้อความลาพักสำหรับ {0}"
 
 , "Notification for {0}"
 : ""
 
-, "Edit Filter Rule"
-: "แก้ไขระเบียบตัวกรอง"
-
-, "Apply filter if"
-: "ใช้ตัวกรองในกรณี"
-
-, "all conditions match"
-: "ตรงตามทุกเงื่อนไข"
-
-, "any condition matches"
-: "ตรงกับเงื่อนไขใดๆก็ได้"
-
-, "Do this action:"
-: "ทำสิ่งนี้:"
-
-, "Keep a copy"
-: ""
-
-, "Move mail to folder"
-: "ย้ายเมลไปแฟ้ม"
-
-, "Redirect mail to address"
-: "เปลี่ยนส่งเมลไปยังที่อยู่"
-
-, "Reject mail with this text"
-: "ปฏิเสธเมลที่มีเนื้อเความนี้อยู่"
-
-, "Discard mail"
-: "กำจัดเมล"
-
-, "Auto-Reply mail with this text"
-: ""
-
-, "Keep mail"
-: "เก็บเมล"
-
-, "Sieve Filter Rules"
-: "กรองระเบียบตัวกรอง"
-
-, "Sieve Filter Rules for {0}"
-: "กรองระเบียบตัวกรองสำหรับ {0}"
-
 , "Move up"
 : "ย้ายขึ้น"
 
@@ -508,6 +595,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Action"
 : "ปฏิกิริยา"
 
+, "Keep a copy"
+: ""
+
 , "is greater than"
 : "มากกว่า"
 
@@ -520,8 +610,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Header \"{0}\" matches \"{1}\""
 : "หัวเรื่อง \"{0}\" ตรงกับ \"{1}\""
 
-, "Vacation Message for {0}"
-: "ข้อความลาพักสำหรับ {0}"
+, "Sieve Filter Rules"
+: "กรองระเบียบตัวกรอง"
+
+, "Sieve Filter Rules for {0}"
+: "กรองระเบียบตัวกรองสำหรับ {0}"
+
+, "From (Email and Name)"
+: "จาก (อีเมลและชื่อ)"
+
+, "To (Email)"
+: "ถึง (อีเมล)"
+
+, "To (Email CC)"
+: "ถึง (อีเมล CC)"
+
+, "Header contains"
+: "หัวเรื่องบรรจุ"
+
+, "Header name"
+: "ชื่อหัวเรื่อง"
+
+, "Header value"
+: "ค่าหัวเรื่อง"
+
+, "Header regex"
+: "นิพจน์ปรกติของหัวเรื่อง"
+
+, "Edit Filter Rule"
+: "แก้ไขระเบียบตัวกรอง"
+
+, "Apply filter if"
+: "ใช้ตัวกรองในกรณี"
+
+, "all conditions match"
+: "ตรงตามทุกเงื่อนไข"
+
+, "any condition matches"
+: "ตรงกับเงื่อนไขใดๆก็ได้"
+
+, "Do this action:"
+: "ทำสิ่งนี้:"
+
+, "Move mail to folder"
+: "ย้ายเมลไปแฟ้ม"
+
+, "Redirect mail to address"
+: "เปลี่ยนส่งเมลไปยังที่อยู่"
+
+, "Reject mail with this text"
+: "ปฏิเสธเมลที่มีเนื้อเความนี้อยู่"
+
+, "Discard mail"
+: "กำจัดเมล"
+
+, "Auto-Reply mail with this text"
+: ""
+
+, "Keep mail"
+: "เก็บเมล"
 
 , "General"
 : "ทั่วไป"
@@ -574,62 +721,182 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Choose Template ..."
 : "เลือกแม่แบบ ..."
 
-, "From (Email)"
-: "จาก (อีเมล)"
-
-, "From (Email and Name)"
-: "จาก (อีเมลและชื่อ)"
-
-, "To (Email)"
-: "ถึง (อีเมล)"
-
-, "To (Email CC)"
-: "ถึง (อีเมล CC)"
-
-, "Size"
-: "ขนาด"
-
-, "Header contains"
-: "หัวเรื่องบรรจุ"
-
-, "Header name"
-: "ชื่อหัวเรื่อง"
-
-, "Header value"
-: "ค่าหัวเรื่อง"
-
-, "Header regex"
-: "นิพจน์ปรกติของหัวเรื่อง"
-
-, "Filemanager (Download link)"
+, "Mailvelope decryption Error [{0}]"
 : ""
 
-, "Filemanager (Download link, password)"
+, "To decrypt this message please install {0} with API support enabled"
 : ""
 
-, "Filemanager (Systemlink)"
+, "PGP encrypted Message"
 : ""
 
-, "Attachment Type"
+, "GENDER_Message"
 : ""
 
-, "Click icon to change"
+, "Message, Messages"
+: [
+  "ข้อความ"
+
+]
+, "Subject/From"
+: "หัวเรื่อง/ จาก"
+
+, "Cc"
+: "Cc"
+
+, "Bcc"
+: "Bcc"
+
+, "INBOX"
+: "กล่องข้อความเข้า"
+
+, "Drafts"
+: "โครงร่าง"
+
+, "Templates"
+: "แม่แบบ"
+
+, "Junk"
+: "ขย"
+
+, "Trash"
+: "ขยะ"
+
+, "GENDER_Folder"
 : ""
 
-, "name"
+, "record list, record lists"
+: [
+  "บันทึกรายชื่อ"
+
+]
+, "Rule, Rules"
+: [
+  "ระเบียบ"
+
+]
+, "Flag, Flags"
+: [
+  "ป้าย"
+
+]
+, "Flag list, Flag lists"
+: [
+  "รายชื่อป้ายต่างๆ"
+
+]
+, "Total Messages:"
+: "ข้อความทั้งหมด:"
+
+, "Unread Messages:"
+: "ข้อความที่ยังไม่ได้อ่าน:"
+
+, "Name on Server:"
+: "ชื่อบนเซิร์ฟเวอร์:"
+
+, "Last update:"
+: "ปรับปรุงล่าสุด:"
+
+, "Fetching messages... ({0} done)"
 : ""
 
-, "size"
+, "{0} unread message, {0} unread messages"
+: [
+  "{0} ข้อความที่ยังไม่ได้อ่าน"
+
+]
+, "New Mail"
+: "เมลใหม่"
+
+, "Email"
+: "อีเมล"
+
+, "Active Vacation Message"
+: "ข้อความลาพักที่ใช้อยู่"
+
+, "Email account \"{0}\" has an active vacation message."
+: "บัญชีอีเมล \"{0}\" มีข้อความที่ใช้สำหรับพักร้อนเปิดอยู่"
+
+, "Poll URL: {0}"
 : ""
 
-, "type"
+, "{0} as default mailer"
 : ""
 
-, "Failure"
-: ""
+, "New mails"
+: "เมลใหม่"
 
-, "This file is already attached to this record."
-: ""
+, "You got {0} new mail(s) in folder {1} ({2})."
+: "คุณมี {0} เมลใหม่(s) ในแฟ้ม {1} ({2})"
+
+, "IMAP Credentials for {0}"
+: "IMAP อ้างอิงสำหรับ {0}"
+
+, "Credentials"
+: "ตัวอ้างอิง"
+
+, "IMAP Error"
+: "ข้อผิดพลาด IMAP"
+
+, "No connection to IMAP server."
+: "ไม่มีการติดต่อไปยังเซิร์ฟเวอร์ IMAP"
+
+, "IMAP Credentials Error"
+: "IMAP ตัวอ้างอิงผิดพลาด"
+
+, "Your email credentials are wrong. Please contact your administrator"
+: "ตัวอ้างอิงอีเมลของคุณผิด กรุณาติดต่อผู้ดูแลระบบ"
+
+, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
+: "หนึ่งในแฟ้มของคุณถูกลบหรือโดนเปลี่ยนชื่อโดยผู้ใช้คนอื่น กรุณาอัพเดทรายชื่อแฟ้มของบัญชีนี้"
+
+, "SMTP Error"
+: "ข้อผิดพลาด SMTP"
+
+, "No connection to SMTP server."
+: "ไม่มีการติดต่อไปยังเซิร์ฟเวอร์ SMTP"
+
+, "Sieve Error"
+: "กรองข้อผิดพลาด"
+
+, "No connection to Sieve server."
+: "ไม่มีการติดต่อไปยังเซิร์ฟเวอร์ที่กรอง"
+
+, "Save Sieve Script Error"
+: "จัดเก็บตัวกรองข้อผิดพลาดด้านสคริป"
+
+, "Could not save script on Sieve server."
+: "ไม่สามารถจัดเก็บสคริปบนตัวให้บริการกรอง"
+
+, "Add as \"To\""
+: "เพิ่มเป็น \"To\""
+
+, "Add as \"Cc\""
+: "เพิ่มเป็น \"Cc\""
+
+, "Add as \"Bcc\""
+: "เพิ่มเป็น \"Bcc\""
+
+, "Remove from recipients"
+: "เอาออกจากผู้รับ"
+
+, "Loading Mail Addresses"
+: "กำลังโหลดที่อยู่อีเมล"
+
+, "Click here to set To/CC/BCC."
+: "กดที่นี่เพื่อตั้งเป็น To/CC/BCC"
+
+, "To:"
+: "To:"
+
+, "Cc:"
+: "Cc:"
+
+, "Bcc:"
+: "Bcc:"
+
+, "Remove"
+: "เอาออก"
 
 , "Send"
 : "ส่ง"
@@ -711,12 +978,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 
 , "Signature, Signatures"
 : [
-  "ลายเซ็นต์"
+  ""
 
 ]
-, "Warning"
-: ""
-
 , "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
 : ""
 
@@ -732,224 +996,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "No recipients set."
 : "ไม่ได้ตั้งผู้รับ"
 
+, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
+: ""
+
 , "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
 : ""
 
-, "Message, Messages"
-: [
-  "ข้อความ"
+, "All inboxes"
+: "กล่องข้อความเข้าทั้งหมด"
 
-]
-, "Subject/From"
-: "หัวเรื่อง/ จาก"
+, "Default Email Account"
+: "บัญชีอีเมลหลัก"
 
-, "From (Name)"
-: "จาก (ชื่อ)"
+, "The default email account to use when sending mails."
+: "บัญชีอีเมลหลักที่ใช้ส่งอีเมล"
 
-, "Cc"
-: "Cc"
-
-, "Bcc"
-: "Bcc"
-
-, "Flags"
-: "ป้าย"
-
-, "Received"
-: "ได้รับแล้ว"
-
-, "INBOX"
-: "กล่องข้อความเข้า"
-
-, "Drafts"
-: "โครงร่าง"
-
-, "Sent"
-: "ส่งแล้ว"
-
-, "Templates"
-: "แม่แบบ"
-
-, "Junk"
-: "ขย"
-
-, "Trash"
-: "ขยะ"
-
-, "record list, record lists"
-: [
-  "บันทึกรายชื่อ"
-
-]
-, "Vacation, Vacations"
-: [
-  "พักร้อน"
-
-]
-, "Rule, Rules"
-: [
-  "ระเบียบ"
-
-]
-, "Flag, Flags"
-: [
-  "ป้าย"
-
-]
-, "Flag list, Flag lists"
-: [
-  "รายชื่อป้ายต่างๆ"
-
-]
-, "No Messages found."
+, "Mark Email Automatically As Read"
 : ""
 
-, "Compose"
-: "เขียน"
-
-, "Toggle highlighting"
-: "เปิดปิดการเน้นให้เด่น"
-
-, "Mark read/unread"
-: "ทำเครื่องหมาย อ่านแล้ว/ ยังไม่ได้อ่าน"
-
-, "Move"
+, "Is email marked as read automatically or by user action"
 : ""
 
-, "Add Account"
-: "เพิ่มบัญชี"
+, "Email Update Interval"
+: "ความถี่ในการอัพเดทอีเมล"
 
-, "Id"
-: "รหัส"
+, "How often should Felamimail check for new Emails (in minutes)."
+: "ต้องการให้ Felamimail เช็คอีเมลใหม่ บ่อยแค่ไหน (เป็นนาที)"
 
-, "Sender"
-: "ผู้ส่ง"
+, "Use for mailto links"
+: "ใช้สำหรับเชื่อมต่อ เมลไปยัง"
 
-, "Answered"
-: "ตอบแล้ว"
+, "Use Felamimail in mailto links, otherwise use the default desktop client."
+: "ใช้ Felamimail ในการเชื่อมต่อเมลไปยัง หรือไม่ก็ใช้ค่าหลักที่ลูกค้าตั้งไว้บนเดสก์ท็อป"
 
-, "Forwarded"
-: "ส่งต่อแล้ว"
+, "Use for NOTES"
+: "ใช้สำหรับบันทึก"
 
-, "Tine20"
+, "Save Note default Value."
+: "ค่าหลักของบันทึกโน๊ต"
+
+, "Confirm Delete"
+: "ยืนยันการลบ"
+
+, "Show confirmation dialog when deleting mails."
+: "แสดงข้อความยืนยันเมื่อกำลังลบเมล"
+
+, ".eml file Attachment in forwarded mails"
 : ""
 
-, "Filed as:"
+, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
 : ""
 
-, "Select Message File Location"
+, "Default Font"
 : ""
 
-, "Filing Messages"
+, "Setting the default font in the E-Mail app"
 : ""
 
-, "Error Filing Message"
+, "Mail Type"
 : ""
 
-, "Could not file message."
+, "Possible mail types."
 : ""
 
-, "Send Reading Confirmation"
-: "ส่งการยืนยันการอ่าน"
-
-, "Do you want to send a reading confirmation message?"
-: "คุณต้องการส่งข้อความยืนยันการอ่านหรือไม่?"
-
-, "New Mail"
-: "เมลใหม่"
-
-, "Email"
-: "อีเมล"
-
-, "Active Vacation Message"
-: "ข้อความลาพักที่ใช้อยู่"
-
-, "Email account \"{0}\" has an active vacation message."
-: "บัญชีอีเมล \"{0}\" มีข้อความที่ใช้สำหรับพักร้อนเปิดอยู่"
-
-, "Poll URL: {0}"
+, "Additional Personal External Account"
 : ""
 
-, "{0} as default mailer"
+, "Shared System Account"
 : ""
 
-, "New mails"
-: "เมลใหม่"
+, "Additional Personal System Account"
+: ""
 
-, "You got {0} new mail(s) in folder {1} ({2})."
-: "คุณมี {0} เมลใหม่(s) ในแฟ้ม {1} ({2})"
+, "Default Personal System Account"
+: ""
 
-, "IMAP Credentials for {0}"
-: "IMAP อ้างอิงสำหรับ {0}"
-
-, "Credentials"
-: "ตัวอ้างอิง"
-
-, "IMAP Error"
-: "ข้อผิดพลาด IMAP"
-
-, "No connection to IMAP server."
-: "ไม่มีการติดต่อไปยังเซิร์ฟเวอร์ IMAP"
-
-, "IMAP Credentials Error"
-: "IMAP ตัวอ้างอิงผิดพลาด"
-
-, "Your email credentials are wrong. Please contact your administrator"
-: "ตัวอ้างอิงอีเมลของคุณผิด กรุณาติดต่อผู้ดูแลระบบ"
-
-, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
-: "หนึ่งในแฟ้มของคุณถูกลบหรือโดนเปลี่ยนชื่อโดยผู้ใช้คนอื่น กรุณาอัพเดทรายชื่อแฟ้มของบัญชีนี้"
-
-, "SMTP Error"
-: "ข้อผิดพลาด SMTP"
-
-, "No connection to SMTP server."
-: "ไม่มีการติดต่อไปยังเซิร์ฟเวอร์ SMTP"
-
-, "Sieve Error"
-: "กรองข้อผิดพลาด"
-
-, "No connection to Sieve server."
-: "ไม่มีการติดต่อไปยังเซิร์ฟเวอร์ที่กรอง"
-
-, "Save Sieve Script Error"
-: "จัดเก็บตัวกรองข้อผิดพลาดด้านสคริป"
-
-, "Could not save script on Sieve server."
-: "ไม่สามารถจัดเก็บสคริปบนตัวให้บริการกรอง"
-
-, "Cancel"
-: "ยกเลิก"
-
-, "Ok"
-: "ตกลง"
-
-, "Folders of account {0}"
-: "แฟ้มของบัญชี {0}"
-
-, "Folders of all accounts"
-: "แฟ้มของทุกบัญชี"
-
-, "All inboxes of my email accounts"
-: "แสดงกล่องข้อความเข้าทั้งหมดของบัญชีอีเมลฉัน"
-
-, "All unread mail"
-: "เมลที่ยังไม่ได้อ่านทั้งหมด"
-
-, "All unread mail of my email accounts"
-: "เมลที่ยังไม่ได้อ่านทั้งหมดของบัญชีอีเมลฉัน"
-
-, "All highlighted mail"
-: "ทุกอีเมลที่ได้เน้นให้เด่น"
-
-, "All highlighted mail of my email accounts"
-: "ทุกอีเมลที่ได้เน้นให้เด่นของบัญชีอีเมลของฉัน"
-
-, "All drafts"
-: "โครงร่างทั้งหมด"
-
-, "All mails with the draft flag"
-: "เมลทั้งหมดที่มีป้ายร่าง"
+, "Mailinglist"
+: ""
 
 , "Mailinglist Reject Reason"
 : ""
@@ -978,12 +1101,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Delete Archived Mail"
 : ""
 
+, "Prevent copying mails in the same account"
+: ""
+
 , "Enabled Features"
 : ""
 
 , "Enabled Features in Felamimail Application."
 : ""
 
+, "Account Migration"
+: ""
+
+, "Shows context menu for system accounts to approve migration"
+: ""
+
+, "Move notifications"
+: ""
+
+, "Move notifications to a subfolder via sieve"
+: ""
+
+, "Auto-Save Drafts"
+: ""
+
+, "Save drafts automatically while editing an email"
+: ""
+
+, "Only password download link"
+: ""
+
+, "Allow only password download link"
+: ""
+
 , "Tine 2.0 Flag"
 : ""
 
@@ -1002,6 +1152,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create template, trash, sent, draft and junks folders for system accounts"
 : ""
 
+, "Enable Spam Suspicion Strategy"
+: ""
+
+, "SEnable pam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy Config"
+: ""
+
+, "Spam User Processing Pipeline"
+: ""
+
+, "Confirm SPAM Suspicion Message"
+: ""
+
+, "Message for users when they press the info button in a SPAM suspicion toolbar."
+: ""
+
 , "Filter E-Mail URIs"
 : ""
 
@@ -1044,89 +1215,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "shared / adb_list accounts need to have a password set"
 : ""
 
-, "shared / adb_list accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an user_id set"
-: ""
-
-, "Seen"
-: "เห็นแล้ว"
-
-, "Deleted"
-: "ลบแล้ว"
-
-, "Draft"
-: "โครงร่าง"
-
-, "Flagged"
-: "ติดป้ายชื่อแล้ว"
-
-, "Bad recipient address syntax"
-: ""
-
-, "Recipient address rejected"
-: ""
-
-, "Invalid address format"
-: ""
-
-, "Error: %s"
-: "ข้อผิดพลาด: %s"
-
-, "Could not send message"
-: "ไม่สามารถส่งข้อความได้"
-
-, "My Mail Download Links"
-: ""
-
-, "Out of Office reply from %1$s"
-: "ไม่ได้อยู่ที่บริษัท ตอบจาก %1$s"
-
-, "You have new mail from "
-: ""
-
-, "Can not combine \"allow external\" and \"allow only members\""
-: ""
-
-, "Message File Suggestion, Message File Suggestions"
-: [
-  ""
-
-]
-, "Message File Suggestions"
-: ""
-
-, "Message File Location, Message File Locations"
-: [
-  ""
-
-]
-, "Message File Locations"
-: ""
-
-, "Message ID Hash"
-: ""
-
-, "Message ID"
-: ""
-
-, "Model"
-: ""
-
-, "Record ID"
-: ""
-
-, "Record Title"
-: ""
-
-, "Node ID"
-: ""
-
-, "Type"
+, "Is default"
 : ""
 
 , "Email Account, Email Accounts"
@@ -1200,7 +1289,161 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "on"
 : "เมื่อ"
 
-, "Is default"
+, "Message File Location, Message File Locations"
+: [
+  ""
+
+]
+, "Message File Locations"
+: ""
+
+, "Message ID Hash"
+: ""
+
+, "Message ID"
+: ""
+
+, "Model"
+: ""
+
+, "Record ID"
+: ""
+
+, "Record Title"
+: ""
+
+, "Node ID"
+: ""
+
+, "Message File Suggestion, Message File Suggestions"
+: [
+  ""
+
+]
+, "Message File Suggestions"
+: ""
+
+, "Out of Office reply from %1$s"
+: "ไม่ได้อยู่ที่บริษัท ตอบจาก %1$s"
+
+, "It is not allowed to redirect emails to self! Please change the recipient."
+: ""
+
+, "Redirects to external email domains are not allowed."
+: ""
+
+, "You have new mail from "
+: ""
+
+, "shared / adb_list accounts need to have an email set"
+: ""
+
+, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
+: ""
+
+, "userInternal accounts need to have an email set"
+: ""
+
+, "userInternal accounts need to have an user_id set"
+: ""
+
+, "Please choose a new email address for userInternal accounts"
+: ""
+
+, "system account for user does not exist"
+: ""
+
+, "Account type cannot be changed from {0} to {1}"
+: ""
+
+, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
+: ""
+
+, "Migration of this account has not been approved!"
+: ""
+
+, "Could not find email user xprops!"
+: ""
+
+, "Internal user accounts need a valid user"
+: ""
+
+, "System account of user is missing"
+: ""
+
+, "Bad recipient address syntax"
+: ""
+
+, "Recipient address rejected"
+: ""
+
+, "Original message not found, email was moved or deleted"
+: ""
+
+, "Invalid address format"
+: ""
+
+, "Error: %s"
+: "ข้อผิดพลาด: %s"
+
+, "Could not send message"
+: "ไม่สามารถส่งข้อความได้"
+
+, "My Mail Download Links"
+: ""
+
+, "Seen"
+: "เห็นแล้ว"
+
+, "Deleted"
+: "ลบแล้ว"
+
+, "Draft"
+: "โครงร่าง"
+
+, "Flagged"
+: "ติดป้ายชื่อแล้ว"
+
+, "It is not allowed to copy e-mails in the same account."
+: ""
+
+, "Folder with name {0} already exists!"
+: ""
+
+, "Failure on create folder"
+: ""
+
+, "All inboxes of my email accounts"
+: "แสดงกล่องข้อความเข้าทั้งหมดของบัญชีอีเมลฉัน"
+
+, "All unread mail"
+: "เมลที่ยังไม่ได้อ่านทั้งหมด"
+
+, "All unread mail of my email accounts"
+: "เมลที่ยังไม่ได้อ่านทั้งหมดของบัญชีอีเมลฉัน"
+
+, "All highlighted mail"
+: "ทุกอีเมลที่ได้เน้นให้เด่น"
+
+, "All highlighted mail of my email accounts"
+: "ทุกอีเมลที่ได้เน้นให้เด่นของบัญชีอีเมลของฉัน"
+
+, "All drafts"
+: "โครงร่างทั้งหมด"
+
+, "All mails with the draft flag"
+: "เมลทั้งหมดที่มีป้ายร่าง"
+
+, "IMAP Hostname missing"
+: ""
+
+, "IMAP Credentials missing"
+: ""
+
+, "SMTP Hostname missing"
+: ""
+
+, "SMTP Credentials missing"
 : ""
 
 , "manage email accounts"
@@ -1215,10 +1458,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create new email accounts"
 : "สร้างบัญชีอีเมลใหม่"
 
-
-
-
-
+, "Vacation"
+: "พักร้อน"
 
 , "Account"
 : "บัญชี"
@@ -1226,21 +1467,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Folder"
 : "แฟ้มเอกสาร"
 
-, "{0} unread message"
-: "{0} ข้อความที่ยังไม่ได้อ่าน"
-
-, "Signature"
-: "ลายเซ็นต์"
-
 , "Message"
 : "ข้อความ"
 
 , "record list"
 : "บันทึกรายชื่อ"
 
-, "Vacation"
-: "พักร้อน"
-
 , "Rule"
 : "ระเบียบ"
 
@@ -1250,15 +1482,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Flag list"
 : "รายชื่อป้ายต่างๆ"
 
-, "Message File Suggestion"
-: ""
+, "{0} unread message"
+: "{0} ข้อความที่ยังไม่ได้อ่าน"
 
-, "Message File Location"
+, "Signature"
 : ""
 
 , "Email Account"
 : ""
 
+, "Message File Location"
+: ""
+
+, "Message File Suggestion"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
