@@ -5,79 +5,28 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Felamimail **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "All inboxes"
-: "Mọi thư đến"
-
-, "Default Email Account"
-: "Tài khoản email mặc định"
-
-, "The default email account to use when sending mails."
-: "Tài khoản email mặc định được dùng khi gửi email"
-
-, "Mark Email Automatically As Read"
+, "Can not combine \"allow external\" and \"allow only members\""
 : ""
 
-, "Is email marked as read automatically or by user action"
-: ""
+, "Delete"
+: "Xóa"
 
-, "Email Update Interval"
-: "Khoảng thời gian cập nhật email"
+, "Reply"
+: "Trả lời"
 
-, "How often should Felamimail check for new Emails (in minutes)."
-: ""
+, "Reply To All"
+: "Trả lời tất cả"
 
-, "Use for mailto links"
-: ""
+, "Forward"
+: "Chuyển tiếp"
 
-, "Use Felamimail in mailto links, otherwise use the default desktop client."
-: ""
+, "Print Message"
+: "In nội dung"
 
-, "Use for NOTES"
-: "Sử dụng cho GHI CHÉP"
-
-, "Save Note default Value."
-: "Lưu giá trị ghi chép mặc định "
-
-, "Confirm Delete"
-: "Xác nhận xóa"
-
-, "Show confirmation dialog when deleting mails."
-: "Hiển thị cửa sổ xác nhận khi xóa thư."
-
-, ".eml file Attachment in forwarded mails"
-: ""
-
-, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
-: ""
-
-, "Message not available."
-: "Nội dung không sẵn sàng"
-
-, "File Message"
-: ""
-
-, "Filemanager ..."
-: ""
-
-, "Attachment"
-: ""
-
-, "Download"
-: ""
-
-, "{messageCount, plural, one {Message was filed} other {# messages where filed}}"
-: ""
-
-, "Success"
-: ""
-
-, "Error"
-: ""
-
-, "File Messages as Attachment"
-: ""
+, "Print Preview"
+: "Xem trước khi in"
 
 , "Add New Account"
 : ""
@@ -85,6 +34,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Permissions"
 : ""
 
+, "Rules"
+: ""
+
+, "Vacation, Vacations"
+: [
+  "one: Trả lời tự động\nother: Trả lời tự động"
+
+]
 , "Account, Accounts"
 : [
   "one: Tài khoản\nother: Tài khoản"
@@ -93,7 +50,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Account Name"
 : "Tên tài khoản"
 
-, "Account Type"
+, "Type"
+: ""
+
+, "Migration Approved"
+: ""
+
+, "Approve Migration"
+: ""
+
+, "Do you want to approve the migration of this account?"
 : ""
 
 , "User"
@@ -144,6 +110,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password"
 : "Mật khẩu"
 
+, "Test IMAP Connection"
+: ""
+
 , "SMTP"
 : "SMTP"
 
@@ -165,6 +134,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Password (optional)"
 : "Mật khẩu (tùy chọn)"
 
+, "Test SMTP Connection"
+: ""
+
 , "Sieve"
 : "Sieve"
 
@@ -174,6 +146,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Notification Email"
 : ""
 
+, "Auto-move notifications"
+: ""
+
+, "Auto-move notifications folder"
+: ""
+
 , "Other Settings"
 : "Thiết lập khác"
 
@@ -216,16 +194,22 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Reply-To Email"
 : ""
 
-, "Shared System Account"
+, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
 : ""
 
-, "Additional Personal System Account"
+, "Migration has not been approved."
 : ""
 
-, "Additional Personal External Account"
+, "It is not possible to convert the account to this type."
 : ""
 
-, "Default Personal System Account"
+, "System accounts cannot be created manually."
+: ""
+
+, "Mailinglist accounts cannot be created manually."
+: ""
+
+, "Account type change not possible"
 : ""
 
 , "E-Mail account needs a password"
@@ -243,52 +227,171 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "The grant edit the shared email account"
 : ""
 
-, "Click here to set To/CC/BCC."
-: "Click vào đây để đặt To/CC/BCC"
+, "Send Mails"
+: ""
 
-, "To:"
-: "To:"
+, "The grant to send mails via the email account"
+: ""
 
-, "Cc:"
-: "Cc:"
+, "Warning"
+: ""
 
-, "Bcc:"
-: "Bcc:"
+, "Server connection failed. Do you still want to save this setting and exit?"
+: ""
 
-, "Remove"
-: "Xóa"
+, "Connection succeed"
+: ""
 
-, "Compose email"
-: "Soạn Email"
+, "Connecting to {0} server..."
+: ""
+
+, "Connection failed"
+: ""
+
+, "{server} Connection Status"
+: ""
+
+, "Save Message as"
+: ""
+
+, "File (in Filemanager) ..."
+: ""
+
+, "Attachment (of Record)"
+: ""
+
+, "Download"
+: ""
+
+, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
+: ""
+
+, "Success"
+: ""
+
+, "Error"
+: ""
+
+, "Save Messages as Attachment"
+: ""
+
+, "No Messages found."
+: ""
+
+, "It is SPAM"
+: ""
+
+, "It is not SPAM"
+: ""
+
+, "Compose"
+: "Soạn thư"
+
+, "Toggle highlighting"
+: "Bật tắt điểm nhấn"
+
+, "Mark read/unread"
+: "Đánh dấu đọc/chưa đọc"
+
+, "Move"
+: ""
+
+, "Copy"
+: ""
+
+, "Import Messages"
+: ""
+
+, "Add Account"
+: "Thêm tài khoản"
+
+, "No target folder selected"
+: ""
+
+, "You need to select a target folder for the messages."
+: ""
+
+, "Wrong File Type"
+: ""
+
+, "Files of type eml allowed only."
+: ""
+
+, "Importing Messages..."
+: ""
+
+, "Id"
+: "ID"
+
+, "Attachments"
+: "Đính kèm"
+
+, "Flags"
+: "Cờ"
+
+, "Subject"
+: "Tiêu đề"
+
+, "From (Email)"
+: "Từ (email)"
+
+, "From (Name)"
+: "Từ (tên)"
+
+, "Sender"
+: "Người gửi"
 
 , "To"
 : "Tới"
 
-, "CC"
+, "Sent"
+: "Đã gửi"
+
+, "Received"
+: "Đã nhận"
+
+, "Folder, Folders"
+: [
+  "one:Thư mục\nother:Thư mục"
+
+]
+, "Size"
+: "Dung lượng"
+
+, "Answered"
+: "Đã trả lời"
+
+, "Forwarded"
+: "Đã chuyển tiếp"
+
+, "This message might be SPAM"
 : ""
 
-, "BCC"
+, "Tine20"
 : ""
 
-, "Mass Mailing"
+, "Encrypted Message"
 : ""
 
-, "Signatures"
+, "Filed as:"
 : ""
 
-, "Name"
+, "Select Message File Location"
 : ""
 
-, "Is Default"
+, "Filing Messages"
 : ""
 
-, "Add Signature"
+, "Error Filing Message"
 : ""
 
-, "Edit Signature"
+, "Could not file message."
 : ""
 
-, "Delete Signature"
+, "Send Reading Confirmation"
+: "Gửi xác nhận đã đọc"
+
+, "Do you want to send a reading confirmation message?"
 : ""
 
 , "Empty Folder"
@@ -300,11 +403,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "New {0}"
 : "Tạo {0}"
 
-, "Folder, Folders"
-: [
-  "one:Thư mục\nother:Thư mục"
-
-]
 , "Please enter the name of the new {0}:"
 : "Xin nhập tên của {0} mới:"
 
@@ -338,27 +436,36 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Update Folder List"
 : "Cập nhật danh sách thư mục"
 
-, "Add as \"To\""
-: "Thêm vào \"Đến\""
+, "Message not available."
+: "Nội dung không sẵn sàng"
 
-, "Add as \"Cc\""
-: "Thêm \"CC\""
+, "Cancel"
+: "Hủy bỏ"
 
-, "Add as \"Bcc\""
-: "Thêm \"BCC\""
+, "Ok"
+: "OK"
 
-, "Remove from recipients"
-: "Xóa khỏi người nhận"
+, "Folders of account {0}"
+: "Thư mục của tài khoản {0}"
 
-, "Loading Mail Addresses"
-: "Đang tải địa chỉ email"
+, "Folders of all accounts"
+: "Thư mục của mọi tài khoản"
+
+, "Compose email"
+: "Soạn Email"
+
+, "CC"
+: ""
+
+, "BCC"
+: ""
+
+, "Mass Mailing"
+: ""
 
 , "Open in Felamimail"
 : ""
 
-, "Subject"
-: "Tiêu đề"
-
 , "From"
 : "Từ"
 
@@ -374,12 +481,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Show or hide header information"
 : "Hiện/ ẩn thông tin header"
 
-, "Attachments"
-: "Đính kèm"
-
 , "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
 : ""
 
+, "Open"
+: ""
+
+, "Save As"
+: ""
+
+, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
+: ""
+
+, "Save as Record Attachment"
+: ""
+
+, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
+: ""
+
+, "Confirm SPAM Suspicion"
+: ""
+
+, "Yes, it is SPAM"
+: ""
+
+, "No, it is not"
+: ""
+
+, "(new message)"
+: "(thư mới)"
+
+, "Select recipients for \"{0}\""
+: "Chọn người nhận cho \"{0}\""
+
+, "Signatures"
+: ""
+
+, "Name"
+: ""
+
+, "Is Default"
+: ""
+
+, "Add Signature"
+: ""
+
+, "Edit Signature"
+: ""
+
+, "Delete Signature"
+: ""
+
 , "Recipient filter"
 : "Bộ lọc người nhận"
 
@@ -389,104 +541,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "\"{0}\" recipients"
 : "\"{0}\" người nhận"
 
-, "Total Messages:"
-: "Tổng số tin nhắn"
-
-, "Unread Messages:"
-: "Thư chưa đọc:"
-
-, "Name on Server:"
-: "Tên trên máy chủ:"
-
-, "Last update:"
-: "Cập nhật lần cuối:"
-
-, "Fetching messages... ({0} done)"
+, "Attachment"
 : ""
 
-, "{0} unread message, {0} unread messages"
-: [
-  "one:{0} thư chưa đọc\nother:{0} thư chưa đọc"
-
-]
-, "(new message)"
-: "(thư mới)"
-
-, "Select recipients for \"{0}\""
-: "Chọn người nhận cho \"{0}\""
-
-, "Mailvelope decryption Error [{0}]"
+, "Filemanager (Download link)"
 : ""
 
-, "To decrypt this message please install {0} with API support enabled"
+, "Filemanager (Download link, password)"
 : ""
 
-, "PGP encrypted Message"
+, "Filemanager (Systemlink)"
 : ""
 
-, "Delete"
-: "Xóa"
+, "Attachment Type"
+: ""
 
-, "Reply"
-: "Trả lời"
+, "Click icon to change"
+: ""
 
-, "Reply To All"
-: "Trả lời tất cả"
+, "name"
+: ""
 
-, "Forward"
-: "Chuyển tiếp"
+, "size"
+: ""
 
-, "Print Message"
-: "In nội dung"
+, "type"
+: ""
 
-, "Print Preview"
-: "Xem trước khi in"
+, "Vacation Message for {0}"
+: "Nội dung trả lời tự động cho {0}"
 
 , "Notification for {0}"
 : ""
 
-, "Edit Filter Rule"
-: "Sửa quy tắc lọc"
-
-, "Apply filter if"
-: ""
-
-, "all conditions match"
-: ""
-
-, "any condition matches"
-: ""
-
-, "Do this action:"
-: "Thực hiện hành động:"
-
-, "Keep a copy"
-: ""
-
-, "Move mail to folder"
-: "Chuyển thư tới thư mục"
-
-, "Redirect mail to address"
-: "Chuyển hướng tới địa chỉ"
-
-, "Reject mail with this text"
-: "R"
-
-, "Discard mail"
-: "Hủy thư"
-
-, "Auto-Reply mail with this text"
-: ""
-
-, "Keep mail"
-: "Giữ email"
-
-, "Sieve Filter Rules"
-: "Quy tắc lọc Sieve"
-
-, "Sieve Filter Rules for {0}"
-: "Quy tắc lọc Sieve cho {0}"
-
 , "Move up"
 : "Chuyển lên"
 
@@ -508,6 +595,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Action"
 : "Hành động"
 
+, "Keep a copy"
+: ""
+
 , "is greater than"
 : "lớn hơn"
 
@@ -520,8 +610,65 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Header \"{0}\" matches \"{1}\""
 : "Header \"{0}\" matches \"{1}\""
 
-, "Vacation Message for {0}"
-: "Nội dung trả lời tự động cho {0}"
+, "Sieve Filter Rules"
+: "Quy tắc lọc Sieve"
+
+, "Sieve Filter Rules for {0}"
+: "Quy tắc lọc Sieve cho {0}"
+
+, "From (Email and Name)"
+: "Từ (Email và Tên)"
+
+, "To (Email)"
+: "To (Email)"
+
+, "To (Email CC)"
+: ""
+
+, "Header contains"
+: "Chứa header"
+
+, "Header name"
+: "Tên header"
+
+, "Header value"
+: "Giá trị Header"
+
+, "Header regex"
+: "Header regex"
+
+, "Edit Filter Rule"
+: "Sửa quy tắc lọc"
+
+, "Apply filter if"
+: ""
+
+, "all conditions match"
+: ""
+
+, "any condition matches"
+: ""
+
+, "Do this action:"
+: "Thực hiện hành động:"
+
+, "Move mail to folder"
+: "Chuyển thư tới thư mục"
+
+, "Redirect mail to address"
+: "Chuyển hướng tới địa chỉ"
+
+, "Reject mail with this text"
+: "R"
+
+, "Discard mail"
+: "Hủy thư"
+
+, "Auto-Reply mail with this text"
+: ""
+
+, "Keep mail"
+: "Giữ email"
 
 , "General"
 : "Chung"
@@ -574,62 +721,182 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Choose Template ..."
 : "Chọn mẫu..."
 
-, "From (Email)"
-: "Từ (email)"
-
-, "From (Email and Name)"
-: "Từ (Email và Tên)"
-
-, "To (Email)"
-: "To (Email)"
-
-, "To (Email CC)"
+, "Mailvelope decryption Error [{0}]"
 : ""
 
-, "Size"
-: "Dung lượng"
-
-, "Header contains"
-: "Chứa header"
-
-, "Header name"
-: "Tên header"
-
-, "Header value"
-: "Giá trị Header"
-
-, "Header regex"
-: "Header regex"
-
-, "Filemanager (Download link)"
+, "To decrypt this message please install {0} with API support enabled"
 : ""
 
-, "Filemanager (Download link, password)"
+, "PGP encrypted Message"
 : ""
 
-, "Filemanager (Systemlink)"
+, "GENDER_Message"
 : ""
 
-, "Attachment Type"
+, "Message, Messages"
+: [
+  "one: Nội dung\nother: Nội dung"
+
+]
+, "Subject/From"
+: "Tiêu đề/Từ"
+
+, "Cc"
+: "Cc"
+
+, "Bcc"
+: "Bcc"
+
+, "INBOX"
+: "Thư đến"
+
+, "Drafts"
+: "Nháp"
+
+, "Templates"
+: "Mẫu"
+
+, "Junk"
+: "Thư rác"
+
+, "Trash"
+: "Thùng rác"
+
+, "GENDER_Folder"
 : ""
 
-, "Click icon to change"
+, "record list, record lists"
+: [
+  "one: danh sách biểu ghi\nother: danh sách biểu ghi"
+
+]
+, "Rule, Rules"
+: [
+  "one: Quy tắc\nother: Quy tắc"
+
+]
+, "Flag, Flags"
+: [
+  "one:Cờ\nother:Cờ"
+
+]
+, "Flag list, Flag lists"
+: [
+  "one:Danh sách cờ\nother:Danh sách cờ"
+
+]
+, "Total Messages:"
+: "Tổng số tin nhắn"
+
+, "Unread Messages:"
+: "Thư chưa đọc:"
+
+, "Name on Server:"
+: "Tên trên máy chủ:"
+
+, "Last update:"
+: "Cập nhật lần cuối:"
+
+, "Fetching messages... ({0} done)"
 : ""
 
-, "name"
+, "{0} unread message, {0} unread messages"
+: [
+  "one:{0} thư chưa đọc\nother:{0} thư chưa đọc"
+
+]
+, "New Mail"
+: "Email mới"
+
+, "Email"
+: "Email"
+
+, "Active Vacation Message"
+: "Bật chế độ tự động trả lời"
+
+, "Email account \"{0}\" has an active vacation message."
+: "Tài khoản email \"{0}\" có 1 email tự động trả lời đang hoạt động"
+
+, "Poll URL: {0}"
 : ""
 
-, "size"
+, "{0} as default mailer"
 : ""
 
-, "type"
-: ""
+, "New mails"
+: "Email mới"
 
-, "Failure"
-: ""
+, "You got {0} new mail(s) in folder {1} ({2})."
+: "Bạn có {0} email mới trong thư mục {1} ({2})."
 
-, "This file is already attached to this record."
-: ""
+, "IMAP Credentials for {0}"
+: "IMAP Credentials for {0}"
+
+, "Credentials"
+: "Credentials"
+
+, "IMAP Error"
+: "IMAP Error"
+
+, "No connection to IMAP server."
+: "Không kết nối tới máy chủ IMAP"
+
+, "IMAP Credentials Error"
+: "IMAP Credentials Error"
+
+, "Your email credentials are wrong. Please contact your administrator"
+: "Thông tin email bị sai. Xin hãy liên lạc với quản trị hệ thống của bạn."
+
+, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
+: "Một trong số thư mục của bạn đã bị xóa hoặc đổi tên bởi người dùng khác."
+
+, "SMTP Error"
+: "SMTP Error"
+
+, "No connection to SMTP server."
+: "Không có kết nối tới máy chủ SMTP"
+
+, "Sieve Error"
+: "Sieve Error"
+
+, "No connection to Sieve server."
+: "Không có kết nối tới máy chủ Sieve"
+
+, "Save Sieve Script Error"
+: "Lưu lỗi Sieve Script"
+
+, "Could not save script on Sieve server."
+: "Không thể lưu scrip trên máy chủ Sieve"
+
+, "Add as \"To\""
+: "Thêm vào \"Đến\""
+
+, "Add as \"Cc\""
+: "Thêm \"CC\""
+
+, "Add as \"Bcc\""
+: "Thêm \"BCC\""
+
+, "Remove from recipients"
+: "Xóa khỏi người nhận"
+
+, "Loading Mail Addresses"
+: "Đang tải địa chỉ email"
+
+, "Click here to set To/CC/BCC."
+: "Click vào đây để đặt To/CC/BCC"
+
+, "To:"
+: "To:"
+
+, "Cc:"
+: "Cc:"
+
+, "Bcc:"
+: "Bcc:"
+
+, "Remove"
+: "Xóa"
 
 , "Send"
 : "Gửi"
@@ -711,12 +978,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 
 , "Signature, Signatures"
 : [
-  "Chữ ký"
+  ""
 
 ]
-, "Warning"
-: ""
-
 , "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
 : ""
 
@@ -732,224 +996,83 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "No recipients set."
 : "Không chỉ ra người nhận."
 
+, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
+: ""
+
 , "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
 : ""
 
-, "Message, Messages"
-: [
-  "one: Nội dung\nother: Nội dung"
+, "All inboxes"
+: "Mọi thư đến"
 
-]
-, "Subject/From"
-: "Tiêu đề/Từ"
+, "Default Email Account"
+: "Tài khoản email mặc định"
 
-, "From (Name)"
-: "Từ (tên)"
+, "The default email account to use when sending mails."
+: "Tài khoản email mặc định được dùng khi gửi email"
 
-, "Cc"
-: "Cc"
-
-, "Bcc"
-: "Bcc"
-
-, "Flags"
-: "Cờ"
-
-, "Received"
-: "Đã nhận"
-
-, "INBOX"
-: "Thư đến"
-
-, "Drafts"
-: "Nháp"
-
-, "Sent"
-: "Đã gửi"
-
-, "Templates"
-: "Mẫu"
-
-, "Junk"
-: "Thư rác"
-
-, "Trash"
-: "Thùng rác"
-
-, "record list, record lists"
-: [
-  "one: danh sách biểu ghi\nother: danh sách biểu ghi"
-
-]
-, "Vacation, Vacations"
-: [
-  "one: Trả lời tự động\nother: Trả lời tự động"
-
-]
-, "Rule, Rules"
-: [
-  "one: Quy tắc\nother: Quy tắc"
-
-]
-, "Flag, Flags"
-: [
-  "one:Cờ\nother:Cờ"
-
-]
-, "Flag list, Flag lists"
-: [
-  "one:Danh sách cờ\nother:Danh sách cờ"
-
-]
-, "No Messages found."
+, "Mark Email Automatically As Read"
 : ""
 
-, "Compose"
-: "Soạn thư"
-
-, "Toggle highlighting"
-: "Bật tắt điểm nhấn"
-
-, "Mark read/unread"
-: "Đánh dấu đọc/chưa đọc"
-
-, "Move"
+, "Is email marked as read automatically or by user action"
 : ""
 
-, "Add Account"
-: "Thêm tài khoản"
+, "Email Update Interval"
+: "Khoảng thời gian cập nhật email"
 
-, "Id"
-: "ID"
-
-, "Sender"
-: "Người gửi"
-
-, "Answered"
-: "Đã trả lời"
-
-, "Forwarded"
-: "Đã chuyển tiếp"
-
-, "Tine20"
+, "How often should Felamimail check for new Emails (in minutes)."
 : ""
 
-, "Filed as:"
+, "Use for mailto links"
 : ""
 
-, "Select Message File Location"
+, "Use Felamimail in mailto links, otherwise use the default desktop client."
 : ""
 
-, "Filing Messages"
+, "Use for NOTES"
+: "Sử dụng cho GHI CHÉP"
+
+, "Save Note default Value."
+: "Lưu giá trị ghi chép mặc định "
+
+, "Confirm Delete"
+: "Xác nhận xóa"
+
+, "Show confirmation dialog when deleting mails."
+: "Hiển thị cửa sổ xác nhận khi xóa thư."
+
+, ".eml file Attachment in forwarded mails"
 : ""
 
-, "Error Filing Message"
+, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
 : ""
 
-, "Could not file message."
+, "Default Font"
 : ""
 
-, "Send Reading Confirmation"
-: "Gửi xác nhận đã đọc"
-
-, "Do you want to send a reading confirmation message?"
+, "Setting the default font in the E-Mail app"
 : ""
 
-, "New Mail"
-: "Email mới"
-
-, "Email"
-: "Email"
-
-, "Active Vacation Message"
-: "Bật chế độ tự động trả lời"
-
-, "Email account \"{0}\" has an active vacation message."
-: "Tài khoản email \"{0}\" có 1 email tự động trả lời đang hoạt động"
-
-, "Poll URL: {0}"
+, "Mail Type"
 : ""
 
-, "{0} as default mailer"
+, "Possible mail types."
 : ""
 
-, "New mails"
-: "Email mới"
+, "Additional Personal External Account"
+: ""
 
-, "You got {0} new mail(s) in folder {1} ({2})."
-: "Bạn có {0} email mới trong thư mục {1} ({2})."
+, "Shared System Account"
+: ""
 
-, "IMAP Credentials for {0}"
-: "IMAP Credentials for {0}"
+, "Additional Personal System Account"
+: ""
 
-, "Credentials"
-: "Credentials"
+, "Default Personal System Account"
+: ""
 
-, "IMAP Error"
-: "IMAP Error"
-
-, "No connection to IMAP server."
-: "Không kết nối tới máy chủ IMAP"
-
-, "IMAP Credentials Error"
-: "IMAP Credentials Error"
-
-, "Your email credentials are wrong. Please contact your administrator"
-: "Thông tin email bị sai. Xin hãy liên lạc với quản trị hệ thống của bạn."
-
-, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
-: "Một trong số thư mục của bạn đã bị xóa hoặc đổi tên bởi người dùng khác."
-
-, "SMTP Error"
-: "SMTP Error"
-
-, "No connection to SMTP server."
-: "Không có kết nối tới máy chủ SMTP"
-
-, "Sieve Error"
-: "Sieve Error"
-
-, "No connection to Sieve server."
-: "Không có kết nối tới máy chủ Sieve"
-
-, "Save Sieve Script Error"
-: "Lưu lỗi Sieve Script"
-
-, "Could not save script on Sieve server."
-: "Không thể lưu scrip trên máy chủ Sieve"
-
-, "Cancel"
-: "Hủy bỏ"
-
-, "Ok"
-: "OK"
-
-, "Folders of account {0}"
-: "Thư mục của tài khoản {0}"
-
-, "Folders of all accounts"
-: "Thư mục của mọi tài khoản"
-
-, "All inboxes of my email accounts"
-: "Mọi thư đến trong tài khoản email của tôi."
-
-, "All unread mail"
-: "Mọi thư chưa đọc"
-
-, "All unread mail of my email accounts"
-: "Mọi email chưa đọc trong tài khoản email của tôi"
-
-, "All highlighted mail"
-: "Mọi thư được nhấn mạnh"
-
-, "All highlighted mail of my email accounts"
-: "Mọi thư nhấn mạnh trong tài khoản email của tôi"
-
-, "All drafts"
-: "Mọi bản nháp"
-
-, "All mails with the draft flag"
-: "Mọi thư với cờ nháp"
+, "Mailinglist"
+: ""
 
 , "Mailinglist Reject Reason"
 : ""
@@ -978,12 +1101,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Delete Archived Mail"
 : ""
 
+, "Prevent copying mails in the same account"
+: ""
+
 , "Enabled Features"
 : ""
 
 , "Enabled Features in Felamimail Application."
 : ""
 
+, "Account Migration"
+: ""
+
+, "Shows context menu for system accounts to approve migration"
+: ""
+
+, "Move notifications"
+: ""
+
+, "Move notifications to a subfolder via sieve"
+: ""
+
+, "Auto-Save Drafts"
+: ""
+
+, "Save drafts automatically while editing an email"
+: ""
+
+, "Only password download link"
+: ""
+
+, "Allow only password download link"
+: ""
+
 , "Tine 2.0 Flag"
 : ""
 
@@ -1002,6 +1152,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create template, trash, sent, draft and junks folders for system accounts"
 : ""
 
+, "Enable Spam Suspicion Strategy"
+: ""
+
+, "SEnable pam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy"
+: ""
+
+, "Spam Suspicion Strategy Config"
+: ""
+
+, "Spam User Processing Pipeline"
+: ""
+
+, "Confirm SPAM Suspicion Message"
+: ""
+
+, "Message for users when they press the info button in a SPAM suspicion toolbar."
+: ""
+
 , "Filter E-Mail URIs"
 : ""
 
@@ -1044,89 +1215,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "shared / adb_list accounts need to have a password set"
 : ""
 
-, "shared / adb_list accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an email set"
-: ""
-
-, "userInternal accounts need to have an user_id set"
-: ""
-
-, "Seen"
-: "Đã xem"
-
-, "Deleted"
-: "Đã xóa"
-
-, "Draft"
-: "Nháp"
-
-, "Flagged"
-: "Đã cắm cờ"
-
-, "Bad recipient address syntax"
-: ""
-
-, "Recipient address rejected"
-: ""
-
-, "Invalid address format"
-: ""
-
-, "Error: %s"
-: "Lỗi: %s"
-
-, "Could not send message"
-: "Không thể gửi message"
-
-, "My Mail Download Links"
-: ""
-
-, "Out of Office reply from %1$s"
-: "Trả lời bên ngoài cơ quan từ %1$s"
-
-, "You have new mail from "
-: ""
-
-, "Can not combine \"allow external\" and \"allow only members\""
-: ""
-
-, "Message File Suggestion, Message File Suggestions"
-: [
-  ""
-
-]
-, "Message File Suggestions"
-: ""
-
-, "Message File Location, Message File Locations"
-: [
-  ""
-
-]
-, "Message File Locations"
-: ""
-
-, "Message ID Hash"
-: ""
-
-, "Message ID"
-: ""
-
-, "Model"
-: ""
-
-, "Record ID"
-: ""
-
-, "Record Title"
-: ""
-
-, "Node ID"
-: ""
-
-, "Type"
+, "Is default"
 : ""
 
 , "Email Account, Email Accounts"
@@ -1200,7 +1289,161 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "on"
 : "vào"
 
-, "Is default"
+, "Message File Location, Message File Locations"
+: [
+  ""
+
+]
+, "Message File Locations"
+: ""
+
+, "Message ID Hash"
+: ""
+
+, "Message ID"
+: ""
+
+, "Model"
+: ""
+
+, "Record ID"
+: ""
+
+, "Record Title"
+: ""
+
+, "Node ID"
+: ""
+
+, "Message File Suggestion, Message File Suggestions"
+: [
+  ""
+
+]
+, "Message File Suggestions"
+: ""
+
+, "Out of Office reply from %1$s"
+: "Trả lời bên ngoài cơ quan từ %1$s"
+
+, "It is not allowed to redirect emails to self! Please change the recipient."
+: ""
+
+, "Redirects to external email domains are not allowed."
+: ""
+
+, "You have new mail from "
+: ""
+
+, "shared / adb_list accounts need to have an email set"
+: ""
+
+, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
+: ""
+
+, "userInternal accounts need to have an email set"
+: ""
+
+, "userInternal accounts need to have an user_id set"
+: ""
+
+, "Please choose a new email address for userInternal accounts"
+: ""
+
+, "system account for user does not exist"
+: ""
+
+, "Account type cannot be changed from {0} to {1}"
+: ""
+
+, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
+: ""
+
+, "Migration of this account has not been approved!"
+: ""
+
+, "Could not find email user xprops!"
+: ""
+
+, "Internal user accounts need a valid user"
+: ""
+
+, "System account of user is missing"
+: ""
+
+, "Bad recipient address syntax"
+: ""
+
+, "Recipient address rejected"
+: ""
+
+, "Original message not found, email was moved or deleted"
+: ""
+
+, "Invalid address format"
+: ""
+
+, "Error: %s"
+: "Lỗi: %s"
+
+, "Could not send message"
+: "Không thể gửi message"
+
+, "My Mail Download Links"
+: ""
+
+, "Seen"
+: "Đã xem"
+
+, "Deleted"
+: "Đã xóa"
+
+, "Draft"
+: "Nháp"
+
+, "Flagged"
+: "Đã cắm cờ"
+
+, "It is not allowed to copy e-mails in the same account."
+: ""
+
+, "Folder with name {0} already exists!"
+: ""
+
+, "Failure on create folder"
+: ""
+
+, "All inboxes of my email accounts"
+: "Mọi thư đến trong tài khoản email của tôi."
+
+, "All unread mail"
+: "Mọi thư chưa đọc"
+
+, "All unread mail of my email accounts"
+: "Mọi email chưa đọc trong tài khoản email của tôi"
+
+, "All highlighted mail"
+: "Mọi thư được nhấn mạnh"
+
+, "All highlighted mail of my email accounts"
+: "Mọi thư nhấn mạnh trong tài khoản email của tôi"
+
+, "All drafts"
+: "Mọi bản nháp"
+
+, "All mails with the draft flag"
+: "Mọi thư với cờ nháp"
+
+, "IMAP Hostname missing"
+: ""
+
+, "IMAP Credentials missing"
+: ""
+
+, "SMTP Hostname missing"
+: ""
+
+, "SMTP Credentials missing"
 : ""
 
 , "manage email accounts"
@@ -1215,10 +1458,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Create new email accounts"
 : "Tạo tài khoản email"
 
-
-
-
-
+, "Vacation"
+: "one: Trả lời tự động\nother: Trả lời tự động"
 
 , "Account"
 : "one: Tài khoản\nother: Tài khoản"
@@ -1226,21 +1467,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Folder"
 : "one:Thư mục\nother:Thư mục"
 
-, "{0} unread message"
-: "one:{0} thư chưa đọc\nother:{0} thư chưa đọc"
-
-, "Signature"
-: "Chữ ký"
-
 , "Message"
 : "one: Nội dung\nother: Nội dung"
 
 , "record list"
 : "one: danh sách biểu ghi\nother: danh sách biểu ghi"
 
-, "Vacation"
-: "one: Trả lời tự động\nother: Trả lời tự động"
-
 , "Rule"
 : "one: Quy tắc\nother: Quy tắc"
 
@@ -1250,15 +1482,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Flag list"
 : "one:Danh sách cờ\nother:Danh sách cờ"
 
-, "Message File Suggestion"
-: ""
+, "{0} unread message"
+: "one:{0} thư chưa đọc\nother:{0} thư chưa đọc"
 
-, "Message File Location"
+, "Signature"
 : ""
 
 , "Email Account"
 : ""
 
+, "Message File Location"
+: ""
+
+, "Message File Suggestion"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
