@@ -7,209 +7,44 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 ""
 : "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-04-06 12:24+0200\nLast-Translator: Paul Hartog <p.hartog@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.3\n"
 
-, "Password for download required"
-: "Zum Herunterladen Passwort eingeben"
-
-, "Submit"
-: "Abschicken"
-
-, "File not found!"
-: "Datei nicht gefunden!"
-
-, "Name"
-: "Name"
+, "Usage"
+: "Verbrauch"
 
 , "Size"
 : "Größe"
 
-, "Last Modified"
-: "Letzter Änderungszeitpunkt"
+, "This folder has own quota"
+: "Dieser Ordner hat ein eigenes Kontingent"
 
-, "Description"
-: "Beschreibung"
+, "Quota"
+: "Kontingent"
 
-, "Folder, Folders"
-: [
-  "Ordner"
- ,"Ordner"
+, "No quota set (examples: 10 GB, 900 MB)"
+: "Kein Kontingent gesetzt (Bsp.: 10 GB, 900 MB)"
 
-]
-, "File, Files"
-: [
-  "Datei"
- ,"Dateien"
+, "Current Usage"
+: "Aktuelle Nutzung"
 
-]
-, "Default behavior when double-clicking on a Row"
-: "Standardverhalten beim Doppelklicken auf eine Zeile"
-
-, "Defines which action should be executed by default when double-clicked."
-: "Legt fest, welche Aktion bei einem Doppelklick standardmäßig ausgeführt werden soll."
-
-, "Invalid Filename"
-: "Ungültiger Dateiname"
-
-, "Content type"
-: "Inhaltstyp"
-
-, "path"
-: "Pfad"
-
-, "URL"
-: "URL"
-
-, "Password"
-: "Passwort"
-
-, "Valid until"
-: "Gültig bis"
-
-, "Send as e-mail"
-: "Sende als E-Mail"
-
-, "Download"
-: "Herunterladen"
-
-, "Create Public Link"
-: "Öffentlichen Link erstellen"
-
-, "Remove record"
-: "Eintrag entfernen"
-
-, "Creating new Download Link..."
-: "Erstelle neuen Download Link..."
-
-, "Deleting Download Links..."
-: "Lösche Download Links..."
-
-, "Deleting Download Link..."
-: "Lösche Download Link..."
-
-, "Created By"
-: "Erstellt von"
-
-, "Creation Time"
-: "Erstellt am"
-
-, "Expiration Time"
-: "Fristablauf"
-
-, "Access Count"
-: "Anzahl der Zugriffe"
-
-, "Last Modified Time"
-: "Zuletzt geändert"
-
-, "Last Modified By"
-: "Zuletzt geändert von"
-
-, "Revision"
-: "Version"
-
-, "This folder has own revision settings"
-: "Dieser Ordner hat eigene Revisions Einstellungen"
-
-, "Revision active"
-: "Revision aktiv"
-
-, "Limit revision amount to"
-: "Revisionen limitieren auf"
-
-, "Hold-back in months"
-: "Vorhalten in Monaten"
-
-, "Upload Failed"
-: "Hochladen fehlgeschlagen"
-
-, "It is not permitted to store files in this folder!"
-: "In diesem Ordner dürfen keine Dateien abgelegt werden!"
-
-, "Select a file"
-: "Wähle eine Datei"
-
-, "Select files"
-: "Wähle Dateien aus"
-
-, "Select a folder"
-: "Wähle einen Ordner aus"
-
-, "Select folders"
-: "Ordner Auswählen"
-
-, "Select an item"
-: "Wähle einen Artikel aus"
-
-, "Select items"
-: "Artikel Auswählen"
-
-, "Checking ..."
-: "Prüfe…"
-
-, "Overwrite Existing File?"
-: "Bestehende Datei Überschreiben?"
-
-, "Do you really want to overwrite the selected file?"
-: "Wollen Sie wirklich die ausgewählten Dateien überschreiben?"
-
-, "Tags"
-: "Tags"
+, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
+: "Das Kontingent gilt rekursiv für Dateien und Unterordner. Achtung: Das effektive Kontingent kann abweichen wenn ein übergeordneter Ordner eine geringeres Kontingent gesetzt hat."
 
 , "Revision Size"
 : "Revisions Größe"
 
-, "Total size of all available revisions"
-: "Gesamtgröße der verfügbaren Revisionen"
+, "File Type"
+: "Dateityp"
 
-, "Indexed"
-: "Indiziert"
+, "Usage by File Type"
+: "Verbrauch nach Dateityp"
 
-, "File contents is part of the search index"
-: "Dateiinhalte sind im Suchindex"
+, "User"
+: "Benutzer"
 
-, "Upload"
-: "Hochladen"
+, "Usage by User"
+: "Verbrauch nach Benutzer"
 
-, "Open Data Safe"
-: "Datentresor öffnen"
-
-, "Folder Up"
-: "Aufwärts"
-
-, "Close Data Safe"
-: "Datentresor schließen"
-
-, "Filemanager"
-: "Dateimanager"
-
-, "Save locally"
-: "Lokal speichern"
-
-, "Close"
-: "Schließen"
-
-, "Loading preview ..."
-: "Lade Vorschau …"
-
-, "Edit folder"
-: "Ordner bearbeiten"
-
-, "edit file"
-: "Datei bearbeiten"
-
-, "Public Links"
-: "Öffentliche Links"
-
-, "Type"
-: "Typ"
-
-, "Not yet indexed"
-: "Noch nicht indiziert"
-
-, "Modified By"
-: "Zuletzt geändert von"
-
-, "Enter description"
-: "Beschreibung eingeben"
+, "unknown"
+: "unbekannt"
 
 , "Service Unavailable"
 : "Dienst nicht verfügbar"
@@ -229,6 +64,102 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Item with this name already exists!"
 : "Item(s) mit diesem Namen schon vorhanden!"
 
+, "Filemanager"
+: "Dateimanager"
+
+, "Save locally"
+: "Lokal speichern"
+
+, "Close"
+: "Schließen"
+
+, "Loading preview ..."
+: "Lade Vorschau …"
+
+, "Node Download Links"
+: "Knoten Download Links"
+
+, "Create Public Link"
+: "Öffentlichen Link erstellen"
+
+, "Remove record"
+: "Eintrag entfernen"
+
+, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
+: "Download Links können mit einem Passwort geschützt werden. Wenn kein Passwort angegeben ist, kann jeder der den Link kennt auf die selektierten Dateien zugreifen."
+
+, "Creating new Download Link..."
+: "Erstelle neuen Download Link..."
+
+, "Deleting Download Links..."
+: "Lösche Download Links..."
+
+, "Deleting Download Link..."
+: "Lösche Download Link..."
+
+, "URL"
+: "URL"
+
+, "Created By"
+: "Erstellt von"
+
+, "Creation Time"
+: "Erstellt am"
+
+, "Expiration Time"
+: "Fristablauf"
+
+, "Password"
+: "Passwort"
+
+, "Access Count"
+: "Anzahl der Zugriffe"
+
+, "Last Modified Time"
+: "Zuletzt geändert"
+
+, "Last Modified By"
+: "Zuletzt geändert von"
+
+, "Folder, Folders"
+: [
+  "Ordner"
+ ,"Ordner"
+
+]
+, "Total size of all available revisions"
+: "Gesamtgröße der verfügbaren Revisionen"
+
+, "File contents is part of the search index"
+: "Dateiinhalte sind im Suchindex"
+
+, "Upload"
+: "Hochladen"
+
+, "Open Data Safe"
+: "Datentresor öffnen"
+
+, "Folder Up"
+: "Aufwärts"
+
+, "Locking data safe..."
+: "Datentresor wird geschlossen..."
+
+, "Unlocking data safe..."
+: "Datentresor wird geöffnet..."
+
+, "Close Data Safe"
+: "Datentresor schließen"
+
+, "Upload Failed"
+: "Hochladen fehlgeschlagen"
+
+, "Upload File"
+: "Datei hochladen"
+
+, "It is not permitted to store files in this folder!"
+: "In diesem Ordner dürfen keine Dateien abgelegt werden!"
+
 , "Whole Filemanager"
 : "Gesamter Dateimanager"
 
@@ -238,161 +169,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Search"
 : "Suche"
 
-, "The grant to download files"
-: "Das Recht, Dateien zu herunterzuladen"
-
-, "Publish"
-: "Veröffentlichen"
-
-, "The grant to create anonymous download links for files"
-: "Das Recht, anonyme Download Links für Dateien zu erstellen"
-
-, "Copying data .. {0}"
-: "Kopiere Daten .. {0}"
-
-, "Moving data .. {0}"
-: "Verschiebe Daten .. {0}"
-
-, "Please wait"
-: "Bitte warten"
-
-, "Error while uploading \"{fileName}\". Please try again later."
-: "Fehler beim Hochladen von „{fileName}“ . Bitte versuchen Sie es später noch einmal."
-
-, "Quick Search"
-: "Schnellsuche"
-
-, "Content Type"
-: "Inhaltstyp"
-
-, "File Contents"
-: "Dateiinhalt"
-
-, "Download Link, Download Links"
-: [
-  "Download Link"
- ,"Download Links"
-
-]
-, "Node Download Links"
-: "Knoten Download Links"
-
-, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
-: "Schade, gerne hätte Tine 2.0 Ihnen jetzt den Inhalt der Datei angezeigt."
-
-, "This is possible for .doc, .jpg, .pdf and even more file formats."
-: "Das geht z.B. für .doc, .jpg, .pdf und noch für weitere Dateiformate."
-
-, "Interested? Then let us know!"
-: "Interessiert? Dann melden Sie sich bei uns!"
-
-, "We would be happy to make you a non-binding offer."
-: "Wir machen Ihnen gerne ein unverbindliches Angebot."
-
-, "No preview available yet - Please try again in a few minutes."
-: "Leider noch keine Vorschau verfügbar - Bitte versuchen Sie es in einigen Minuten erneut."
-
-, "Notifications"
-: "Benachrichtigungen"
-
-, "This folder has own notification settings"
-: "Dieser Ordner hat eigene Benachrichtigungs Einstellungen"
-
-, "Notification"
-: "Benachrichtigung"
-
-, "Notification active"
-: "Benachrichtigung aktiv"
-
-, "Summary"
-: "Zusammenfassung"
-
-, "Once a Day, Every {0} Days"
-: [
-  "Einmal am Tag"
- ,"Alle {0} Tage"
-
-]
-, "No"
-: "Nein"
-
-, "Don't summarize"
-: "Nicht zusammenfassen"
-
-, "Once a day"
-: "Einmal täglich"
-
-, "Every 3 days"
-: "Alle 3 Tage"
-
-, "Once a week"
-: "Einmal die Woche"
-
-, "Once a month"
-: "Einmal pro Monat"
-
-, "Once a year"
-: "Einmal pro Jahr"
-
-, "Search for users ..."
-: "Suche nach Benutzern ..."
-
-, "No permission"
-: "Keine Berechtigung"
-
-, "all"
-: "alle"
-
-, "Search for groups ..."
-: "Suche nach Gruppen ..."
-
-, "Grants"
-: "Berechtigungen"
-
-, "This folder has its own grants"
-: "Diese Ordner hat eigene Berechtigungen"
-
-, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
-: "Rechte eines Ordners gelten auch rekursiv für alle Unterordner, es sei denn, sie verfügen über eigene Rechte."
-
-, "This folder is part of the data safe"
-: "Dieser Ordner ist Teil des Datentresors"
-
-, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
-: "Wenn der Datenschutz aktiviert ist, kann auf diesen Ordner und seinen Inhalt nur zugegriffen werden, wenn der Datenschutz geöffnet ist."
-
-, "Usage"
-: "Verbrauch"
-
-, "This folder has own quota"
-: "Dieser Ordner hat ein eigenes Kontingent"
-
-, "Quota"
-: "Kontingent"
-
-, "No quota set (examples: 10 GB, 900 MB)"
-: "Kein Kontingent gesetzt (Bsp.: 10 GB, 900 MB)"
-
-, "Current Usage"
-: "Aktuelle Nutzung"
-
-, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
-: "Das Kontingent gilt rekursiv für Dateien und Unterordner. Achtung: Das effektive Kontingent kann abweichen wenn ein übergeordneter Ordner eine geringeres Kontingent gesetzt hat."
-
-, "File Type"
-: "Dateityp"
-
-, "Usage by File Type"
-: "Verbrauch nach Dateityp"
-
-, "User"
-: "Benutzer"
-
-, "Usage by User"
-: "Verbrauch nach Benutzer"
-
-, "unknown"
-: "unbekannt"
+, "path"
+: "Pfad"
 
 , "Reload"
 : "Aktualisieren"
@@ -448,8 +226,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Preview"
 : "Vorschau"
 
-, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
-: "Download Links können mit einem Passwort geschützt werden. Wenn kein Passwort angegeben ist, kann jeder der den Link kennt auf die selektierten Dateien zugreifen."
+, "Publish"
+: "Veröffentlichen"
 
 , "Folder has been published successfully"
 : "Ordner wurde erfolgreich veröffentlicht"
@@ -457,12 +235,252 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "File has been published successfully"
 : "Datei wurde erfolgreich veröffentlicht"
 
+, "Notification"
+: "Benachrichtigung"
+
+, "Notification active"
+: "Benachrichtigung aktiv"
+
+, "Summary"
+: "Zusammenfassung"
+
+, "Once a Day, Every {0} Days"
+: [
+  "Einmal am Tag"
+ ,"Alle {0} Tage"
+
+]
+, "No"
+: "Nein"
+
+, "Don't summarize"
+: "Nicht zusammenfassen"
+
+, "Once a day"
+: "Einmal täglich"
+
+, "Every 3 days"
+: "Alle 3 Tage"
+
+, "Once a week"
+: "Einmal die Woche"
+
+, "Once a month"
+: "Einmal pro Monat"
+
+, "Once a year"
+: "Einmal pro Jahr"
+
+, "Name"
+: "Name"
+
+, "Search for users ..."
+: "Suche nach Benutzern ..."
+
+, "No permission"
+: "Keine Berechtigung"
+
+, "all"
+: "alle"
+
+, "Search for groups ..."
+: "Suche nach Gruppen ..."
+
+, "Valid until"
+: "Gültig bis"
+
+, "Send as e-mail"
+: "Sende als E-Mail"
+
+, "Download"
+: "Herunterladen"
+
+, "Revision"
+: "Version"
+
+, "This folder has own revision settings"
+: "Dieser Ordner hat eigene Revisions Einstellungen"
+
+, "Revision active"
+: "Revision aktiv"
+
+, "Limit revision amount to"
+: "Revisionen limitieren auf"
+
+, "Hold-back in months"
+: "Vorhalten in Monaten"
+
+, "The grant to download files"
+: "Das Recht, Dateien zu herunterzuladen"
+
+, "The grant to create anonymous download links for files"
+: "Das Recht, anonyme Download Links für Dateien zu erstellen"
+
+, "Copying data .. {0}"
+: "Kopiere Daten .. {0}"
+
+, "Moving data .. {0}"
+: "Verschiebe Daten .. {0}"
+
+, "Confirm Changing of Folder Grants"
+: "Ordner Berechtigungen werden geändert"
+
+, "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."
+: "Sie sind im Begriff einen Ordner zu verschieben der eigene Berechtigungen enthält. Diese gehen verloren und es werden die Berechtigungen des neuen übergeordneten Ordners geerbt."
+
+, "Please wait"
+: "Bitte warten"
+
+, "Error while uploading \"{fileName}\". Please try again later."
+: "Fehler beim Hochladen von „{fileName}“ . Bitte versuchen Sie es später noch einmal."
+
+, "Download Link, Download Links"
+: [
+  "Download Link"
+ ,"Download Links"
+
+]
+, "Grants"
+: "Berechtigungen"
+
+, "This folder has its own grants"
+: "Diese Ordner hat eigene Berechtigungen"
+
+, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
+: "Rechte eines Ordners gelten auch rekursiv für alle Unterordner, es sei denn, sie verfügen über eigene Rechte."
+
+, "This folder is part of the data safe"
+: "Dieser Ordner ist Teil des Datentresors"
+
+, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
+: "Wenn der Datenschutz aktiviert ist, kann auf diesen Ordner und seinen Inhalt nur zugegriffen werden, wenn der Datenschutz geöffnet ist."
+
+, "Select a file"
+: "Wähle eine Datei"
+
+, "Select files"
+: "Wähle Dateien aus"
+
+, "Select a folder"
+: "Wähle einen Ordner aus"
+
+, "Select folders"
+: "Ordner Auswählen"
+
+, "Select an item"
+: "Wähle einen Artikel aus"
+
+, "Select items"
+: "Artikel Auswählen"
+
+, "Notifications"
+: "Benachrichtigungen"
+
+, "This folder has own notification settings"
+: "Dieser Ordner hat eigene Benachrichtigungs Einstellungen"
+
+, "Edit folder"
+: "Ordner bearbeiten"
+
+, "edit file"
+: "Datei bearbeiten"
+
+, "File, Files"
+: [
+  "Datei"
+ ,"Dateien"
+
+]
+, "Public Links"
+: "Öffentliche Links"
+
+, "Type"
+: "Typ"
+
+, "Indexed"
+: "Indiziert"
+
+, "Not yet indexed"
+: "Noch nicht indiziert"
+
+, "Modified By"
+: "Zuletzt geändert von"
+
+, "Last Modified"
+: "Letzter Änderungszeitpunkt"
+
+, "Description"
+: "Beschreibung"
+
+, "Enter description"
+: "Beschreibung eingeben"
+
+, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
+: "Schade, gerne hätte Tine 2.0 Ihnen jetzt den Inhalt der Datei angezeigt."
+
+, "This is possible for .doc, .jpg, .pdf and even more file formats."
+: "Das geht z.B. für .doc, .jpg, .pdf und noch für weitere Dateiformate."
+
+, "Interested? Then let us know!"
+: "Interessiert? Dann melden Sie sich bei uns!"
+
+, "We would be happy to make you a non-binding offer."
+: "Wir machen Ihnen gerne ein unverbindliches Angebot."
+
+, "This file has no contents. The Upload has failed or has not yet finished."
+: "Diese Datei hat keinen Inhalt. Der Upload ist entweder fehlgeschlagen oder noch nicht fertig."
+
+, "No preview available yet - Please try again in a few minutes."
+: "Leider noch keine Vorschau verfügbar - Bitte versuchen Sie es in einigen Minuten erneut."
+
+, "No preview available."
+: "Keine Vorschau verfügbar."
+
+, "File named {0} already exist in this location. Do you want to replace it with the current one?"
+: "Eine Datei mit dem Namen {0} ist bereits vorhanden. Möchten Sie diese durch die aktuelle Datei ersetzen?"
+
+, "Replace"
+: "Ersetzen"
+
+, "Stop"
+: "Stopp"
+
+, "Skip"
+: "Überspringen"
+
+, "Apply to All"
+: "Auf Alle anwenden"
+
+, "Checking ..."
+: "Prüfe…"
+
+, "Overwrite Existing File?"
+: "Bestehende Datei Überschreiben?"
+
+, "Do you really want to overwrite the selected file?"
+: "Wollen Sie wirklich die ausgewählten Dateien überschreiben?"
+
+, "Content type"
+: "Inhaltstyp"
+
 , "Public Download URL"
 : "Öffentliche Download URL"
 
 , "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
 : "Liefern Sie anonyme Downloads von einer anderen URL. Stellen Sie sicher, dass die Umschreiberegeln entsprechend angepasst sind."
 
+, "Destination has the same Path"
+: "Ziel hat den gleichen Pfad"
+
+, "The destination has the same path as the source. No action has been performed."
+: "Das Ziel hat den selben Pfad wie die Quelle. Die Aktion wurde nicht ausgeführt."
+
+, "Destination is a Subfolder"
+: "Ziel ist ein Unterordner"
+
+, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
+: "Das Ziel ist ein Unterordner. Es ist nicht erlaubt einen Ordner in einen seiner Unterordner zu kopieren oder zu verschieben."
+
 , "you can't remove your own admin grant"
 : "Sie können Ihr eigenes Administrator-Recht nicht entfernen"
 
@@ -499,17 +517,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Attachments"
 : "Anhänge"
 
-, "Destination is a Subfolder"
-: "Ziel ist ein Unterordner"
+, "Password for download required"
+: "Zum Herunterladen Passwort eingeben"
 
-, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
-: "Das Ziel ist ein Unterordner. Es ist nicht erlaubt einen Ordner in einen seiner Unterordner zu kopieren oder zu verschieben."
+, "Submit"
+: "Abschicken"
 
-, "Destination has the same Path"
-: "Ziel hat den gleichen Pfad"
-
-, "The destination has the same path as the source. No action has been performed."
-: "Das Ziel hat den selben Pfad wie die Quelle. Die Aktion wurde nicht ausgeführt."
+, "File not found!"
+: "Datei nicht gefunden!"
 
 , "manage shared folders"
 : "Gemeinsame Ordner verwalten"
@@ -523,8 +538,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Allow viewing, adding and deleting download links"
 : "Anzeigen, Hinzufügen und Löschen von Download Links erlauben"
 
-, "This file has no contents. The Upload has failed or has not yet finished."
-: "Diese Datei hat keinen Inhalt. Der Upload ist entweder fehlgeschlagen oder noch nicht fertig."
+, "Folder with this name already exists!"
+: "Ordner mit dem Namen ist bereits vorhanden!"
+
+, "Upload Folder"
+: "Ordner Hochladen"
+
+, "Stop and Clear All Uploads"
+: "Alle Uploads stoppen und löschen"
+
+, "Uploads Monitor"
+: "Uploads Fortschritt"
+
+, "Total Uploads : "
+: "Gesamt-Uploads : "
+
+
+
+
+
+
+
+, "File Contents"
+: "Dateiinhalt"
 
 
 
@@ -550,14 +586,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Folder"
 : "Ordner"
 
-, "File"
-: "Datei"
+, "Once a Day"
+: "Einmal am Tag"
 
 , "Download Link"
 : "Download Link"
 
-, "Once a Day"
-: "Einmal am Tag"
+, "File"
+: "Datei"
 
 }); 
 /********************** translation loaded flag **********************/ 
