@@ -5,212 +5,47 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Filemanager **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:53+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Password for download required"
+, "Usage"
 : ""
 
-, "Submit"
-: ""
-
-, "File not found!"
-: ""
-
-, "Name"
-: "Nom"
-
 , "Size"
 : "Taille"
 
-, "Last Modified"
-: "Dernière modification"
-
-, "Description"
-: "Description"
-
-, "Folder, Folders"
-: [
-  "Dossier"
- ,"Dossiers"
-
-]
-, "File, Files"
-: [
-  "Fichier"
- ,"Fichiers"
-
-]
-, "Default behavior when double-clicking on a Row"
+, "This folder has own quota"
 : ""
 
-, "Defines which action should be executed by default when double-clicked."
+, "Quota"
 : ""
 
-, "Invalid Filename"
+, "No quota set (examples: 10 GB, 900 MB)"
 : ""
 
-, "Content type"
+, "Current Usage"
 : ""
 
-, "path"
-: "Chemin"
-
-, "URL"
+, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
 : ""
 
-, "Password"
-: ""
-
-, "Valid until"
-: ""
-
-, "Send as e-mail"
-: ""
-
-, "Download"
-: ""
-
-, "Create Public Link"
-: ""
-
-, "Remove record"
-: ""
-
-, "Creating new Download Link..."
-: ""
-
-, "Deleting Download Links..."
-: ""
-
-, "Deleting Download Link..."
-: ""
-
-, "Created By"
-: "Créé par"
-
-, "Creation Time"
-: "Date et heure de création"
-
-, "Expiration Time"
-: ""
-
-, "Access Count"
-: ""
-
-, "Last Modified Time"
-: "Dernière modification"
-
-, "Last Modified By"
-: "Dernier modificateur"
-
-, "Revision"
-: "Révision"
-
-, "This folder has own revision settings"
-: ""
-
-, "Revision active"
-: ""
-
-, "Limit revision amount to"
-: ""
-
-, "Hold-back in months"
-: ""
-
-, "Upload Failed"
-: "Échec du téléchargement"
-
-, "It is not permitted to store files in this folder!"
-: ""
-
-, "Select a file"
-: ""
-
-, "Select files"
-: ""
-
-, "Select a folder"
-: ""
-
-, "Select folders"
-: ""
-
-, "Select an item"
-: ""
-
-, "Select items"
-: ""
-
-, "Checking ..."
-: ""
-
-, "Overwrite Existing File?"
-: ""
-
-, "Do you really want to overwrite the selected file?"
-: ""
-
-, "Tags"
-: "Tags"
-
 , "Revision Size"
 : ""
 
-, "Total size of all available revisions"
+, "File Type"
 : ""
 
-, "Indexed"
+, "Usage by File Type"
 : ""
 
-, "File contents is part of the search index"
+, "User"
 : ""
 
-, "Upload"
-: "Télécharger"
-
-, "Open Data Safe"
+, "Usage by User"
 : ""
 
-, "Folder Up"
-: "Dossier parent"
-
-, "Close Data Safe"
+, "unknown"
 : ""
 
-, "Filemanager"
-: "Gestionnaire de fichiers"
-
-, "Save locally"
-: "Sauvegarder sur le disque"
-
-, "Close"
-: ""
-
-, "Loading preview ..."
-: ""
-
-, "Edit folder"
-: ""
-
-, "edit file"
-: ""
-
-, "Public Links"
-: ""
-
-, "Type"
-: "Type"
-
-, "Not yet indexed"
-: ""
-
-, "Modified By"
-: "Dernier modificateur"
-
-, "Enter description"
-: "Saisir une description"
-
 , "Service Unavailable"
 : "Service indisponible"
 
@@ -229,6 +64,96 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Item with this name already exists!"
 : "Ce nom est déjà utilisé"
 
+, "Filemanager"
+: "Gestionnaire de fichiers"
+
+, "Save locally"
+: "Sauvegarder sur le disque"
+
+, "Close"
+: ""
+
+, "Loading preview ..."
+: ""
+
+, "Node Download Links"
+: ""
+
+, "Create Public Link"
+: ""
+
+, "Remove record"
+: ""
+
+, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
+: ""
+
+, "Creating new Download Link..."
+: ""
+
+, "Deleting Download Links..."
+: ""
+
+, "Deleting Download Link..."
+: ""
+
+, "URL"
+: ""
+
+, "Created By"
+: "Créé par"
+
+, "Creation Time"
+: "Date et heure de création"
+
+, "Expiration Time"
+: ""
+
+, "Password"
+: ""
+
+, "Access Count"
+: ""
+
+, "Last Modified Time"
+: "Dernière modification"
+
+, "Last Modified By"
+: "Dernier modificateur"
+
+, "Folder"
+: "Dossier"
+
+, "Total size of all available revisions"
+: ""
+
+, "File contents is part of the search index"
+: ""
+
+, "Upload"
+: "Télécharger"
+
+, "Open Data Safe"
+: ""
+
+, "Folder Up"
+: "Dossier parent"
+
+, "Locking data safe..."
+: ""
+
+, "Unlocking data safe..."
+: ""
+
+, "Close Data Safe"
+: ""
+
+, "Upload Failed"
+: "Échec du téléchargement"
+
+, "It is not permitted to store files in this folder!"
+: ""
+
 , "Whole Filemanager"
 : ""
 
@@ -238,161 +163,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Search"
 : ""
 
-, "The grant to download files"
-: ""
-
-, "Publish"
-: ""
-
-, "The grant to create anonymous download links for files"
-: ""
-
-, "Copying data .. {0}"
-: "Copie en cours... {0}"
-
-, "Moving data .. {0}"
-: "Déplacement en cours... {0}"
-
-, "Please wait"
-: "Veuillez patienter"
-
-, "Error while uploading \"{fileName}\". Please try again later."
-: ""
-
-, "Quick Search"
-: "Recherche rapide"
-
-, "Content Type"
-: ""
-
-, "File Contents"
-: ""
-
-, "Download Link, Download Links"
-: [
-  ""
- ,""
-
-]
-, "Node Download Links"
-: ""
-
-, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
-: ""
-
-, "This is possible for .doc, .jpg, .pdf and even more file formats."
-: ""
-
-, "Interested? Then let us know!"
-: ""
-
-, "We would be happy to make you a non-binding offer."
-: ""
-
-, "No preview available yet - Please try again in a few minutes."
-: ""
-
-, "Notifications"
-: ""
-
-, "This folder has own notification settings"
-: ""
-
-, "Notification"
-: ""
-
-, "Notification active"
-: ""
-
-, "Summary"
-: ""
-
-, "Once a Day, Every {0} Days"
-: [
-  ""
- ,""
-
-]
-, "No"
-: ""
-
-, "Don't summarize"
-: ""
-
-, "Once a day"
-: ""
-
-, "Every 3 days"
-: ""
-
-, "Once a week"
-: ""
-
-, "Once a month"
-: ""
-
-, "Once a year"
-: ""
-
-, "Search for users ..."
-: ""
-
-, "No permission"
-: ""
-
-, "all"
-: ""
-
-, "Search for groups ..."
-: ""
-
-, "Grants"
-: ""
-
-, "This folder has its own grants"
-: ""
-
-, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
-: ""
-
-, "This folder is part of the data safe"
-: ""
-
-, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
-: ""
-
-, "Usage"
-: ""
-
-, "This folder has own quota"
-: ""
-
-, "Quota"
-: ""
-
-, "No quota set (examples: 10 GB, 900 MB)"
-: ""
-
-, "Current Usage"
-: ""
-
-, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
-: ""
-
-, "File Type"
-: ""
-
-, "Usage by File Type"
-: ""
-
-, "User"
-: ""
-
-, "Usage by User"
-: ""
-
-, "unknown"
-: ""
+, "path"
+: "Chemin"
 
 , "Reload"
 : ""
@@ -448,7 +220,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Preview"
 : ""
 
-, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
+, "Publish"
 : ""
 
 , "Folder has been published successfully"
@@ -457,12 +229,231 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "File has been published successfully"
 : ""
 
+, "Notification"
+: ""
+
+, "Notification active"
+: ""
+
+, "Summary"
+: ""
+
+, "Once a Day, Every {0} Days"
+: [
+  ""
+ ,""
+
+]
+, "No"
+: ""
+
+, "Don't summarize"
+: ""
+
+, "Once a day"
+: ""
+
+, "Every 3 days"
+: ""
+
+, "Once a week"
+: ""
+
+, "Once a month"
+: ""
+
+, "Once a year"
+: ""
+
+, "Name"
+: "Nom"
+
+, "Search for users ..."
+: ""
+
+, "No permission"
+: ""
+
+, "all"
+: ""
+
+, "Search for groups ..."
+: ""
+
+, "Valid until"
+: ""
+
+, "Send as e-mail"
+: ""
+
+, "Download"
+: ""
+
+, "Revision"
+: "Révision"
+
+, "This folder has own revision settings"
+: ""
+
+, "Revision active"
+: ""
+
+, "Limit revision amount to"
+: ""
+
+, "Hold-back in months"
+: ""
+
+, "The grant to download files"
+: ""
+
+, "The grant to create anonymous download links for files"
+: ""
+
+, "Copying data .. {0}"
+: "Copie en cours... {0}"
+
+, "Moving data .. {0}"
+: "Déplacement en cours... {0}"
+
+, "Confirm Changing of Folder Grants"
+: ""
+
+, "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."
+: ""
+
+, "Please wait"
+: "Veuillez patienter"
+
+, "Error while uploading \"{fileName}\". Please try again later."
+: ""
+
+, "Download Link, Download Links"
+: [
+  ""
+ ,""
+
+]
+, "Grants"
+: ""
+
+, "This folder has its own grants"
+: ""
+
+, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
+: ""
+
+, "This folder is part of the data safe"
+: ""
+
+, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
+: ""
+
+, "Select a file"
+: ""
+
+, "Select files"
+: ""
+
+, "Select a folder"
+: ""
+
+, "Select folders"
+: ""
+
+, "Select an item"
+: ""
+
+, "Select items"
+: ""
+
+, "Notifications"
+: ""
+
+, "This folder has own notification settings"
+: ""
+
+, "Edit folder"
+: ""
+
+, "edit file"
+: ""
+
+, "File"
+: "Fichier"
+
+, "Public Links"
+: ""
+
+, "Type"
+: "Type"
+
+, "Indexed"
+: ""
+
+, "Not yet indexed"
+: ""
+
+, "Modified By"
+: "Dernier modificateur"
+
+, "Last Modified"
+: "Dernière modification"
+
+, "Description"
+: "Description"
+
+, "Enter description"
+: "Saisir une description"
+
+, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
+: ""
+
+, "This is possible for .doc, .jpg, .pdf and even more file formats."
+: ""
+
+, "Interested? Then let us know!"
+: ""
+
+, "We would be happy to make you a non-binding offer."
+: ""
+
+, "This file has no contents. The Upload has failed or has not yet finished."
+: ""
+
+, "No preview available yet - Please try again in a few minutes."
+: ""
+
+, "Checking ..."
+: ""
+
+, "Overwrite Existing File?"
+: ""
+
+, "Do you really want to overwrite the selected file?"
+: ""
+
+, "Content type"
+: ""
+
 , "Public Download URL"
 : ""
 
 , "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
 : ""
 
+, "Destination has the same Path"
+: ""
+
+, "The destination has the same path as the source. No action has been performed."
+: ""
+
+, "Destination is a Subfolder"
+: ""
+
+, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
+: ""
+
 , "you can't remove your own admin grant"
 : ""
 
@@ -499,16 +490,13 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Attachments"
 : ""
 
-, "Destination is a Subfolder"
+, "Password for download required"
 : ""
 
-, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
+, "Submit"
 : ""
 
-, "Destination has the same Path"
-: ""
-
-, "The destination has the same path as the source. No action has been performed."
+, "File not found!"
 : ""
 
 , "manage shared folders"
@@ -527,18 +515,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 
 
 
-, "Folder"
-: "Dossier"
 
-, "File"
-: "Fichier"
-
-, "Download Link"
-: ""
 
 , "Once a Day"
 : ""
 
+, "Download Link"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
