@@ -5,214 +5,45 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Filemanager **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hebrew (http://www.transifex.com/tine20/tine20/language/he/)\nLanguage: he\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:53+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hebrew (http://www.transifex.com/tine20/tine20/language/he/)\nLanguage: he\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Password for download required"
-: ""
-
-, "Submit"
-: ""
-
-, "File not found!"
-: ""
-
-, "Name"
+, "Usage"
 : ""
 
 , "Size"
 : ""
 
-, "Last Modified"
+, "This folder has own quota"
 : ""
 
-, "Description"
+, "Quota"
 : ""
 
-, "Folder, Folders"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "File, Files"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Default behavior when double-clicking on a Row"
+, "No quota set (examples: 10 GB, 900 MB)"
 : ""
 
-, "Defines which action should be executed by default when double-clicked."
+, "Current Usage"
 : ""
 
-, "Invalid Filename"
-: ""
-
-, "Content type"
-: ""
-
-, "path"
-: ""
-
-, "URL"
-: ""
-
-, "Password"
-: ""
-
-, "Valid until"
-: ""
-
-, "Send as e-mail"
-: ""
-
-, "Download"
-: ""
-
-, "Create Public Link"
-: ""
-
-, "Remove record"
-: ""
-
-, "Creating new Download Link..."
-: ""
-
-, "Deleting Download Links..."
-: ""
-
-, "Deleting Download Link..."
-: ""
-
-, "Created By"
-: ""
-
-, "Creation Time"
-: ""
-
-, "Expiration Time"
-: ""
-
-, "Access Count"
-: ""
-
-, "Last Modified Time"
-: ""
-
-, "Last Modified By"
-: ""
-
-, "Revision"
-: ""
-
-, "This folder has own revision settings"
-: ""
-
-, "Revision active"
-: ""
-
-, "Limit revision amount to"
-: ""
-
-, "Hold-back in months"
-: ""
-
-, "Upload Failed"
-: ""
-
-, "It is not permitted to store files in this folder!"
-: ""
-
-, "Select a file"
-: ""
-
-, "Select files"
-: ""
-
-, "Select a folder"
-: ""
-
-, "Select folders"
-: ""
-
-, "Select an item"
-: ""
-
-, "Select items"
-: ""
-
-, "Checking ..."
-: ""
-
-, "Overwrite Existing File?"
-: ""
-
-, "Do you really want to overwrite the selected file?"
-: ""
-
-, "Tags"
+, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
 : ""
 
 , "Revision Size"
 : ""
 
-, "Total size of all available revisions"
+, "File Type"
 : ""
 
-, "Indexed"
+, "Usage by File Type"
 : ""
 
-, "File contents is part of the search index"
+, "User"
 : ""
 
-, "Upload"
+, "Usage by User"
 : ""
 
-, "Open Data Safe"
-: ""
-
-, "Folder Up"
-: ""
-
-, "Close Data Safe"
-: ""
-
-, "Filemanager"
-: ""
-
-, "Save locally"
-: ""
-
-, "Close"
-: ""
-
-, "Loading preview ..."
-: ""
-
-, "Edit folder"
-: ""
-
-, "edit file"
-: ""
-
-, "Public Links"
-: ""
-
-, "Type"
-: ""
-
-, "Not yet indexed"
-: ""
-
-, "Modified By"
-: ""
-
-, "Enter description"
+, "unknown"
 : ""
 
 , "Service Unavailable"
@@ -233,6 +64,96 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Item with this name already exists!"
 : ""
 
+, "Filemanager"
+: ""
+
+, "Save locally"
+: ""
+
+, "Close"
+: ""
+
+, "Loading preview ..."
+: ""
+
+, "Node Download Links"
+: ""
+
+, "Create Public Link"
+: ""
+
+, "Remove record"
+: ""
+
+, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
+: ""
+
+, "Creating new Download Link..."
+: ""
+
+, "Deleting Download Links..."
+: ""
+
+, "Deleting Download Link..."
+: ""
+
+, "URL"
+: ""
+
+, "Created By"
+: ""
+
+, "Creation Time"
+: ""
+
+, "Expiration Time"
+: ""
+
+, "Password"
+: ""
+
+, "Access Count"
+: ""
+
+, "Last Modified Time"
+: ""
+
+, "Last Modified By"
+: ""
+
+, "Folder"
+: ""
+
+, "Total size of all available revisions"
+: ""
+
+, "File contents is part of the search index"
+: ""
+
+, "Upload"
+: ""
+
+, "Open Data Safe"
+: ""
+
+, "Folder Up"
+: ""
+
+, "Locking data safe..."
+: ""
+
+, "Unlocking data safe..."
+: ""
+
+, "Close Data Safe"
+: ""
+
+, "Upload Failed"
+: ""
+
+, "It is not permitted to store files in this folder!"
+: ""
+
 , "Whole Filemanager"
 : ""
 
@@ -242,164 +163,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Search"
 : ""
 
-, "The grant to download files"
-: ""
-
-, "Publish"
-: ""
-
-, "The grant to create anonymous download links for files"
-: ""
-
-, "Copying data .. {0}"
-: ""
-
-, "Moving data .. {0}"
-: ""
-
-, "Please wait"
-: ""
-
-, "Error while uploading \"{fileName}\". Please try again later."
-: ""
-
-, "Quick Search"
-: ""
-
-, "Content Type"
-: ""
-
-, "File Contents"
-: ""
-
-, "Download Link, Download Links"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Node Download Links"
-: ""
-
-, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
-: ""
-
-, "This is possible for .doc, .jpg, .pdf and even more file formats."
-: ""
-
-, "Interested? Then let us know!"
-: ""
-
-, "We would be happy to make you a non-binding offer."
-: ""
-
-, "No preview available yet - Please try again in a few minutes."
-: ""
-
-, "Notifications"
-: ""
-
-, "This folder has own notification settings"
-: ""
-
-, "Notification"
-: ""
-
-, "Notification active"
-: ""
-
-, "Summary"
-: ""
-
-, "Once a Day, Every {0} Days"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "No"
-: ""
-
-, "Don't summarize"
-: ""
-
-, "Once a day"
-: ""
-
-, "Every 3 days"
-: ""
-
-, "Once a week"
-: ""
-
-, "Once a month"
-: ""
-
-, "Once a year"
-: ""
-
-, "Search for users ..."
-: ""
-
-, "No permission"
-: ""
-
-, "all"
-: ""
-
-, "Search for groups ..."
-: ""
-
-, "Grants"
-: ""
-
-, "This folder has its own grants"
-: ""
-
-, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
-: ""
-
-, "This folder is part of the data safe"
-: ""
-
-, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
-: ""
-
-, "Usage"
-: ""
-
-, "This folder has own quota"
-: ""
-
-, "Quota"
-: ""
-
-, "No quota set (examples: 10 GB, 900 MB)"
-: ""
-
-, "Current Usage"
-: ""
-
-, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
-: ""
-
-, "File Type"
-: ""
-
-, "Usage by File Type"
-: ""
-
-, "User"
-: ""
-
-, "Usage by User"
-: ""
-
-, "unknown"
+, "path"
 : ""
 
 , "Reload"
@@ -456,7 +220,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Preview"
 : ""
 
-, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
+, "Publish"
 : ""
 
 , "Folder has been published successfully"
@@ -465,12 +229,235 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "File has been published successfully"
 : ""
 
+, "Notification"
+: ""
+
+, "Notification active"
+: ""
+
+, "Summary"
+: ""
+
+, "Once a Day, Every {0} Days"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "No"
+: ""
+
+, "Don't summarize"
+: ""
+
+, "Once a day"
+: ""
+
+, "Every 3 days"
+: ""
+
+, "Once a week"
+: ""
+
+, "Once a month"
+: ""
+
+, "Once a year"
+: ""
+
+, "Name"
+: ""
+
+, "Search for users ..."
+: ""
+
+, "No permission"
+: ""
+
+, "all"
+: ""
+
+, "Search for groups ..."
+: ""
+
+, "Valid until"
+: ""
+
+, "Send as e-mail"
+: ""
+
+, "Download"
+: ""
+
+, "Revision"
+: ""
+
+, "This folder has own revision settings"
+: ""
+
+, "Revision active"
+: ""
+
+, "Limit revision amount to"
+: ""
+
+, "Hold-back in months"
+: ""
+
+, "The grant to download files"
+: ""
+
+, "The grant to create anonymous download links for files"
+: ""
+
+, "Copying data .. {0}"
+: ""
+
+, "Moving data .. {0}"
+: ""
+
+, "Confirm Changing of Folder Grants"
+: ""
+
+, "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."
+: ""
+
+, "Please wait"
+: ""
+
+, "Error while uploading \"{fileName}\". Please try again later."
+: ""
+
+, "Download Link, Download Links"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Grants"
+: ""
+
+, "This folder has its own grants"
+: ""
+
+, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
+: ""
+
+, "This folder is part of the data safe"
+: ""
+
+, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
+: ""
+
+, "Select a file"
+: ""
+
+, "Select files"
+: ""
+
+, "Select a folder"
+: ""
+
+, "Select folders"
+: ""
+
+, "Select an item"
+: ""
+
+, "Select items"
+: ""
+
+, "Notifications"
+: ""
+
+, "This folder has own notification settings"
+: ""
+
+, "Edit folder"
+: ""
+
+, "edit file"
+: ""
+
+, "File"
+: ""
+
+, "Public Links"
+: ""
+
+, "Type"
+: ""
+
+, "Indexed"
+: ""
+
+, "Not yet indexed"
+: ""
+
+, "Modified By"
+: ""
+
+, "Last Modified"
+: ""
+
+, "Description"
+: ""
+
+, "Enter description"
+: ""
+
+, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
+: ""
+
+, "This is possible for .doc, .jpg, .pdf and even more file formats."
+: ""
+
+, "Interested? Then let us know!"
+: ""
+
+, "We would be happy to make you a non-binding offer."
+: ""
+
+, "This file has no contents. The Upload has failed or has not yet finished."
+: ""
+
+, "No preview available yet - Please try again in a few minutes."
+: ""
+
+, "Checking ..."
+: ""
+
+, "Overwrite Existing File?"
+: ""
+
+, "Do you really want to overwrite the selected file?"
+: ""
+
+, "Content type"
+: ""
+
 , "Public Download URL"
 : ""
 
 , "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
 : ""
 
+, "Destination has the same Path"
+: ""
+
+, "The destination has the same path as the source. No action has been performed."
+: ""
+
+, "Destination is a Subfolder"
+: ""
+
+, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
+: ""
+
 , "you can't remove your own admin grant"
 : ""
 
@@ -507,16 +494,13 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Attachments"
 : ""
 
-, "Destination is a Subfolder"
+, "Password for download required"
 : ""
 
-, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
+, "Submit"
 : ""
 
-, "Destination has the same Path"
-: ""
-
-, "The destination has the same path as the source. No action has been performed."
+, "File not found!"
 : ""
 
 , "manage shared folders"
@@ -531,18 +515,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Allow viewing, adding and deleting download links"
 : ""
 
-, "Folder"
-: ""
-
-, "File"
+, "Once a Day"
 : ""
 
 , "Download Link"
 : ""
 
-, "Once a Day"
-: ""
-
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
