@@ -5,212 +5,47 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Filemanager **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:53+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Password for download required"
+, "Usage"
 : ""
 
-, "Submit"
-: ""
-
-, "File not found!"
-: ""
-
-, "Name"
-: "Naam"
-
 , "Size"
 : "Grootte"
 
-, "Last Modified"
-: "Laatst gewijzigd"
-
-, "Description"
-: "Omschrijving"
-
-, "Folder, Folders"
-: [
-  "Folder"
- ,"Folders"
-
-]
-, "File, Files"
-: [
-  "Bestand"
- ,"Bestanden"
-
-]
-, "Default behavior when double-clicking on a Row"
+, "This folder has own quota"
 : ""
 
-, "Defines which action should be executed by default when double-clicked."
+, "Quota"
 : ""
 
-, "Invalid Filename"
+, "No quota set (examples: 10 GB, 900 MB)"
 : ""
 
-, "Content type"
+, "Current Usage"
 : ""
 
-, "path"
-: "path"
-
-, "URL"
+, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
 : ""
 
-, "Password"
-: ""
-
-, "Valid until"
-: ""
-
-, "Send as e-mail"
-: ""
-
-, "Download"
-: ""
-
-, "Create Public Link"
-: "Maak publieke link"
-
-, "Remove record"
-: "Verwijder record"
-
-, "Creating new Download Link..."
-: "Maak nieuwe download link..."
-
-, "Deleting Download Links..."
-: "Verwijder dowload links..."
-
-, "Deleting Download Link..."
-: "Download links verwijderen..."
-
-, "Created By"
-: "Aangemaakt door"
-
-, "Creation Time"
-: "Tijdstip aanmaak"
-
-, "Expiration Time"
-: "Vervaltijd"
-
-, "Access Count"
-: ""
-
-, "Last Modified Time"
-: "Laatst gewijzigd op"
-
-, "Last Modified By"
-: "Laatst gewijzigd door"
-
-, "Revision"
-: "Versie"
-
-, "This folder has own revision settings"
-: ""
-
-, "Revision active"
-: ""
-
-, "Limit revision amount to"
-: ""
-
-, "Hold-back in months"
-: ""
-
-, "Upload Failed"
-: "Upload mislukt"
-
-, "It is not permitted to store files in this folder!"
-: ""
-
-, "Select a file"
-: ""
-
-, "Select files"
-: ""
-
-, "Select a folder"
-: ""
-
-, "Select folders"
-: ""
-
-, "Select an item"
-: ""
-
-, "Select items"
-: ""
-
-, "Checking ..."
-: ""
-
-, "Overwrite Existing File?"
-: ""
-
-, "Do you really want to overwrite the selected file?"
-: ""
-
-, "Tags"
-: "Tags"
-
 , "Revision Size"
 : ""
 
-, "Total size of all available revisions"
+, "File Type"
 : ""
 
-, "Indexed"
+, "Usage by File Type"
 : ""
 
-, "File contents is part of the search index"
+, "User"
 : ""
 
-, "Upload"
-: "Upload"
-
-, "Open Data Safe"
+, "Usage by User"
 : ""
 
-, "Folder Up"
-: "Folder omhoog"
-
-, "Close Data Safe"
+, "unknown"
 : ""
 
-, "Filemanager"
-: "Bestandsbeheerder"
-
-, "Save locally"
-: "Bewaar lokaal"
-
-, "Close"
-: ""
-
-, "Loading preview ..."
-: ""
-
-, "Edit folder"
-: "M"
-
-, "edit file"
-: "Bewerk bestand"
-
-, "Public Links"
-: "Publieke links"
-
-, "Type"
-: "Type"
-
-, "Not yet indexed"
-: ""
-
-, "Modified By"
-: "Gewijzigd door"
-
-, "Enter description"
-: "Voer omschrijving in"
-
 , "Service Unavailable"
 : "Service niet beschikbaar"
 
@@ -229,6 +64,96 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Item with this name already exists!"
 : "Item met deze naam bestaat al!"
 
+, "Filemanager"
+: "Bestandsbeheerder"
+
+, "Save locally"
+: "Bewaar lokaal"
+
+, "Close"
+: ""
+
+, "Loading preview ..."
+: ""
+
+, "Node Download Links"
+: "Knooppunt Download Links"
+
+, "Create Public Link"
+: "Maak publieke link"
+
+, "Remove record"
+: "Verwijder record"
+
+, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
+: ""
+
+, "Creating new Download Link..."
+: "Maak nieuwe download link..."
+
+, "Deleting Download Links..."
+: "Verwijder dowload links..."
+
+, "Deleting Download Link..."
+: "Download links verwijderen..."
+
+, "URL"
+: ""
+
+, "Created By"
+: "Aangemaakt door"
+
+, "Creation Time"
+: "Tijdstip aanmaak"
+
+, "Expiration Time"
+: "Vervaltijd"
+
+, "Password"
+: ""
+
+, "Access Count"
+: ""
+
+, "Last Modified Time"
+: "Laatst gewijzigd op"
+
+, "Last Modified By"
+: "Laatst gewijzigd door"
+
+, "Folder"
+: "Folder"
+
+, "Total size of all available revisions"
+: ""
+
+, "File contents is part of the search index"
+: ""
+
+, "Upload"
+: "Upload"
+
+, "Open Data Safe"
+: ""
+
+, "Folder Up"
+: "Folder omhoog"
+
+, "Locking data safe..."
+: ""
+
+, "Unlocking data safe..."
+: ""
+
+, "Close Data Safe"
+: ""
+
+, "Upload Failed"
+: "Upload mislukt"
+
+, "It is not permitted to store files in this folder!"
+: ""
+
 , "Whole Filemanager"
 : ""
 
@@ -238,161 +163,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Search"
 : ""
 
-, "The grant to download files"
-: ""
-
-, "Publish"
-: "Publiceer"
-
-, "The grant to create anonymous download links for files"
-: ""
-
-, "Copying data .. {0}"
-: "Kopieren gegevens... {0}"
-
-, "Moving data .. {0}"
-: "Verplaatsen gegevens... {0}"
-
-, "Please wait"
-: "Moment"
-
-, "Error while uploading \"{fileName}\". Please try again later."
-: ""
-
-, "Quick Search"
-: "Snel zoeken"
-
-, "Content Type"
-: ""
-
-, "File Contents"
-: ""
-
-, "Download Link, Download Links"
-: [
-  ""
- ,""
-
-]
-, "Node Download Links"
-: "Knooppunt Download Links"
-
-, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
-: ""
-
-, "This is possible for .doc, .jpg, .pdf and even more file formats."
-: ""
-
-, "Interested? Then let us know!"
-: ""
-
-, "We would be happy to make you a non-binding offer."
-: ""
-
-, "No preview available yet - Please try again in a few minutes."
-: ""
-
-, "Notifications"
-: ""
-
-, "This folder has own notification settings"
-: ""
-
-, "Notification"
-: ""
-
-, "Notification active"
-: ""
-
-, "Summary"
-: ""
-
-, "Once a Day, Every {0} Days"
-: [
-  ""
- ,""
-
-]
-, "No"
-: ""
-
-, "Don't summarize"
-: ""
-
-, "Once a day"
-: ""
-
-, "Every 3 days"
-: ""
-
-, "Once a week"
-: ""
-
-, "Once a month"
-: ""
-
-, "Once a year"
-: ""
-
-, "Search for users ..."
-: ""
-
-, "No permission"
-: ""
-
-, "all"
-: ""
-
-, "Search for groups ..."
-: ""
-
-, "Grants"
-: ""
-
-, "This folder has its own grants"
-: ""
-
-, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
-: ""
-
-, "This folder is part of the data safe"
-: ""
-
-, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
-: ""
-
-, "Usage"
-: ""
-
-, "This folder has own quota"
-: ""
-
-, "Quota"
-: ""
-
-, "No quota set (examples: 10 GB, 900 MB)"
-: ""
-
-, "Current Usage"
-: ""
-
-, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
-: ""
-
-, "File Type"
-: ""
-
-, "Usage by File Type"
-: ""
-
-, "User"
-: ""
-
-, "Usage by User"
-: ""
-
-, "unknown"
-: ""
+, "path"
+: "path"
 
 , "Reload"
 : ""
@@ -448,8 +220,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Preview"
 : ""
 
-, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
-: ""
+, "Publish"
+: "Publiceer"
 
 , "Folder has been published successfully"
 : "Map is met succes gepubliceerd"
@@ -457,12 +229,231 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "File has been published successfully"
 : "Bestand is met succes gepubliceerd"
 
+, "Notification"
+: ""
+
+, "Notification active"
+: ""
+
+, "Summary"
+: ""
+
+, "Once a Day, Every {0} Days"
+: [
+  ""
+ ,""
+
+]
+, "No"
+: ""
+
+, "Don't summarize"
+: ""
+
+, "Once a day"
+: ""
+
+, "Every 3 days"
+: ""
+
+, "Once a week"
+: ""
+
+, "Once a month"
+: ""
+
+, "Once a year"
+: ""
+
+, "Name"
+: "Naam"
+
+, "Search for users ..."
+: ""
+
+, "No permission"
+: ""
+
+, "all"
+: ""
+
+, "Search for groups ..."
+: ""
+
+, "Valid until"
+: ""
+
+, "Send as e-mail"
+: ""
+
+, "Download"
+: ""
+
+, "Revision"
+: "Versie"
+
+, "This folder has own revision settings"
+: ""
+
+, "Revision active"
+: ""
+
+, "Limit revision amount to"
+: ""
+
+, "Hold-back in months"
+: ""
+
+, "The grant to download files"
+: ""
+
+, "The grant to create anonymous download links for files"
+: ""
+
+, "Copying data .. {0}"
+: "Kopieren gegevens... {0}"
+
+, "Moving data .. {0}"
+: "Verplaatsen gegevens... {0}"
+
+, "Confirm Changing of Folder Grants"
+: ""
+
+, "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."
+: ""
+
+, "Please wait"
+: "Moment"
+
+, "Error while uploading \"{fileName}\". Please try again later."
+: ""
+
+, "Download Link, Download Links"
+: [
+  ""
+ ,""
+
+]
+, "Grants"
+: ""
+
+, "This folder has its own grants"
+: ""
+
+, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
+: ""
+
+, "This folder is part of the data safe"
+: ""
+
+, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
+: ""
+
+, "Select a file"
+: ""
+
+, "Select files"
+: ""
+
+, "Select a folder"
+: ""
+
+, "Select folders"
+: ""
+
+, "Select an item"
+: ""
+
+, "Select items"
+: ""
+
+, "Notifications"
+: ""
+
+, "This folder has own notification settings"
+: ""
+
+, "Edit folder"
+: "M"
+
+, "edit file"
+: "Bewerk bestand"
+
+, "File"
+: "Bestand"
+
+, "Public Links"
+: "Publieke links"
+
+, "Type"
+: "Type"
+
+, "Indexed"
+: ""
+
+, "Not yet indexed"
+: ""
+
+, "Modified By"
+: "Gewijzigd door"
+
+, "Last Modified"
+: "Laatst gewijzigd"
+
+, "Description"
+: "Omschrijving"
+
+, "Enter description"
+: "Voer omschrijving in"
+
+, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
+: ""
+
+, "This is possible for .doc, .jpg, .pdf and even more file formats."
+: ""
+
+, "Interested? Then let us know!"
+: ""
+
+, "We would be happy to make you a non-binding offer."
+: ""
+
+, "This file has no contents. The Upload has failed or has not yet finished."
+: ""
+
+, "No preview available yet - Please try again in a few minutes."
+: ""
+
+, "Checking ..."
+: ""
+
+, "Overwrite Existing File?"
+: ""
+
+, "Do you really want to overwrite the selected file?"
+: ""
+
+, "Content type"
+: ""
+
 , "Public Download URL"
 : ""
 
 , "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
 : ""
 
+, "Destination has the same Path"
+: "Bestemming heeft dezelfde pad"
+
+, "The destination has the same path as the source. No action has been performed."
+: ""
+
+, "Destination is a Subfolder"
+: "Bestemming is een submap"
+
+, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
+: "De bestemming is een submap. Het is niet toegestaan om te kopiëren of verplaatsen van een map in een van de submappen."
+
 , "you can't remove your own admin grant"
 : ""
 
@@ -499,16 +490,13 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Attachments"
 : ""
 
-, "Destination is a Subfolder"
-: "Bestemming is een submap"
+, "Password for download required"
+: ""
 
-, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
-: "De bestemming is een submap. Het is niet toegestaan om te kopiëren of verplaatsen van een map in een van de submappen."
+, "Submit"
+: ""
 
-, "Destination has the same Path"
-: "Bestemming heeft dezelfde pad"
-
-, "The destination has the same path as the source. No action has been performed."
+, "File not found!"
 : ""
 
 , "manage shared folders"
@@ -530,18 +518,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 
 
 
-, "Folder"
-: "Folder"
 
-, "File"
-: "Bestand"
-
-, "Download Link"
-: ""
 
 , "Once a Day"
 : ""
 
+, "Download Link"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
