@@ -5,216 +5,47 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Filemanager **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:53+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Password for download required"
+, "Usage"
 : ""
 
-, "Submit"
-: ""
-
-, "File not found!"
-: ""
-
-, "Name"
-: "Имя"
-
 , "Size"
 : "Размер"
 
-, "Last Modified"
-: "Последнее изменение"
-
-, "Description"
-: "Описание"
-
-, "Folder, Folders"
-: [
-  ""
- ,""
- ,"Папка"
- ,"Папка"
-
-]
-, "File, Files"
-: [
-  "Файл"
- ,"Файла"
- ,"Файлов"
- ,"Файлов"
-
-]
-, "Default behavior when double-clicking on a Row"
+, "This folder has own quota"
 : ""
 
-, "Defines which action should be executed by default when double-clicked."
+, "Quota"
 : ""
 
-, "Invalid Filename"
+, "No quota set (examples: 10 GB, 900 MB)"
 : ""
 
-, "Content type"
+, "Current Usage"
 : ""
 
-, "path"
-: "путь"
-
-, "URL"
+, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
 : ""
 
-, "Password"
-: ""
-
-, "Valid until"
-: ""
-
-, "Send as e-mail"
-: ""
-
-, "Download"
-: ""
-
-, "Create Public Link"
-: ""
-
-, "Remove record"
-: "Удалить запись"
-
-, "Creating new Download Link..."
-: ""
-
-, "Deleting Download Links..."
-: ""
-
-, "Deleting Download Link..."
-: ""
-
-, "Created By"
-: "Создана"
-
-, "Creation Time"
-: "Время создания"
-
-, "Expiration Time"
-: ""
-
-, "Access Count"
-: ""
-
-, "Last Modified Time"
-: "Время последнего изменения"
-
-, "Last Modified By"
-: "Последнее изменение:"
-
-, "Revision"
-: "Ревизия"
-
-, "This folder has own revision settings"
-: ""
-
-, "Revision active"
-: ""
-
-, "Limit revision amount to"
-: ""
-
-, "Hold-back in months"
-: ""
-
-, "Upload Failed"
-: "Сбой загрузки"
-
-, "It is not permitted to store files in this folder!"
-: ""
-
-, "Select a file"
-: ""
-
-, "Select files"
-: ""
-
-, "Select a folder"
-: ""
-
-, "Select folders"
-: ""
-
-, "Select an item"
-: ""
-
-, "Select items"
-: ""
-
-, "Checking ..."
-: ""
-
-, "Overwrite Existing File?"
-: ""
-
-, "Do you really want to overwrite the selected file?"
-: ""
-
-, "Tags"
-: "Теги"
-
 , "Revision Size"
 : ""
 
-, "Total size of all available revisions"
+, "File Type"
 : ""
 
-, "Indexed"
+, "Usage by File Type"
 : ""
 
-, "File contents is part of the search index"
+, "User"
 : ""
 
-, "Upload"
-: "Загрузить"
-
-, "Open Data Safe"
+, "Usage by User"
 : ""
 
-, "Folder Up"
-: "Вверх на уровень"
-
-, "Close Data Safe"
+, "unknown"
 : ""
 
-, "Filemanager"
-: "Менеджер файлов"
-
-, "Save locally"
-: "Сохранить локально"
-
-, "Close"
-: ""
-
-, "Loading preview ..."
-: ""
-
-, "Edit folder"
-: "Редактировать папку"
-
-, "edit file"
-: "редактировать файл"
-
-, "Public Links"
-: "Внешняя ссылка"
-
-, "Type"
-: "Тип"
-
-, "Not yet indexed"
-: ""
-
-, "Modified By"
-: "Изменено"
-
-, "Enter description"
-: "Введите описание"
-
 , "Service Unavailable"
 : "Сервис не доступен"
 
@@ -233,6 +64,96 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Item with this name already exists!"
 : "Элемент с таким именем уже существует!"
 
+, "Filemanager"
+: "Менеджер файлов"
+
+, "Save locally"
+: "Сохранить локально"
+
+, "Close"
+: ""
+
+, "Loading preview ..."
+: ""
+
+, "Node Download Links"
+: ""
+
+, "Create Public Link"
+: ""
+
+, "Remove record"
+: "Удалить запись"
+
+, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
+: ""
+
+, "Creating new Download Link..."
+: ""
+
+, "Deleting Download Links..."
+: ""
+
+, "Deleting Download Link..."
+: ""
+
+, "URL"
+: ""
+
+, "Created By"
+: "Создана"
+
+, "Creation Time"
+: "Время создания"
+
+, "Expiration Time"
+: ""
+
+, "Password"
+: ""
+
+, "Access Count"
+: ""
+
+, "Last Modified Time"
+: "Время последнего изменения"
+
+, "Last Modified By"
+: "Последнее изменение:"
+
+, "Folder"
+: ""
+
+, "Total size of all available revisions"
+: ""
+
+, "File contents is part of the search index"
+: ""
+
+, "Upload"
+: "Загрузить"
+
+, "Open Data Safe"
+: ""
+
+, "Folder Up"
+: "Вверх на уровень"
+
+, "Locking data safe..."
+: ""
+
+, "Unlocking data safe..."
+: ""
+
+, "Close Data Safe"
+: ""
+
+, "Upload Failed"
+: "Сбой загрузки"
+
+, "It is not permitted to store files in this folder!"
+: ""
+
 , "Whole Filemanager"
 : ""
 
@@ -242,165 +163,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Search"
 : ""
 
-, "The grant to download files"
-: ""
-
-, "Publish"
-: "Опубликовать"
-
-, "The grant to create anonymous download links for files"
-: ""
-
-, "Copying data .. {0}"
-: "Копирование данных... {0}"
-
-, "Moving data .. {0}"
-: "Перемещение данных... {0}"
-
-, "Please wait"
-: "Пожалуйста, подождите"
-
-, "Error while uploading \"{fileName}\". Please try again later."
-: ""
-
-, "Quick Search"
-: "Быстрый поиск"
-
-, "Content Type"
-: ""
-
-, "File Contents"
-: ""
-
-, "Download Link, Download Links"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Node Download Links"
-: ""
-
-, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
-: ""
-
-, "This is possible for .doc, .jpg, .pdf and even more file formats."
-: ""
-
-, "Interested? Then let us know!"
-: ""
-
-, "We would be happy to make you a non-binding offer."
-: ""
-
-, "No preview available yet - Please try again in a few minutes."
-: ""
-
-, "Notifications"
-: ""
-
-, "This folder has own notification settings"
-: ""
-
-, "Notification"
-: ""
-
-, "Notification active"
-: ""
-
-, "Summary"
-: ""
-
-, "Once a Day, Every {0} Days"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "No"
-: ""
-
-, "Don't summarize"
-: ""
-
-, "Once a day"
-: ""
-
-, "Every 3 days"
-: ""
-
-, "Once a week"
-: ""
-
-, "Once a month"
-: ""
-
-, "Once a year"
-: ""
-
-, "Search for users ..."
-: ""
-
-, "No permission"
-: ""
-
-, "all"
-: ""
-
-, "Search for groups ..."
-: ""
-
-, "Grants"
-: ""
-
-, "This folder has its own grants"
-: ""
-
-, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
-: ""
-
-, "This folder is part of the data safe"
-: ""
-
-, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
-: ""
-
-, "Usage"
-: ""
-
-, "This folder has own quota"
-: ""
-
-, "Quota"
-: ""
-
-, "No quota set (examples: 10 GB, 900 MB)"
-: ""
-
-, "Current Usage"
-: ""
-
-, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
-: ""
-
-, "File Type"
-: ""
-
-, "Usage by File Type"
-: ""
-
-, "User"
-: ""
-
-, "Usage by User"
-: ""
-
-, "unknown"
-: ""
+, "path"
+: "путь"
 
 , "Reload"
 : ""
@@ -456,8 +220,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Preview"
 : ""
 
-, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
-: ""
+, "Publish"
+: "Опубликовать"
 
 , "Folder has been published successfully"
 : "Папка успешно опубликована"
@@ -465,12 +229,235 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "File has been published successfully"
 : "Файл успешно опубликован"
 
+, "Notification"
+: ""
+
+, "Notification active"
+: ""
+
+, "Summary"
+: ""
+
+, "Once a Day, Every {0} Days"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "No"
+: ""
+
+, "Don't summarize"
+: ""
+
+, "Once a day"
+: ""
+
+, "Every 3 days"
+: ""
+
+, "Once a week"
+: ""
+
+, "Once a month"
+: ""
+
+, "Once a year"
+: ""
+
+, "Name"
+: "Имя"
+
+, "Search for users ..."
+: ""
+
+, "No permission"
+: ""
+
+, "all"
+: ""
+
+, "Search for groups ..."
+: ""
+
+, "Valid until"
+: ""
+
+, "Send as e-mail"
+: ""
+
+, "Download"
+: ""
+
+, "Revision"
+: "Ревизия"
+
+, "This folder has own revision settings"
+: ""
+
+, "Revision active"
+: ""
+
+, "Limit revision amount to"
+: ""
+
+, "Hold-back in months"
+: ""
+
+, "The grant to download files"
+: ""
+
+, "The grant to create anonymous download links for files"
+: ""
+
+, "Copying data .. {0}"
+: "Копирование данных... {0}"
+
+, "Moving data .. {0}"
+: "Перемещение данных... {0}"
+
+, "Confirm Changing of Folder Grants"
+: ""
+
+, "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."
+: ""
+
+, "Please wait"
+: "Пожалуйста, подождите"
+
+, "Error while uploading \"{fileName}\". Please try again later."
+: ""
+
+, "Download Link, Download Links"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Grants"
+: ""
+
+, "This folder has its own grants"
+: ""
+
+, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
+: ""
+
+, "This folder is part of the data safe"
+: ""
+
+, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
+: ""
+
+, "Select a file"
+: ""
+
+, "Select files"
+: ""
+
+, "Select a folder"
+: ""
+
+, "Select folders"
+: ""
+
+, "Select an item"
+: ""
+
+, "Select items"
+: ""
+
+, "Notifications"
+: ""
+
+, "This folder has own notification settings"
+: ""
+
+, "Edit folder"
+: "Редактировать папку"
+
+, "edit file"
+: "редактировать файл"
+
+, "File"
+: "Файл"
+
+, "Public Links"
+: "Внешняя ссылка"
+
+, "Type"
+: "Тип"
+
+, "Indexed"
+: ""
+
+, "Not yet indexed"
+: ""
+
+, "Modified By"
+: "Изменено"
+
+, "Last Modified"
+: "Последнее изменение"
+
+, "Description"
+: "Описание"
+
+, "Enter description"
+: "Введите описание"
+
+, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
+: ""
+
+, "This is possible for .doc, .jpg, .pdf and even more file formats."
+: ""
+
+, "Interested? Then let us know!"
+: ""
+
+, "We would be happy to make you a non-binding offer."
+: ""
+
+, "This file has no contents. The Upload has failed or has not yet finished."
+: ""
+
+, "No preview available yet - Please try again in a few minutes."
+: ""
+
+, "Checking ..."
+: ""
+
+, "Overwrite Existing File?"
+: ""
+
+, "Do you really want to overwrite the selected file?"
+: ""
+
+, "Content type"
+: ""
+
 , "Public Download URL"
 : ""
 
 , "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
 : ""
 
+, "Destination has the same Path"
+: ""
+
+, "The destination has the same path as the source. No action has been performed."
+: ""
+
+, "Destination is a Subfolder"
+: ""
+
+, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
+: ""
+
 , "you can't remove your own admin grant"
 : ""
 
@@ -507,16 +494,13 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Attachments"
 : ""
 
-, "Destination is a Subfolder"
+, "Password for download required"
 : ""
 
-, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
+, "Submit"
 : ""
 
-, "Destination has the same Path"
-: ""
-
-, "The destination has the same path as the source. No action has been performed."
+, "File not found!"
 : ""
 
 , "manage shared folders"
@@ -536,18 +520,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 
 
 
-, "Folder"
-: ""
 
-, "File"
-: "Файл"
-
-, "Download Link"
-: ""
 
 , "Once a Day"
 : ""
 
+, "Download Link"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
