@@ -5,210 +5,47 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Filemanager **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:53+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "Password for download required"
+, "Usage"
 : ""
 
-, "Submit"
-: ""
-
-, "File not found!"
-: ""
-
-, "Name"
-: "ชื่อ"
-
 , "Size"
 : "ขนาด"
 
-, "Last Modified"
+, "This folder has own quota"
 : ""
 
-, "Description"
-: "การอธิบาย"
-
-, "Folder, Folders"
-: [
-  "แฟ้มเอกสาร"
-
-]
-, "File, Files"
-: [
-  ""
-
-]
-, "Default behavior when double-clicking on a Row"
+, "Quota"
 : ""
 
-, "Defines which action should be executed by default when double-clicked."
+, "No quota set (examples: 10 GB, 900 MB)"
 : ""
 
-, "Invalid Filename"
+, "Current Usage"
 : ""
 
-, "Content type"
+, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
 : ""
 
-, "path"
-: "เส้นทาง"
-
-, "URL"
-: ""
-
-, "Password"
-: ""
-
-, "Valid until"
-: ""
-
-, "Send as e-mail"
-: ""
-
-, "Download"
-: ""
-
-, "Create Public Link"
-: "สร้าง ลิงค์สาธารณะ"
-
-, "Remove record"
-: "เอาบันทึกออก"
-
-, "Creating new Download Link..."
-: "กำลังสร้าง ลิงค์ดาวน์โหลดใหม่..."
-
-, "Deleting Download Links..."
-: "กำลังลบ ลิงค์ดาวน์โหลด..."
-
-, "Deleting Download Link..."
-: ""
-
-, "Created By"
-: "สร้าง โดย"
-
-, "Creation Time"
-: "เวลาที่สร้างขึ้น"
-
-, "Expiration Time"
-: ""
-
-, "Access Count"
-: ""
-
-, "Last Modified Time"
-: "เวลาที่ปรับปรุงครั้งล่าสุด"
-
-, "Last Modified By"
-: "ปรับปรุงครั้งล่าสุด โดย"
-
-, "Revision"
-: "การแก้ไขปรับปรุง"
-
-, "This folder has own revision settings"
-: ""
-
-, "Revision active"
-: ""
-
-, "Limit revision amount to"
-: ""
-
-, "Hold-back in months"
-: ""
-
-, "Upload Failed"
-: "การอัปโหลดได้ล้มเหลว"
-
-, "It is not permitted to store files in this folder!"
-: ""
-
-, "Select a file"
-: ""
-
-, "Select files"
-: ""
-
-, "Select a folder"
-: ""
-
-, "Select folders"
-: ""
-
-, "Select an item"
-: ""
-
-, "Select items"
-: ""
-
-, "Checking ..."
-: ""
-
-, "Overwrite Existing File?"
-: ""
-
-, "Do you really want to overwrite the selected file?"
-: ""
-
-, "Tags"
-: "ป้ายกำกับ"
-
 , "Revision Size"
 : ""
 
-, "Total size of all available revisions"
+, "File Type"
 : ""
 
-, "Indexed"
+, "Usage by File Type"
 : ""
 
-, "File contents is part of the search index"
+, "User"
 : ""
 
-, "Upload"
-: "อัปโหลด"
-
-, "Open Data Safe"
+, "Usage by User"
 : ""
 
-, "Folder Up"
+, "unknown"
 : ""
 
-, "Close Data Safe"
-: ""
-
-, "Filemanager"
-: "ตัวจัดการไฟล์"
-
-, "Save locally"
-: ""
-
-, "Close"
-: ""
-
-, "Loading preview ..."
-: ""
-
-, "Edit folder"
-: ""
-
-, "edit file"
-: ""
-
-, "Public Links"
-: "ลิงค์สาธารณะ"
-
-, "Type"
-: "ประเภท"
-
-, "Not yet indexed"
-: ""
-
-, "Modified By"
-: ""
-
-, "Enter description"
-: "ใส่ คำอธิบาย"
-
 , "Service Unavailable"
 : "ไม่สามารถให้บริการได้"
 
@@ -227,6 +64,96 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Item with this name already exists!"
 : "รายการกับชื่อนี้มีอยู่แล้ว!"
 
+, "Filemanager"
+: "ตัวจัดการไฟล์"
+
+, "Save locally"
+: ""
+
+, "Close"
+: ""
+
+, "Loading preview ..."
+: ""
+
+, "Node Download Links"
+: ""
+
+, "Create Public Link"
+: "สร้าง ลิงค์สาธารณะ"
+
+, "Remove record"
+: "เอาบันทึกออก"
+
+, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
+: ""
+
+, "Creating new Download Link..."
+: "กำลังสร้าง ลิงค์ดาวน์โหลดใหม่..."
+
+, "Deleting Download Links..."
+: "กำลังลบ ลิงค์ดาวน์โหลด..."
+
+, "Deleting Download Link..."
+: ""
+
+, "URL"
+: ""
+
+, "Created By"
+: "สร้าง โดย"
+
+, "Creation Time"
+: "เวลาที่สร้างขึ้น"
+
+, "Expiration Time"
+: ""
+
+, "Password"
+: ""
+
+, "Access Count"
+: ""
+
+, "Last Modified Time"
+: "เวลาที่ปรับปรุงครั้งล่าสุด"
+
+, "Last Modified By"
+: "ปรับปรุงครั้งล่าสุด โดย"
+
+, "Folder"
+: "แฟ้มเอกสาร"
+
+, "Total size of all available revisions"
+: ""
+
+, "File contents is part of the search index"
+: ""
+
+, "Upload"
+: "อัปโหลด"
+
+, "Open Data Safe"
+: ""
+
+, "Folder Up"
+: ""
+
+, "Locking data safe..."
+: ""
+
+, "Unlocking data safe..."
+: ""
+
+, "Close Data Safe"
+: ""
+
+, "Upload Failed"
+: "การอัปโหลดได้ล้มเหลว"
+
+, "It is not permitted to store files in this folder!"
+: ""
+
 , "Whole Filemanager"
 : ""
 
@@ -236,159 +163,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Search"
 : ""
 
-, "The grant to download files"
-: ""
-
-, "Publish"
-: "ตีพิมพ์"
-
-, "The grant to create anonymous download links for files"
-: ""
-
-, "Copying data .. {0}"
-: ""
-
-, "Moving data .. {0}"
-: ""
-
-, "Please wait"
-: "กรุณารอ"
-
-, "Error while uploading \"{fileName}\". Please try again later."
-: ""
-
-, "Quick Search"
-: "ค้นหาอย่างรวดเร็ว"
-
-, "Content Type"
-: ""
-
-, "File Contents"
-: ""
-
-, "Download Link, Download Links"
-: [
-  ""
-
-]
-, "Node Download Links"
-: ""
-
-, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
-: ""
-
-, "This is possible for .doc, .jpg, .pdf and even more file formats."
-: ""
-
-, "Interested? Then let us know!"
-: ""
-
-, "We would be happy to make you a non-binding offer."
-: ""
-
-, "No preview available yet - Please try again in a few minutes."
-: ""
-
-, "Notifications"
-: ""
-
-, "This folder has own notification settings"
-: ""
-
-, "Notification"
-: ""
-
-, "Notification active"
-: ""
-
-, "Summary"
-: ""
-
-, "Once a Day, Every {0} Days"
-: [
-  ""
-
-]
-, "No"
-: ""
-
-, "Don't summarize"
-: ""
-
-, "Once a day"
-: ""
-
-, "Every 3 days"
-: ""
-
-, "Once a week"
-: ""
-
-, "Once a month"
-: ""
-
-, "Once a year"
-: ""
-
-, "Search for users ..."
-: ""
-
-, "No permission"
-: ""
-
-, "all"
-: ""
-
-, "Search for groups ..."
-: ""
-
-, "Grants"
-: ""
-
-, "This folder has its own grants"
-: ""
-
-, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
-: ""
-
-, "This folder is part of the data safe"
-: ""
-
-, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
-: ""
-
-, "Usage"
-: ""
-
-, "This folder has own quota"
-: ""
-
-, "Quota"
-: ""
-
-, "No quota set (examples: 10 GB, 900 MB)"
-: ""
-
-, "Current Usage"
-: ""
-
-, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
-: ""
-
-, "File Type"
-: ""
-
-, "Usage by File Type"
-: ""
-
-, "User"
-: ""
-
-, "Usage by User"
-: ""
-
-, "unknown"
-: ""
+, "path"
+: "เส้นทาง"
 
 , "Reload"
 : ""
@@ -444,8 +220,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Preview"
 : ""
 
-, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
-: ""
+, "Publish"
+: "ตีพิมพ์"
 
 , "Folder has been published successfully"
 : "แฟ้มได้ถูกตีพิมพ์อย่างประสบความสำเร็จ"
@@ -453,12 +229,229 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "File has been published successfully"
 : "ไฟล์ได้ถูกตีพิมพ์อย่างถูกต้อง"
 
+, "Notification"
+: ""
+
+, "Notification active"
+: ""
+
+, "Summary"
+: ""
+
+, "Once a Day, Every {0} Days"
+: [
+  ""
+
+]
+, "No"
+: ""
+
+, "Don't summarize"
+: ""
+
+, "Once a day"
+: ""
+
+, "Every 3 days"
+: ""
+
+, "Once a week"
+: ""
+
+, "Once a month"
+: ""
+
+, "Once a year"
+: ""
+
+, "Name"
+: "ชื่อ"
+
+, "Search for users ..."
+: ""
+
+, "No permission"
+: ""
+
+, "all"
+: ""
+
+, "Search for groups ..."
+: ""
+
+, "Valid until"
+: ""
+
+, "Send as e-mail"
+: ""
+
+, "Download"
+: ""
+
+, "Revision"
+: "การแก้ไขปรับปรุง"
+
+, "This folder has own revision settings"
+: ""
+
+, "Revision active"
+: ""
+
+, "Limit revision amount to"
+: ""
+
+, "Hold-back in months"
+: ""
+
+, "The grant to download files"
+: ""
+
+, "The grant to create anonymous download links for files"
+: ""
+
+, "Copying data .. {0}"
+: ""
+
+, "Moving data .. {0}"
+: ""
+
+, "Confirm Changing of Folder Grants"
+: ""
+
+, "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."
+: ""
+
+, "Please wait"
+: "กรุณารอ"
+
+, "Error while uploading \"{fileName}\". Please try again later."
+: ""
+
+, "Download Link, Download Links"
+: [
+  ""
+
+]
+, "Grants"
+: ""
+
+, "This folder has its own grants"
+: ""
+
+, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
+: ""
+
+, "This folder is part of the data safe"
+: ""
+
+, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
+: ""
+
+, "Select a file"
+: ""
+
+, "Select files"
+: ""
+
+, "Select a folder"
+: ""
+
+, "Select folders"
+: ""
+
+, "Select an item"
+: ""
+
+, "Select items"
+: ""
+
+, "Notifications"
+: ""
+
+, "This folder has own notification settings"
+: ""
+
+, "Edit folder"
+: ""
+
+, "edit file"
+: ""
+
+, "File"
+: ""
+
+, "Public Links"
+: "ลิงค์สาธารณะ"
+
+, "Type"
+: "ประเภท"
+
+, "Indexed"
+: ""
+
+, "Not yet indexed"
+: ""
+
+, "Modified By"
+: ""
+
+, "Last Modified"
+: ""
+
+, "Description"
+: "การอธิบาย"
+
+, "Enter description"
+: "ใส่ คำอธิบาย"
+
+, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
+: ""
+
+, "This is possible for .doc, .jpg, .pdf and even more file formats."
+: ""
+
+, "Interested? Then let us know!"
+: ""
+
+, "We would be happy to make you a non-binding offer."
+: ""
+
+, "This file has no contents. The Upload has failed or has not yet finished."
+: ""
+
+, "No preview available yet - Please try again in a few minutes."
+: ""
+
+, "Checking ..."
+: ""
+
+, "Overwrite Existing File?"
+: ""
+
+, "Do you really want to overwrite the selected file?"
+: ""
+
+, "Content type"
+: ""
+
 , "Public Download URL"
 : ""
 
 , "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
 : ""
 
+, "Destination has the same Path"
+: "จุดมุ่งหมายมีหนทางเดียวกัน"
+
+, "The destination has the same path as the source. No action has been performed."
+: ""
+
+, "Destination is a Subfolder"
+: "เป้าหมายคือแฟ้มรอง"
+
+, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
+: ""
+
 , "you can't remove your own admin grant"
 : ""
 
@@ -495,16 +488,13 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 , "Attachments"
 : ""
 
-, "Destination is a Subfolder"
-: "เป้าหมายคือแฟ้มรอง"
-
-, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
+, "Password for download required"
 : ""
 
-, "Destination has the same Path"
-: "จุดมุ่งหมายมีหนทางเดียวกัน"
+, "Submit"
+: ""
 
-, "The destination has the same path as the source. No action has been performed."
+, "File not found!"
 : ""
 
 , "manage shared folders"
@@ -526,18 +516,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
 
 
 
-, "Folder"
-: "แฟ้มเอกสาร"
 
-, "File"
+
+, "Once a Day"
 : ""
 
 , "Download Link"
 : ""
 
-, "Once a Day"
-: ""
-
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
