@@ -5,328 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Sales **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:21+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: de\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "CLEARED"
-: "GEBUCHT"
-
-, "INVOICE"
-: "RECHNUNG"
-
-, "Invoice Timesheet"
-: "Rechnungs Timesheet"
-
-, "Customer, Customers"
-: [
-  "Kunde"
- ,"Kunden"
-
-]
-, "Core Data"
-: "Stammdaten"
-
-, "Accounting"
-: "Abrechnung"
-
-, "Miscellaneous"
-: "Sonstiges"
-
-, "Customer Number"
-: "Kundennummer"
-
-, "Name"
-: "Name"
-
-, "Name shorthand"
-: "Kunden Kürzel"
-
-, "Web"
-: "Internet"
-
-, "Description"
-: "Beschreibung"
-
-, "Contact Person (external)"
-: "Kontaktperson (extern)"
-
-, "Contact Person (internal)"
-: "Kontaktperson (intern)"
-
-, "VAT No."
-: "USt.-ID"
-
-, "Credit Term (days)"
-: "Zahlungsziel in Tagen"
-
-, "Currency"
-: "Währung"
-
-, "Currency Translation Rate"
-: "Wechselkurs"
-
-, "Discount (%)"
-: "Rabatt in Prozent"
-
-, "Delivery Addresses"
-: "Lieferanschriften"
-
-, "Billing Addresses"
-: "Rechnungsanschriften"
-
-, "Prefix"
-: "Zusatz"
-
-, "Additional Prefix"
-: "Zusatz 2"
-
-, "Street"
-: "Straße"
-
-, "Postalcode"
-: "Postleitzahl"
-
-, "Locality"
-: "Ort"
-
-, "Region"
-: "Region"
-
-, "Country"
-: "Land"
-
-, "Postbox"
-: "Postfach"
-
-, "Invoice Position, Invoice Positions"
-: [
-  "Rechnungsposition"
- ,"Rechnungspositionen"
-
-]
-, "Type"
-: "Typ"
-
-, "Title"
-: "Titel"
-
-, "Month"
-: "Monat"
-
-, "Unit"
-: "Einheit"
-
-, "Quantity"
-: "Anzahl"
-
-, "Offer, Offers"
-: [
-  "Angebot"
- ,"Angebote"
-
-]
-, "Order Confirmation, Order Confirmations"
-: [
-  "Auftragsbestätigung"
- ,"Auftragsbestätigungen"
-
-]
-, "Number"
-: "Nummer"
-
-, "Product, Products"
-: [
-  "Produkt"
- ,"Produkte"
-
-]
-, "Contract, Contracts"
-: [
-  "Vertrag"
- ,"Verträge"
-
-]
-, "Billing Interval"
-: "Mtl. Abrechnungsintervall (variabel)"
-
-, "Billing Point"
-: "Abrechnungszeitpunkt"
-
-, "Start Date"
-: "Anfang"
-
-, "End Date"
-: "Ende"
-
-, "Invoice Item"
-: "Rechnungsposten"
-
-, "Piece"
-: "Stück"
-
-, "Purchaseprice"
-: "Einkaufspreis"
-
-, "Salesprice"
-: "Verkaufspreis"
-
-, "Category"
-: "Kategorie"
-
-, "Manufacturer"
-: "Hersteller"
-
-, "Accountable"
-: "Rechnet ab"
-
-, "GTIN"
-: "GTIN"
-
-, "Lifespan start"
-: "Laufzeit Beginn"
-
-, "Lifespan end"
-: "Laufzeit Ende"
-
-, "Is active"
-: "Ist aktiv"
-
-, "Invoice, Invoices"
-: [
-  "Rechnung"
- ,"Rechnungen"
-
-]
-, "Invoice Number"
-: "Rechnungsnummer"
-
-, "Address, Addresss"
-: [
-  "Anschrift"
- ,"Anschriften"
-
-]
-, "Date"
-: "Datum"
-
-, "Interval Begins"
-: "Buchungszeitraum Beginn"
-
-, "Interval Ends"
-: "Buchungszeitraum Ende"
-
-, "Credit Term"
-: "Zahlungsziel in Tagen"
-
-, "Cost Center, Cost Centers"
-: [
-  "Kostenstelle"
- ,"Kostenstellen"
-
-]
-, "Cleared"
-: "Gebucht"
-
-, "Price Net"
-: "Nettopreis"
-
-, "Price Tax"
-: "MwSt."
-
-, "Price Gross"
-: "Bruttopreis"
-
-, "Sales Tax"
-: "Mehrwertsteuer"
-
-, "Inventory Change"
-: "Bestandsänderung"
-
-, "Positions"
-: "Positionen"
-
-, "Reversal Invoice"
-: "Storno-Rechnung"
-
-, "Supplier, Suppliers"
-: [
-  "Lieferant"
- ,"Lieferanten"
-
-]
-, "Supplier Number"
-: "Lieferantennummer"
-
-, "Division, Divisions"
-: [
-  "Abteilung"
- ,"Abteilung"
-
-]
-, "Number Debit"
-: "Debitorennummer"
-
-, "Products"
-: "Produkte"
-
-, "Billing Address"
-: "Rechnungsanschrift"
-
-, "Lead Cost Center"
-: "Hauptkostenstelle"
-
-, "Merge"
-: "Zusammenführen"
-
-, "Responsible"
-: "Verantwortlicher"
-
-, "Partner"
-: "Partner"
-
-, "Time Account"
-: "Zeitkonto"
-
-, "Remark"
-: "Anmerkung"
-
-, "Purchase Invoice, Purchase Invoices"
-: [
-  "Eingangsrechnung"
- ,"Eingangsrechnungen"
-
-]
-, "Approver"
-: "Genehmigt von"
-
-, "Date of invoice"
-: "Rechnungsdatum"
-
-, "Due in"
-: "Fällig in"
-
-, "Due at"
-: "Fällig am"
-
-, "Payed at"
-: "Gezahlt am"
-
-, "Payment_method"
-: "Zahlungsart"
-
-, "Discount until"
-: "Skonto bis"
-
-, "Additional Price Gross"
-: "Zusätzlicher Bruttopreis"
-
-, "Total Price"
-: "Gesamtpreis"
-
-, "without customer"
-: "ohne Kunde"
-
-, "Export Records from these Positions"
-: "Exportiere Einträge dieser Positionen"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:21+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Either postalcode or postbox is required!"
 : "Bitte geben Sie entweder eine Postleitzahl oder ein Postfach an!"
@@ -343,6 +22,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Copy address to the clipboard"
 : "Adresse in die Zwischenablage kopieren"
 
+, "Supplier, Suppliers"
+: [
+  "Lieferant"
+ ,"Lieferanten"
+
+]
+, "Core Data"
+: "Stammdaten"
+
+, "Supplier Number"
+: "Lieferantennummer"
+
+, "Name"
+: "Name"
+
+, "Contact Person (external)"
+: "Kontaktperson (extern)"
+
+, "Contact Person (internal)"
+: "Kontaktperson (intern)"
+
+, "Accounting"
+: "Abrechnung"
+
+, "VAT ID"
+: "USt.-ID"
+
+, "Credit Term (days)"
+: "Zahlungsziel in Tagen"
+
+, "Currency"
+: "Währung"
+
+, "Currency Translation Rate"
+: "Wechselkurs"
+
 , "IBAN"
 : "IBAN"
 
@@ -352,30 +67,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Postal Address"
 : "Postanschrift"
 
+, "Street"
+: "Straße"
+
+, "Postbox"
+: "Postfach"
+
+, "Postalcode"
+: "Postleitzahl"
+
+, "Locality"
+: "Ort"
+
+, "Region"
+: "Region"
+
+, "Country"
+: "Land"
+
+, "Prefix"
+: "Zusatz"
+
+, "Additional Prefix"
+: "Zusatz 2"
+
+, "Miscellaneous"
+: "Sonstiges"
+
+, "Web"
+: "Internet"
+
+, "Description"
+: "Beschreibung"
+
 , "Enter description"
 : "Bitte geben Sie eine Beschreibung an"
 
-, "Cancel"
-: "Abbrechen"
-
-, "Ok"
-: "Ok"
-
-, "Select customer"
-: "Kunden auswählen"
-
-, "Bill Contract"
-: "Vertrag abrechnen"
-
-, "Billing Contract..."
-: "Rechne Vertrag ab..."
-
-, "Bill Contract \"{0} - {1}\""
-: "Vertrag \"{0} - {1}\" abrechnen"
-
-, "Select the date to generate the bill for"
-: "Bitte wählen Sie das Datum, zu dem Sie die Rechnung erzeugen möchten"
-
 , "total"
 : "Gesamtsumme"
 
@@ -415,12 +142,75 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
 : "Dem ausgewählten Vertrag ist bisher keine Kostenstelle zugeordnet worden. Bitte verknüpfen Sie den Vertrag mit einer Kostenstelle."
 
+, "Price Net"
+: "Nettopreis"
+
+, "Taxes (VAT)"
+: "MwSt"
+
+, "Price Gross"
+: "Bruttopreis"
+
 , "Sales Tax (percent)"
 : "MwSt. in Prozent"
 
+, "Inventory Change"
+: "Bestandsänderung"
+
+, "Invoice, Invoices"
+: [
+  "Rechnung"
+ ,"Rechnungen"
+
+]
+, "Invoice Number"
+: "Rechnungsnummer"
+
 , "automatically set..."
 : "automatisch ausgefüllt..."
 
+, "Date"
+: "Datum"
+
+, "Type"
+: "Typ"
+
+, "Contract, Contracts"
+: [
+  "Vertrag"
+ ,"Verträge"
+
+]
+, "Customer, Customers"
+: [
+  "Kunde"
+ ,"Kunden"
+
+]
+, "Billing Address"
+: "Rechnungsanschrift"
+
+, "Credit Term"
+: "Zahlungsziel in Tagen"
+
+, "Cleared"
+: "Gebucht"
+
+, "Interval Begins"
+: "Buchungszeitraum Beginn"
+
+, "Interval Ends"
+: "Buchungszeitraum Ende"
+
+, "Select invoice"
+: "Rechnung auswählen"
+
+, "Total Price"
+: "Gesamtpreis"
+
+, "Cancel"
+: "Abbrechen"
+
 , "OK"
 : "OK"
 
@@ -430,56 +220,53 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Euro (€)"
 : "Euro (€)"
 
-, "Set as accountable"
-: "Als verantwortlich festlegen"
+, "Order Confirmation, Order Confirmations"
+: [
+  "Auftragsbestätigung"
+ ,"Auftragsbestätigungen"
 
-, "Choose product for accountable"
-: "Wählen Sie das Produkt für verantwortlich"
+]
+, "without order confirmation"
+: "ohne Auftragsbestätigung"
 
-, "Please use a decimal number here!"
-: "Bitte benutzen Sie eine Dezimalzahl!"
+, "Number"
+: "Nummer"
 
-, "Enter description..."
-: "Bitte geben Sie eine Beschreibung ein..."
+, "Title"
+: "Titel"
 
-, "Add New Product"
-: "Neues Produkt hinzufügen"
+, "Billing Addresses"
+: "Rechnungsanschriften"
 
-, "Product Number"
-: "Produktnummer"
+, "Delivery Address"
+: "Lieferanschrift"
 
-, "Select supplier"
-: "Lieferant auswählen"
+, "Delivery Addresses"
+: "Lieferanschriften"
 
-, "Add New Cost Center"
-: "Neue Kostenstelle hinzufügen"
+, "Edit {0} \"{1}\""
+: "{0} \"{1}\" bearbeiten"
 
-, "Select invoice"
-: "Rechnung auswählen"
+, "Add New Billing Address"
+: "Neue Rechnungsanschrift Hinzufügen"
 
-, "Either street or postbox is required!"
-: "Bitte geben Sie entweder eine Straße oder ein Postfach an!"
+, "Add New Delivery Address"
+: "Neue Lieferanschrift Hinzufügen"
 
-, "Only numbers are allowed!"
-: "Es sind nur Zahlen erlaubt."
+, "Apply postal address"
+: "Postanschrift anwenden"
 
-, "Copy Customer"
-: "Kunden kopieren"
+, "Number Debit"
+: "Debitorennummer"
 
-, "Add New Customer"
-: "Neuen Kunden hinzufügen"
+, "Address, Addresss"
+: [
+  "Anschrift"
+ ,"Anschriften"
 
-, "Edit Customer \"{0}\""
-: "Kunden \"{0}\" bearbeiten"
-
-, "without external contact person"
-: "ohne externe Kontaktperson"
-
-, "without approver"
-: "nicht genehmigt"
-
-, "without supplier"
-: "ohne Lieferant"
+]
+, "without customer"
+: "ohne Kunde"
 
 , "Copy Purchase Invoice"
 : "Eingangsrechnung kopieren"
@@ -490,51 +277,84 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Edit Purchase Invoice \"{0}\""
 : "Eingangsrechnung \"{0}\" bearbeiten"
 
+, "Date of invoice"
+: "Rechnungsdatum"
+
+, "Due in"
+: "Fällig in"
+
 , "Due date"
 : "Fälligkeitsdatum"
 
+, "Additional Price Gross"
+: "Zusätzlicher Bruttopreis"
+
+, "Discount (%)"
+: "Rabatt in Prozent"
+
+, "Purchase Invoice, Purchase Invoices"
+: [
+  "Eingangsrechnung"
+ ,"Eingangsrechnungen"
+
+]
 , "Overdue date"
 : "Überfälligkeits Datum"
 
+, "Discount until"
+: "Skonto bis"
+
 , "Dun date"
 : "Mahnungsdatum"
 
+, "Payed at"
+: "Gezahlt am"
+
 , "Method of payment"
 : "Zahlungsart"
 
-, "without internal contact person"
-: "ohne interne Kontaktperson"
+, "Approver"
+: "Genehmigt von"
 
-, "Delivery Address"
-: "Lieferanschrift"
-
-, "Edit {0} \"{1}\""
-: "{0} \"{1}\" bearbeiten"
-
-, "Add new Billing Address"
-: "Neue Rechnungsanschrift hinzufügen"
-
-, "Add new Delivery Address"
-: "Neue Lieferanschrift hinzufügen"
-
-, "Apply postal address"
-: "Postanschrift anwenden"
+, "Lead Cost Center"
+: "Hauptkostenstelle"
 
 , "Add New Offer"
 : "Neues Angebot hinzufügen"
 
-, "Add New Order Confirmation"
-: "Neue Auftragsbestätigung hinzufügen"
+, "Clipboard"
+: "Zwischenablage"
+
+, "Product, Products"
+: [
+  "Produkt"
+ ,"Produkte"
+
+]
+, "Quantity"
+: "Anzahl"
 
 , "Interval"
 : "Intervall"
 
+, "Billing Point"
+: "Abrechnungszeitpunkt"
+
 , "begin"
 : "Anfang des Intervalls"
 
 , "end"
 : "Ende des Intervalls"
 
+, "Start Date"
+: "Anfang"
+
+, "End Date"
+: "Ende"
+
+, "Attributes"
+: ""
+
 , "Last Autobill"
 : "Zuletzt Abgerechnet"
 
@@ -562,17 +382,62 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add a New Value..."
 : "Neuen Wert hinzufügen ..."
 
-, "Clipboard"
-: "Zwischenablage"
-
-, "Add New Division"
-: "Neue Abteilung hinzufügen"
-
 , "without contract"
 : "ohne Vertrag"
 
-, "without order confirmation"
-: "ohne Auftragsbestätigung"
+, "Add New Order Confirmation"
+: "Neue Auftragsbestätigung hinzufügen"
+
+, "Offer, Offers"
+: [
+  "Angebot"
+ ,"Angebote"
+
+]
+, "Add New Product"
+: "Neues Produkt hinzufügen"
+
+, "Product Number"
+: "Produktnummer"
+
+, "GTIN"
+: "GTIN"
+
+, "Category"
+: "Kategorie"
+
+, "Manufacturer"
+: "Hersteller"
+
+, "Purchaseprice"
+: "Einkaufspreis"
+
+, "Salesprice"
+: "Verkaufspreis"
+
+, "Lifespan start"
+: "Laufzeit Beginn"
+
+, "Lifespan end"
+: "Laufzeit Ende"
+
+, "Enter description..."
+: "Bitte geben Sie eine Beschreibung ein..."
+
+, "Accountable"
+: "Rechnet ab"
+
+, "Selected  {0}"
+: "{0} ausgewählt"
+
+, "Select customer"
+: "Kunden auswählen"
+
+, "Customer Number"
+: "Kundennummer"
+
+, "Products"
+: "Produkte"
 
 , "Rebilling Invoice..."
 : "Erzeuge Rechnung neu..."
@@ -583,8 +448,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Merge Invoices"
 : "Rechnungen zusammenführen"
 
-, "without Cost Center"
-: "ohne Kostenstelle"
+, "Select supplier"
+: "Lieferant auswählen"
+
+, "Add New Cost Center"
+: "Neue Kostenstelle hinzufügen"
+
+, "Remark"
+: "Anmerkung"
+
+, "without supplier"
+: "ohne Lieferant"
+
+, "Add New Division"
+: "Neue Abteilung hinzufügen"
+
+, "Bill Contract"
+: "Vertrag abrechnen"
+
+, "Billing Contract..."
+: "Rechne Vertrag ab..."
+
+, "Bill Contract \"{0} - {1}\""
+: "Vertrag \"{0} - {1}\" abrechnen"
+
+, "Select the date to generate the bill for"
+: "Bitte wählen Sie das Datum, zu dem Sie die Rechnung erzeugen möchten"
+
+, "Either street or postbox is required!"
+: "Bitte geben Sie entweder eine Straße oder ein Postfach an!"
+
+, "Copy Customer"
+: "Kunden kopieren"
+
+, "Add New Customer"
+: "Neuen Kunden hinzufügen"
+
+, "Edit Customer \"{0}\""
+: "Kunden \"{0}\" bearbeiten"
+
+, "Name shorthand"
+: "Kunden Kürzel"
+
+, "Set as accountable"
+: "Als verantwortlich festlegen"
+
+, "Choose product for accountable"
+: "Wählen Sie das Produkt für verantwortlich"
+
+, "Please use a decimal number here!"
+: "Bitte benutzen Sie eine Dezimalzahl!"
+
+, "Positions"
+: "Positionen"
+
+, "Ok"
+: "Ok"
+
+, "Export Records from these Positions"
+: "Exportiere Einträge dieser Positionen"
+
+, "without approver"
+: "nicht genehmigt"
 
 , "Auto Invoice Contract Interval"
 : "Vertragsintervall automatisch abrechnen"
@@ -691,6 +616,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Paypal"
 : "Paypal"
 
+, "Assets"
+: "Guthaben"
+
 , "Invoice Cleared"
 : "Rechnung gebucht"
 
@@ -724,89 +652,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Purchase Invoice Module"
 : "Eingangsrechnungsmodul"
 
-, "manage products"
-: "Produkte verwalten"
-
-, "add, edit and delete products"
-: "Hinzufügen, Editieren und Löschen von Produkten"
-
-, "manage contracts"
-: "Verträge verwalten"
-
-, "add, edit and delete contracts"
-: "Verträge hinzufügen, bearbeiten und löschen"
-
-, "manage cost centers"
-: "Kostenstellen verwalten"
-
-, "add, edit and delete cost centers"
-: "Kostenstellen hinzufügen, bearbeiten und löschen"
-
-, "manage customers"
-: "Kunden verwalten"
-
-, "add, edit and delete customers"
-: "Kunden hinzufügen, bearbeiten und löschen"
-
-, "manage suppliers"
-: "Lieferanten verwalten"
-
-, "add, edit and delete suppliers"
-: "Lieferanten hinzufügen, editieren oder entfernen"
-
-, "manage invoices"
-: "Rechungen verwalten"
-
-, "add, edit and delete invoices"
-: "Rechnungen hinzufügen, bearbeiten und löschen"
-
-, "manage divisions"
-: "Abteilungen verwalten"
-
-, "add, edit and delete divisions"
-: "Abteilungen hinzufügen, bearbeiten und löschen"
-
-, "manage order confirmations"
-: "Auftragsbestätigungen verwalten"
-
-, "add, edit and delete order confirmations"
-: "Auftragsbestätigungen hinzufügen, bearbeiten und löschen"
-
-, "manage offers"
-: "Angebote verwalten"
-
-, "add, edit and delete offers"
-: "Angebote hinzufügen, bearbeiten und löschen"
-
-, "manage purchase invoices"
-: "Eingangsrechnungen verwalten"
-
-, "add, edit and delete purchase invoices"
-: "Eingangsrechnungen hinzufügen, editieren oder entfernen"
-
-, "change number of an order confirmations"
-: "Nummer einer Auftragsbestätigung ändern"
-
-, "allow to change the number of an order confirmation on update"
-: "Änderung der Nummer einer Auftragsbestätigung beim Update erlauben"
-
-, "set number of invoices"
-: "Rechnungsnummer manuell vergeben"
-
-, "allow to set the number of an invoice"
-: "Erlaubt, die Rechnungsnummer manuell zu vergeben"
-
-, "No Right to alter the Number"
-: "Keine Berechtigung die Nummer zu verändern"
-
-, "You are not allowed to alter the number afterwards!"
-: "Die Nummer kann nachträglich nicht mehr geändert werden!"
-
-, "Address as Billing Address in Use"
-: "Adresse als Rechnungsadresse in Benutzung"
-
-, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
-: "Die Adresse, die Sie löschen wollten, ist bei einem oder mehreren Verträgen als Rechnungsadresse gesetzt. Bitte weisen Sie den Verträgen eine andere Rechnungsadresse zu oder verändern Sie diese, ohne sie zu löschen."
+, "You do not have admin rights on Sales"
+: "Sie haben kein Adminrecht in der Sales-Applikation"
 
 , "Number duplicate"
 : "Mehrfach vergebene Nummer"
@@ -820,23 +667,125 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
 : "Es existiert bereits eine spätere Rechnung für den selben Vertrag. Bitte löschen Sie die spätere(n) Rechnung(en), bevor Sie diese Rechnung löschen!"
 
+, "Address as Billing Address in Use"
+: "Adresse als Rechnungsadresse in Benutzung"
+
+, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
+: "Die Adresse, die Sie löschen wollten, ist bei einem oder mehreren Verträgen als Rechnungsadresse gesetzt. Bitte weisen Sie den Verträgen eine andere Rechnungsadresse zu oder verändern Sie diese, ohne sie zu löschen."
+
 , "Invoice is cleared already"
 : "Rechnung ist bereits gebucht"
 
-, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
-: "Die Rechnung die Sie bearbeiten wollten, ist bereits gebucht und kann nicht weiter bearbeitet werden!"
-
 , "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
 : "Die Rechnung die Sie löschen wollten, ist bereits gebucht und kann nicht mehr gelöscht werden!"
 
+, "No Right to alter the Number"
+: "Keine Berechtigung die Nummer zu verändern"
+
+, "You are not allowed to alter the number afterwards!"
+: "Die Nummer kann nachträglich nicht mehr geändert werden!"
+
+, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
+: "Die Rechnung die Sie bearbeiten wollten, ist bereits gebucht und kann nicht weiter bearbeitet werden!"
+
 , "Unknown Currency Code"
 : "Unbekannter Währungscode"
 
 , "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
 : "Der Währungscode, den Sie versucht haben, einzugeben, ist nicht gültig. Bitte verwenden Sie einen gültigen Währungscode nach ISO 4217."
 
-, "You do not have admin rights on Sales"
-: "Sie haben kein Adminrecht in der Sales-Applikation"
+, "Invoice Timesheet"
+: "Rechnungs Timesheet"
+
+, "CLEARED"
+: "GEBUCHT"
+
+, "INVOICE"
+: "RECHNUNG"
+
+, "GENDER_Cost Center"
+: "female"
+
+, "Cost Center, Cost Centers"
+: [
+  "Kostenstelle"
+ ,"Kostenstellen"
+
+]
+, "GENDER_Offer"
+: "other"
+
+, "GENDER_Invoice"
+: "female"
+
+, "Sales Tax"
+: "Mehrwertsteuer"
+
+, "Reversal Invoice"
+: "Storno-Rechnung"
+
+, "Invoice Item"
+: "Rechnungsposten"
+
+, "Is active"
+: "Ist aktiv"
+
+, "GENDER_Contract"
+: "male"
+
+, "Merge"
+: "Zusammenführen"
+
+, "Responsible"
+: "Verantwortlicher"
+
+, "Partner"
+: "Partner"
+
+, "Time Account"
+: "Zeitkonto"
+
+, "GENDER_Customer)recordsName"
+: ""
+
+, "GENDER_Order Confirmation"
+: ""
+
+, "GENDER_Supplier"
+: ""
+
+, "GENDER_Division"
+: "female"
+
+, "Division, Divisions"
+: [
+  "Abteilung"
+ ,"Abteilung"
+
+]
+, "Billing Interval"
+: "Mtl. Abrechnungsintervall (variabel)"
+
+, "Piece"
+: "Stück"
+
+, "GENDER_Address"
+: "female"
+
+, "Due at"
+: "Fällig am"
+
+, "Invoice Position, Invoice Positions"
+: [
+  "Rechnungsposition"
+ ,"Rechnungspositionen"
+
+]
+, "Month"
+: "Monat"
+
+, "Unit"
+: "Einheit"
 
 , "The number you have tried to set is already in use!"
 : "Diese Nummer ist bereits vergeben!"
@@ -877,15 +826,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Contracts that are still running"
 : "Verträge die noch am laufen sind"
 
-, "Products created by myself"
-: "Von mir erstellte Produkte"
-
-, "Status"
-: "Status"
-
-, "Cleared In"
-: "Gebucht in"
-
 , "All Suppliers"
 : "Alle Lieferanten"
 
@@ -937,21 +877,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "You have to set a customer!"
 : "Bitte legen Seien Kunden fest."
 
-, "Taxes (VAT)"
-: "MwSt"
-
-, "VAT ID"
-: "USt.-ID"
-
-, "Selected  {0}"
-: "{0} ausgewählt"
-
-, "Add New Billing Address"
-: "Neue Rechnungsanschrift Hinzufügen"
-
-, "Add New Delivery Address"
-: "Neue Lieferanschrift Hinzufügen"
-
 , "Manage Products"
 : "Produkte Verwalten"
 
@@ -982,6 +907,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add, edit and delete suppliers."
 : "Lieferanten hinzufügen, editieren oder entfernen."
 
+, "manage invoices"
+: "Rechungen verwalten"
+
 , "Add, edit and delete invoices."
 : "Rechnungen hinzufügen, bearbeiten und löschen."
 
@@ -1021,48 +949,78 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Allow to set the number of an invoice."
 : "Erlaubt, die Rechnungsnummer manuell zu vergeben."
 
-, "Assets"
-: "Guthaben"
 
-, "GENDER_Contract"
-: "male"
 
-, "Customer"
-: "Kunde"
 
-, "Invoice Position"
-: "Rechnungsposition"
 
-, "Offer"
-: "Angebot"
 
-, "Order Confirmation"
-: "Auftragsbestätigung"
 
-, "Product"
-: "Produkt"
 
-, "Contract"
-: "Vertrag"
 
-, "Invoice"
-: "Rechnung"
 
-, "Address"
-: "Anschrift"
 
-, "Cost Center"
-: "Kostenstelle"
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 , "Supplier"
 : "Lieferant"
 
-, "Division"
-: "Abteilung"
+, "Invoice"
+: "Rechnung"
+
+, "Contract"
+: "Vertrag"
+
+, "Customer"
+: "Kunde"
+
+, "Order Confirmation"
+: "Auftragsbestätigung"
+
+, "Address"
+: "Anschrift"
 
 , "Purchase Invoice"
 : "Eingangsrechnung"
 
+, "Product"
+: "Produkt"
+
+, "Offer"
+: "Angebot"
+
+, "Cost Center"
+: "Kostenstelle"
+
+, "Division"
+: "Abteilung"
+
+, "Invoice Position"
+: "Rechnungsposition"
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
