@@ -7,132 +7,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 ""
 : "Project-Id-Version: Tine 2.0 - Sales\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"
 
-, "You do not have admin rights on Sales"
-: "You do not have admin rights on Sales"
-
-, "Add New Offer"
-: "Add New Offer"
-
-, "Number"
-: "Number"
-
-, "Title"
-: "Title"
-
-, "Customer, Customers"
-: [
-  "Customer"
- ,"Customers"
-
-]
-, "Description"
-: "Description"
-
-, "Enter description"
-: "Enter description"
-
-, "Approver"
-: "Approver"
-
-, "without approver"
-: "without approver"
-
-, "Select invoice"
-: "Select invoice"
-
-, "Invoice, Invoices"
-: [
-  "Invoice"
- ,"Invoices"
-
-]
-, "Invoice Number"
-: "Invoice Number"
-
-, "Date"
-: "Date"
-
-, "Type"
-: "Type"
-
-, "Contract, Contracts"
-: [
-  "Contract"
- ,"Contracts"
-
-]
-, "Billing Address"
-: "Billing Address"
-
-, "Miscellaneous"
-: "Miscellaneous"
-
-, "Credit Term"
-: "Credit Term"
-
-, "Cleared"
-: "Cleared"
-
-, "Price Net"
-: "Price Net"
-
-, "Price Tax"
-: "Price Tax"
-
-, "Total Price"
-: "Total Price"
-
-, "Add New Order Confirmation"
-: "Add New Order Confirmation"
-
-, "Offer, Offers"
-: [
-  "Offer"
- ,"Offers"
-
-]
-, "Copy address to the clipboard"
-: "Copy address to the clipboard"
-
-, "Select supplier"
-: "Select supplier"
-
-, "Core Data"
-: "Core Data"
-
-, "Supplier Number"
-: "Supplier Number"
-
-, "Name"
-: "Name"
-
-, "Web"
-: "Web"
-
-, "Contact Person (external)"
-: "Contact Person (external)"
-
-, "Contact Person (internal)"
-: "Contact Person (internal)"
-
-, "Accounting"
-: "Accounting"
-
-, "IBAN"
-: "IBAN"
-
-, "BIC"
-: "BIC"
-
-, "VAT No."
-: "VAT No."
-
-, "Currency"
-: "Currency"
-
-, "Currency Translation Rate"
-: "Currency Translation Rate"
-
 , "Either postalcode or postbox is required!"
 : "Either postalcode or postbox is required!"
 
@@ -145,15 +19,51 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Edit Supplier \"{0}\""
 : "Edit Supplier \"{0}\""
 
+, "Copy address to the clipboard"
+: "Copy address to the clipboard"
+
 , "Supplier, Suppliers"
 : [
   "Supplier"
  ,"Suppliers"
 
 ]
+, "Core Data"
+: "Core Data"
+
+, "Supplier Number"
+: "Supplier Number"
+
+, "Name"
+: "Name"
+
+, "Contact Person (external)"
+: "Contact Person (external)"
+
+, "Contact Person (internal)"
+: "Contact Person (internal)"
+
+, "Accounting"
+: "Accounting"
+
+, "VAT ID"
+: "VAT ID"
+
 , "Credit Term (days)"
 : "Credit Term (days)"
 
+, "Currency"
+: "Currency"
+
+, "Currency Translation Rate"
+: "Currency Translation Rate"
+
+, "IBAN"
+: "IBAN"
+
+, "BIC"
+: "BIC"
+
 , "Postal Address"
 : "Postal Address"
 
@@ -181,15 +91,126 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Additional Prefix"
 : "Additional Prefix"
 
+, "Miscellaneous"
+: "Miscellaneous"
+
+, "Web"
+: "Web"
+
+, "Description"
+: "Description"
+
+, "Enter description"
+: "Enter description"
+
+, "total"
+: "total"
+
+, "inclusive"
+: "inclusive"
+
+, "exceeding"
+: "exceeding"
+
+, "Create timesheet"
+: "Create timesheet"
+
+, "Create Reversal Invoice"
+: "Create Reversal Invoice"
+
+, "Copy Invoice"
+: "Copy Invoice"
+
+, "Add New Invoice"
+: "Add New Invoice"
+
+, "Edit Invoice \"{0}\""
+: "Edit Invoice \"{0}\""
+
+, "Positions ({0})"
+: "Positions ({0})"
+
+, "No customer assigned"
+: "No customer assigned"
+
+, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
+: "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
+
+, "No cost center assigned"
+: "No cost center assigned"
+
+, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
+: "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
+
+, "Price Net"
+: "Price Net"
+
+, "Taxes (VAT)"
+: "Taxes (VAT)"
+
+, "Price Gross"
+: "Price Gross"
+
+, "Sales Tax (percent)"
+: "Sales Tax (percent)"
+
+, "Inventory Change"
+: "Inventory Change"
+
+, "Invoice, Invoices"
+: [
+  "Invoice"
+ ,"Invoices"
+
+]
+, "Invoice Number"
+: "Invoice Number"
+
+, "automatically set..."
+: "automatically set..."
+
+, "Date"
+: "Date"
+
+, "Type"
+: "Type"
+
+, "Contract, Contracts"
+: [
+  "Contract"
+ ,"Contracts"
+
+]
+, "Customer, Customers"
+: [
+  "Customer"
+ ,"Customers"
+
+]
+, "Billing Address"
+: "Billing Address"
+
+, "Credit Term"
+: "Credit Term"
+
+, "Cleared"
+: "Cleared"
+
+, "Interval Begins"
+: "Interval Begins"
+
+, "Interval Ends"
+: "Interval Ends"
+
+, "Select invoice"
+: "Select invoice"
+
+, "Total Price"
+: "Total Price"
+
 , "Cancel"
 : "Cancel"
 
-, "Ok"
-: "Ok"
-
-, "Billing Addresses"
-: "Billing Addresses"
-
 , "OK"
 : "OK"
 
@@ -199,27 +220,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Euro (€)"
 : "Euro (€)"
 
-, "without external contact person"
-: "without external contact person"
-
-, "Price Gross"
-: "Price Gross"
-
-, "Export Records from these Positions"
-: "Export Records from these Positions"
-
-, "Select customer"
-: "Select customer"
-
-, "Customer Number"
-: "Customer Number"
-
-, "Remark"
-: "Remark"
-
-, "without Cost Center"
-: "without Cost Center"
-
 , "Order Confirmation, Order Confirmations"
 : [
   "Order Confirmation"
@@ -229,65 +229,101 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "without order confirmation"
 : "without order confirmation"
 
+, "Number"
+: "Number"
+
+, "Title"
+: "Title"
+
+, "Billing Addresses"
+: "Billing Addresses"
+
+, "Delivery Address"
+: "Delivery Address"
+
+, "Delivery Addresses"
+: "Delivery Addresses"
+
+, "Edit {0} \"{1}\""
+: "Edit {0} \"{1}\""
+
+, "Add New Billing Address"
+: "Add New Billing Address"
+
+, "Add New Delivery Address"
+: "Add New Delivery Address"
+
+, "Apply postal address"
+: "Apply postal address"
+
+, "Number Debit"
+: "Number Debit"
+
+, "Address, Addresss"
+: [
+  "Address"
+ ,"Addresss"
+
+]
 , "without customer"
 : "without customer"
 
-, "Bill Contract"
-: "Bill Contract"
+, "Copy Purchase Invoice"
+: "Copy Purchase Invoice"
 
-, "Billing Contract..."
-: "Billing Contract..."
+, "Add New Purchase Invoice"
+: "Add New Purchase Invoice"
 
-, "Bill Contract \"{0} - {1}\""
-: "Bill Contract \"{0} - {1}\""
+, "Edit Purchase Invoice \"{0}\""
+: "Edit Purchase Invoice \"{0}\""
 
-, "Select the date to generate the bill for"
-: "Select the date to generate the bill for"
+, "Date of invoice"
+: "Date of invoice"
 
-, "Please use a decimal number here!"
-: "Please use a decimal number here!"
+, "Due in"
+: "Due in"
 
-, "Products"
-: "Products"
+, "Due date"
+: "Due date"
 
-, "Start Date"
-: "Start Date"
-
-, "End Date"
-: "End Date"
-
-, "Lead Cost Center"
-: "Lead Cost Center"
-
-, "Enter description..."
-: "Enter description..."
-
-, "without internal contact person"
-: "without internal contact person"
-
-, "without contract"
-: "without contract"
-
-, "Either street or postbox is required!"
-: "Either street or postbox is required!"
-
-, "Only numbers are allowed!"
-: "Only numbers are allowed!"
-
-, "Copy Customer"
-: "Copy Customer"
-
-, "Add New Customer"
-: "Add New Customer"
-
-, "Edit Customer \"{0}\""
-: "Edit Customer \"{0}\""
+, "Additional Price Gross"
+: "Additional Price Gross"
 
 , "Discount (%)"
 : "Discount (%)"
 
-, "Name shorthand"
-: "Name shorthand"
+, "Purchase Invoice, Purchase Invoices"
+: [
+  "Purchase Invoice"
+ ,"Purchase Invoices"
+
+]
+, "Overdue date"
+: "Overdue date"
+
+, "Discount until"
+: "Discount until"
+
+, "Dun date"
+: "Dun date"
+
+, "Payed at"
+: "Payed at"
+
+, "Method of payment"
+: "Method of payment"
+
+, "Approver"
+: "Approver"
+
+, "Lead Cost Center"
+: "Lead Cost Center"
+
+, "Add New Offer"
+: "Add New Offer"
+
+, "Clipboard"
+: "Clipboard"
 
 , "Product, Products"
 : [
@@ -310,6 +346,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "end"
 : "end"
 
+, "Start Date"
+: "Start Date"
+
+, "End Date"
+: "End Date"
+
+, "Attributes"
+: "Attributes"
+
 , "Last Autobill"
 : "Last Autobill"
 
@@ -337,90 +382,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add a New Value..."
 : "Add a New Value..."
 
-, "Delivery Address"
-: "Delivery Address"
+, "without contract"
+: "without contract"
 
-, "Delivery Addresses"
-: "Delivery Addresses"
+, "Add New Order Confirmation"
+: "Add New Order Confirmation"
 
-, "Edit {0} \"{1}\""
-: "Edit {0} \"{1}\""
-
-, "Add new Billing Address"
-: "Add new Billing Address"
-
-, "Add new Delivery Address"
-: "Add new Delivery Address"
-
-, "Apply postal address"
-: "Apply postal address"
-
-, "Number Debit"
-: "Number Debit"
-
-, "Address, Addresss"
+, "Offer, Offers"
 : [
-  "Address"
- ,"Addresss"
+  "Offer"
+ ,"Offers"
 
 ]
-, "Copy Purchase Invoice"
-: "Copy Purchase Invoice"
-
-, "Add New Purchase Invoice"
-: "Add New Purchase Invoice"
-
-, "Edit Purchase Invoice \"{0}\""
-: "Edit Purchase Invoice \"{0}\""
-
-, "Date of invoice"
-: "Date of invoice"
-
-, "Due in"
-: "Due in"
-
-, "Due date"
-: "Due date"
-
-, "Additional Price Gross"
-: "Additional Price Gross"
-
-, "Sales Tax (percent)"
-: "Sales Tax (percent)"
-
-, "Purchase Invoice, Purchase Invoices"
-: [
-  "Purchase Invoice"
- ,"Purchase Invoices"
-
-]
-, "automatically set..."
-: "automatically set..."
-
-, "Overdue date"
-: "Overdue date"
-
-, "Discount until"
-: "Discount until"
-
-, "Dun date"
-: "Dun date"
-
-, "Payed at"
-: "Payed at"
-
-, "Method of payment"
-: "Method of payment"
-
-, "without supplier"
-: "without supplier"
-
-, "Clipboard"
-: "Clipboard"
-
-, "Add New Cost Center"
-: "Add New Cost Center"
-
 , "Add New Product"
 : "Add New Product"
 
@@ -448,50 +421,23 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Lifespan end"
 : "Lifespan end"
 
+, "Enter description..."
+: "Enter description..."
+
 , "Accountable"
 : "Accountable"
 
-, "Add New Division"
-: "Add New Division"
+, "Selected  {0}"
+: "Selected  {0}"
 
-, "Create timesheet"
-: "Create timesheet"
+, "Select customer"
+: "Select customer"
 
-, "Create Reversal Invoice"
-: "Create Reversal Invoice"
+, "Customer Number"
+: "Customer Number"
 
-, "Copy Invoice"
-: "Copy Invoice"
-
-, "Add New Invoice"
-: "Add New Invoice"
-
-, "Edit Invoice \"{0}\""
-: "Edit Invoice \"{0}\""
-
-, "Positions"
-: "Positions"
-
-, "No customer assigned"
-: "No customer assigned"
-
-, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
-: "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
-
-, "No cost center assigned"
-: "No cost center assigned"
-
-, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
-: "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
-
-, "Inventory Change"
-: "Inventory Change"
-
-, "Interval Begins"
-: "Interval Begins"
-
-, "Interval Ends"
-: "Interval Ends"
+, "Products"
+: "Products"
 
 , "Rebilling Invoice..."
 : "Rebilling Invoice..."
@@ -502,107 +448,68 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Merge Invoices"
 : "Merge Invoices"
 
-, "Status"
-: "Status"
+, "Select supplier"
+: "Select supplier"
 
-, "Cleared In"
-: "Cleared In"
+, "Add New Cost Center"
+: "Add New Cost Center"
 
-, "All Customers"
-: "All Customers"
+, "Remark"
+: "Remark"
 
-, "All customer records"
-: "All customer records"
+, "without supplier"
+: "without supplier"
 
-, "All Offers"
-: "All Offers"
+, "Add New Division"
+: "Add New Division"
 
-, "All offer records"
-: "All offer records"
+, "Bill Contract"
+: "Bill Contract"
 
-, "All Suppliers"
-: "All Suppliers"
+, "Billing Contract..."
+: "Billing Contract..."
 
-, "All supllier records"
-: "All supllier records"
+, "Bill Contract \"{0} - {1}\""
+: "Bill Contract \"{0} - {1}\""
 
-, "All Purchase Imvoices"
-: "All Purchase Imvoices"
+, "Select the date to generate the bill for"
+: "Select the date to generate the bill for"
 
-, "All purchase invoices"
-: "All purchase invoices"
+, "Either street or postbox is required!"
+: "Either street or postbox is required!"
 
-, "All Products"
-: "All Products"
+, "Copy Customer"
+: "Copy Customer"
 
-, "All product records"
-: "All product records"
+, "Add New Customer"
+: "Add New Customer"
 
-, "All Contracts"
-: "All Contracts"
+, "Edit Customer \"{0}\""
+: "Edit Customer \"{0}\""
 
-, "All contract records"
-: "All contract records"
+, "Name shorthand"
+: "Name shorthand"
 
-, "All Invoices"
-: "All Invoices"
+, "Set as accountable"
+: "Set as accountable"
 
-, "All invoice records"
-: "All invoice records"
+, "Choose product for accountable"
+: "Choose product for accountable"
 
-, "All Cost Centers"
-: "All Cost Centers"
+, "Please use a decimal number here!"
+: "Please use a decimal number here!"
 
-, "All costcenter records"
-: "All costcenter records"
+, "Positions"
+: "Positions"
 
-, "All Divisions"
-: "All Divisions"
+, "Ok"
+: "Ok"
 
-, "All division records"
-: "All division records"
+, "Export Records from these Positions"
+: "Export Records from these Positions"
 
-, "All Order Confirmations"
-: "All Order Confirmations"
-
-, "All order confirmation records"
-: "All order confirmation records"
-
-, "Bank transfer"
-: "Bank transfer"
-
-, "Direct debit"
-: "Direct debit"
-
-, "Default"
-: "Default"
-
-, "Cancellation"
-: "Cancellation"
-
-, "Credit"
-: "Credit"
-
-, "Credit card"
-: "Credit card"
-
-, "Paypal"
-: "Paypal"
-
-, "My Products"
-: "My Products"
-
-, "Products created by myself"
-: "Products created by myself"
-
-, "My Contracts"
-: "My Contracts"
-
-, "Contracts created by myself"
-: "Contracts created by myself"
-
-, "Products created by me"
-: "Products created by me"
+, "without approver"
+: "without approver"
 
 , "Auto Invoice Contract Interval"
 : "Auto Invoice Contract Interval"
@@ -652,12 +559,18 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Reversal"
 : "Reversal"
 
+, "Credit"
+: "Credit"
+
 , "Product Category"
 : "Product Category"
 
 , "Possible Product Categories."
 : "Possible Product Categories."
 
+, "Default"
+: "Default"
+
 , "Product Number Creation"
 : "Product Number Creation"
 
@@ -685,9 +598,27 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Possible Payment Methods."
 : "Possible Payment Methods."
 
+, "Bank transfer"
+: "Bank transfer"
+
+, "Direct debit"
+: "Direct debit"
+
+, "Cancellation"
+: "Cancellation"
+
+, "Credit card"
+: "Credit card"
+
 , "EC card"
 : "EC card"
 
+, "Paypal"
+: "Paypal"
+
+, "Assets"
+: "Assets"
+
 , "Invoice Cleared"
 : "Invoice Cleared"
 
@@ -721,23 +652,59 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Purchase Invoice Module"
 : "Purchase Invoice Module"
 
-, "The number you have tried to set is already in use!"
-: "The number you have tried to set is already in use!"
+, "You do not have admin rights on Sales"
+: "You do not have admin rights on Sales"
 
-, "Invoice Position, Invoice Positions"
-: [
-  "Invoice Position"
- ,"Invoice Positions"
+, "Number duplicate"
+: "Number duplicate"
 
-]
-, "Month"
-: "Month"
+, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
+: "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
 
-, "Unit"
-: "Unit"
+, "Following Invoices Found"
+: "Following Invoices Found"
 
-, "Is active"
-: "Is active"
+, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
+: "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
+
+, "Address as Billing Address in Use"
+: "Address as Billing Address in Use"
+
+, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
+: "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
+
+, "Invoice is cleared already"
+: "Invoice is cleared already"
+
+, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
+: "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
+
+, "No Right to alter the Number"
+: "No Right to alter the Number"
+
+, "You are not allowed to alter the number afterwards!"
+: "You are not allowed to alter the number afterwards!"
+
+, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
+: "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
+
+, "Unknown Currency Code"
+: "Unknown Currency Code"
+
+, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
+: "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
+
+, "Invoice Timesheet"
+: "Invoice Timesheet"
+
+, "CLEARED"
+: "CLEARED"
+
+, "INVOICE"
+: "INVOICE"
+
+, "GENDER_Cost Center"
+: "GENDER_Cost Center"
 
 , "Cost Center, Cost Centers"
 : [
@@ -745,32 +712,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
  ,"Cost Centers"
 
 ]
-, "Billing Interval"
-: "Billing Interval"
+, "GENDER_Offer"
+: "GENDER_Offer"
 
-, "Invoice Item"
-: "Invoice Item"
+, "GENDER_Invoice"
+: "GENDER_Invoice"
 
-, "Piece"
-: "Piece"
-
-, "Division, Divisions"
-: [
-  "Division"
- ,"Divisions"
-
-]
 , "Sales Tax"
 : "Sales Tax"
 
 , "Reversal Invoice"
 : "Reversal Invoice"
 
-, "Due at"
-: "Due at"
+, "Invoice Item"
+: "Invoice Item"
 
-, "Payment_method"
-: "Payment_method"
+, "Is active"
+: "Is active"
+
+, "GENDER_Contract"
+: "GENDER_Contract"
 
 , "Merge"
 : "Merge"
@@ -784,161 +745,74 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Time Account"
 : "Time Account"
 
-, "CLEARED"
-: "CLEARED"
+, "GENDER_Customer)recordsName"
+: "GENDER_Customer)recordsName"
 
-, "INVOICE"
-: "INVOICE"
+, "GENDER_Order Confirmation"
+: "GENDER_Order Confirmation"
 
-, "Invoice Timesheet"
-: "Invoice Timesheet"
+, "GENDER_Supplier"
+: "GENDER_Supplier"
 
-, "No Right to alter the Number"
-: "No Right to alter the Number"
+, "GENDER_Division"
+: "GENDER_Division"
 
-, "You are not allowed to alter the number afterwards!"
-: "You are not allowed to alter the number afterwards!"
+, "Division, Divisions"
+: [
+  "Division"
+ ,"Divisions"
 
-, "Invoice is cleared already"
-: "Invoice is cleared already"
+]
+, "Billing Interval"
+: "Billing Interval"
 
-, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
-: "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
+, "Piece"
+: "Piece"
 
-, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
-: "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
+, "GENDER_Address"
+: "GENDER_Address"
 
-, "Following Invoices Found"
-: "Following Invoices Found"
+, "Due at"
+: "Due at"
 
-, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
-: "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
+, "Invoice Position, Invoice Positions"
+: [
+  "Invoice Position"
+ ,"Invoice Positions"
 
-, "Number duplicate"
-: "Number duplicate"
+]
+, "Month"
+: "Month"
 
-, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
-: "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
+, "Unit"
+: "Unit"
 
-, "Unknown Currency Code"
-: "Unknown Currency Code"
+, "The number you have tried to set is already in use!"
+: "The number you have tried to set is already in use!"
 
-, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
-: "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
+, "My Products"
+: "My Products"
 
-, "Address as Billing Address in Use"
-: "Address as Billing Address in Use"
+, "Products created by me"
+: "Products created by me"
 
-, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
-: "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
+, "My Contracts"
+: "My Contracts"
 
-, "manage products"
-: "manage products"
+, "Contracts created by myself"
+: "Contracts created by myself"
 
-, "add, edit and delete products"
-: "add, edit and delete products"
+, "All Customers"
+: "All Customers"
 
-, "manage contracts"
-: "manage contracts"
+, "All customer records"
+: "All customer records"
 
-, "add, edit and delete contracts"
-: "add, edit and delete contracts"
+, "All Offers"
+: "All Offers"
 
-, "manage cost centers"
-: "manage cost centers"
-
-, "add, edit and delete cost centers"
-: "add, edit and delete cost centers"
-
-, "manage customers"
-: "manage customers"
-
-, "add, edit and delete customers"
-: "add, edit and delete customers"
-
-, "manage suppliers"
-: "manage suppliers"
-
-, "add, edit and delete suppliers"
-: "add, edit and delete suppliers"
-
-, "manage invoices"
-: "manage invoices"
-
-, "add, edit and delete invoices"
-: "add, edit and delete invoices"
-
-, "manage divisions"
-: "manage divisions"
-
-, "add, edit and delete divisions"
-: "add, edit and delete divisions"
-
-, "manage order confirmations"
-: "manage order confirmations"
-
-, "add, edit and delete order confirmations"
-: "add, edit and delete order confirmations"
-
-, "manage offers"
-: "manage offers"
-
-, "add, edit and delete offers"
-: "add, edit and delete offers"
-
-, "manage purchase invoices"
-: "manage purchase invoices"
-
-, "add, edit and delete purchase invoices"
-: "add, edit and delete purchase invoices"
-
-, "change number of an order confirmations"
-: "change number of an order confirmations"
-
-, "allow to change the number of an order confirmation on update"
-: "allow to change the number of an order confirmation on update"
-
-, "set number of invoices"
-: "set number of invoices"
-
-, "allow to set the number of an invoice"
-: "allow to set the number of an invoice"
-
-, "You have to set a customer!"
-: "You have to set a customer!"
-
-, "Taxes (VAT)"
-: "Taxes (VAT)"
-
-, "VAT ID"
-: "VAT ID"
-
-, "Selected  {0}"
-: "Selected  {0}"
-
-, "Set as accountable"
-: "Set as accountable"
-
-, "Choose product for accountable"
-: "Choose product for accountable"
-
-, "Add New Billing Address"
-: "Add New Billing Address"
-
-, "Add New Delivery Address"
-: "Add New Delivery Address"
-
-, "total"
-: "total"
-
-, "inclusive"
-: "inclusive"
-
-, "exceeding"
-: "exceeding"
-
-, "Positions ({0})"
-: "Positions ({0})"
+, "All offer records"
+: "All offer records"
 
 , "Inactive Contracts"
 : "Inactive Contracts"
@@ -952,6 +826,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Contracts that are still running"
 : "Contracts that are still running"
 
+, "All Suppliers"
+: "All Suppliers"
+
+, "All supllier records"
+: "All supllier records"
+
+, "All Purchase Imvoices"
+: "All Purchase Imvoices"
+
+, "All purchase invoices"
+: "All purchase invoices"
+
+, "All Products"
+: "All Products"
+
+, "All product records"
+: "All product records"
+
+, "All Contracts"
+: "All Contracts"
+
+, "All contract records"
+: "All contract records"
+
+, "All Invoices"
+: "All Invoices"
+
+, "All invoice records"
+: "All invoice records"
+
+, "All Cost Centers"
+: "All Cost Centers"
+
+, "All costcenter records"
+: "All costcenter records"
+
+, "All Divisions"
+: "All Divisions"
+
+, "All division records"
+: "All division records"
+
+, "All Order Confirmations"
+: "All Order Confirmations"
+
+, "All order confirmation records"
+: "All order confirmation records"
+
+, "You have to set a customer!"
+: "You have to set a customer!"
+
 , "Manage Products"
 : "Manage Products"
 
@@ -982,6 +907,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add, edit and delete suppliers."
 : "Add, edit and delete suppliers."
 
+, "manage invoices"
+: "manage invoices"
+
 , "Add, edit and delete invoices."
 : "Add, edit and delete invoices."
 
@@ -1021,11 +949,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Allow to set the number of an invoice."
 : "Allow to set the number of an invoice."
 
-, "Assets"
-: "Assets"
-
-, "Customer"
-: "Customer"
+, "Supplier"
+: "Supplier"
 
 , "Invoice"
 : "Invoice"
@@ -1033,26 +958,23 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Contract"
 : "Contract"
 
-, "Offer"
-: "Offer"
-
-, "Supplier"
-: "Supplier"
+, "Customer"
+: "Customer"
 
 , "Order Confirmation"
 : "Order Confirmation"
 
-, "Product"
-: "Product"
-
 , "Address"
 : "Address"
 
 , "Purchase Invoice"
 : "Purchase Invoice"
 
-, "Invoice Position"
-: "Invoice Position"
+, "Product"
+: "Product"
+
+, "Offer"
+: "Offer"
 
 , "Cost Center"
 : "Cost Center"
@@ -1060,6 +982,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Division"
 : "Division"
 
+, "Invoice Position"
+: "Invoice Position"
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
