@@ -5,328 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Sales **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "CLEARED"
-: ""
-
-, "INVOICE"
-: ""
-
-, "Invoice Timesheet"
-: ""
-
-, "Customer, Customers"
-: [
-  ""
- ,""
-
-]
-, "Core Data"
-: ""
-
-, "Accounting"
-: ""
-
-, "Miscellaneous"
-: ""
-
-, "Customer Number"
-: ""
-
-, "Name"
-: "Nome"
-
-, "Name shorthand"
-: ""
-
-, "Web"
-: ""
-
-, "Description"
-: "Descrição"
-
-, "Contact Person (external)"
-: ""
-
-, "Contact Person (internal)"
-: ""
-
-, "VAT No."
-: ""
-
-, "Credit Term (days)"
-: ""
-
-, "Currency"
-: ""
-
-, "Currency Translation Rate"
-: ""
-
-, "Discount (%)"
-: ""
-
-, "Delivery Addresses"
-: ""
-
-, "Billing Addresses"
-: ""
-
-, "Prefix"
-: ""
-
-, "Additional Prefix"
-: ""
-
-, "Street"
-: ""
-
-, "Postalcode"
-: ""
-
-, "Locality"
-: ""
-
-, "Region"
-: ""
-
-, "Country"
-: ""
-
-, "Postbox"
-: ""
-
-, "Invoice Position, Invoice Positions"
-: [
-  ""
- ,""
-
-]
-, "Type"
-: ""
-
-, "Title"
-: "Título"
-
-, "Month"
-: "Mês"
-
-, "Unit"
-: ""
-
-, "Quantity"
-: ""
-
-, "Offer, Offers"
-: [
-  ""
- ,""
-
-]
-, "Order Confirmation, Order Confirmations"
-: [
-  ""
- ,""
-
-]
-, "Number"
-: "Número"
-
-, "Product, Products"
-: [
-  "Produto"
- ,"Produtos"
-
-]
-, "Contract, Contracts"
-: [
-  "Contrato"
- ,"Contratos"
-
-]
-, "Billing Interval"
-: ""
-
-, "Billing Point"
-: ""
-
-, "Start Date"
-: ""
-
-, "End Date"
-: ""
-
-, "Invoice Item"
-: ""
-
-, "Piece"
-: ""
-
-, "Purchaseprice"
-: ""
-
-, "Salesprice"
-: ""
-
-, "Category"
-: "Categoria"
-
-, "Manufacturer"
-: "Fabricante"
-
-, "Accountable"
-: ""
-
-, "GTIN"
-: ""
-
-, "Lifespan start"
-: ""
-
-, "Lifespan end"
-: ""
-
-, "Is active"
-: ""
-
-, "Invoice, Invoices"
-: [
-  ""
- ,""
-
-]
-, "Invoice Number"
-: ""
-
-, "Address, Addresss"
-: [
-  ""
- ,""
-
-]
-, "Date"
-: ""
-
-, "Interval Begins"
-: ""
-
-, "Interval Ends"
-: ""
-
-, "Credit Term"
-: ""
-
-, "Cost Center, Cost Centers"
-: [
-  ""
- ,""
-
-]
-, "Cleared"
-: "Autorizado"
-
-, "Price Net"
-: ""
-
-, "Price Tax"
-: ""
-
-, "Price Gross"
-: ""
-
-, "Sales Tax"
-: ""
-
-, "Inventory Change"
-: ""
-
-, "Positions"
-: ""
-
-, "Reversal Invoice"
-: ""
-
-, "Supplier, Suppliers"
-: [
-  ""
- ,""
-
-]
-, "Supplier Number"
-: ""
-
-, "Division, Divisions"
-: [
-  "Divisão"
- ,"Divisões"
-
-]
-, "Number Debit"
-: ""
-
-, "Products"
-: ""
-
-, "Billing Address"
-: ""
-
-, "Lead Cost Center"
-: ""
-
-, "Merge"
-: ""
-
-, "Responsible"
-: "Responsável"
-
-, "Partner"
-: "Sócio"
-
-, "Time Account"
-: ""
-
-, "Remark"
-: "Observação"
-
-, "Purchase Invoice, Purchase Invoices"
-: [
-  ""
- ,""
-
-]
-, "Approver"
-: ""
-
-, "Date of invoice"
-: ""
-
-, "Due in"
-: ""
-
-, "Due at"
-: ""
-
-, "Payed at"
-: ""
-
-, "Payment_method"
-: ""
-
-, "Discount until"
-: ""
-
-, "Additional Price Gross"
-: ""
-
-, "Total Price"
-: ""
-
-, "without customer"
-: ""
-
-, "Export Records from these Positions"
-: ""
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:58+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Either postalcode or postbox is required!"
 : ""
@@ -343,6 +22,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Copy address to the clipboard"
 : ""
 
+, "Supplier, Suppliers"
+: [
+  ""
+ ,""
+
+]
+, "Core Data"
+: ""
+
+, "Supplier Number"
+: ""
+
+, "Name"
+: "Nome"
+
+, "Contact Person (external)"
+: ""
+
+, "Contact Person (internal)"
+: ""
+
+, "Accounting"
+: ""
+
+, "VAT ID"
+: ""
+
+, "Credit Term (days)"
+: ""
+
+, "Currency"
+: ""
+
+, "Currency Translation Rate"
+: ""
+
 , "IBAN"
 : ""
 
@@ -352,30 +67,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Postal Address"
 : ""
 
+, "Street"
+: ""
+
+, "Postbox"
+: ""
+
+, "Postalcode"
+: ""
+
+, "Locality"
+: ""
+
+, "Region"
+: ""
+
+, "Country"
+: ""
+
+, "Prefix"
+: ""
+
+, "Additional Prefix"
+: ""
+
+, "Miscellaneous"
+: ""
+
+, "Web"
+: ""
+
+, "Description"
+: "Descrição"
+
 , "Enter description"
 : ""
 
-, "Cancel"
-: "Cancelar"
-
-, "Ok"
-: "OK"
-
-, "Select customer"
-: ""
-
-, "Bill Contract"
-: ""
-
-, "Billing Contract..."
-: ""
-
-, "Bill Contract \"{0} - {1}\""
-: ""
-
-, "Select the date to generate the bill for"
-: ""
-
 , "total"
 : ""
 
@@ -415,12 +142,75 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
 : ""
 
+, "Price Net"
+: ""
+
+, "Taxes (VAT)"
+: ""
+
+, "Price Gross"
+: ""
+
 , "Sales Tax (percent)"
 : ""
 
+, "Inventory Change"
+: ""
+
+, "Invoice, Invoices"
+: [
+  ""
+ ,""
+
+]
+, "Invoice Number"
+: ""
+
 , "automatically set..."
 : ""
 
+, "Date"
+: ""
+
+, "Type"
+: ""
+
+, "Contract, Contracts"
+: [
+  "Contrato"
+ ,"Contratos"
+
+]
+, "Customer, Customers"
+: [
+  ""
+ ,""
+
+]
+, "Billing Address"
+: ""
+
+, "Credit Term"
+: ""
+
+, "Cleared"
+: "Autorizado"
+
+, "Interval Begins"
+: ""
+
+, "Interval Ends"
+: ""
+
+, "Select invoice"
+: ""
+
+, "Total Price"
+: ""
+
+, "Cancel"
+: "Cancelar"
+
 , "OK"
 : "OK"
 
@@ -430,55 +220,52 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Euro (€)"
 : ""
 
-, "Set as accountable"
+, "Order Confirmation, Order Confirmations"
+: [
+  ""
+ ,""
+
+]
+, "without order confirmation"
 : ""
 
-, "Choose product for accountable"
+, "Number"
+: "Número"
+
+, "Title"
+: "Título"
+
+, "Billing Addresses"
 : ""
 
-, "Please use a decimal number here!"
-: "Favor usar número decimal aqui!"
-
-, "Enter description..."
-: "Digite a descrição..."
-
-, "Add New Product"
+, "Delivery Address"
 : ""
 
-, "Product Number"
+, "Delivery Addresses"
 : ""
 
-, "Select supplier"
+, "Edit {0} \"{1}\""
 : ""
 
-, "Add New Cost Center"
+, "Add New Billing Address"
 : ""
 
-, "Select invoice"
+, "Add New Delivery Address"
 : ""
 
-, "Either street or postbox is required!"
+, "Apply postal address"
 : ""
 
-, "Only numbers are allowed!"
+, "Number Debit"
 : ""
 
-, "Copy Customer"
-: ""
+, "Address, Addresss"
+: [
+  ""
+ ,""
 
-, "Add New Customer"
-: ""
-
-, "Edit Customer \"{0}\""
-: ""
-
-, "without external contact person"
-: ""
-
-, "without approver"
-: ""
-
-, "without supplier"
+]
+, "without customer"
 : ""
 
 , "Copy Purchase Invoice"
@@ -490,51 +277,84 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Edit Purchase Invoice \"{0}\""
 : ""
 
+, "Date of invoice"
+: ""
+
+, "Due in"
+: ""
+
 , "Due date"
 : ""
 
+, "Additional Price Gross"
+: ""
+
+, "Discount (%)"
+: ""
+
+, "Purchase Invoice, Purchase Invoices"
+: [
+  ""
+ ,""
+
+]
 , "Overdue date"
 : ""
 
+, "Discount until"
+: ""
+
 , "Dun date"
 : ""
 
+, "Payed at"
+: ""
+
 , "Method of payment"
 : ""
 
-, "without internal contact person"
+, "Approver"
 : ""
 
-, "Delivery Address"
-: ""
-
-, "Edit {0} \"{1}\""
-: ""
-
-, "Add new Billing Address"
-: ""
-
-, "Add new Delivery Address"
-: ""
-
-, "Apply postal address"
+, "Lead Cost Center"
 : ""
 
 , "Add New Offer"
 : ""
 
-, "Add New Order Confirmation"
+, "Clipboard"
+: ""
+
+, "Product, Products"
+: [
+  "Produto"
+ ,"Produtos"
+
+]
+, "Quantity"
 : ""
 
 , "Interval"
 : ""
 
+, "Billing Point"
+: ""
+
 , "begin"
 : ""
 
 , "end"
 : ""
 
+, "Start Date"
+: ""
+
+, "End Date"
+: ""
+
+, "Attributes"
+: ""
+
 , "Last Autobill"
 : ""
 
@@ -562,16 +382,61 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add a New Value..."
 : ""
 
-, "Clipboard"
-: ""
-
-, "Add New Division"
-: ""
-
 , "without contract"
 : ""
 
-, "without order confirmation"
+, "Add New Order Confirmation"
+: ""
+
+, "Offer, Offers"
+: [
+  ""
+ ,""
+
+]
+, "Add New Product"
+: ""
+
+, "Product Number"
+: ""
+
+, "GTIN"
+: ""
+
+, "Category"
+: "Categoria"
+
+, "Manufacturer"
+: "Fabricante"
+
+, "Purchaseprice"
+: ""
+
+, "Salesprice"
+: ""
+
+, "Lifespan start"
+: ""
+
+, "Lifespan end"
+: ""
+
+, "Enter description..."
+: "Digite a descrição..."
+
+, "Accountable"
+: ""
+
+, "Selected  {0}"
+: ""
+
+, "Select customer"
+: ""
+
+, "Customer Number"
+: ""
+
+, "Products"
 : ""
 
 , "Rebilling Invoice..."
@@ -583,7 +448,67 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Merge Invoices"
 : ""
 
-, "without Cost Center"
+, "Select supplier"
+: ""
+
+, "Add New Cost Center"
+: ""
+
+, "Remark"
+: "Observação"
+
+, "without supplier"
+: ""
+
+, "Add New Division"
+: ""
+
+, "Bill Contract"
+: ""
+
+, "Billing Contract..."
+: ""
+
+, "Bill Contract \"{0} - {1}\""
+: ""
+
+, "Select the date to generate the bill for"
+: ""
+
+, "Either street or postbox is required!"
+: ""
+
+, "Copy Customer"
+: ""
+
+, "Add New Customer"
+: ""
+
+, "Edit Customer \"{0}\""
+: ""
+
+, "Name shorthand"
+: ""
+
+, "Set as accountable"
+: ""
+
+, "Choose product for accountable"
+: ""
+
+, "Please use a decimal number here!"
+: "Favor usar número decimal aqui!"
+
+, "Positions"
+: ""
+
+, "Ok"
+: "OK"
+
+, "Export Records from these Positions"
+: ""
+
+, "without approver"
 : ""
 
 , "Auto Invoice Contract Interval"
@@ -691,6 +616,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Paypal"
 : ""
 
+, "Assets"
+: ""
+
 , "Invoice Cleared"
 : ""
 
@@ -724,89 +652,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Purchase Invoice Module"
 : ""
 
-, "manage products"
-: "gerenciar produtos"
-
-, "add, edit and delete products"
-: "adicionar, editar e apagar produtos"
-
-, "manage contracts"
-: ""
-
-, "add, edit and delete contracts"
-: ""
-
-, "manage cost centers"
-: ""
-
-, "add, edit and delete cost centers"
-: ""
-
-, "manage customers"
-: ""
-
-, "add, edit and delete customers"
-: ""
-
-, "manage suppliers"
-: ""
-
-, "add, edit and delete suppliers"
-: ""
-
-, "manage invoices"
-: ""
-
-, "add, edit and delete invoices"
-: ""
-
-, "manage divisions"
-: ""
-
-, "add, edit and delete divisions"
-: ""
-
-, "manage order confirmations"
-: ""
-
-, "add, edit and delete order confirmations"
-: ""
-
-, "manage offers"
-: ""
-
-, "add, edit and delete offers"
-: ""
-
-, "manage purchase invoices"
-: ""
-
-, "add, edit and delete purchase invoices"
-: ""
-
-, "change number of an order confirmations"
-: ""
-
-, "allow to change the number of an order confirmation on update"
-: ""
-
-, "set number of invoices"
-: ""
-
-, "allow to set the number of an invoice"
-: ""
-
-, "No Right to alter the Number"
-: ""
-
-, "You are not allowed to alter the number afterwards!"
-: ""
-
-, "Address as Billing Address in Use"
-: ""
-
-, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
-: ""
+, "You do not have admin rights on Sales"
+: "Você não tem privilégios de administrador em Vendas"
 
 , "Number duplicate"
 : ""
@@ -820,13 +667,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
 : ""
 
+, "Address as Billing Address in Use"
+: ""
+
+, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
+: ""
+
 , "Invoice is cleared already"
 : ""
 
-, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
+, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
 : ""
 
-, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
+, "No Right to alter the Number"
+: ""
+
+, "You are not allowed to alter the number afterwards!"
+: ""
+
+, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
 : ""
 
 , "Unknown Currency Code"
@@ -835,8 +694,98 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
 : ""
 
-, "You do not have admin rights on Sales"
-: "Você não tem privilégios de administrador em Vendas"
+, "Invoice Timesheet"
+: ""
+
+, "CLEARED"
+: ""
+
+, "INVOICE"
+: ""
+
+, "GENDER_Cost Center"
+: ""
+
+, "Cost Center, Cost Centers"
+: [
+  ""
+ ,""
+
+]
+, "GENDER_Offer"
+: ""
+
+, "GENDER_Invoice"
+: ""
+
+, "Sales Tax"
+: ""
+
+, "Reversal Invoice"
+: ""
+
+, "Invoice Item"
+: ""
+
+, "Is active"
+: ""
+
+, "GENDER_Contract"
+: ""
+
+, "Merge"
+: ""
+
+, "Responsible"
+: "Responsável"
+
+, "Partner"
+: "Sócio"
+
+, "Time Account"
+: ""
+
+, "GENDER_Customer)recordsName"
+: ""
+
+, "GENDER_Order Confirmation"
+: ""
+
+, "GENDER_Supplier"
+: ""
+
+, "GENDER_Division"
+: ""
+
+, "Division, Divisions"
+: [
+  "Divisão"
+ ,"Divisões"
+
+]
+, "Billing Interval"
+: ""
+
+, "Piece"
+: ""
+
+, "GENDER_Address"
+: ""
+
+, "Due at"
+: ""
+
+, "Invoice Position, Invoice Positions"
+: [
+  ""
+ ,""
+
+]
+, "Month"
+: "Mês"
+
+, "Unit"
+: ""
 
 , "The number you have tried to set is already in use!"
 : "O número que você tentou atribuir já está em uso!"
@@ -877,15 +826,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Contracts that are still running"
 : ""
 
-, "Products created by myself"
-: "Produtos criados por mim"
-
-, "Status"
-: "Situação"
-
-, "Cleared In"
-: ""
-
 , "All Suppliers"
 : ""
 
@@ -937,21 +877,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "You have to set a customer!"
 : ""
 
-, "Taxes (VAT)"
-: ""
-
-, "VAT ID"
-: ""
-
-, "Selected  {0}"
-: ""
-
-, "Add New Billing Address"
-: ""
-
-, "Add New Delivery Address"
-: ""
-
 , "Manage Products"
 : ""
 
@@ -982,6 +907,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add, edit and delete suppliers."
 : ""
 
+, "manage invoices"
+: ""
+
 , "Add, edit and delete invoices."
 : ""
 
@@ -1021,40 +949,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Allow to set the number of an invoice."
 : ""
 
+
+
+, "Supplier"
+: ""
+
+, "Invoice"
+: ""
+
+, "Contract"
+: "Contrato"
+
 , "Customer"
 : ""
 
-, "Invoice Position"
-: ""
-
-, "Offer"
-: ""
-
 , "Order Confirmation"
 : ""
 
+, "Address"
+: ""
+
+, "Purchase Invoice"
+: ""
+
 , "Product"
 : "Produto"
 
-, "Contract"
-: "Contrato"
-
-, "Invoice"
-: ""
-
-, "Address"
+, "Offer"
 : ""
 
 , "Cost Center"
 : ""
 
-, "Supplier"
-: ""
-
 , "Division"
 : "Divisão"
 
-, "Purchase Invoice"
+, "Invoice Position"
 : ""
 
 }); 
