@@ -5,352 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Sales **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:21+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ru\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "CLEARED"
-: ""
-
-, "INVOICE"
-: ""
-
-, "Invoice Timesheet"
-: ""
-
-, "Customer, Customers"
-: [
-  "Клиент"
- ,"Клиента"
- ,"Клиентов"
- ,"Клиенты"
-
-]
-, "Core Data"
-: ""
-
-, "Accounting"
-: ""
-
-, "Miscellaneous"
-: ""
-
-, "Customer Number"
-: "Номер клиента"
-
-, "Name"
-: "Название"
-
-, "Name shorthand"
-: ""
-
-, "Web"
-: "Сайт"
-
-, "Description"
-: "Описание"
-
-, "Contact Person (external)"
-: "Контактное лицо (внешнее)"
-
-, "Contact Person (internal)"
-: "Контактное лицо (внутреннее)"
-
-, "VAT No."
-: ""
-
-, "Credit Term (days)"
-: "Срок оплаты (дней)"
-
-, "Currency"
-: "Валюта"
-
-, "Currency Translation Rate"
-: "Курс валюты"
-
-, "Discount (%)"
-: "Скидка (%)"
-
-, "Delivery Addresses"
-: "Адреса доставки"
-
-, "Billing Addresses"
-: "Адреса для выставления счетов"
-
-, "Prefix"
-: ""
-
-, "Additional Prefix"
-: ""
-
-, "Street"
-: "Улица"
-
-, "Postalcode"
-: "Почтовый индекс"
-
-, "Locality"
-: "Местонахождение"
-
-, "Region"
-: "Область"
-
-, "Country"
-: "Страна"
-
-, "Postbox"
-: ""
-
-, "Invoice Position, Invoice Positions"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Type"
-: "Тип"
-
-, "Title"
-: "Заголовок"
-
-, "Month"
-: "Месяц"
-
-, "Unit"
-: ""
-
-, "Quantity"
-: "Количество"
-
-, "Offer, Offers"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Order Confirmation, Order Confirmations"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Number"
-: "Число"
-
-, "Product, Products"
-: [
-  "Продукт"
- ,"Продукты"
- ,"Продукты"
- ,"Продукты"
-
-]
-, "Contract, Contracts"
-: [
-  "Договор"
- ,"Договора"
- ,"Договоров"
- ,"Договоров"
-
-]
-, "Billing Interval"
-: ""
-
-, "Billing Point"
-: ""
-
-, "Start Date"
-: "Дата начала"
-
-, "End Date"
-: "Дата окончания"
-
-, "Invoice Item"
-: ""
-
-, "Piece"
-: ""
-
-, "Purchaseprice"
-: ""
-
-, "Salesprice"
-: ""
-
-, "Category"
-: "Категория"
-
-, "Manufacturer"
-: "Производитель"
-
-, "Accountable"
-: ""
-
-, "GTIN"
-: ""
-
-, "Lifespan start"
-: ""
-
-, "Lifespan end"
-: ""
-
-, "Is active"
-: ""
-
-, "Invoice, Invoices"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Invoice Number"
-: "Номер счёта"
-
-, "Address, Addresss"
-: [
-  "Адрес"
- ,"Адреса"
- ,"Адресов"
- ,"Адреса"
-
-]
-, "Date"
-: "Дата"
-
-, "Interval Begins"
-: "Период начинается"
-
-, "Interval Ends"
-: "Период заканчивается"
-
-, "Credit Term"
-: "Срок оплаты"
-
-, "Cost Center, Cost Centers"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Cleared"
-: "Просчитано"
-
-, "Price Net"
-: ""
-
-, "Price Tax"
-: ""
-
-, "Price Gross"
-: ""
-
-, "Sales Tax"
-: ""
-
-, "Inventory Change"
-: ""
-
-, "Positions"
-: ""
-
-, "Reversal Invoice"
-: ""
-
-, "Supplier, Suppliers"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Supplier Number"
-: "Номер поставщика"
-
-, "Division, Divisions"
-: [
-  "Подразделение"
- ,"Подразделения"
- ,"Подразделения"
- ,"Подразделения"
-
-]
-, "Number Debit"
-: ""
-
-, "Products"
-: ""
-
-, "Billing Address"
-: "Адрес для выставления счетов"
-
-, "Lead Cost Center"
-: ""
-
-, "Merge"
-: ""
-
-, "Responsible"
-: "Ответственный"
-
-, "Partner"
-: "Партнёр"
-
-, "Time Account"
-: "Временный счет"
-
-, "Remark"
-: "Примечание"
-
-, "Purchase Invoice, Purchase Invoices"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
-, "Approver"
-: ""
-
-, "Date of invoice"
-: "Дата счёта"
-
-, "Due in"
-: "Оплата через "
-
-, "Due at"
-: ""
-
-, "Payed at"
-: "Оплачено"
-
-, "Payment_method"
-: ""
-
-, "Discount until"
-: "Скидка до"
-
-, "Additional Price Gross"
-: ""
-
-, "Total Price"
-: "Итоговая цена"
-
-, "without customer"
-: "без клиента"
-
-, "Export Records from these Positions"
-: ""
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:58+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Either postalcode or postbox is required!"
 : "Необходимо указать почтовый индекс или почтовый ящик!"
@@ -367,6 +22,44 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Copy address to the clipboard"
 : "Скопировать адрес в буфер обмена"
 
+, "Supplier, Suppliers"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Core Data"
+: ""
+
+, "Supplier Number"
+: "Номер поставщика"
+
+, "Name"
+: "Название"
+
+, "Contact Person (external)"
+: "Контактное лицо (внешнее)"
+
+, "Contact Person (internal)"
+: "Контактное лицо (внутреннее)"
+
+, "Accounting"
+: ""
+
+, "VAT ID"
+: ""
+
+, "Credit Term (days)"
+: "Срок оплаты (дней)"
+
+, "Currency"
+: "Валюта"
+
+, "Currency Translation Rate"
+: "Курс валюты"
+
 , "IBAN"
 : "IBAN"
 
@@ -376,30 +69,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Postal Address"
 : "Почтовый адрес"
 
+, "Street"
+: "Улица"
+
+, "Postbox"
+: ""
+
+, "Postalcode"
+: "Почтовый индекс"
+
+, "Locality"
+: "Местонахождение"
+
+, "Region"
+: "Область"
+
+, "Country"
+: "Страна"
+
+, "Prefix"
+: ""
+
+, "Additional Prefix"
+: ""
+
+, "Miscellaneous"
+: ""
+
+, "Web"
+: "Сайт"
+
+, "Description"
+: "Описание"
+
 , "Enter description"
 : "Введите описание"
 
-, "Cancel"
-: "Отмена"
-
-, "Ok"
-: "Ok"
-
-, "Select customer"
-: ""
-
-, "Bill Contract"
-: ""
-
-, "Billing Contract..."
-: ""
-
-, "Bill Contract \"{0} - {1}\""
-: ""
-
-, "Select the date to generate the bill for"
-: ""
-
 , "total"
 : ""
 
@@ -439,12 +144,81 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
 : ""
 
+, "Price Net"
+: ""
+
+, "Taxes (VAT)"
+: ""
+
+, "Price Gross"
+: ""
+
 , "Sales Tax (percent)"
 : ""
 
+, "Inventory Change"
+: ""
+
+, "Invoice, Invoices"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Invoice Number"
+: "Номер счёта"
+
 , "automatically set..."
 : "автоматически установлено..."
 
+, "Date"
+: "Дата"
+
+, "Type"
+: "Тип"
+
+, "Contract, Contracts"
+: [
+  "Договор"
+ ,"Договора"
+ ,"Договоров"
+ ,"Договоров"
+
+]
+, "Customer, Customers"
+: [
+  "Клиент"
+ ,"Клиента"
+ ,"Клиентов"
+ ,"Клиенты"
+
+]
+, "Billing Address"
+: "Адрес для выставления счетов"
+
+, "Credit Term"
+: "Срок оплаты"
+
+, "Cleared"
+: "Просчитано"
+
+, "Interval Begins"
+: "Период начинается"
+
+, "Interval Ends"
+: "Период заканчивается"
+
+, "Select invoice"
+: "Выберите счёт"
+
+, "Total Price"
+: "Итоговая цена"
+
+, "Cancel"
+: "Отмена"
+
 , "OK"
 : "OK"
 
@@ -454,56 +228,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Euro (€)"
 : "Евро (€)"
 
-, "Set as accountable"
+, "Order Confirmation, Order Confirmations"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "without order confirmation"
 : ""
 
-, "Choose product for accountable"
+, "Number"
+: "Число"
+
+, "Title"
+: "Заголовок"
+
+, "Billing Addresses"
+: "Адреса для выставления счетов"
+
+, "Delivery Address"
+: "Адрес доставки"
+
+, "Delivery Addresses"
+: "Адреса доставки"
+
+, "Edit {0} \"{1}\""
+: "Редактировать {0} \"{1}\""
+
+, "Add New Billing Address"
 : ""
 
-, "Please use a decimal number here!"
-: "Пожалуйста, используйте десятичные цифры!"
-
-, "Enter description..."
-: "Ввести описание..."
-
-, "Add New Product"
-: "Добавить новый продукт"
-
-, "Product Number"
+, "Add New Delivery Address"
 : ""
 
-, "Select supplier"
-: "Выбрать поставщика"
-
-, "Add New Cost Center"
+, "Apply postal address"
 : ""
 
-, "Select invoice"
-: "Выберите счёт"
-
-, "Either street or postbox is required!"
+, "Number Debit"
 : ""
 
-, "Only numbers are allowed!"
-: ""
+, "Address, Addresss"
+: [
+  "Адрес"
+ ,"Адреса"
+ ,"Адресов"
+ ,"Адреса"
 
-, "Copy Customer"
-: ""
-
-, "Add New Customer"
-: ""
-
-, "Edit Customer \"{0}\""
-: ""
-
-, "without external contact person"
-: "без внешнего контактного лица"
-
-, "without approver"
-: ""
-
-, "without supplier"
-: "без поставщика"
+]
+, "without customer"
+: "без клиента"
 
 , "Copy Purchase Invoice"
 : ""
@@ -514,51 +289,88 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Edit Purchase Invoice \"{0}\""
 : ""
 
+, "Date of invoice"
+: "Дата счёта"
+
+, "Due in"
+: "Оплата через "
+
 , "Due date"
 : "Дата оплаты"
 
+, "Additional Price Gross"
+: ""
+
+, "Discount (%)"
+: "Скидка (%)"
+
+, "Purchase Invoice, Purchase Invoices"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
 , "Overdue date"
 : "Дата просрочки"
 
+, "Discount until"
+: "Скидка до"
+
 , "Dun date"
 : ""
 
+, "Payed at"
+: "Оплачено"
+
 , "Method of payment"
 : "Способ оплаты"
 
-, "without internal contact person"
+, "Approver"
 : ""
 
-, "Delivery Address"
-: "Адрес доставки"
-
-, "Edit {0} \"{1}\""
-: "Редактировать {0} \"{1}\""
-
-, "Add new Billing Address"
-: ""
-
-, "Add new Delivery Address"
-: ""
-
-, "Apply postal address"
+, "Lead Cost Center"
 : ""
 
 , "Add New Offer"
 : "Добавить новое предложение"
 
-, "Add New Order Confirmation"
-: ""
+, "Clipboard"
+: "Буфер обмена"
+
+, "Product, Products"
+: [
+  "Продукт"
+ ,"Продукты"
+ ,"Продукты"
+ ,"Продукты"
+
+]
+, "Quantity"
+: "Количество"
 
 , "Interval"
 : "Интервал"
 
+, "Billing Point"
+: ""
+
 , "begin"
 : ""
 
 , "end"
 : ""
 
+, "Start Date"
+: "Дата начала"
+
+, "End Date"
+: "Дата окончания"
+
+, "Attributes"
+: ""
+
 , "Last Autobill"
 : ""
 
@@ -586,16 +398,63 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add a New Value..."
 : ""
 
-, "Clipboard"
-: "Буфер обмена"
-
-, "Add New Division"
-: "Добавить новое подразделение"
-
 , "without contract"
 : "без контракта"
 
-, "without order confirmation"
+, "Add New Order Confirmation"
+: ""
+
+, "Offer, Offers"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Add New Product"
+: "Добавить новый продукт"
+
+, "Product Number"
+: ""
+
+, "GTIN"
+: ""
+
+, "Category"
+: "Категория"
+
+, "Manufacturer"
+: "Производитель"
+
+, "Purchaseprice"
+: ""
+
+, "Salesprice"
+: ""
+
+, "Lifespan start"
+: ""
+
+, "Lifespan end"
+: ""
+
+, "Enter description..."
+: "Ввести описание..."
+
+, "Accountable"
+: ""
+
+, "Selected  {0}"
+: ""
+
+, "Select customer"
+: ""
+
+, "Customer Number"
+: "Номер клиента"
+
+, "Products"
 : ""
 
 , "Rebilling Invoice..."
@@ -607,7 +466,67 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Merge Invoices"
 : ""
 
-, "without Cost Center"
+, "Select supplier"
+: "Выбрать поставщика"
+
+, "Add New Cost Center"
+: ""
+
+, "Remark"
+: "Примечание"
+
+, "without supplier"
+: "без поставщика"
+
+, "Add New Division"
+: "Добавить новое подразделение"
+
+, "Bill Contract"
+: ""
+
+, "Billing Contract..."
+: ""
+
+, "Bill Contract \"{0} - {1}\""
+: ""
+
+, "Select the date to generate the bill for"
+: ""
+
+, "Either street or postbox is required!"
+: ""
+
+, "Copy Customer"
+: ""
+
+, "Add New Customer"
+: ""
+
+, "Edit Customer \"{0}\""
+: ""
+
+, "Name shorthand"
+: ""
+
+, "Set as accountable"
+: ""
+
+, "Choose product for accountable"
+: ""
+
+, "Please use a decimal number here!"
+: "Пожалуйста, используйте десятичные цифры!"
+
+, "Positions"
+: ""
+
+, "Ok"
+: "Ok"
+
+, "Export Records from these Positions"
+: ""
+
+, "without approver"
 : ""
 
 , "Auto Invoice Contract Interval"
@@ -715,6 +634,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Paypal"
 : "Paypal"
 
+, "Assets"
+: ""
+
 , "Invoice Cleared"
 : ""
 
@@ -748,89 +670,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Purchase Invoice Module"
 : ""
 
-, "manage products"
-: "управление продуктами"
-
-, "add, edit and delete products"
-: "добавление, изменение и удаление продуктов"
-
-, "manage contracts"
-: "управление контрактами"
-
-, "add, edit and delete contracts"
-: "добавление, изменение и удаление контактов"
-
-, "manage cost centers"
-: ""
-
-, "add, edit and delete cost centers"
-: ""
-
-, "manage customers"
-: "управление клиентами"
-
-, "add, edit and delete customers"
-: "добавление, изменение и удаление клиентов"
-
-, "manage suppliers"
-: "управление поставщиками"
-
-, "add, edit and delete suppliers"
-: "добавление, изменение и удаление поставщиков"
-
-, "manage invoices"
-: "управление счетами"
-
-, "add, edit and delete invoices"
-: "добавление, изменение и удаление счетов"
-
-, "manage divisions"
-: ""
-
-, "add, edit and delete divisions"
-: ""
-
-, "manage order confirmations"
-: ""
-
-, "add, edit and delete order confirmations"
-: ""
-
-, "manage offers"
-: ""
-
-, "add, edit and delete offers"
-: ""
-
-, "manage purchase invoices"
-: ""
-
-, "add, edit and delete purchase invoices"
-: ""
-
-, "change number of an order confirmations"
-: ""
-
-, "allow to change the number of an order confirmation on update"
-: ""
-
-, "set number of invoices"
-: ""
-
-, "allow to set the number of an invoice"
-: ""
-
-, "No Right to alter the Number"
-: ""
-
-, "You are not allowed to alter the number afterwards!"
-: ""
-
-, "Address as Billing Address in Use"
-: ""
-
-, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
-: ""
+, "You do not have admin rights on Sales"
+: "У вас нет административных прав на Продажи"
 
 , "Number duplicate"
 : ""
@@ -844,13 +685,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
 : ""
 
+, "Address as Billing Address in Use"
+: ""
+
+, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
+: ""
+
 , "Invoice is cleared already"
 : ""
 
-, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
+, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
 : ""
 
-, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
+, "No Right to alter the Number"
+: ""
+
+, "You are not allowed to alter the number afterwards!"
+: ""
+
+, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
 : ""
 
 , "Unknown Currency Code"
@@ -859,8 +712,104 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
 : ""
 
-, "You do not have admin rights on Sales"
-: "У вас нет административных прав на Продажи"
+, "Invoice Timesheet"
+: ""
+
+, "CLEARED"
+: ""
+
+, "INVOICE"
+: ""
+
+, "GENDER_Cost Center"
+: ""
+
+, "Cost Center, Cost Centers"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "GENDER_Offer"
+: ""
+
+, "GENDER_Invoice"
+: ""
+
+, "Sales Tax"
+: ""
+
+, "Reversal Invoice"
+: ""
+
+, "Invoice Item"
+: ""
+
+, "Is active"
+: ""
+
+, "GENDER_Contract"
+: ""
+
+, "Merge"
+: ""
+
+, "Responsible"
+: "Ответственный"
+
+, "Partner"
+: "Партнёр"
+
+, "Time Account"
+: "Временный счет"
+
+, "GENDER_Customer)recordsName"
+: ""
+
+, "GENDER_Order Confirmation"
+: ""
+
+, "GENDER_Supplier"
+: ""
+
+, "GENDER_Division"
+: ""
+
+, "Division, Divisions"
+: [
+  "Подразделение"
+ ,"Подразделения"
+ ,"Подразделения"
+ ,"Подразделения"
+
+]
+, "Billing Interval"
+: ""
+
+, "Piece"
+: ""
+
+, "GENDER_Address"
+: ""
+
+, "Due at"
+: ""
+
+, "Invoice Position, Invoice Positions"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Month"
+: "Месяц"
+
+, "Unit"
+: ""
 
 , "The number you have tried to set is already in use!"
 : "Число, которое вы пытались установить, уже используется!"
@@ -901,15 +850,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Contracts that are still running"
 : ""
 
-, "Products created by myself"
-: "Созданные мной продукты"
-
-, "Status"
-: "Статус"
-
-, "Cleared In"
-: ""
-
 , "All Suppliers"
 : "Все поставщики"
 
@@ -961,21 +901,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "You have to set a customer!"
 : ""
 
-, "Taxes (VAT)"
-: ""
-
-, "VAT ID"
-: ""
-
-, "Selected  {0}"
-: ""
-
-, "Add New Billing Address"
-: ""
-
-, "Add New Delivery Address"
-: ""
-
 , "Manage Products"
 : ""
 
@@ -1006,6 +931,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add, edit and delete suppliers."
 : ""
 
+, "manage invoices"
+: "управление счетами"
+
 , "Add, edit and delete invoices."
 : ""
 
@@ -1045,40 +973,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Allow to set the number of an invoice."
 : ""
 
-, "Customer"
-: "Клиент"
 
-, "Invoice Position"
+
+
+
+
+
+
+
+
+
+, "Supplier"
 : ""
 
-, "Offer"
+, "Invoice"
 : ""
 
-, "Order Confirmation"
-: ""
-
-, "Product"
-: "Продукт"
-
 , "Contract"
 : "Договор"
 
-, "Invoice"
+, "Customer"
+: "Клиент"
+
+, "Order Confirmation"
 : ""
 
 , "Address"
 : "Адрес"
 
-, "Cost Center"
+, "Purchase Invoice"
 : ""
 
-, "Supplier"
+, "Product"
+: "Продукт"
+
+, "Offer"
+: ""
+
+, "Cost Center"
 : ""
 
 , "Division"
 : "Подразделение"
 
-, "Purchase Invoice"
+, "Invoice Position"
 : ""
 
 }); 
