@@ -5,316 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Sales **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: th\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "CLEARED"
-: ""
-
-, "INVOICE"
-: ""
-
-, "Invoice Timesheet"
-: ""
-
-, "Customer, Customers"
-: [
-  ""
-
-]
-, "Core Data"
-: ""
-
-, "Accounting"
-: ""
-
-, "Miscellaneous"
-: ""
-
-, "Customer Number"
-: ""
-
-, "Name"
-: "ชื่อ"
-
-, "Name shorthand"
-: ""
-
-, "Web"
-: ""
-
-, "Description"
-: "การอธิบาย"
-
-, "Contact Person (external)"
-: ""
-
-, "Contact Person (internal)"
-: ""
-
-, "VAT No."
-: ""
-
-, "Credit Term (days)"
-: ""
-
-, "Currency"
-: ""
-
-, "Currency Translation Rate"
-: ""
-
-, "Discount (%)"
-: ""
-
-, "Delivery Addresses"
-: ""
-
-, "Billing Addresses"
-: ""
-
-, "Prefix"
-: ""
-
-, "Additional Prefix"
-: ""
-
-, "Street"
-: ""
-
-, "Postalcode"
-: ""
-
-, "Locality"
-: ""
-
-, "Region"
-: ""
-
-, "Country"
-: ""
-
-, "Postbox"
-: ""
-
-, "Invoice Position, Invoice Positions"
-: [
-  ""
-
-]
-, "Type"
-: ""
-
-, "Title"
-: "คำนำหน้าชื่อ"
-
-, "Month"
-: ""
-
-, "Unit"
-: ""
-
-, "Quantity"
-: ""
-
-, "Offer, Offers"
-: [
-  ""
-
-]
-, "Order Confirmation, Order Confirmations"
-: [
-  ""
-
-]
-, "Number"
-: "หมายเลข"
-
-, "Product, Products"
-: [
-  "สินค้า"
-
-]
-, "Contract, Contracts"
-: [
-  "สัญญา"
-
-]
-, "Billing Interval"
-: ""
-
-, "Billing Point"
-: ""
-
-, "Start Date"
-: ""
-
-, "End Date"
-: ""
-
-, "Invoice Item"
-: ""
-
-, "Piece"
-: ""
-
-, "Purchaseprice"
-: ""
-
-, "Salesprice"
-: ""
-
-, "Category"
-: "ประเภท"
-
-, "Manufacturer"
-: "ผู้ผลิต"
-
-, "Accountable"
-: ""
-
-, "GTIN"
-: ""
-
-, "Lifespan start"
-: ""
-
-, "Lifespan end"
-: ""
-
-, "Is active"
-: ""
-
-, "Invoice, Invoices"
-: [
-  ""
-
-]
-, "Invoice Number"
-: ""
-
-, "Address, Addresss"
-: [
-  ""
-
-]
-, "Date"
-: ""
-
-, "Interval Begins"
-: ""
-
-, "Interval Ends"
-: ""
-
-, "Credit Term"
-: ""
-
-, "Cost Center, Cost Centers"
-: [
-  ""
-
-]
-, "Cleared"
-: "เคลียร์แล้ว"
-
-, "Price Net"
-: ""
-
-, "Price Tax"
-: ""
-
-, "Price Gross"
-: ""
-
-, "Sales Tax"
-: ""
-
-, "Inventory Change"
-: ""
-
-, "Positions"
-: ""
-
-, "Reversal Invoice"
-: ""
-
-, "Supplier, Suppliers"
-: [
-  ""
-
-]
-, "Supplier Number"
-: ""
-
-, "Division, Divisions"
-: [
-  "แผนก"
-
-]
-, "Number Debit"
-: ""
-
-, "Products"
-: ""
-
-, "Billing Address"
-: ""
-
-, "Lead Cost Center"
-: "ศูนย์ต้นทุนนำ"
-
-, "Merge"
-: ""
-
-, "Responsible"
-: "รับผิดชอบ"
-
-, "Partner"
-: ""
-
-, "Time Account"
-: "บัญชีเวลา"
-
-, "Remark"
-: ""
-
-, "Purchase Invoice, Purchase Invoices"
-: [
-  ""
-
-]
-, "Approver"
-: ""
-
-, "Date of invoice"
-: ""
-
-, "Due in"
-: ""
-
-, "Due at"
-: ""
-
-, "Payed at"
-: ""
-
-, "Payment_method"
-: ""
-
-, "Discount until"
-: ""
-
-, "Additional Price Gross"
-: ""
-
-, "Total Price"
-: ""
-
-, "without customer"
-: ""
-
-, "Export Records from these Positions"
-: ""
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:58+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Either postalcode or postbox is required!"
 : ""
@@ -331,6 +22,41 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Copy address to the clipboard"
 : ""
 
+, "Supplier, Suppliers"
+: [
+  ""
+
+]
+, "Core Data"
+: ""
+
+, "Supplier Number"
+: ""
+
+, "Name"
+: "ชื่อ"
+
+, "Contact Person (external)"
+: ""
+
+, "Contact Person (internal)"
+: ""
+
+, "Accounting"
+: ""
+
+, "VAT ID"
+: ""
+
+, "Credit Term (days)"
+: ""
+
+, "Currency"
+: ""
+
+, "Currency Translation Rate"
+: ""
+
 , "IBAN"
 : ""
 
@@ -340,30 +66,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Postal Address"
 : ""
 
+, "Street"
+: ""
+
+, "Postbox"
+: ""
+
+, "Postalcode"
+: ""
+
+, "Locality"
+: ""
+
+, "Region"
+: ""
+
+, "Country"
+: ""
+
+, "Prefix"
+: ""
+
+, "Additional Prefix"
+: ""
+
+, "Miscellaneous"
+: ""
+
+, "Web"
+: ""
+
+, "Description"
+: "การอธิบาย"
+
 , "Enter description"
 : ""
 
-, "Cancel"
-: "ยกเลิก"
-
-, "Ok"
-: ""
-
-, "Select customer"
-: ""
-
-, "Bill Contract"
-: ""
-
-, "Billing Contract..."
-: ""
-
-, "Bill Contract \"{0} - {1}\""
-: ""
-
-, "Select the date to generate the bill for"
-: ""
-
 , "total"
 : ""
 
@@ -403,12 +141,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
 : ""
 
+, "Price Net"
+: ""
+
+, "Taxes (VAT)"
+: ""
+
+, "Price Gross"
+: ""
+
 , "Sales Tax (percent)"
 : ""
 
+, "Inventory Change"
+: ""
+
+, "Invoice, Invoices"
+: [
+  ""
+
+]
+, "Invoice Number"
+: ""
+
 , "automatically set..."
 : ""
 
+, "Date"
+: ""
+
+, "Type"
+: ""
+
+, "Contract, Contracts"
+: [
+  "สัญญา"
+
+]
+, "Customer, Customers"
+: [
+  ""
+
+]
+, "Billing Address"
+: ""
+
+, "Credit Term"
+: ""
+
+, "Cleared"
+: "เคลียร์แล้ว"
+
+, "Interval Begins"
+: ""
+
+, "Interval Ends"
+: ""
+
+, "Select invoice"
+: ""
+
+, "Total Price"
+: ""
+
+, "Cancel"
+: "ยกเลิก"
+
 , "OK"
 : "ตกลง"
 
@@ -418,55 +216,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Euro (€)"
 : ""
 
-, "Set as accountable"
+, "Order Confirmation, Order Confirmations"
+: [
+  ""
+
+]
+, "without order confirmation"
 : ""
 
-, "Choose product for accountable"
+, "Number"
+: "หมายเลข"
+
+, "Title"
+: "คำนำหน้าชื่อ"
+
+, "Billing Addresses"
 : ""
 
-, "Please use a decimal number here!"
+, "Delivery Address"
 : ""
 
-, "Enter description..."
-: "ใส่ คำอธิบาย"
-
-, "Add New Product"
+, "Delivery Addresses"
 : ""
 
-, "Product Number"
+, "Edit {0} \"{1}\""
 : ""
 
-, "Select supplier"
+, "Add New Billing Address"
 : ""
 
-, "Add New Cost Center"
+, "Add New Delivery Address"
 : ""
 
-, "Select invoice"
+, "Apply postal address"
 : ""
 
-, "Either street or postbox is required!"
+, "Number Debit"
 : ""
 
-, "Only numbers are allowed!"
-: ""
+, "Address, Addresss"
+: [
+  ""
 
-, "Copy Customer"
-: ""
-
-, "Add New Customer"
-: ""
-
-, "Edit Customer \"{0}\""
-: ""
-
-, "without external contact person"
-: ""
-
-, "without approver"
-: ""
-
-, "without supplier"
+]
+, "without customer"
 : ""
 
 , "Copy Purchase Invoice"
@@ -478,51 +271,82 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Edit Purchase Invoice \"{0}\""
 : ""
 
+, "Date of invoice"
+: ""
+
+, "Due in"
+: ""
+
 , "Due date"
 : ""
 
+, "Additional Price Gross"
+: ""
+
+, "Discount (%)"
+: ""
+
+, "Purchase Invoice, Purchase Invoices"
+: [
+  ""
+
+]
 , "Overdue date"
 : ""
 
+, "Discount until"
+: ""
+
 , "Dun date"
 : ""
 
+, "Payed at"
+: ""
+
 , "Method of payment"
 : ""
 
-, "without internal contact person"
+, "Approver"
 : ""
 
-, "Delivery Address"
-: ""
-
-, "Edit {0} \"{1}\""
-: ""
-
-, "Add new Billing Address"
-: ""
-
-, "Add new Delivery Address"
-: ""
-
-, "Apply postal address"
-: ""
+, "Lead Cost Center"
+: "ศูนย์ต้นทุนนำ"
 
 , "Add New Offer"
 : ""
 
-, "Add New Order Confirmation"
+, "Clipboard"
+: ""
+
+, "Product, Products"
+: [
+  "สินค้า"
+
+]
+, "Quantity"
 : ""
 
 , "Interval"
 : ""
 
+, "Billing Point"
+: ""
+
 , "begin"
 : ""
 
 , "end"
 : ""
 
+, "Start Date"
+: ""
+
+, "End Date"
+: ""
+
+, "Attributes"
+: ""
+
 , "Last Autobill"
 : ""
 
@@ -550,16 +374,60 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add a New Value..."
 : ""
 
-, "Clipboard"
-: ""
-
-, "Add New Division"
-: ""
-
 , "without contract"
 : ""
 
-, "without order confirmation"
+, "Add New Order Confirmation"
+: ""
+
+, "Offer, Offers"
+: [
+  ""
+
+]
+, "Add New Product"
+: ""
+
+, "Product Number"
+: ""
+
+, "GTIN"
+: ""
+
+, "Category"
+: "ประเภท"
+
+, "Manufacturer"
+: "ผู้ผลิต"
+
+, "Purchaseprice"
+: ""
+
+, "Salesprice"
+: ""
+
+, "Lifespan start"
+: ""
+
+, "Lifespan end"
+: ""
+
+, "Enter description..."
+: "ใส่ คำอธิบาย"
+
+, "Accountable"
+: ""
+
+, "Selected  {0}"
+: ""
+
+, "Select customer"
+: ""
+
+, "Customer Number"
+: ""
+
+, "Products"
 : ""
 
 , "Rebilling Invoice..."
@@ -571,7 +439,67 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Merge Invoices"
 : ""
 
-, "without Cost Center"
+, "Select supplier"
+: ""
+
+, "Add New Cost Center"
+: ""
+
+, "Remark"
+: ""
+
+, "without supplier"
+: ""
+
+, "Add New Division"
+: ""
+
+, "Bill Contract"
+: ""
+
+, "Billing Contract..."
+: ""
+
+, "Bill Contract \"{0} - {1}\""
+: ""
+
+, "Select the date to generate the bill for"
+: ""
+
+, "Either street or postbox is required!"
+: ""
+
+, "Copy Customer"
+: ""
+
+, "Add New Customer"
+: ""
+
+, "Edit Customer \"{0}\""
+: ""
+
+, "Name shorthand"
+: ""
+
+, "Set as accountable"
+: ""
+
+, "Choose product for accountable"
+: ""
+
+, "Please use a decimal number here!"
+: ""
+
+, "Positions"
+: ""
+
+, "Ok"
+: ""
+
+, "Export Records from these Positions"
+: ""
+
+, "without approver"
 : ""
 
 , "Auto Invoice Contract Interval"
@@ -679,6 +607,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Paypal"
 : ""
 
+, "Assets"
+: ""
+
 , "Invoice Cleared"
 : ""
 
@@ -712,89 +643,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Purchase Invoice Module"
 : ""
 
-, "manage products"
-: "จัดการสินค้า"
-
-, "add, edit and delete products"
-: "เพิ่ม แก้ไข และลบสินค้า"
-
-, "manage contracts"
-: ""
-
-, "add, edit and delete contracts"
-: ""
-
-, "manage cost centers"
-: "จัดการ ศูนย์ต้นทุน"
-
-, "add, edit and delete cost centers"
-: "เพิ่ม แก้ไข และลบค่าศูนย์ต้นทุน"
-
-, "manage customers"
-: ""
-
-, "add, edit and delete customers"
-: ""
-
-, "manage suppliers"
-: ""
-
-, "add, edit and delete suppliers"
-: ""
-
-, "manage invoices"
-: ""
-
-, "add, edit and delete invoices"
-: ""
-
-, "manage divisions"
-: ""
-
-, "add, edit and delete divisions"
-: ""
-
-, "manage order confirmations"
-: ""
-
-, "add, edit and delete order confirmations"
-: ""
-
-, "manage offers"
-: ""
-
-, "add, edit and delete offers"
-: ""
-
-, "manage purchase invoices"
-: ""
-
-, "add, edit and delete purchase invoices"
-: ""
-
-, "change number of an order confirmations"
-: ""
-
-, "allow to change the number of an order confirmation on update"
-: ""
-
-, "set number of invoices"
-: ""
-
-, "allow to set the number of an invoice"
-: ""
-
-, "No Right to alter the Number"
-: ""
-
-, "You are not allowed to alter the number afterwards!"
-: ""
-
-, "Address as Billing Address in Use"
-: ""
-
-, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
-: ""
+, "You do not have admin rights on Sales"
+: "คุณไม่มีสิทธิ์ของผู้ดูแลระบบใน Sales"
 
 , "Number duplicate"
 : ""
@@ -808,13 +658,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
 : ""
 
+, "Address as Billing Address in Use"
+: ""
+
+, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
+: ""
+
 , "Invoice is cleared already"
 : ""
 
-, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
+, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
 : ""
 
-, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
+, "No Right to alter the Number"
+: ""
+
+, "You are not allowed to alter the number afterwards!"
+: ""
+
+, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
 : ""
 
 , "Unknown Currency Code"
@@ -823,8 +685,95 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
 : ""
 
-, "You do not have admin rights on Sales"
-: "คุณไม่มีสิทธิ์ของผู้ดูแลระบบใน Sales"
+, "Invoice Timesheet"
+: ""
+
+, "CLEARED"
+: ""
+
+, "INVOICE"
+: ""
+
+, "GENDER_Cost Center"
+: ""
+
+, "Cost Center, Cost Centers"
+: [
+  ""
+
+]
+, "GENDER_Offer"
+: ""
+
+, "GENDER_Invoice"
+: ""
+
+, "Sales Tax"
+: ""
+
+, "Reversal Invoice"
+: ""
+
+, "Invoice Item"
+: ""
+
+, "Is active"
+: ""
+
+, "GENDER_Contract"
+: ""
+
+, "Merge"
+: ""
+
+, "Responsible"
+: "รับผิดชอบ"
+
+, "Partner"
+: ""
+
+, "Time Account"
+: "บัญชีเวลา"
+
+, "GENDER_Customer)recordsName"
+: ""
+
+, "GENDER_Order Confirmation"
+: ""
+
+, "GENDER_Supplier"
+: ""
+
+, "GENDER_Division"
+: ""
+
+, "Division, Divisions"
+: [
+  "แผนก"
+
+]
+, "Billing Interval"
+: ""
+
+, "Piece"
+: ""
+
+, "GENDER_Address"
+: ""
+
+, "Due at"
+: ""
+
+, "Invoice Position, Invoice Positions"
+: [
+  ""
+
+]
+, "Month"
+: ""
+
+, "Unit"
+: ""
 
 , "The number you have tried to set is already in use!"
 : ""
@@ -865,15 +814,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Contracts that are still running"
 : ""
 
-, "Products created by myself"
-: "สินค้าที่สร้างขึ้นโดยฉันเอง"
-
-, "Status"
-: "สถานะ"
-
-, "Cleared In"
-: ""
-
 , "All Suppliers"
 : ""
 
@@ -925,21 +865,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "You have to set a customer!"
 : ""
 
-, "Taxes (VAT)"
-: ""
-
-, "VAT ID"
-: ""
-
-, "Selected  {0}"
-: ""
-
-, "Add New Billing Address"
-: ""
-
-, "Add New Delivery Address"
-: ""
-
 , "Manage Products"
 : ""
 
@@ -970,6 +895,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add, edit and delete suppliers."
 : ""
 
+, "manage invoices"
+: ""
+
 , "Add, edit and delete invoices."
 : ""
 
@@ -1009,40 +937,44 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Allow to set the number of an invoice."
 : ""
 
+
+
+
+
+, "Supplier"
+: ""
+
+, "Invoice"
+: ""
+
+, "Contract"
+: "สัญญา"
+
 , "Customer"
 : ""
 
-, "Invoice Position"
-: ""
-
-, "Offer"
-: ""
-
 , "Order Confirmation"
 : ""
 
+, "Address"
+: ""
+
+, "Purchase Invoice"
+: ""
+
 , "Product"
 : "สินค้า"
 
-, "Contract"
-: "สัญญา"
-
-, "Invoice"
-: ""
-
-, "Address"
+, "Offer"
 : ""
 
 , "Cost Center"
 : ""
 
-, "Supplier"
-: ""
-
 , "Division"
 : "แผนก"
 
-, "Purchase Invoice"
+, "Invoice Position"
 : ""
 
 }); 
