@@ -5,316 +5,7 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Sales **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: vi\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
-
-, "CLEARED"
-: "ĐÃ XÓA"
-
-, "INVOICE"
-: "HÓA ĐƠN"
-
-, "Invoice Timesheet"
-: ""
-
-, "Customer, Customers"
-: [
-  ""
-
-]
-, "Core Data"
-: ""
-
-, "Accounting"
-: ""
-
-, "Miscellaneous"
-: ""
-
-, "Customer Number"
-: ""
-
-, "Name"
-: "Tên"
-
-, "Name shorthand"
-: ""
-
-, "Web"
-: ""
-
-, "Description"
-: "Mo tả"
-
-, "Contact Person (external)"
-: ""
-
-, "Contact Person (internal)"
-: ""
-
-, "VAT No."
-: ""
-
-, "Credit Term (days)"
-: ""
-
-, "Currency"
-: ""
-
-, "Currency Translation Rate"
-: ""
-
-, "Discount (%)"
-: ""
-
-, "Delivery Addresses"
-: ""
-
-, "Billing Addresses"
-: ""
-
-, "Prefix"
-: ""
-
-, "Additional Prefix"
-: ""
-
-, "Street"
-: ""
-
-, "Postalcode"
-: ""
-
-, "Locality"
-: ""
-
-, "Region"
-: ""
-
-, "Country"
-: ""
-
-, "Postbox"
-: ""
-
-, "Invoice Position, Invoice Positions"
-: [
-  ""
-
-]
-, "Type"
-: ""
-
-, "Title"
-: "Tiêu đề"
-
-, "Month"
-: ""
-
-, "Unit"
-: ""
-
-, "Quantity"
-: ""
-
-, "Offer, Offers"
-: [
-  ""
-
-]
-, "Order Confirmation, Order Confirmations"
-: [
-  ""
-
-]
-, "Number"
-: "Số"
-
-, "Product, Products"
-: [
-  "one:Sản phẩm\nother:Sản phẩm"
-
-]
-, "Contract, Contracts"
-: [
-  "one:Hợp đồng\nother:Hợp đồng"
-
-]
-, "Billing Interval"
-: ""
-
-, "Billing Point"
-: ""
-
-, "Start Date"
-: ""
-
-, "End Date"
-: ""
-
-, "Invoice Item"
-: ""
-
-, "Piece"
-: ""
-
-, "Purchaseprice"
-: ""
-
-, "Salesprice"
-: ""
-
-, "Category"
-: "Danh mục"
-
-, "Manufacturer"
-: "Nhà sản xuất"
-
-, "Accountable"
-: ""
-
-, "GTIN"
-: ""
-
-, "Lifespan start"
-: ""
-
-, "Lifespan end"
-: ""
-
-, "Is active"
-: ""
-
-, "Invoice, Invoices"
-: [
-  ""
-
-]
-, "Invoice Number"
-: ""
-
-, "Address, Addresss"
-: [
-  ""
-
-]
-, "Date"
-: ""
-
-, "Interval Begins"
-: ""
-
-, "Interval Ends"
-: ""
-
-, "Credit Term"
-: ""
-
-, "Cost Center, Cost Centers"
-: [
-  ""
-
-]
-, "Cleared"
-: "Đã xóa"
-
-, "Price Net"
-: ""
-
-, "Price Tax"
-: ""
-
-, "Price Gross"
-: ""
-
-, "Sales Tax"
-: ""
-
-, "Inventory Change"
-: ""
-
-, "Positions"
-: ""
-
-, "Reversal Invoice"
-: ""
-
-, "Supplier, Suppliers"
-: [
-  ""
-
-]
-, "Supplier Number"
-: ""
-
-, "Division, Divisions"
-: [
-  "one: Bộ phận\nother: Bộ phận"
-
-]
-, "Number Debit"
-: ""
-
-, "Products"
-: ""
-
-, "Billing Address"
-: ""
-
-, "Lead Cost Center"
-: "Trung tâm giá"
-
-, "Merge"
-: ""
-
-, "Responsible"
-: "Chịu trách nhiệm"
-
-, "Partner"
-: "Đối tác"
-
-, "Time Account"
-: "Tài khoản theo thời gian"
-
-, "Remark"
-: "Đánh dấu lại"
-
-, "Purchase Invoice, Purchase Invoices"
-: [
-  ""
-
-]
-, "Approver"
-: ""
-
-, "Date of invoice"
-: ""
-
-, "Due in"
-: ""
-
-, "Due at"
-: ""
-
-, "Payed at"
-: ""
-
-, "Payment_method"
-: ""
-
-, "Discount until"
-: ""
-
-, "Additional Price Gross"
-: ""
-
-, "Total Price"
-: ""
-
-, "without customer"
-: ""
-
-, "Export Records from these Positions"
-: ""
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:58+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
 , "Either postalcode or postbox is required!"
 : ""
@@ -331,6 +22,41 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Copy address to the clipboard"
 : ""
 
+, "Supplier, Suppliers"
+: [
+  ""
+
+]
+, "Core Data"
+: ""
+
+, "Supplier Number"
+: ""
+
+, "Name"
+: "Tên"
+
+, "Contact Person (external)"
+: ""
+
+, "Contact Person (internal)"
+: ""
+
+, "Accounting"
+: ""
+
+, "VAT ID"
+: ""
+
+, "Credit Term (days)"
+: ""
+
+, "Currency"
+: ""
+
+, "Currency Translation Rate"
+: ""
+
 , "IBAN"
 : ""
 
@@ -340,30 +66,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Postal Address"
 : ""
 
+, "Street"
+: ""
+
+, "Postbox"
+: ""
+
+, "Postalcode"
+: ""
+
+, "Locality"
+: ""
+
+, "Region"
+: ""
+
+, "Country"
+: ""
+
+, "Prefix"
+: ""
+
+, "Additional Prefix"
+: ""
+
+, "Miscellaneous"
+: ""
+
+, "Web"
+: ""
+
+, "Description"
+: "Mo tả"
+
 , "Enter description"
 : ""
 
-, "Cancel"
-: "Hủy"
-
-, "Ok"
-: ""
-
-, "Select customer"
-: ""
-
-, "Bill Contract"
-: ""
-
-, "Billing Contract..."
-: ""
-
-, "Bill Contract \"{0} - {1}\""
-: ""
-
-, "Select the date to generate the bill for"
-: ""
-
 , "total"
 : ""
 
@@ -403,12 +141,72 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
 : ""
 
+, "Price Net"
+: ""
+
+, "Taxes (VAT)"
+: ""
+
+, "Price Gross"
+: ""
+
 , "Sales Tax (percent)"
 : ""
 
+, "Inventory Change"
+: ""
+
+, "Invoice, Invoices"
+: [
+  ""
+
+]
+, "Invoice Number"
+: ""
+
 , "automatically set..."
 : ""
 
+, "Date"
+: ""
+
+, "Type"
+: ""
+
+, "Contract, Contracts"
+: [
+  "one:Hợp đồng\nother:Hợp đồng"
+
+]
+, "Customer, Customers"
+: [
+  ""
+
+]
+, "Billing Address"
+: ""
+
+, "Credit Term"
+: ""
+
+, "Cleared"
+: "Đã xóa"
+
+, "Interval Begins"
+: ""
+
+, "Interval Ends"
+: ""
+
+, "Select invoice"
+: ""
+
+, "Total Price"
+: ""
+
+, "Cancel"
+: "Hủy"
+
 , "OK"
 : "OK"
 
@@ -418,55 +216,50 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Euro (€)"
 : ""
 
-, "Set as accountable"
+, "Order Confirmation, Order Confirmations"
+: [
+  ""
+
+]
+, "without order confirmation"
 : ""
 
-, "Choose product for accountable"
+, "Number"
+: "Số"
+
+, "Title"
+: "Tiêu đề"
+
+, "Billing Addresses"
 : ""
 
-, "Please use a decimal number here!"
-: "Xin sử dụng 1 số thập phân tại đây!"
-
-, "Enter description..."
-: "Nhập vào mô tả"
-
-, "Add New Product"
+, "Delivery Address"
 : ""
 
-, "Product Number"
+, "Delivery Addresses"
 : ""
 
-, "Select supplier"
+, "Edit {0} \"{1}\""
 : ""
 
-, "Add New Cost Center"
+, "Add New Billing Address"
 : ""
 
-, "Select invoice"
+, "Add New Delivery Address"
 : ""
 
-, "Either street or postbox is required!"
+, "Apply postal address"
 : ""
 
-, "Only numbers are allowed!"
+, "Number Debit"
 : ""
 
-, "Copy Customer"
-: ""
+, "Address, Addresss"
+: [
+  ""
 
-, "Add New Customer"
-: ""
-
-, "Edit Customer \"{0}\""
-: ""
-
-, "without external contact person"
-: ""
-
-, "without approver"
-: ""
-
-, "without supplier"
+]
+, "without customer"
 : ""
 
 , "Copy Purchase Invoice"
@@ -478,51 +271,82 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Edit Purchase Invoice \"{0}\""
 : ""
 
+, "Date of invoice"
+: ""
+
+, "Due in"
+: ""
+
 , "Due date"
 : ""
 
+, "Additional Price Gross"
+: ""
+
+, "Discount (%)"
+: ""
+
+, "Purchase Invoice, Purchase Invoices"
+: [
+  ""
+
+]
 , "Overdue date"
 : ""
 
+, "Discount until"
+: ""
+
 , "Dun date"
 : ""
 
+, "Payed at"
+: ""
+
 , "Method of payment"
 : ""
 
-, "without internal contact person"
+, "Approver"
 : ""
 
-, "Delivery Address"
-: ""
-
-, "Edit {0} \"{1}\""
-: ""
-
-, "Add new Billing Address"
-: ""
-
-, "Add new Delivery Address"
-: ""
-
-, "Apply postal address"
-: ""
+, "Lead Cost Center"
+: "Trung tâm giá"
 
 , "Add New Offer"
 : ""
 
-, "Add New Order Confirmation"
+, "Clipboard"
+: ""
+
+, "Product, Products"
+: [
+  "one:Sản phẩm\nother:Sản phẩm"
+
+]
+, "Quantity"
 : ""
 
 , "Interval"
 : ""
 
+, "Billing Point"
+: ""
+
 , "begin"
 : ""
 
 , "end"
 : ""
 
+, "Start Date"
+: ""
+
+, "End Date"
+: ""
+
+, "Attributes"
+: ""
+
 , "Last Autobill"
 : ""
 
@@ -550,16 +374,60 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add a New Value..."
 : ""
 
-, "Clipboard"
-: ""
-
-, "Add New Division"
-: ""
-
 , "without contract"
 : ""
 
-, "without order confirmation"
+, "Add New Order Confirmation"
+: ""
+
+, "Offer, Offers"
+: [
+  ""
+
+]
+, "Add New Product"
+: ""
+
+, "Product Number"
+: ""
+
+, "GTIN"
+: ""
+
+, "Category"
+: "Danh mục"
+
+, "Manufacturer"
+: "Nhà sản xuất"
+
+, "Purchaseprice"
+: ""
+
+, "Salesprice"
+: ""
+
+, "Lifespan start"
+: ""
+
+, "Lifespan end"
+: ""
+
+, "Enter description..."
+: "Nhập vào mô tả"
+
+, "Accountable"
+: ""
+
+, "Selected  {0}"
+: ""
+
+, "Select customer"
+: ""
+
+, "Customer Number"
+: ""
+
+, "Products"
 : ""
 
 , "Rebilling Invoice..."
@@ -571,7 +439,67 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Merge Invoices"
 : ""
 
-, "without Cost Center"
+, "Select supplier"
+: ""
+
+, "Add New Cost Center"
+: ""
+
+, "Remark"
+: "Đánh dấu lại"
+
+, "without supplier"
+: ""
+
+, "Add New Division"
+: ""
+
+, "Bill Contract"
+: ""
+
+, "Billing Contract..."
+: ""
+
+, "Bill Contract \"{0} - {1}\""
+: ""
+
+, "Select the date to generate the bill for"
+: ""
+
+, "Either street or postbox is required!"
+: ""
+
+, "Copy Customer"
+: ""
+
+, "Add New Customer"
+: ""
+
+, "Edit Customer \"{0}\""
+: ""
+
+, "Name shorthand"
+: ""
+
+, "Set as accountable"
+: ""
+
+, "Choose product for accountable"
+: ""
+
+, "Please use a decimal number here!"
+: "Xin sử dụng 1 số thập phân tại đây!"
+
+, "Positions"
+: ""
+
+, "Ok"
+: ""
+
+, "Export Records from these Positions"
+: ""
+
+, "without approver"
 : ""
 
 , "Auto Invoice Contract Interval"
@@ -679,6 +607,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Paypal"
 : ""
 
+, "Assets"
+: ""
+
 , "Invoice Cleared"
 : ""
 
@@ -712,89 +643,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Purchase Invoice Module"
 : ""
 
-, "manage products"
-: "quản lý sản phẩm"
-
-, "add, edit and delete products"
-: "thêm, xóa, sửa sản phẩm"
-
-, "manage contracts"
-: ""
-
-, "add, edit and delete contracts"
-: ""
-
-, "manage cost centers"
-: ""
-
-, "add, edit and delete cost centers"
-: ""
-
-, "manage customers"
-: ""
-
-, "add, edit and delete customers"
-: ""
-
-, "manage suppliers"
-: ""
-
-, "add, edit and delete suppliers"
-: ""
-
-, "manage invoices"
-: ""
-
-, "add, edit and delete invoices"
-: ""
-
-, "manage divisions"
-: ""
-
-, "add, edit and delete divisions"
-: ""
-
-, "manage order confirmations"
-: ""
-
-, "add, edit and delete order confirmations"
-: ""
-
-, "manage offers"
-: ""
-
-, "add, edit and delete offers"
-: ""
-
-, "manage purchase invoices"
-: ""
-
-, "add, edit and delete purchase invoices"
-: ""
-
-, "change number of an order confirmations"
-: ""
-
-, "allow to change the number of an order confirmation on update"
-: ""
-
-, "set number of invoices"
-: ""
-
-, "allow to set the number of an invoice"
-: ""
-
-, "No Right to alter the Number"
-: ""
-
-, "You are not allowed to alter the number afterwards!"
-: ""
-
-, "Address as Billing Address in Use"
-: ""
-
-, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
-: ""
+, "You do not have admin rights on Sales"
+: "Bạn không có quyền quản trị trên hệ thống Kinh doanh"
 
 , "Number duplicate"
 : ""
@@ -808,13 +658,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
 : ""
 
+, "Address as Billing Address in Use"
+: ""
+
+, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
+: ""
+
 , "Invoice is cleared already"
 : ""
 
-, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
+, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
 : ""
 
-, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
+, "No Right to alter the Number"
+: ""
+
+, "You are not allowed to alter the number afterwards!"
+: ""
+
+, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
 : ""
 
 , "Unknown Currency Code"
@@ -823,8 +685,95 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
 : ""
 
-, "You do not have admin rights on Sales"
-: "Bạn không có quyền quản trị trên hệ thống Kinh doanh"
+, "Invoice Timesheet"
+: ""
+
+, "CLEARED"
+: "ĐÃ XÓA"
+
+, "INVOICE"
+: "HÓA ĐƠN"
+
+, "GENDER_Cost Center"
+: ""
+
+, "Cost Center, Cost Centers"
+: [
+  ""
+
+]
+, "GENDER_Offer"
+: ""
+
+, "GENDER_Invoice"
+: ""
+
+, "Sales Tax"
+: ""
+
+, "Reversal Invoice"
+: ""
+
+, "Invoice Item"
+: ""
+
+, "Is active"
+: ""
+
+, "GENDER_Contract"
+: ""
+
+, "Merge"
+: ""
+
+, "Responsible"
+: "Chịu trách nhiệm"
+
+, "Partner"
+: "Đối tác"
+
+, "Time Account"
+: "Tài khoản theo thời gian"
+
+, "GENDER_Customer)recordsName"
+: ""
+
+, "GENDER_Order Confirmation"
+: ""
+
+, "GENDER_Supplier"
+: ""
+
+, "GENDER_Division"
+: ""
+
+, "Division, Divisions"
+: [
+  "one: Bộ phận\nother: Bộ phận"
+
+]
+, "Billing Interval"
+: ""
+
+, "Piece"
+: ""
+
+, "GENDER_Address"
+: ""
+
+, "Due at"
+: ""
+
+, "Invoice Position, Invoice Positions"
+: [
+  ""
+
+]
+, "Month"
+: ""
+
+, "Unit"
+: ""
 
 , "The number you have tried to set is already in use!"
 : "Số bạn đang đặt đã tồn tại!"
@@ -865,15 +814,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Contracts that are still running"
 : ""
 
-, "Products created by myself"
-: "Sản phẩm tạo bởi tôi"
-
-, "Status"
-: "Trạng thái"
-
-, "Cleared In"
-: ""
-
 , "All Suppliers"
 : ""
 
@@ -925,21 +865,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "You have to set a customer!"
 : ""
 
-, "Taxes (VAT)"
-: ""
-
-, "VAT ID"
-: ""
-
-, "Selected  {0}"
-: ""
-
-, "Add New Billing Address"
-: ""
-
-, "Add New Delivery Address"
-: ""
-
 , "Manage Products"
 : ""
 
@@ -970,6 +895,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Add, edit and delete suppliers."
 : ""
 
+, "manage invoices"
+: ""
+
 , "Add, edit and delete invoices."
 : ""
 
@@ -1009,40 +937,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
 , "Allow to set the number of an invoice."
 : ""
 
+
+
+, "Supplier"
+: ""
+
+, "Invoice"
+: ""
+
+, "Contract"
+: "one:Hợp đồng\nother:Hợp đồng"
+
 , "Customer"
 : ""
 
-, "Invoice Position"
-: ""
-
-, "Offer"
-: ""
-
 , "Order Confirmation"
 : ""
 
+, "Address"
+: ""
+
+, "Purchase Invoice"
+: ""
+
 , "Product"
 : "one:Sản phẩm\nother:Sản phẩm"
 
-, "Contract"
-: "one:Hợp đồng\nother:Hợp đồng"
-
-, "Invoice"
-: ""
-
-, "Address"
+, "Offer"
 : ""
 
 , "Cost Center"
 : ""
 
-, "Supplier"
-: ""
-
 , "Division"
 : "one: Bộ phận\nother: Bộ phận"
 
-, "Purchase Invoice"
+, "Invoice Position"
 : ""
 
 }); 
