@@ -5,190 +5,31 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Setup **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "I have read the license agreement and accept it"
-: "Přečetl(a) jsem si licenční ujednání a souhlasím"
+, "Performing Environment Checks..."
+: "Provádím test prostředí"
 
-, "License Agreement"
-: "Licenční ujednání"
-
-, "I have read the privacy agreement and accept it"
-: "Přečetl(a) jsem si ujednání o ochraně soukromí a souhlasím"
-
-, "Privacy Agreement"
-: "Ujednání o ochraně soukromí"
-
-, "Accept Terms and Conditions"
-: "Přijmout podmínky"
-
-, "Backend"
-: "Backend"
-
-, "Standard IMAP"
-: "Standardní IMAP"
-
-, "Standard SMTP"
-: "Standardní SMTP"
-
-, "Imap"
-: "IMAP"
-
-, "Hostname"
-: "Název nebo adresa počítače"
-
-, "Username"
-: "Uživatelské jméno"
-
-, "Password"
-: "Heslo"
-
-, "Port"
-: "Port"
-
-, "Secure Connection"
-: "Zabezpečení připojení"
-
-, "None"
-: "Žádné"
-
-, "TLS"
-: "TLS"
-
-, "SSL"
-: "SSL"
-
-, "Verify peer Certificate"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
 : ""
 
-, "Use system account"
-: "Použít systémový účet"
+, "Check"
+: "Kontrola"
 
-, "No"
-: "Ne"
+, "Result"
+: "Výsledek"
 
-, "Yes"
-: "Ano"
-
-, "Append domain to login name"
-: "Připojit doménu k přihlašovacímu jménu"
-
-, "Use email address as login name"
+, "Message"
 : ""
 
-, "Cyrus Admin"
-: ""
+, "Run setup tests"
+: "Spustit instalační testy"
 
-, "Cyrus Admin Password"
-: ""
+, "Ignore setup tests"
+: "Ignorovat instalační testy"
 
-, "Use proxy auth"
-: ""
-
-, "Smtp"
-: "SMTP"
-
-, "Authentication"
-: "Autentikace"
-
-, "Login"
-: "Přihlášení"
-
-, "Plain"
-: "Prosté"
-
-, "Primary Domain"
-: "Primární doména"
-
-, "Secondary Domains (comma separated)"
-: "Sekundární domény (oddělené čárkou)"
-
-, "Notifications service address"
-: "Adresa služby pro zasílání upozornění"
-
-, "Notification Username"
-: "Uživatelské jméno pro upozornění"
-
-, "Notification Password"
-: "Heslo pro upozornění"
-
-, "Notifications local client (hostname or IP address)"
-: ""
-
-, "SIEVE"
-: ""
-
-, "MySql Hostname"
-: "Adresa MySQL serveru"
-
-, "MySql Database"
-: "Název MySQL databáze"
-
-, "MySql User"
-: "Uživatel MySQL"
-
-, "MySql Password"
-: "Heslo k MySQL databázi"
-
-, "MySql Port"
-: "Port MySQL"
-
-, "User or UID"
-: ""
-
-, "Group or GID"
-: ""
-
-, "Home Template"
-: ""
-
-, "Password Scheme"
-: ""
-
-, "PLAIN-MD5"
-: ""
-
-, "MD5-CRYPT"
-: ""
-
-, "SHA1"
-: ""
-
-, "SHA256"
-: ""
-
-, "SSHA256"
-: ""
-
-, "SHA512"
-: ""
-
-, "SSHA512"
-: ""
-
-, "PLAIN"
-: ""
-
-, "Terms and Conditions"
-: "Podmínky a ujednání"
-
-, "Setup Checks"
-: "Instalační kontroly"
-
-, "Config Manager"
-: "Správce konfigurace"
-
-, "Authentication/Accounts"
-: "Autentikace/Účty"
-
-, "Email"
-: "Email"
-
-, "Application Manager"
-: "Správce aplikací"
-
-, "Setup"
-: ""
+, "Install application"
+: "Instalovat aplikaci"
 
 , "Name"
 : "Název"
@@ -211,14 +52,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : "Závisí na"
 
-, "Install application"
-: "Instalovat aplikaci"
-
 , "Uninstall application"
 : "Odinstalovat aplikaci"
 
-, "Update application"
-: "Aktualizovat aplikaci"
+, "Update applications"
+: ""
 
 , "Go to {0} login"
 : "Jít na příhlášení do {0}"
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : "Přechod z SQL na LDAP smaže všechny stávající uživatelské účty, skupiny a role. Opravdu chcete změnit backend pro uložení účtů na LDAP?"
 
+, "Backend"
+: "Backend"
+
 , "TLS client certificate"
 : ""
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : "Zkusit rozdělit uživatelské jméno"
 
+, "Yes"
+: "Ano"
+
+, "No"
+: "Ne"
+
 , "Account canonical form"
 : "Kanonická forma účtu"
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : "Přihlašovací jméno"
 
+, "Password"
+: "Heslo"
+
 , "Bind requires DN"
 : "Připojení vyžaduje DN"
 
 , "Start TLS"
 : ""
 
+, "SSL"
+: "SSL"
+
+, "Port"
+: "Port"
+
 , "Base DN"
 : "Základní DN"
 
 , "Search filter"
 : "Vyhledávací filtr"
 
+, "Hostname"
+: "Název nebo adresa počítače"
+
+, "Secure Connection"
+: "Zabezpečení připojení"
+
+, "None"
+: "Žádné"
+
+, "TLS"
+: "TLS"
+
+, "Append domain to login name"
+: "Připojit doménu k přihlašovacímu jménu"
+
 , "Certificate validation"
 : ""
 
@@ -454,41 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : "Nemělo by být prázdné"
 
-, "Performing Environment Checks..."
-: "Provádím test prostředí"
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: ""
-
-, "Check"
-: "Kontrola"
-
-, "Result"
-: "Výsledek"
-
-, "Error"
-: "Chyba"
-
-, "Run setup tests"
-: "Spustit instalační testy"
-
-, "Ignore setup tests"
-: "Ignorovat instalační testy"
-
-, "Application, Applications"
-: [
-  "Aplikace"
- ,"Aplikace"
- ,"Aplikací"
- ,"Aplikací"
-
-]
 , "File"
 : ""
 
 , "Setup Authentication"
 : "Přihlášení do instalačního programu"
 
+, "Username"
+: "Uživatelské jméno"
+
 , "Database"
 : "Databáze"
 
@@ -555,6 +400,162 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : ""
 
+, "Standard IMAP"
+: "Standardní IMAP"
+
+, "Standard SMTP"
+: "Standardní SMTP"
+
+, "Imap"
+: "IMAP"
+
+, "Verify peer Certificate"
+: ""
+
+, "Use system account"
+: "Použít systémový účet"
+
+, "Use email address as login name"
+: ""
+
+, "Cyrus Admin"
+: ""
+
+, "Cyrus Admin Password"
+: ""
+
+, "Use proxy auth"
+: ""
+
+, "Smtp"
+: "SMTP"
+
+, "Authentication"
+: "Autentikace"
+
+, "Login"
+: "Přihlášení"
+
+, "Plain"
+: "Prosté"
+
+, "Primary Domain"
+: "Primární doména"
+
+, "Secondary Domains (comma separated)"
+: "Sekundární domény (oddělené čárkou)"
+
+, "Notifications service address"
+: "Adresa služby pro zasílání upozornění"
+
+, "Notification Username"
+: "Uživatelské jméno pro upozornění"
+
+, "Notification Password"
+: "Heslo pro upozornění"
+
+, "Notifications local client (hostname or IP address)"
+: ""
+
+, "SIEVE"
+: ""
+
+, "MySql Hostname"
+: "Adresa MySQL serveru"
+
+, "MySql Database"
+: "Název MySQL databáze"
+
+, "MySql User"
+: "Uživatel MySQL"
+
+, "MySql Password"
+: "Heslo k MySQL databázi"
+
+, "MySql Port"
+: "Port MySQL"
+
+, "User or UID"
+: ""
+
+, "Group or GID"
+: ""
+
+, "Home Template"
+: ""
+
+, "Password Scheme"
+: ""
+
+, "PLAIN-MD5"
+: ""
+
+, "MD5-CRYPT"
+: ""
+
+, "SHA1"
+: ""
+
+, "SHA256"
+: ""
+
+, "SSHA256"
+: ""
+
+, "SHA512"
+: ""
+
+, "SSHA512"
+: ""
+
+, "PLAIN"
+: ""
+
+, "Setup"
+: ""
+
+, "Application, Applications"
+: [
+  "Aplikace"
+ ,"Aplikace"
+ ,"Aplikací"
+ ,"Aplikací"
+
+]
+, "Terms and Conditions"
+: "Podmínky a ujednání"
+
+, "Setup Checks"
+: "Instalační kontroly"
+
+, "Config Manager"
+: "Správce konfigurace"
+
+, "Authentication/Accounts"
+: "Autentikace/Účty"
+
+, "Email"
+: "Email"
+
+, "Application Manager"
+: "Správce aplikací"
+
+, "I have read the license agreement and accept it"
+: "Přečetl(a) jsem si licenční ujednání a souhlasím"
+
+, "License Agreement"
+: "Licenční ujednání"
+
+, "I have read the privacy agreement and accept it"
+: "Přečetl(a) jsem si ujednání o ochraně soukromí a souhlasím"
+
+, "Privacy Agreement"
+: "Ujednání o ochraně soukromí"
+
+, "Accept Terms and Conditions"
+: "Přijmout podmínky"
+
+
 , "Application"
 : "Aplikace"
 
