@@ -19,8 +19,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Result"
 : "Ergebnis"
 
-, "Error"
-: "Fehler"
+, "Message"
+: "Informationen"
 
 , "Run setup tests"
 : "Setup Tests ausführen"
@@ -31,39 +31,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Install application"
 : "Anwendung installieren"
 
-, "Terms and Conditions"
-: "Bedingungen und Konditionen"
-
-, "Setup Checks"
-: "Setup Tests"
-
-, "Config Manager"
-: "Konfigurations-Verwaltung"
-
-, "Authentication/Accounts"
-: "Authentifizierung/Benutzerkonten"
-
-, "Email"
-: "Email"
-
-, "Application Manager"
-: "Anwendungs-Verwaltung"
-
-, "I have read the license agreement and accept it"
-: "Ich habe die Lizenzvereinbarung gelesen und akzeptiere sie"
-
-, "License Agreement"
-: "Lizenzvereinbarung"
-
-, "I have read the privacy agreement and accept it"
-: "Ich habe die Datenschutzvereinbarung gelesen und akzeptiere sie"
-
-, "Privacy Agreement"
-: "Datenschutzvereinbarung"
-
-, "Accept Terms and Conditions"
-: "Bedingungen und Konditionen akzeptieren"
-
 , "Name"
 : "Name"
 
@@ -88,8 +55,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Uninstall application"
 : "Anwendung deinstallieren"
 
-, "Update application"
-: "Anwendung aktualisieren"
+, "Update applications"
+: "Anwendungen aktualisieren"
 
 , "Go to {0} login"
 : "Zum {0} Login"
@@ -109,12 +76,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "CLI Required"
 : "CLI erforderlich"
 
-, "Application, Applications"
-: [
-  "Anwendung"
- ,"Anwendungen"
-
-]
 , "Delete all existing users and groups"
 : "Lösche alle existierenden Benutzer und Gruppen"
 
@@ -163,9 +124,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Host"
 : "Host"
 
-, "Port"
-: "Port"
-
 , "Login name"
 : "Loginname"
 
@@ -181,6 +139,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "SSL"
 : "SSL"
 
+, "Port"
+: "Port"
+
 , "Base DN"
 : "Base DN"
 
@@ -430,15 +391,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "enabled"
 : "aktiviert"
 
-, "Use Custom Theme"
-: "Custom Theme verwenden"
-
-, "Theme path"
-: "Theme Pfad"
-
-, "Use blue theme as base"
-: "Verwende blaues Theme als Basis"
-
 , "Config file is not writable"
 : "Konfigurationsdatei nicht schreibbar"
 
@@ -457,6 +409,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Imap"
 : "Imap"
 
+, "Verify peer Certificate"
+: ""
+
 , "Use system account"
 : "Systemkonto benutzen"
 
@@ -556,30 +511,57 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "PLAIN"
 : "PLAIN"
 
-, "Message"
-: "Informationen"
-
-, "Verify peer Certificate"
-: ""
-
 , "Setup"
 : ""
 
-, "Update applications"
-: "Anwendungen aktualisieren"
-
-, "Updating application, Updating applications"
+, "Application, Applications"
 : [
-  "Aktualisiere Anwendung"
- ,"Aktualisiere Anwendungen"
+  "Anwendung"
+ ,"Anwendungen"
 
 ]
+, "Terms and Conditions"
+: "Bedingungen und Konditionen"
+
+, "Setup Checks"
+: "Setup Tests"
+
+, "Config Manager"
+: "Konfigurations-Verwaltung"
+
+, "Authentication/Accounts"
+: "Authentifizierung/Benutzerkonten"
+
+, "Email"
+: "Email"
+
+, "Application Manager"
+: "Anwendungs-Verwaltung"
+
+, "I have read the license agreement and accept it"
+: "Ich habe die Lizenzvereinbarung gelesen und akzeptiere sie"
+
+, "License Agreement"
+: "Lizenzvereinbarung"
+
+, "I have read the privacy agreement and accept it"
+: "Ich habe die Datenschutzvereinbarung gelesen und akzeptiere sie"
+
+, "Privacy Agreement"
+: "Datenschutzvereinbarung"
+
+, "Accept Terms and Conditions"
+: "Bedingungen und Konditionen akzeptieren"
+
+
+
+
+
+
+
 , "Application"
 : "Anwendung"
 
-, "Updating application"
-: "Aktualisiere Anwendung"
-
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
