@@ -7,188 +7,29 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
 : "Project-Id-Version: Tine 2.0 - Setup\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"
 
-, "I have read the license agreement and accept it"
-: "I have read the license agreement and accept it"
+, "Performing Environment Checks..."
+: "Performing Environment Checks..."
 
-, "License Agreement"
-: "License Agreement"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
+: "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
 
-, "I have read the privacy agreement and accept it"
-: "I have read the privacy agreement and accept it"
+, "Check"
+: "Check"
 
-, "Privacy Agreement"
-: "Privacy Agreement"
+, "Result"
+: "Result"
 
-, "Accept Terms and Conditions"
-: "Accept Terms and Conditions"
+, "Message"
+: "Message"
 
-, "Backend"
-: "Backend"
+, "Run setup tests"
+: "Run setup tests"
 
-, "Standard IMAP"
-: "Standard IMAP"
+, "Ignore setup tests"
+: "Ignore setup tests"
 
-, "Standard SMTP"
-: "Standard SMTP"
-
-, "Imap"
-: "Imap"
-
-, "Hostname"
-: "Hostname"
-
-, "Username"
-: "Username"
-
-, "Password"
-: "Password"
-
-, "Port"
-: "Port"
-
-, "Secure Connection"
-: "Secure Connection"
-
-, "None"
-: "None"
-
-, "TLS"
-: "TLS"
-
-, "SSL"
-: "SSL"
-
-, "Verify peer Certificate"
-: "Verify peer Certificate"
-
-, "Use system account"
-: "Use system account"
-
-, "No"
-: "No"
-
-, "Yes"
-: "Yes"
-
-, "Append domain to login name"
-: "Append domain to login name"
-
-, "Use email address as login name"
-: "Use email address as login name"
-
-, "Cyrus Admin"
-: "Cyrus Admin"
-
-, "Cyrus Admin Password"
-: "Cyrus Admin Password"
-
-, "Use proxy auth"
-: "Use proxy auth"
-
-, "Smtp"
-: "Smtp"
-
-, "Authentication"
-: "Authentication"
-
-, "Login"
-: "Login"
-
-, "Plain"
-: "Plain"
-
-, "Primary Domain"
-: "Primary Domain"
-
-, "Secondary Domains (comma separated)"
-: "Secondary Domains (comma separated)"
-
-, "Notifications service address"
-: "Notifications service address"
-
-, "Notification Username"
-: "Notification Username"
-
-, "Notification Password"
-: "Notification Password"
-
-, "Notifications local client (hostname or IP address)"
-: "Notifications local client (hostname or IP address)"
-
-, "SIEVE"
-: "SIEVE"
-
-, "MySql Hostname"
-: "MySql Hostname"
-
-, "MySql Database"
-: "MySql Database"
-
-, "MySql User"
-: "MySql User"
-
-, "MySql Password"
-: "MySql Password"
-
-, "MySql Port"
-: "MySql Port"
-
-, "User or UID"
-: "User or UID"
-
-, "Group or GID"
-: "Group or GID"
-
-, "Home Template"
-: "Home Template"
-
-, "Password Scheme"
-: "Password Scheme"
-
-, "PLAIN-MD5"
-: "PLAIN-MD5"
-
-, "MD5-CRYPT"
-: "MD5-CRYPT"
-
-, "SHA1"
-: "SHA1"
-
-, "SHA256"
-: "SHA256"
-
-, "SSHA256"
-: "SSHA256"
-
-, "SHA512"
-: "SHA512"
-
-, "SSHA512"
-: "SSHA512"
-
-, "PLAIN"
-: "PLAIN"
-
-, "Terms and Conditions"
-: "Terms and Conditions"
-
-, "Setup Checks"
-: "Setup Checks"
-
-, "Config Manager"
-: "Config Manager"
-
-, "Authentication/Accounts"
-: "Authentication/Accounts"
-
-, "Email"
-: "Email"
-
-, "Application Manager"
-: "Application Manager"
-
-, "Setup"
-: "Setup"
+, "Install application"
+: "Install application"
 
 , "Name"
 : "Name"
@@ -211,14 +52,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : "Depends on"
 
-, "Install application"
-: "Install application"
-
 , "Uninstall application"
 : "Uninstall application"
 
-, "Update application"
-: "Update application"
+, "Update applications"
+: "Update applications"
 
 , "Go to {0} login"
 : "Go to {0} login"
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 
+, "Backend"
+: "Backend"
+
 , "TLS client certificate"
 : "TLS client certificate"
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : "Try to split username"
 
+, "Yes"
+: "Yes"
+
+, "No"
+: "No"
+
 , "Account canonical form"
 : "Account canonical form"
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : "Login name"
 
+, "Password"
+: "Password"
+
 , "Bind requires DN"
 : "Bind requires DN"
 
 , "Start TLS"
 : "Start TLS"
 
+, "SSL"
+: "SSL"
+
+, "Port"
+: "Port"
+
 , "Base DN"
 : "Base DN"
 
 , "Search filter"
 : "Search filter"
 
+, "Hostname"
+: "Hostname"
+
+, "Secure Connection"
+: "Secure Connection"
+
+, "None"
+: "None"
+
+, "TLS"
+: "TLS"
+
+, "Append domain to login name"
+: "Append domain to login name"
+
 , "Certificate validation"
 : "Certificate validation"
 
@@ -454,39 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : "Should not be empty"
 
-, "Performing Environment Checks..."
-: "Performing Environment Checks..."
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-
-, "Check"
-: "Check"
-
-, "Result"
-: "Result"
-
-, "Error"
-: "Error"
-
-, "Run setup tests"
-: "Run setup tests"
-
-, "Ignore setup tests"
-: "Ignore setup tests"
-
-, "Application, Applications"
-: [
-  "Application"
- ,"Applications"
-
-]
 , "File"
 : "File"
 
 , "Setup Authentication"
 : "Setup Authentication"
 
+, "Username"
+: "Username"
+
 , "Database"
 : "Database"
 
@@ -553,6 +400,159 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : "This prefix is too long. Please choose a prefix no longer than {0} chars."
 
+, "Standard IMAP"
+: "Standard IMAP"
+
+, "Standard SMTP"
+: "Standard SMTP"
+
+, "Imap"
+: "Imap"
+
+, "Verify peer Certificate"
+: "Verify peer Certificate"
+
+, "Use system account"
+: "Use system account"
+
+, "Use email address as login name"
+: "Use email address as login name"
+
+, "Cyrus Admin"
+: "Cyrus Admin"
+
+, "Cyrus Admin Password"
+: "Cyrus Admin Password"
+
+, "Use proxy auth"
+: "Use proxy auth"
+
+, "Smtp"
+: "Smtp"
+
+, "Authentication"
+: "Authentication"
+
+, "Login"
+: "Login"
+
+, "Plain"
+: "Plain"
+
+, "Primary Domain"
+: "Primary Domain"
+
+, "Secondary Domains (comma separated)"
+: "Secondary Domains (comma separated)"
+
+, "Notifications service address"
+: "Notifications service address"
+
+, "Notification Username"
+: "Notification Username"
+
+, "Notification Password"
+: "Notification Password"
+
+, "Notifications local client (hostname or IP address)"
+: "Notifications local client (hostname or IP address)"
+
+, "SIEVE"
+: "SIEVE"
+
+, "MySql Hostname"
+: "MySql Hostname"
+
+, "MySql Database"
+: "MySql Database"
+
+, "MySql User"
+: "MySql User"
+
+, "MySql Password"
+: "MySql Password"
+
+, "MySql Port"
+: "MySql Port"
+
+, "User or UID"
+: "User or UID"
+
+, "Group or GID"
+: "Group or GID"
+
+, "Home Template"
+: "Home Template"
+
+, "Password Scheme"
+: "Password Scheme"
+
+, "PLAIN-MD5"
+: "PLAIN-MD5"
+
+, "MD5-CRYPT"
+: "MD5-CRYPT"
+
+, "SHA1"
+: "SHA1"
+
+, "SHA256"
+: "SHA256"
+
+, "SSHA256"
+: "SSHA256"
+
+, "SHA512"
+: "SHA512"
+
+, "SSHA512"
+: "SSHA512"
+
+, "PLAIN"
+: "PLAIN"
+
+, "Setup"
+: "Setup"
+
+, "Application, Applications"
+: [
+  "Application"
+ ,"Applications"
+
+]
+, "Terms and Conditions"
+: "Terms and Conditions"
+
+, "Setup Checks"
+: "Setup Checks"
+
+, "Config Manager"
+: "Config Manager"
+
+, "Authentication/Accounts"
+: "Authentication/Accounts"
+
+, "Email"
+: "Email"
+
+, "Application Manager"
+: "Application Manager"
+
+, "I have read the license agreement and accept it"
+: "I have read the license agreement and accept it"
+
+, "License Agreement"
+: "License Agreement"
+
+, "I have read the privacy agreement and accept it"
+: "I have read the privacy agreement and accept it"
+
+, "Privacy Agreement"
+: "Privacy Agreement"
+
+, "Accept Terms and Conditions"
+: "Accept Terms and Conditions"
+
 , "Application"
 : "Application"
 
