@@ -5,190 +5,31 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Setup **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "I have read the license agreement and accept it"
-: "He leído los términos de la licencia y estoy de acuerdo con ellos"
+, "Performing Environment Checks..."
+: "Realizando controles de entorno..."
 
-, "License Agreement"
-: "Términos de Licenciamiento"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
+: "No se puede encontrar ningun resultado de {0}. Por favor, intenta modificar tus criterios de filtro, opciones de vista o de {1} que estaba buscando."
 
-, "I have read the privacy agreement and accept it"
-: "He leído la política de privacidad y estoy de acuerdo con ella"
+, "Check"
+: "Verificar"
 
-, "Privacy Agreement"
-: "Política de Privacidad"
+, "Result"
+: "Resultado"
 
-, "Accept Terms and Conditions"
-: "Aceptar Términos y Condiciones"
-
-, "Backend"
-: "Administración"
-
-, "Standard IMAP"
-: "IMAP estándar"
-
-, "Standard SMTP"
-: "SMTP estándar"
-
-, "Imap"
-: "Imap"
-
-, "Hostname"
-: "Nombre del Dominio"
-
-, "Username"
-: "Nombre de usuario"
-
-, "Password"
-: "Contraseña"
-
-, "Port"
-: "Puerto"
-
-, "Secure Connection"
-: "Conexión Segura"
-
-, "None"
-: "Ninguno"
-
-, "TLS"
-: "TLS"
-
-, "SSL"
-: "SSL"
-
-, "Verify peer Certificate"
+, "Message"
 : ""
 
-, "Use system account"
-: "Usar cuenta del sistema"
+, "Run setup tests"
+: "Realizar pruebas de instalación"
 
-, "No"
-: "No"
+, "Ignore setup tests"
+: "Ignorar pruebas de instalación"
 
-, "Yes"
-: "Si"
-
-, "Append domain to login name"
-: "Anexar dominio para iniciar sesión Nombre"
-
-, "Use email address as login name"
-: ""
-
-, "Cyrus Admin"
-: "Admin Cyrus"
-
-, "Cyrus Admin Password"
-: "Contraseña Admin Cyrus"
-
-, "Use proxy auth"
-: "Utilizar autorizacion de proxy"
-
-, "Smtp"
-: "Smtp"
-
-, "Authentication"
-: "Autentificación"
-
-, "Login"
-: "Ingreso"
-
-, "Plain"
-: "Plano"
-
-, "Primary Domain"
-: "Dominio Primario"
-
-, "Secondary Domains (comma separated)"
-: "Dominios secundarios (separados por coma)"
-
-, "Notifications service address"
-: "Dirección del servicio de notificaciones"
-
-, "Notification Username"
-: "Notificación Nombre de Usuario"
-
-, "Notification Password"
-: "Notificación Contraseña"
-
-, "Notifications local client (hostname or IP address)"
-: "Notificaciones cliente local (nombre de host o IP)"
-
-, "SIEVE"
-: "SIEVE"
-
-, "MySql Hostname"
-: "Dominio de MySql"
-
-, "MySql Database"
-: "Base de Datos MySql"
-
-, "MySql User"
-: "Usuario MySql"
-
-, "MySql Password"
-: "Contraseña MySql"
-
-, "MySql Port"
-: "Puerto MySql"
-
-, "User or UID"
-: "Usuario o UID"
-
-, "Group or GID"
-: "Grupo o GID"
-
-, "Home Template"
-: "Plantilla Home"
-
-, "Password Scheme"
-: "Esquema de contraseña"
-
-, "PLAIN-MD5"
-: "PLANO-MD5"
-
-, "MD5-CRYPT"
-: "MD5-CRYPT"
-
-, "SHA1"
-: "SHA1"
-
-, "SHA256"
-: "SHA256"
-
-, "SSHA256"
-: "SSHA256"
-
-, "SHA512"
-: "SHA512"
-
-, "SSHA512"
-: "SSHA512"
-
-, "PLAIN"
-: "PLANO"
-
-, "Terms and Conditions"
-: "Términos y Condiciones"
-
-, "Setup Checks"
-: "Pruebas de Instalación"
-
-, "Config Manager"
-: "Administrador de Configuración"
-
-, "Authentication/Accounts"
-: "Autentificación/Cuentas"
-
-, "Email"
-: "Email"
-
-, "Application Manager"
-: "Administrador de Aplicaciones"
-
-, "Setup"
-: ""
+, "Install application"
+: "Instalar aplicación"
 
 , "Name"
 : "Nombre"
@@ -211,14 +52,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : "Depende de"
 
-, "Install application"
-: "Instalar aplicación"
-
 , "Uninstall application"
 : "Desinstalar aplicación"
 
-, "Update application"
-: "Actualizar aplicación"
+, "Update applications"
+: ""
 
 , "Go to {0} login"
 : "Ir al {0} de ingreso"
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : "Cambiar desde SQL a LDAP borrará todas las cuentas, cargos y grupos de usuario. ¿Realmente desea cambiar el almacenamiento de cuentas administrativo a LDAP?"
 
+, "Backend"
+: "Administración"
+
 , "TLS client certificate"
 : "Certificado TLS Cliente"
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : "Trate de dividir nombre de usuario"
 
+, "Yes"
+: "Si"
+
+, "No"
+: "No"
+
 , "Account canonical form"
 : "Formulación de cuenta canónica"
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : "Nombre de ingreso"
 
+, "Password"
+: "Contraseña"
+
 , "Bind requires DN"
 : "Bind requiere DN"
 
 , "Start TLS"
 : "Start TLS"
 
+, "SSL"
+: "SSL"
+
+, "Port"
+: "Puerto"
+
 , "Base DN"
 : "Base DN"
 
 , "Search filter"
 : "Buscar filtro"
 
+, "Hostname"
+: "Nombre del Dominio"
+
+, "Secure Connection"
+: "Conexión Segura"
+
+, "None"
+: "Ninguno"
+
+, "TLS"
+: "TLS"
+
+, "Append domain to login name"
+: "Anexar dominio para iniciar sesión Nombre"
+
 , "Certificate validation"
 : "Validación con Certificado"
 
@@ -454,39 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : "No debería estar vacío"
 
-, "Performing Environment Checks..."
-: "Realizando controles de entorno..."
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: "No se puede encontrar ningun resultado de {0}. Por favor, intenta modificar tus criterios de filtro, opciones de vista o de {1} que estaba buscando."
-
-, "Check"
-: "Verificar"
-
-, "Result"
-: "Resultado"
-
-, "Error"
-: "Error"
-
-, "Run setup tests"
-: "Realizar pruebas de instalación"
-
-, "Ignore setup tests"
-: "Ignorar pruebas de instalación"
-
-, "Application, Applications"
-: [
-  "Aplicación"
- ,"Aplicaciones"
-
-]
 , "File"
 : "Fichero"
 
 , "Setup Authentication"
 : "Autentificación del Instalador"
 
+, "Username"
+: "Nombre de usuario"
+
 , "Database"
 : "Base de Datos"
 
@@ -553,6 +400,160 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : ""
 
+, "Standard IMAP"
+: "IMAP estándar"
+
+, "Standard SMTP"
+: "SMTP estándar"
+
+, "Imap"
+: "Imap"
+
+, "Verify peer Certificate"
+: ""
+
+, "Use system account"
+: "Usar cuenta del sistema"
+
+, "Use email address as login name"
+: ""
+
+, "Cyrus Admin"
+: "Admin Cyrus"
+
+, "Cyrus Admin Password"
+: "Contraseña Admin Cyrus"
+
+, "Use proxy auth"
+: "Utilizar autorizacion de proxy"
+
+, "Smtp"
+: "Smtp"
+
+, "Authentication"
+: "Autentificación"
+
+, "Login"
+: "Ingreso"
+
+, "Plain"
+: "Plano"
+
+, "Primary Domain"
+: "Dominio Primario"
+
+, "Secondary Domains (comma separated)"
+: "Dominios secundarios (separados por coma)"
+
+, "Notifications service address"
+: "Dirección del servicio de notificaciones"
+
+, "Notification Username"
+: "Notificación Nombre de Usuario"
+
+, "Notification Password"
+: "Notificación Contraseña"
+
+, "Notifications local client (hostname or IP address)"
+: "Notificaciones cliente local (nombre de host o IP)"
+
+, "SIEVE"
+: "SIEVE"
+
+, "MySql Hostname"
+: "Dominio de MySql"
+
+, "MySql Database"
+: "Base de Datos MySql"
+
+, "MySql User"
+: "Usuario MySql"
+
+, "MySql Password"
+: "Contraseña MySql"
+
+, "MySql Port"
+: "Puerto MySql"
+
+, "User or UID"
+: "Usuario o UID"
+
+, "Group or GID"
+: "Grupo o GID"
+
+, "Home Template"
+: "Plantilla Home"
+
+, "Password Scheme"
+: "Esquema de contraseña"
+
+, "PLAIN-MD5"
+: "PLANO-MD5"
+
+, "MD5-CRYPT"
+: "MD5-CRYPT"
+
+, "SHA1"
+: "SHA1"
+
+, "SHA256"
+: "SHA256"
+
+, "SSHA256"
+: "SSHA256"
+
+, "SHA512"
+: "SHA512"
+
+, "SSHA512"
+: "SSHA512"
+
+, "PLAIN"
+: "PLANO"
+
+, "Setup"
+: ""
+
+, "Application, Applications"
+: [
+  "Aplicación"
+ ,"Aplicaciones"
+
+]
+, "Terms and Conditions"
+: "Términos y Condiciones"
+
+, "Setup Checks"
+: "Pruebas de Instalación"
+
+, "Config Manager"
+: "Administrador de Configuración"
+
+, "Authentication/Accounts"
+: "Autentificación/Cuentas"
+
+, "Email"
+: "Email"
+
+, "Application Manager"
+: "Administrador de Aplicaciones"
+
+, "I have read the license agreement and accept it"
+: "He leído los términos de la licencia y estoy de acuerdo con ellos"
+
+, "License Agreement"
+: "Términos de Licenciamiento"
+
+, "I have read the privacy agreement and accept it"
+: "He leído la política de privacidad y estoy de acuerdo con ella"
+
+, "Privacy Agreement"
+: "Política de Privacidad"
+
+, "Accept Terms and Conditions"
+: "Aceptar Términos y Condiciones"
+
+
 , "Application"
 : "Aplicación"
 
