@@ -5,190 +5,31 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Setup **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Estonian (http://www.transifex.com/tine20/tine20/language/et/)\nLanguage: et\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Estonian (http://www.transifex.com/tine20/tine20/language/et/)\nLanguage: et\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "I have read the license agreement and accept it"
+, "Performing Environment Checks..."
 : ""
 
-, "License Agreement"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
 : ""
 
-, "I have read the privacy agreement and accept it"
+, "Check"
 : ""
 
-, "Privacy Agreement"
+, "Result"
 : ""
 
-, "Accept Terms and Conditions"
+, "Message"
 : ""
 
-, "Backend"
+, "Run setup tests"
 : ""
 
-, "Standard IMAP"
+, "Ignore setup tests"
 : ""
 
-, "Standard SMTP"
-: ""
-
-, "Imap"
-: "Imap"
-
-, "Hostname"
-: "Hostinimi"
-
-, "Username"
-: "Kasutajanimi"
-
-, "Password"
-: "Parool"
-
-, "Port"
-: "Port"
-
-, "Secure Connection"
-: "Turvaline ühendus"
-
-, "None"
-: "Pole"
-
-, "TLS"
-: "TLS"
-
-, "SSL"
-: "SSL"
-
-, "Verify peer Certificate"
-: ""
-
-, "Use system account"
-: ""
-
-, "No"
-: "Ei"
-
-, "Yes"
-: "Jah"
-
-, "Append domain to login name"
-: ""
-
-, "Use email address as login name"
-: ""
-
-, "Cyrus Admin"
-: ""
-
-, "Cyrus Admin Password"
-: ""
-
-, "Use proxy auth"
-: ""
-
-, "Smtp"
-: "Smtp"
-
-, "Authentication"
-: "Autentimine"
-
-, "Login"
-: ""
-
-, "Plain"
-: ""
-
-, "Primary Domain"
-: ""
-
-, "Secondary Domains (comma separated)"
-: ""
-
-, "Notifications service address"
-: ""
-
-, "Notification Username"
-: ""
-
-, "Notification Password"
-: ""
-
-, "Notifications local client (hostname or IP address)"
-: ""
-
-, "SIEVE"
-: ""
-
-, "MySql Hostname"
-: "MySql hostinimi"
-
-, "MySql Database"
-: "MySql andmebaas"
-
-, "MySql User"
-: "MySql kasutaja"
-
-, "MySql Password"
-: "MySql parool"
-
-, "MySql Port"
-: "MySql port"
-
-, "User or UID"
-: "Kasutaja või UID"
-
-, "Group or GID"
-: "Grupp või GID"
-
-, "Home Template"
-: ""
-
-, "Password Scheme"
-: ""
-
-, "PLAIN-MD5"
-: "PLAIN-MD5"
-
-, "MD5-CRYPT"
-: "MD5-CRYPT"
-
-, "SHA1"
-: "SHA1"
-
-, "SHA256"
-: "SHA256"
-
-, "SSHA256"
-: "SSHA256"
-
-, "SHA512"
-: "SHA512"
-
-, "SSHA512"
-: ""
-
-, "PLAIN"
-: ""
-
-, "Terms and Conditions"
-: ""
-
-, "Setup Checks"
-: ""
-
-, "Config Manager"
-: ""
-
-, "Authentication/Accounts"
-: ""
-
-, "Email"
-: ""
-
-, "Application Manager"
-: ""
-
-, "Setup"
-: ""
+, "Install application"
+: "Paigalda rakendus"
 
 , "Name"
 : "Nimi"
@@ -211,14 +52,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : "Sõltub"
 
-, "Install application"
-: "Paigalda rakendus"
-
 , "Uninstall application"
 : "Eemalda rakendus"
 
-, "Update application"
-: "Uuenda rakendust"
+, "Update applications"
+: ""
 
 , "Go to {0} login"
 : ""
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : ""
 
+, "Backend"
+: ""
+
 , "TLS client certificate"
 : ""
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : ""
 
+, "Yes"
+: "Jah"
+
+, "No"
+: "Ei"
+
 , "Account canonical form"
 : ""
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : "Kasutajanimi"
 
+, "Password"
+: "Parool"
+
 , "Bind requires DN"
 : ""
 
 , "Start TLS"
 : ""
 
+, "SSL"
+: "SSL"
+
+, "Port"
+: "Port"
+
 , "Base DN"
 : ""
 
 , "Search filter"
 : ""
 
+, "Hostname"
+: "Hostinimi"
+
+, "Secure Connection"
+: "Turvaline ühendus"
+
+, "None"
+: "Pole"
+
+, "TLS"
+: "TLS"
+
+, "Append domain to login name"
+: ""
+
 , "Certificate validation"
 : ""
 
@@ -454,39 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : ""
 
-, "Performing Environment Checks..."
-: ""
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: ""
-
-, "Check"
-: ""
-
-, "Result"
-: ""
-
-, "Error"
-: ""
-
-, "Run setup tests"
-: ""
-
-, "Ignore setup tests"
-: ""
-
-, "Application, Applications"
-: [
-  ""
- ,""
-
-]
 , "File"
 : "Fail"
 
 , "Setup Authentication"
 : ""
 
+, "Username"
+: "Kasutajanimi"
+
 , "Database"
 : "Andmebaas"
 
@@ -553,6 +400,160 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : ""
 
+, "Standard IMAP"
+: ""
+
+, "Standard SMTP"
+: ""
+
+, "Imap"
+: "Imap"
+
+, "Verify peer Certificate"
+: ""
+
+, "Use system account"
+: ""
+
+, "Use email address as login name"
+: ""
+
+, "Cyrus Admin"
+: ""
+
+, "Cyrus Admin Password"
+: ""
+
+, "Use proxy auth"
+: ""
+
+, "Smtp"
+: "Smtp"
+
+, "Authentication"
+: "Autentimine"
+
+, "Login"
+: ""
+
+, "Plain"
+: ""
+
+, "Primary Domain"
+: ""
+
+, "Secondary Domains (comma separated)"
+: ""
+
+, "Notifications service address"
+: ""
+
+, "Notification Username"
+: ""
+
+, "Notification Password"
+: ""
+
+, "Notifications local client (hostname or IP address)"
+: ""
+
+, "SIEVE"
+: ""
+
+, "MySql Hostname"
+: "MySql hostinimi"
+
+, "MySql Database"
+: "MySql andmebaas"
+
+, "MySql User"
+: "MySql kasutaja"
+
+, "MySql Password"
+: "MySql parool"
+
+, "MySql Port"
+: "MySql port"
+
+, "User or UID"
+: "Kasutaja või UID"
+
+, "Group or GID"
+: "Grupp või GID"
+
+, "Home Template"
+: ""
+
+, "Password Scheme"
+: ""
+
+, "PLAIN-MD5"
+: "PLAIN-MD5"
+
+, "MD5-CRYPT"
+: "MD5-CRYPT"
+
+, "SHA1"
+: "SHA1"
+
+, "SHA256"
+: "SHA256"
+
+, "SSHA256"
+: "SSHA256"
+
+, "SHA512"
+: "SHA512"
+
+, "SSHA512"
+: ""
+
+, "PLAIN"
+: ""
+
+, "Setup"
+: ""
+
+, "Application, Applications"
+: [
+  ""
+ ,""
+
+]
+, "Terms and Conditions"
+: ""
+
+, "Setup Checks"
+: ""
+
+, "Config Manager"
+: ""
+
+, "Authentication/Accounts"
+: ""
+
+, "Email"
+: ""
+
+, "Application Manager"
+: ""
+
+, "I have read the license agreement and accept it"
+: ""
+
+, "License Agreement"
+: ""
+
+, "I have read the privacy agreement and accept it"
+: ""
+
+, "Privacy Agreement"
+: ""
+
+, "Accept Terms and Conditions"
+: ""
+
+
 , "Application"
 : ""
 
