@@ -5,190 +5,31 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Setup **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "I have read the license agreement and accept it"
-: "Pročitao sam ugovor o korištenju i prihvaćam ga"
+, "Performing Environment Checks..."
+: "Izvršavam provjere okruženja..."
 
-, "License Agreement"
-: "Ugovor o korištenju"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
+: "{0} ne može biti pronađeno. Pokušajte promijeniti svoje filter-kriterije, opcije pregleda ili što traži u {1}. "
 
-, "I have read the privacy agreement and accept it"
-: "Pročitao sam ugovor o privatnosti i prihvaćam ga"
+, "Check"
+: "Provjeri"
 
-, "Privacy Agreement"
-: "Ugovor o privatnosti"
+, "Result"
+: "Rezultat"
 
-, "Accept Terms and Conditions"
-: "Prihvaćam uvjete korištenja"
-
-, "Backend"
-: "Pozadina"
-
-, "Standard IMAP"
-: "Standardni IMAP"
-
-, "Standard SMTP"
-: "Standardni SMTP"
-
-, "Imap"
-: "Imap"
-
-, "Hostname"
-: "Poslužitelj"
-
-, "Username"
-: "Korisničko ime"
-
-, "Password"
-: "Zaporka"
-
-, "Port"
-: "Port"
-
-, "Secure Connection"
-: "Sigurna konekcija"
-
-, "None"
-: "Ništa"
-
-, "TLS"
-: "TLS"
-
-, "SSL"
-: "SSL"
-
-, "Verify peer Certificate"
+, "Message"
 : ""
 
-, "Use system account"
-: "Koristi sistemski račun"
+, "Run setup tests"
+: "Pokreni testove podešavanja"
 
-, "No"
-: "Ne"
+, "Ignore setup tests"
+: "Ignoriraj testove podešavanja"
 
-, "Yes"
-: "Da"
-
-, "Append domain to login name"
-: "Dodaj domenu imenu za prijavu"
-
-, "Use email address as login name"
-: ""
-
-, "Cyrus Admin"
-: "Cyrus administator"
-
-, "Cyrus Admin Password"
-: "Cyrus lozinka administratora"
-
-, "Use proxy auth"
-: ""
-
-, "Smtp"
-: "Smtp"
-
-, "Authentication"
-: "Autentikacija"
-
-, "Login"
-: "Login"
-
-, "Plain"
-: "Jednostavno"
-
-, "Primary Domain"
-: "Primarna domena"
-
-, "Secondary Domains (comma separated)"
-: "Sekundarna domena (odvojena zarezom)"
-
-, "Notifications service address"
-: "Servisna adresa notifikacija"
-
-, "Notification Username"
-: "Korisničko ime notifikacija"
-
-, "Notification Password"
-: "Zaporka notifikacija"
-
-, "Notifications local client (hostname or IP address)"
-: "Obavijesti lokalno klijenta (poslužitelj ili IP adresa)"
-
-, "SIEVE"
-: "SIEVE"
-
-, "MySql Hostname"
-: "MySql Hostname"
-
-, "MySql Database"
-: "MySql Database"
-
-, "MySql User"
-: "MySql User"
-
-, "MySql Password"
-: "MySql Password"
-
-, "MySql Port"
-: "MySql Port"
-
-, "User or UID"
-: "Korisnik ili UID"
-
-, "Group or GID"
-: "Grupa ili GID"
-
-, "Home Template"
-: "Početni predložak"
-
-, "Password Scheme"
-: "Shema lozinke"
-
-, "PLAIN-MD5"
-: "PLAIN-MD5"
-
-, "MD5-CRYPT"
-: "MD5-CRYPT"
-
-, "SHA1"
-: "SHA1"
-
-, "SHA256"
-: "SHA256"
-
-, "SSHA256"
-: "SSHA256"
-
-, "SHA512"
-: "SHA512"
-
-, "SSHA512"
-: "SSHA512"
-
-, "PLAIN"
-: "PLAIN"
-
-, "Terms and Conditions"
-: "Uvjeti i odredbe"
-
-, "Setup Checks"
-: "Provjere postavki"
-
-, "Config Manager"
-: "Uređivač konfiguracije"
-
-, "Authentication/Accounts"
-: "Autentikacija/Računi"
-
-, "Email"
-: "E-mail"
-
-, "Application Manager"
-: "Uređivač aplikacija"
-
-, "Setup"
-: ""
+, "Install application"
+: "Instaliraj aplikaciju"
 
 , "Name"
 : "Ime"
@@ -211,14 +52,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : "Ovisi o"
 
-, "Install application"
-: "Instaliraj aplikaciju"
-
 , "Uninstall application"
 : "Ukloni aplikaciju"
 
-, "Update application"
-: "Ažuriraj aplikaciju"
+, "Update applications"
+: ""
 
 , "Go to {0} login"
 : "Idi na {0} prijavu"
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : "Prijelaz sa SQL na  LDAP će izbrisati sve postojeće korisničke račune, grupe i uloge. Želite li stvarno zamjeniti pozadinu pohrane računa na LDAP? "
 
+, "Backend"
+: "Pozadina"
+
 , "TLS client certificate"
 : ""
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : "Pokušajte razdvojiti korisničko ime"
 
+, "Yes"
+: "Da"
+
+, "No"
+: "Ne"
+
 , "Account canonical form"
 : "Kanonski oblik računa"
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : "Ime za prijavu"
 
+, "Password"
+: "Zaporka"
+
 , "Bind requires DN"
 : "Zahtjev vezanja DN"
 
 , "Start TLS"
 : ""
 
+, "SSL"
+: "SSL"
+
+, "Port"
+: "Port"
+
 , "Base DN"
 : "Baza DN"
 
 , "Search filter"
 : "Filter pretraživanja"
 
+, "Hostname"
+: "Poslužitelj"
+
+, "Secure Connection"
+: "Sigurna konekcija"
+
+, "None"
+: "Ništa"
+
+, "TLS"
+: "TLS"
+
+, "Append domain to login name"
+: "Dodaj domenu imenu za prijavu"
+
 , "Certificate validation"
 : ""
 
@@ -454,40 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : "Ne bi trebalo biti prazno"
 
-, "Performing Environment Checks..."
-: "Izvršavam provjere okruženja..."
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: "{0} ne može biti pronađeno. Pokušajte promijeniti svoje filter-kriterije, opcije pregleda ili što traži u {1}. "
-
-, "Check"
-: "Provjeri"
-
-, "Result"
-: "Rezultat"
-
-, "Error"
-: "Greška"
-
-, "Run setup tests"
-: "Pokreni testove podešavanja"
-
-, "Ignore setup tests"
-: "Ignoriraj testove podešavanja"
-
-, "Application, Applications"
-: [
-  "Aplikacija"
- ,"Aplikacije"
- ,"Aplikacija"
-
-]
 , "File"
 : "Datoteka"
 
 , "Setup Authentication"
 : "Podešavanje autentikacije"
 
+, "Username"
+: "Korisničko ime"
+
 , "Database"
 : "Baza podataka"
 
@@ -554,6 +400,161 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : ""
 
+, "Standard IMAP"
+: "Standardni IMAP"
+
+, "Standard SMTP"
+: "Standardni SMTP"
+
+, "Imap"
+: "Imap"
+
+, "Verify peer Certificate"
+: ""
+
+, "Use system account"
+: "Koristi sistemski račun"
+
+, "Use email address as login name"
+: ""
+
+, "Cyrus Admin"
+: "Cyrus administator"
+
+, "Cyrus Admin Password"
+: "Cyrus lozinka administratora"
+
+, "Use proxy auth"
+: ""
+
+, "Smtp"
+: "Smtp"
+
+, "Authentication"
+: "Autentikacija"
+
+, "Login"
+: "Login"
+
+, "Plain"
+: "Jednostavno"
+
+, "Primary Domain"
+: "Primarna domena"
+
+, "Secondary Domains (comma separated)"
+: "Sekundarna domena (odvojena zarezom)"
+
+, "Notifications service address"
+: "Servisna adresa notifikacija"
+
+, "Notification Username"
+: "Korisničko ime notifikacija"
+
+, "Notification Password"
+: "Zaporka notifikacija"
+
+, "Notifications local client (hostname or IP address)"
+: "Obavijesti lokalno klijenta (poslužitelj ili IP adresa)"
+
+, "SIEVE"
+: "SIEVE"
+
+, "MySql Hostname"
+: "MySql Hostname"
+
+, "MySql Database"
+: "MySql Database"
+
+, "MySql User"
+: "MySql User"
+
+, "MySql Password"
+: "MySql Password"
+
+, "MySql Port"
+: "MySql Port"
+
+, "User or UID"
+: "Korisnik ili UID"
+
+, "Group or GID"
+: "Grupa ili GID"
+
+, "Home Template"
+: "Početni predložak"
+
+, "Password Scheme"
+: "Shema lozinke"
+
+, "PLAIN-MD5"
+: "PLAIN-MD5"
+
+, "MD5-CRYPT"
+: "MD5-CRYPT"
+
+, "SHA1"
+: "SHA1"
+
+, "SHA256"
+: "SHA256"
+
+, "SSHA256"
+: "SSHA256"
+
+, "SHA512"
+: "SHA512"
+
+, "SSHA512"
+: "SSHA512"
+
+, "PLAIN"
+: "PLAIN"
+
+, "Setup"
+: ""
+
+, "Application, Applications"
+: [
+  "Aplikacija"
+ ,"Aplikacije"
+ ,"Aplikacija"
+
+]
+, "Terms and Conditions"
+: "Uvjeti i odredbe"
+
+, "Setup Checks"
+: "Provjere postavki"
+
+, "Config Manager"
+: "Uređivač konfiguracije"
+
+, "Authentication/Accounts"
+: "Autentikacija/Računi"
+
+, "Email"
+: "E-mail"
+
+, "Application Manager"
+: "Uređivač aplikacija"
+
+, "I have read the license agreement and accept it"
+: "Pročitao sam ugovor o korištenju i prihvaćam ga"
+
+, "License Agreement"
+: "Ugovor o korištenju"
+
+, "I have read the privacy agreement and accept it"
+: "Pročitao sam ugovor o privatnosti i prihvaćam ga"
+
+, "Privacy Agreement"
+: "Ugovor o privatnosti"
+
+, "Accept Terms and Conditions"
+: "Prihvaćam uvjete korištenja"
+
+
 , "Application"
 : "Aplikacija"
 
