@@ -5,190 +5,31 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Setup **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "I have read the license agreement and accept it"
-: "Ik heb de licentie voorwaarden gelezen en accepteer deze"
-
-, "License Agreement"
-: "Licentie voorwaarden"
-
-, "I have read the privacy agreement and accept it"
-: "Ik heb de privacy voorwaarden gelezen en accepteer deze"
-
-, "Privacy Agreement"
-: "Privacy voorwaarden"
-
-, "Accept Terms and Conditions"
-: "Accepteer de voorwaarden"
-
-, "Backend"
+, "Performing Environment Checks..."
 : ""
 
-, "Standard IMAP"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
 : ""
 
-, "Standard SMTP"
+, "Check"
 : ""
 
-, "Imap"
-: "Imap"
+, "Result"
+: "Resultaat"
 
-, "Hostname"
+, "Message"
 : ""
 
-, "Username"
-: "Gebruikersnaam"
-
-, "Password"
-: "Wachtwoord"
-
-, "Port"
-: "Poort"
-
-, "Secure Connection"
+, "Run setup tests"
 : ""
 
-, "None"
+, "Ignore setup tests"
 : ""
 
-, "TLS"
-: "TLS"
-
-, "SSL"
-: "SSL"
-
-, "Verify peer Certificate"
-: ""
-
-, "Use system account"
-: ""
-
-, "No"
-: "Nee"
-
-, "Yes"
-: "Ja"
-
-, "Append domain to login name"
-: ""
-
-, "Use email address as login name"
-: ""
-
-, "Cyrus Admin"
-: ""
-
-, "Cyrus Admin Password"
-: ""
-
-, "Use proxy auth"
-: ""
-
-, "Smtp"
-: ""
-
-, "Authentication"
-: ""
-
-, "Login"
-: ""
-
-, "Plain"
-: ""
-
-, "Primary Domain"
-: ""
-
-, "Secondary Domains (comma separated)"
-: ""
-
-, "Notifications service address"
-: ""
-
-, "Notification Username"
-: ""
-
-, "Notification Password"
-: ""
-
-, "Notifications local client (hostname or IP address)"
-: ""
-
-, "SIEVE"
-: ""
-
-, "MySql Hostname"
-: ""
-
-, "MySql Database"
-: ""
-
-, "MySql User"
-: ""
-
-, "MySql Password"
-: ""
-
-, "MySql Port"
-: ""
-
-, "User or UID"
-: ""
-
-, "Group or GID"
-: ""
-
-, "Home Template"
-: ""
-
-, "Password Scheme"
-: ""
-
-, "PLAIN-MD5"
-: ""
-
-, "MD5-CRYPT"
-: ""
-
-, "SHA1"
-: ""
-
-, "SHA256"
-: ""
-
-, "SSHA256"
-: ""
-
-, "SHA512"
-: ""
-
-, "SSHA512"
-: ""
-
-, "PLAIN"
-: ""
-
-, "Terms and Conditions"
-: "Voorwaarden"
-
-, "Setup Checks"
-: ""
-
-, "Config Manager"
-: ""
-
-, "Authentication/Accounts"
-: ""
-
-, "Email"
-: "Email"
-
-, "Application Manager"
-: ""
-
-, "Setup"
-: ""
+, "Install application"
+: "Installeer toepassing"
 
 , "Name"
 : "Naam"
@@ -211,14 +52,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : "Afhankelijk van"
 
-, "Install application"
-: "Installeer toepassing"
-
 , "Uninstall application"
 : "De-installeer toepassing"
 
-, "Update application"
-: "Toepassing bewerken"
+, "Update applications"
+: ""
 
 , "Go to {0} login"
 : ""
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : ""
 
+, "Backend"
+: ""
+
 , "TLS client certificate"
 : ""
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : ""
 
+, "Yes"
+: "Ja"
+
+, "No"
+: "Nee"
+
 , "Account canonical form"
 : ""
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : "Login naam"
 
+, "Password"
+: "Wachtwoord"
+
 , "Bind requires DN"
 : ""
 
 , "Start TLS"
 : ""
 
+, "SSL"
+: "SSL"
+
+, "Port"
+: "Poort"
+
 , "Base DN"
 : ""
 
 , "Search filter"
 : "Zoekfilter"
 
+, "Hostname"
+: ""
+
+, "Secure Connection"
+: ""
+
+, "None"
+: ""
+
+, "TLS"
+: "TLS"
+
+, "Append domain to login name"
+: ""
+
 , "Certificate validation"
 : ""
 
@@ -454,39 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : ""
 
-, "Performing Environment Checks..."
-: ""
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: ""
-
-, "Check"
-: ""
-
-, "Result"
-: "Resultaat"
-
-, "Error"
-: "Fout"
-
-, "Run setup tests"
-: ""
-
-, "Ignore setup tests"
-: ""
-
-, "Application, Applications"
-: [
-  "Toepassing"
- ,"Toepassingen"
-
-]
 , "File"
 : "Bestand"
 
 , "Setup Authentication"
 : ""
 
+, "Username"
+: "Gebruikersnaam"
+
 , "Database"
 : "Database"
 
@@ -553,6 +400,160 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : ""
 
+, "Standard IMAP"
+: ""
+
+, "Standard SMTP"
+: ""
+
+, "Imap"
+: "Imap"
+
+, "Verify peer Certificate"
+: ""
+
+, "Use system account"
+: ""
+
+, "Use email address as login name"
+: ""
+
+, "Cyrus Admin"
+: ""
+
+, "Cyrus Admin Password"
+: ""
+
+, "Use proxy auth"
+: ""
+
+, "Smtp"
+: ""
+
+, "Authentication"
+: ""
+
+, "Login"
+: ""
+
+, "Plain"
+: ""
+
+, "Primary Domain"
+: ""
+
+, "Secondary Domains (comma separated)"
+: ""
+
+, "Notifications service address"
+: ""
+
+, "Notification Username"
+: ""
+
+, "Notification Password"
+: ""
+
+, "Notifications local client (hostname or IP address)"
+: ""
+
+, "SIEVE"
+: ""
+
+, "MySql Hostname"
+: ""
+
+, "MySql Database"
+: ""
+
+, "MySql User"
+: ""
+
+, "MySql Password"
+: ""
+
+, "MySql Port"
+: ""
+
+, "User or UID"
+: ""
+
+, "Group or GID"
+: ""
+
+, "Home Template"
+: ""
+
+, "Password Scheme"
+: ""
+
+, "PLAIN-MD5"
+: ""
+
+, "MD5-CRYPT"
+: ""
+
+, "SHA1"
+: ""
+
+, "SHA256"
+: ""
+
+, "SSHA256"
+: ""
+
+, "SHA512"
+: ""
+
+, "SSHA512"
+: ""
+
+, "PLAIN"
+: ""
+
+, "Setup"
+: ""
+
+, "Application, Applications"
+: [
+  "Toepassing"
+ ,"Toepassingen"
+
+]
+, "Terms and Conditions"
+: "Voorwaarden"
+
+, "Setup Checks"
+: ""
+
+, "Config Manager"
+: ""
+
+, "Authentication/Accounts"
+: ""
+
+, "Email"
+: "Email"
+
+, "Application Manager"
+: ""
+
+, "I have read the license agreement and accept it"
+: "Ik heb de licentie voorwaarden gelezen en accepteer deze"
+
+, "License Agreement"
+: "Licentie voorwaarden"
+
+, "I have read the privacy agreement and accept it"
+: "Ik heb de privacy voorwaarden gelezen en accepteer deze"
+
+, "Privacy Agreement"
+: "Privacy voorwaarden"
+
+, "Accept Terms and Conditions"
+: "Accepteer de voorwaarden"
+
+
 , "Application"
 : "Toepassing"
 
