@@ -5,190 +5,31 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Setup **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "I have read the license agreement and accept it"
-: "Я прочитал лицензионное соглашение и согласен его соблюдать"
+, "Performing Environment Checks..."
+: "Проведение проверок окружения..."
 
-, "License Agreement"
-: "Лицензионное соглашение"
-
-, "I have read the privacy agreement and accept it"
-: "Я прочёл соглашение о приватных данных и согласен с ними"
-
-, "Privacy Agreement"
-: "Соглашение о приватных данных"
-
-, "Accept Terms and Conditions"
-: "Согласен с правилами и условиями"
-
-, "Backend"
-: "Бэкенд"
-
-, "Standard IMAP"
-: "Стандартный IMAP"
-
-, "Standard SMTP"
-: "Стандартный SMTP"
-
-, "Imap"
-: "Imap"
-
-, "Hostname"
-: "Имя узла"
-
-, "Username"
-: "Имя пользователя"
-
-, "Password"
-: "Пароль"
-
-, "Port"
-: "Порт"
-
-, "Secure Connection"
-: "Безопасное подключение"
-
-, "None"
-: "Нет"
-
-, "TLS"
-: "TLS"
-
-, "SSL"
-: "SSL"
-
-, "Verify peer Certificate"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
 : ""
 
-, "Use system account"
-: "Использование системной учетной записи"
+, "Check"
+: "Проверка"
 
-, "No"
-: "Нет"
+, "Result"
+: "Результат"
 
-, "Yes"
-: "Да"
-
-, "Append domain to login name"
-: "Добавить имя домена в логин"
-
-, "Use email address as login name"
+, "Message"
 : ""
 
-, "Cyrus Admin"
-: ""
+, "Run setup tests"
+: "Запуск тестов установки"
 
-, "Cyrus Admin Password"
-: ""
+, "Ignore setup tests"
+: "Пропустить тестирование"
 
-, "Use proxy auth"
-: ""
-
-, "Smtp"
-: "Smtp"
-
-, "Authentication"
-: "Аутентификация"
-
-, "Login"
-: "Имя пользователя"
-
-, "Plain"
-: "Обычная"
-
-, "Primary Domain"
-: "Основной домен"
-
-, "Secondary Domains (comma separated)"
-: ""
-
-, "Notifications service address"
-: "Адрес службы уведомлений"
-
-, "Notification Username"
-: "Имя службы уведомлений"
-
-, "Notification Password"
-: "Пароль службы уведомлений"
-
-, "Notifications local client (hostname or IP address)"
-: ""
-
-, "SIEVE"
-: "SIEVE"
-
-, "MySql Hostname"
-: "Хост MySQL"
-
-, "MySql Database"
-: "База данных MySql"
-
-, "MySql User"
-: "Пользователь MySql"
-
-, "MySql Password"
-: "Пароль MySql"
-
-, "MySql Port"
-: "Порт MySql"
-
-, "User or UID"
-: "Пользователь или UID"
-
-, "Group or GID"
-: "Группа или GID"
-
-, "Home Template"
-: ""
-
-, "Password Scheme"
-: "Схема пароля"
-
-, "PLAIN-MD5"
-: "PLAIN-MD5"
-
-, "MD5-CRYPT"
-: "MD5-CRYPT"
-
-, "SHA1"
-: "SHA1"
-
-, "SHA256"
-: "SHA256"
-
-, "SSHA256"
-: "SSHA256"
-
-, "SHA512"
-: "SHA512"
-
-, "SSHA512"
-: "SSHA512"
-
-, "PLAIN"
-: "PLAIN"
-
-, "Terms and Conditions"
-: "Условия и Положения"
-
-, "Setup Checks"
-: "Проверки установки"
-
-, "Config Manager"
-: "Управление конфигурацией"
-
-, "Authentication/Accounts"
-: ""
-
-, "Email"
-: "Электронная почта"
-
-, "Application Manager"
-: "Управление приложениями"
-
-, "Setup"
-: ""
+, "Install application"
+: "Установить приложение"
 
 , "Name"
 : "Имя"
@@ -211,14 +52,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : "Зависит от"
 
-, "Install application"
-: "Установить приложение"
-
 , "Uninstall application"
 : "Удалить приложение"
 
-, "Update application"
-: "Обновить приложение"
+, "Update applications"
+: ""
 
 , "Go to {0} login"
 : "Залогиниться в {0}"
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : "Переключение с SQL на LDAP удалит все учётные записи, группы и роли. Вы действительно хотите переключить хранилище учётных записей на LDAP?"
 
+, "Backend"
+: "Бэкенд"
+
 , "TLS client certificate"
 : "TLS сертификат клиента"
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : "Попробуйте разделить имя пользователя"
 
+, "Yes"
+: "Да"
+
+, "No"
+: "Нет"
+
 , "Account canonical form"
 : ""
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : "Имя"
 
+, "Password"
+: "Пароль"
+
 , "Bind requires DN"
 : ""
 
 , "Start TLS"
 : ""
 
+, "SSL"
+: "SSL"
+
+, "Port"
+: "Порт"
+
 , "Base DN"
 : ""
 
 , "Search filter"
 : "Фильтр поиска"
 
+, "Hostname"
+: "Имя узла"
+
+, "Secure Connection"
+: "Безопасное подключение"
+
+, "None"
+: "Нет"
+
+, "TLS"
+: "TLS"
+
+, "Append domain to login name"
+: "Добавить имя домена в логин"
+
 , "Certificate validation"
 : "Проверка сертификата"
 
@@ -454,41 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : "Не должен быть пустым"
 
-, "Performing Environment Checks..."
-: "Проведение проверок окружения..."
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: ""
-
-, "Check"
-: "Проверка"
-
-, "Result"
-: "Результат"
-
-, "Error"
-: "Ошибка"
-
-, "Run setup tests"
-: "Запуск тестов установки"
-
-, "Ignore setup tests"
-: "Пропустить тестирование"
-
-, "Application, Applications"
-: [
-  "Приложение"
- ,"Приложения"
- ,"Приложений"
- ,"Приложений"
-
-]
 , "File"
 : "Файл"
 
 , "Setup Authentication"
 : "Аутентификация установки"
 
+, "Username"
+: "Имя пользователя"
+
 , "Database"
 : "База данных"
 
@@ -555,6 +400,162 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : ""
 
+, "Standard IMAP"
+: "Стандартный IMAP"
+
+, "Standard SMTP"
+: "Стандартный SMTP"
+
+, "Imap"
+: "Imap"
+
+, "Verify peer Certificate"
+: ""
+
+, "Use system account"
+: "Использование системной учетной записи"
+
+, "Use email address as login name"
+: ""
+
+, "Cyrus Admin"
+: ""
+
+, "Cyrus Admin Password"
+: ""
+
+, "Use proxy auth"
+: ""
+
+, "Smtp"
+: "Smtp"
+
+, "Authentication"
+: "Аутентификация"
+
+, "Login"
+: "Имя пользователя"
+
+, "Plain"
+: "Обычная"
+
+, "Primary Domain"
+: "Основной домен"
+
+, "Secondary Domains (comma separated)"
+: ""
+
+, "Notifications service address"
+: "Адрес службы уведомлений"
+
+, "Notification Username"
+: "Имя службы уведомлений"
+
+, "Notification Password"
+: "Пароль службы уведомлений"
+
+, "Notifications local client (hostname or IP address)"
+: ""
+
+, "SIEVE"
+: "SIEVE"
+
+, "MySql Hostname"
+: "Хост MySQL"
+
+, "MySql Database"
+: "База данных MySql"
+
+, "MySql User"
+: "Пользователь MySql"
+
+, "MySql Password"
+: "Пароль MySql"
+
+, "MySql Port"
+: "Порт MySql"
+
+, "User or UID"
+: "Пользователь или UID"
+
+, "Group or GID"
+: "Группа или GID"
+
+, "Home Template"
+: ""
+
+, "Password Scheme"
+: "Схема пароля"
+
+, "PLAIN-MD5"
+: "PLAIN-MD5"
+
+, "MD5-CRYPT"
+: "MD5-CRYPT"
+
+, "SHA1"
+: "SHA1"
+
+, "SHA256"
+: "SHA256"
+
+, "SSHA256"
+: "SSHA256"
+
+, "SHA512"
+: "SHA512"
+
+, "SSHA512"
+: "SSHA512"
+
+, "PLAIN"
+: "PLAIN"
+
+, "Setup"
+: ""
+
+, "Application, Applications"
+: [
+  "Приложение"
+ ,"Приложения"
+ ,"Приложений"
+ ,"Приложений"
+
+]
+, "Terms and Conditions"
+: "Условия и Положения"
+
+, "Setup Checks"
+: "Проверки установки"
+
+, "Config Manager"
+: "Управление конфигурацией"
+
+, "Authentication/Accounts"
+: ""
+
+, "Email"
+: "Электронная почта"
+
+, "Application Manager"
+: "Управление приложениями"
+
+, "I have read the license agreement and accept it"
+: "Я прочитал лицензионное соглашение и согласен его соблюдать"
+
+, "License Agreement"
+: "Лицензионное соглашение"
+
+, "I have read the privacy agreement and accept it"
+: "Я прочёл соглашение о приватных данных и согласен с ними"
+
+, "Privacy Agreement"
+: "Соглашение о приватных данных"
+
+, "Accept Terms and Conditions"
+: "Согласен с правилами и условиями"
+
+
 , "Application"
 : "Приложение"
 
