@@ -5,189 +5,30 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Setup **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Slovenian (http://www.transifex.com/tine20/tine20/language/sl/)\nLanguage: sl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Slovenian (http://www.transifex.com/tine20/tine20/language/sl/)\nLanguage: sl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "I have read the license agreement and accept it"
+, "Performing Environment Checks..."
 : ""
 
-, "License Agreement"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
 : ""
 
-, "I have read the privacy agreement and accept it"
+, "Check"
 : ""
 
-, "Privacy Agreement"
+, "Result"
 : ""
 
-, "Accept Terms and Conditions"
+, "Message"
 : ""
 
-, "Backend"
+, "Run setup tests"
 : ""
 
-, "Standard IMAP"
+, "Ignore setup tests"
 : ""
 
-, "Standard SMTP"
-: ""
-
-, "Imap"
-: ""
-
-, "Hostname"
-: ""
-
-, "Username"
-: ""
-
-, "Password"
-: ""
-
-, "Port"
-: ""
-
-, "Secure Connection"
-: ""
-
-, "None"
-: ""
-
-, "TLS"
-: ""
-
-, "SSL"
-: ""
-
-, "Verify peer Certificate"
-: ""
-
-, "Use system account"
-: ""
-
-, "No"
-: ""
-
-, "Yes"
-: ""
-
-, "Append domain to login name"
-: ""
-
-, "Use email address as login name"
-: ""
-
-, "Cyrus Admin"
-: ""
-
-, "Cyrus Admin Password"
-: ""
-
-, "Use proxy auth"
-: ""
-
-, "Smtp"
-: ""
-
-, "Authentication"
-: ""
-
-, "Login"
-: ""
-
-, "Plain"
-: ""
-
-, "Primary Domain"
-: ""
-
-, "Secondary Domains (comma separated)"
-: ""
-
-, "Notifications service address"
-: ""
-
-, "Notification Username"
-: ""
-
-, "Notification Password"
-: ""
-
-, "Notifications local client (hostname or IP address)"
-: ""
-
-, "SIEVE"
-: ""
-
-, "MySql Hostname"
-: ""
-
-, "MySql Database"
-: ""
-
-, "MySql User"
-: ""
-
-, "MySql Password"
-: ""
-
-, "MySql Port"
-: ""
-
-, "User or UID"
-: ""
-
-, "Group or GID"
-: ""
-
-, "Home Template"
-: ""
-
-, "Password Scheme"
-: ""
-
-, "PLAIN-MD5"
-: ""
-
-, "MD5-CRYPT"
-: ""
-
-, "SHA1"
-: ""
-
-, "SHA256"
-: ""
-
-, "SSHA256"
-: ""
-
-, "SHA512"
-: ""
-
-, "SSHA512"
-: ""
-
-, "PLAIN"
-: ""
-
-, "Terms and Conditions"
-: ""
-
-, "Setup Checks"
-: ""
-
-, "Config Manager"
-: ""
-
-, "Authentication/Accounts"
-: ""
-
-, "Email"
-: ""
-
-, "Application Manager"
-: ""
-
-, "Setup"
+, "Install application"
 : ""
 
 , "Name"
@@ -211,13 +52,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : ""
 
-, "Install application"
-: ""
-
 , "Uninstall application"
 : ""
 
-, "Update application"
+, "Update applications"
 : ""
 
 , "Go to {0} login"
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : ""
 
+, "Backend"
+: ""
+
 , "TLS client certificate"
 : ""
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : ""
 
+, "Yes"
+: ""
+
+, "No"
+: ""
+
 , "Account canonical form"
 : ""
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : ""
 
+, "Password"
+: ""
+
 , "Bind requires DN"
 : ""
 
 , "Start TLS"
 : ""
 
+, "SSL"
+: ""
+
+, "Port"
+: ""
+
 , "Base DN"
 : ""
 
 , "Search filter"
 : ""
 
+, "Hostname"
+: ""
+
+, "Secure Connection"
+: ""
+
+, "None"
+: ""
+
+, "TLS"
+: ""
+
+, "Append domain to login name"
+: ""
+
 , "Certificate validation"
 : ""
 
@@ -454,41 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : ""
 
-, "Performing Environment Checks..."
-: ""
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: ""
-
-, "Check"
-: ""
-
-, "Result"
-: ""
-
-, "Error"
-: ""
-
-, "Run setup tests"
-: ""
-
-, "Ignore setup tests"
-: ""
-
-, "Application, Applications"
-: [
-  ""
- ,""
- ,""
- ,""
-
-]
 , "File"
 : ""
 
 , "Setup Authentication"
 : ""
 
+, "Username"
+: ""
+
 , "Database"
 : ""
 
@@ -555,6 +400,161 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : ""
 
+, "Standard IMAP"
+: ""
+
+, "Standard SMTP"
+: ""
+
+, "Imap"
+: ""
+
+, "Verify peer Certificate"
+: ""
+
+, "Use system account"
+: ""
+
+, "Use email address as login name"
+: ""
+
+, "Cyrus Admin"
+: ""
+
+, "Cyrus Admin Password"
+: ""
+
+, "Use proxy auth"
+: ""
+
+, "Smtp"
+: ""
+
+, "Authentication"
+: ""
+
+, "Login"
+: ""
+
+, "Plain"
+: ""
+
+, "Primary Domain"
+: ""
+
+, "Secondary Domains (comma separated)"
+: ""
+
+, "Notifications service address"
+: ""
+
+, "Notification Username"
+: ""
+
+, "Notification Password"
+: ""
+
+, "Notifications local client (hostname or IP address)"
+: ""
+
+, "SIEVE"
+: ""
+
+, "MySql Hostname"
+: ""
+
+, "MySql Database"
+: ""
+
+, "MySql User"
+: ""
+
+, "MySql Password"
+: ""
+
+, "MySql Port"
+: ""
+
+, "User or UID"
+: ""
+
+, "Group or GID"
+: ""
+
+, "Home Template"
+: ""
+
+, "Password Scheme"
+: ""
+
+, "PLAIN-MD5"
+: ""
+
+, "MD5-CRYPT"
+: ""
+
+, "SHA1"
+: ""
+
+, "SHA256"
+: ""
+
+, "SSHA256"
+: ""
+
+, "SHA512"
+: ""
+
+, "SSHA512"
+: ""
+
+, "PLAIN"
+: ""
+
+, "Setup"
+: ""
+
+, "Application, Applications"
+: [
+  ""
+ ,""
+ ,""
+ ,""
+
+]
+, "Terms and Conditions"
+: ""
+
+, "Setup Checks"
+: ""
+
+, "Config Manager"
+: ""
+
+, "Authentication/Accounts"
+: ""
+
+, "Email"
+: ""
+
+, "Application Manager"
+: ""
+
+, "I have read the license agreement and accept it"
+: ""
+
+, "License Agreement"
+: ""
+
+, "I have read the privacy agreement and accept it"
+: ""
+
+, "Privacy Agreement"
+: ""
+
+, "Accept Terms and Conditions"
+: ""
+
 , "Application"
 : ""
 
