@@ -5,190 +5,31 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Setup **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "I have read the license agreement and accept it"
-: "Unë e kam lexuar marrveshjen e licensave dhe e kam pranuar atë"
+, "Performing Environment Checks..."
+: "Duke kryer kontrollet e ambientit..."
 
-, "License Agreement"
-: "Marveshje Licensash"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
+: "Nuk u gjet ndonje {0}. Ju lutem provoni të ndryshoni kërkesat e fitrave tuaj, mundësite e shfaqesose {1} ku kërkoni"
 
-, "I have read the privacy agreement and accept it"
-: "Unë e kam lexuar marrveshjen e fshehtësive dhe e kam pranuar atë"
+, "Check"
+: "Kontrollo"
 
-, "Privacy Agreement"
-: "Marrveshje e Fshehtësive"
+, "Result"
+: "Rezultati"
 
-, "Accept Terms and Conditions"
-: "Prano Kushtet dhe Konditat"
-
-, "Backend"
-: "Fundori"
-
-, "Standard IMAP"
-: "IMAP standart"
-
-, "Standard SMTP"
-: "SMPT standarte"
-
-, "Imap"
-: "Imap"
-
-, "Hostname"
-: "Emri i Pritësit(Host)"
-
-, "Username"
-: "Emri Përdoruesit"
-
-, "Password"
-: "Fjalëkalimi"
-
-, "Port"
-: "Porta"
-
-, "Secure Connection"
-: "Lidhje e sigurtë"
-
-, "None"
-: "Asnjë"
-
-, "TLS"
-: "TLS"
-
-, "SSL"
-: "SSL"
-
-, "Verify peer Certificate"
+, "Message"
 : ""
 
-, "Use system account"
-: "Përdor llogarinë e sistemit"
+, "Run setup tests"
+: "Kryej teste konfigurimi"
 
-, "No"
-: "Jo"
+, "Ignore setup tests"
+: "Injoro testet e konfigurimit"
 
-, "Yes"
-: "Po"
-
-, "Append domain to login name"
-: "Bashkangjit domain me emrin e hyrjes"
-
-, "Use email address as login name"
-: ""
-
-, "Cyrus Admin"
-: "Administrator Cyrus"
-
-, "Cyrus Admin Password"
-: "Fjalëkalimi i administratorit Cyrus"
-
-, "Use proxy auth"
-: "Përdor autentifikim proxy"
-
-, "Smtp"
-: "Smtp"
-
-, "Authentication"
-: "Autentifikim"
-
-, "Login"
-: "Hyrje"
-
-, "Plain"
-: "E thjeshtë"
-
-, "Primary Domain"
-: "Domain parësor"
-
-, "Secondary Domains (comma separated)"
-: "Domain dytësor (e ndare me presje)"
-
-, "Notifications service address"
-: "Adresa e shërbimit të njoftimeve"
-
-, "Notification Username"
-: "Emër përdoruesi i njoftuesit"
-
-, "Notification Password"
-: "Fjalëkalimi i njoftuesit"
-
-, "Notifications local client (hostname or IP address)"
-: "Klienti lokal i njoftimeve ( emri pritesit(host) ose adresa IP)"
-
-, "SIEVE"
-: "SIEVE"
-
-, "MySql Hostname"
-: "Emri Pritësit(host) MySql"
-
-, "MySql Database"
-: "Databaza MySql"
-
-, "MySql User"
-: "Përdoruesi MySql"
-
-, "MySql Password"
-: "Fjalëkalimi MySql"
-
-, "MySql Port"
-: "Porta MySql"
-
-, "User or UID"
-: "Përdorues ose UID"
-
-, "Group or GID"
-: "Grup ose GID"
-
-, "Home Template"
-: "Shablloni kryesor"
-
-, "Password Scheme"
-: "Skema e Fjalëkalimit"
-
-, "PLAIN-MD5"
-: "PLAIN-MD5"
-
-, "MD5-CRYPT"
-: "MD5-CRYPT"
-
-, "SHA1"
-: "SHA1"
-
-, "SHA256"
-: "SHA256"
-
-, "SSHA256"
-: "SSHA256"
-
-, "SHA512"
-: "SHA512"
-
-, "SSHA512"
-: "SSHA512"
-
-, "PLAIN"
-: "PLAIN"
-
-, "Terms and Conditions"
-: "Kushtet dhe Konditat"
-
-, "Setup Checks"
-: "Kontrolle Konfigurimi"
-
-, "Config Manager"
-: "Menaxhuesi i Konfigurimeve"
-
-, "Authentication/Accounts"
-: "Autentifikimi/Llogaritë"
-
-, "Email"
-: "E-Postë"
-
-, "Application Manager"
-: "Menaxheri i Aplikacioneve"
-
-, "Setup"
-: ""
+, "Install application"
+: "Instalo aplikacionin"
 
 , "Name"
 : "Emër"
@@ -211,14 +52,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : "Varet nga"
 
-, "Install application"
-: "Instalo aplikacionin"
-
 , "Uninstall application"
 : "Ç'instalo aplikacionin"
 
-, "Update application"
-: "Përditëso aplikacionin"
+, "Update applications"
+: ""
 
 , "Go to {0} login"
 : "Shko tek hyrja {0}"
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : "Ndryshimi nga SQL në LDAP do të fshijë të gjitha Logaritë e Përdoruesëve, Grupet, dhe RoletDoni vërtetë të ndryshoni arkivën fundore të përdoruesve në LDAP?"
 
+, "Backend"
+: "Fundori"
+
 , "TLS client certificate"
 : "Certifikata TSL e klientit"
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : "Mundohu të ndash Emrin e përdoruesit"
 
+, "Yes"
+: "Po"
+
+, "No"
+: "Jo"
+
 , "Account canonical form"
 : "Llogari e autorizuar nga"
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : "Emri i Hyrjes"
 
+, "Password"
+: "Fjalëkalimi"
+
 , "Bind requires DN"
 : "Bind kërkon DN"
 
 , "Start TLS"
 : "Nis TSL"
 
+, "SSL"
+: "SSL"
+
+, "Port"
+: "Porta"
+
 , "Base DN"
 : "DN bazë"
 
 , "Search filter"
 : "Filtri i kërkimit"
 
+, "Hostname"
+: "Emri i Pritësit(Host)"
+
+, "Secure Connection"
+: "Lidhje e sigurtë"
+
+, "None"
+: "Asnjë"
+
+, "TLS"
+: "TLS"
+
+, "Append domain to login name"
+: "Bashkangjit domain me emrin e hyrjes"
+
 , "Certificate validation"
 : "Vertetimi i certifikates"
 
@@ -454,39 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : "Nuk duhet të jetë bosh"
 
-, "Performing Environment Checks..."
-: "Duke kryer kontrollet e ambientit..."
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: "Nuk u gjet ndonje {0}. Ju lutem provoni të ndryshoni kërkesat e fitrave tuaj, mundësite e shfaqesose {1} ku kërkoni"
-
-, "Check"
-: "Kontrollo"
-
-, "Result"
-: "Rezultati"
-
-, "Error"
-: "Gabim"
-
-, "Run setup tests"
-: "Kryej teste konfigurimi"
-
-, "Ignore setup tests"
-: "Injoro testet e konfigurimit"
-
-, "Application, Applications"
-: [
-  "Aplikacion"
- ,"Aplikacione"
-
-]
 , "File"
 : "Skedar"
 
 , "Setup Authentication"
 : "Autentifikimi i Konfigurimit"
 
+, "Username"
+: "Emri Përdoruesit"
+
 , "Database"
 : "Databaza"
 
@@ -553,6 +400,160 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : ""
 
+, "Standard IMAP"
+: "IMAP standart"
+
+, "Standard SMTP"
+: "SMPT standarte"
+
+, "Imap"
+: "Imap"
+
+, "Verify peer Certificate"
+: ""
+
+, "Use system account"
+: "Përdor llogarinë e sistemit"
+
+, "Use email address as login name"
+: ""
+
+, "Cyrus Admin"
+: "Administrator Cyrus"
+
+, "Cyrus Admin Password"
+: "Fjalëkalimi i administratorit Cyrus"
+
+, "Use proxy auth"
+: "Përdor autentifikim proxy"
+
+, "Smtp"
+: "Smtp"
+
+, "Authentication"
+: "Autentifikim"
+
+, "Login"
+: "Hyrje"
+
+, "Plain"
+: "E thjeshtë"
+
+, "Primary Domain"
+: "Domain parësor"
+
+, "Secondary Domains (comma separated)"
+: "Domain dytësor (e ndare me presje)"
+
+, "Notifications service address"
+: "Adresa e shërbimit të njoftimeve"
+
+, "Notification Username"
+: "Emër përdoruesi i njoftuesit"
+
+, "Notification Password"
+: "Fjalëkalimi i njoftuesit"
+
+, "Notifications local client (hostname or IP address)"
+: "Klienti lokal i njoftimeve ( emri pritesit(host) ose adresa IP)"
+
+, "SIEVE"
+: "SIEVE"
+
+, "MySql Hostname"
+: "Emri Pritësit(host) MySql"
+
+, "MySql Database"
+: "Databaza MySql"
+
+, "MySql User"
+: "Përdoruesi MySql"
+
+, "MySql Password"
+: "Fjalëkalimi MySql"
+
+, "MySql Port"
+: "Porta MySql"
+
+, "User or UID"
+: "Përdorues ose UID"
+
+, "Group or GID"
+: "Grup ose GID"
+
+, "Home Template"
+: "Shablloni kryesor"
+
+, "Password Scheme"
+: "Skema e Fjalëkalimit"
+
+, "PLAIN-MD5"
+: "PLAIN-MD5"
+
+, "MD5-CRYPT"
+: "MD5-CRYPT"
+
+, "SHA1"
+: "SHA1"
+
+, "SHA256"
+: "SHA256"
+
+, "SSHA256"
+: "SSHA256"
+
+, "SHA512"
+: "SHA512"
+
+, "SSHA512"
+: "SSHA512"
+
+, "PLAIN"
+: "PLAIN"
+
+, "Setup"
+: ""
+
+, "Application, Applications"
+: [
+  "Aplikacion"
+ ,"Aplikacione"
+
+]
+, "Terms and Conditions"
+: "Kushtet dhe Konditat"
+
+, "Setup Checks"
+: "Kontrolle Konfigurimi"
+
+, "Config Manager"
+: "Menaxhuesi i Konfigurimeve"
+
+, "Authentication/Accounts"
+: "Autentifikimi/Llogaritë"
+
+, "Email"
+: "E-Postë"
+
+, "Application Manager"
+: "Menaxheri i Aplikacioneve"
+
+, "I have read the license agreement and accept it"
+: "Unë e kam lexuar marrveshjen e licensave dhe e kam pranuar atë"
+
+, "License Agreement"
+: "Marveshje Licensash"
+
+, "I have read the privacy agreement and accept it"
+: "Unë e kam lexuar marrveshjen e fshehtësive dhe e kam pranuar atë"
+
+, "Privacy Agreement"
+: "Marrveshje e Fshehtësive"
+
+, "Accept Terms and Conditions"
+: "Prano Kushtet dhe Konditat"
+
+
 , "Application"
 : "Aplikacion"
 
