@@ -5,190 +5,31 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Setup **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "I have read the license agreement and accept it"
+, "Performing Environment Checks..."
 : ""
 
-, "License Agreement"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
 : ""
 
-, "I have read the privacy agreement and accept it"
+, "Check"
+: "ตรวจสอบ"
+
+, "Result"
+: "ผลลัพธ์"
+
+, "Message"
 : ""
 
-, "Privacy Agreement"
-: "ข้อตกลงเรื่องความเป็นส่วนตัว"
-
-, "Accept Terms and Conditions"
+, "Run setup tests"
 : ""
 
-, "Backend"
-: "ส่วนหลัง"
-
-, "Standard IMAP"
-: "IMAP มาตรฐาน"
-
-, "Standard SMTP"
-: "SMTP มาตรฐาน "
-
-, "Imap"
+, "Ignore setup tests"
 : ""
 
-, "Hostname"
-: "ชื่อแม่ข่าย"
-
-, "Username"
-: "ชื่อผู้ใช้"
-
-, "Password"
-: "รหัสผ่าน"
-
-, "Port"
-: "พอร์ท"
-
-, "Secure Connection"
-: "การเชื่อมต่อที่ปลอดภัย"
-
-, "None"
-: "ไม่มีเลย"
-
-, "TLS"
-: "TLS"
-
-, "SSL"
-: "SSL"
-
-, "Verify peer Certificate"
-: ""
-
-, "Use system account"
-: "ใช้บัญชีของระบบ"
-
-, "No"
-: "ไม่"
-
-, "Yes"
-: "ใช่"
-
-, "Append domain to login name"
-: ""
-
-, "Use email address as login name"
-: ""
-
-, "Cyrus Admin"
-: ""
-
-, "Cyrus Admin Password"
-: ""
-
-, "Use proxy auth"
-: ""
-
-, "Smtp"
-: "Smtp"
-
-, "Authentication"
-: "การอนุญาต"
-
-, "Login"
-: "ลงบันทึกเข้า"
-
-, "Plain"
-: "ธรรมดา"
-
-, "Primary Domain"
-: "โดเมนหลัก"
-
-, "Secondary Domains (comma separated)"
-: "โดเมนรอง (แบ่งโดยจุลภาค)"
-
-, "Notifications service address"
-: ""
-
-, "Notification Username"
-: "การแจ้งชื่อผู้ใช้"
-
-, "Notification Password"
-: "การแจ้งรหัสผ่าน"
-
-, "Notifications local client (hostname or IP address)"
-: ""
-
-, "SIEVE"
-: "กรอง"
-
-, "MySql Hostname"
-: "ชื่อแม่ข่าย MySql"
-
-, "MySql Database"
-: "ฐานข้อมูล MySql"
-
-, "MySql User"
-: "ผู้ใช้ MySql"
-
-, "MySql Password"
-: "รหัสผ่าน MySql"
-
-, "MySql Port"
-: "พอร์ท MySql"
-
-, "User or UID"
-: "ผู้ใช้ หรือ UID"
-
-, "Group or GID"
-: "กลุ่ม หรือ GID"
-
-, "Home Template"
-: ""
-
-, "Password Scheme"
-: ""
-
-, "PLAIN-MD5"
-: ""
-
-, "MD5-CRYPT"
-: ""
-
-, "SHA1"
-: ""
-
-, "SHA256"
-: ""
-
-, "SSHA256"
-: ""
-
-, "SHA512"
-: ""
-
-, "SSHA512"
-: ""
-
-, "PLAIN"
-: ""
-
-, "Terms and Conditions"
-: ""
-
-, "Setup Checks"
-: ""
-
-, "Config Manager"
-: ""
-
-, "Authentication/Accounts"
-: ""
-
-, "Email"
-: "อีเมล"
-
-, "Application Manager"
-: "ตัวจัดการแอพพลิเคชั่น"
-
-, "Setup"
-: ""
+, "Install application"
+: "ติดตั้งแอพพลิเคชั่น"
 
 , "Name"
 : "ชื่อ"
@@ -211,14 +52,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : "ขึ้นอยู่กับ"
 
-, "Install application"
-: "ติดตั้งแอพพลิเคชั่น"
-
 , "Uninstall application"
 : "ถอนการติดตั้งแอพพลิเคชั่น"
 
-, "Update application"
-: "อัพเดทแอพพลิเคชั่น"
+, "Update applications"
+: ""
 
 , "Go to {0} login"
 : "ไปยังการเข้าใช้ {0} "
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : "การสลับจาก SQL ไปยัง LDAP จะลบบัญชี กลุ่ม และหน้าที่ของผู้ใช้ที่มีอยู่ทั้งหมด คุณแน่ใจว่าต้องการสลับการจัดเก็บบัญชีส่วนหลังไปใช้ LDAP?"
 
+, "Backend"
+: "ส่วนหลัง"
+
 , "TLS client certificate"
 : ""
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : "พยายามที่จะแตกชื่อผู้ใช้"
 
+, "Yes"
+: "ใช่"
+
+, "No"
+: "ไม่"
+
 , "Account canonical form"
 : ""
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : "ชื่อที่เข้าใช้"
 
+, "Password"
+: "รหัสผ่าน"
+
 , "Bind requires DN"
 : "การเชื่อมต่อต้องการ DN"
 
 , "Start TLS"
 : "เริ่ม TLS"
 
+, "SSL"
+: "SSL"
+
+, "Port"
+: "พอร์ท"
+
 , "Base DN"
 : "ฐาน DN"
 
 , "Search filter"
 : "หาตัวกรอง"
 
+, "Hostname"
+: "ชื่อแม่ข่าย"
+
+, "Secure Connection"
+: "การเชื่อมต่อที่ปลอดภัย"
+
+, "None"
+: "ไม่มีเลย"
+
+, "TLS"
+: "TLS"
+
+, "Append domain to login name"
+: ""
+
 , "Certificate validation"
 : ""
 
@@ -454,38 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : "ไม่ควรว่างไว้"
 
-, "Performing Environment Checks..."
-: ""
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: ""
-
-, "Check"
-: "ตรวจสอบ"
-
-, "Result"
-: "ผลลัพธ์"
-
-, "Error"
-: "ผิดพลาด"
-
-, "Run setup tests"
-: ""
-
-, "Ignore setup tests"
-: ""
-
-, "Application, Applications"
-: [
-  "แอพพลิเคชั่น"
-
-]
 , "File"
 : "ไฟล์"
 
 , "Setup Authentication"
 : "การอนุญาตติดตั้ง"
 
+, "Username"
+: "ชื่อผู้ใช้"
+
 , "Database"
 : "ฐานข้อมูล"
 
@@ -552,6 +400,159 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : ""
 
+, "Standard IMAP"
+: "IMAP มาตรฐาน"
+
+, "Standard SMTP"
+: "SMTP มาตรฐาน "
+
+, "Imap"
+: ""
+
+, "Verify peer Certificate"
+: ""
+
+, "Use system account"
+: "ใช้บัญชีของระบบ"
+
+, "Use email address as login name"
+: ""
+
+, "Cyrus Admin"
+: ""
+
+, "Cyrus Admin Password"
+: ""
+
+, "Use proxy auth"
+: ""
+
+, "Smtp"
+: "Smtp"
+
+, "Authentication"
+: "การอนุญาต"
+
+, "Login"
+: "ลงบันทึกเข้า"
+
+, "Plain"
+: "ธรรมดา"
+
+, "Primary Domain"
+: "โดเมนหลัก"
+
+, "Secondary Domains (comma separated)"
+: "โดเมนรอง (แบ่งโดยจุลภาค)"
+
+, "Notifications service address"
+: ""
+
+, "Notification Username"
+: "การแจ้งชื่อผู้ใช้"
+
+, "Notification Password"
+: "การแจ้งรหัสผ่าน"
+
+, "Notifications local client (hostname or IP address)"
+: ""
+
+, "SIEVE"
+: "กรอง"
+
+, "MySql Hostname"
+: "ชื่อแม่ข่าย MySql"
+
+, "MySql Database"
+: "ฐานข้อมูล MySql"
+
+, "MySql User"
+: "ผู้ใช้ MySql"
+
+, "MySql Password"
+: "รหัสผ่าน MySql"
+
+, "MySql Port"
+: "พอร์ท MySql"
+
+, "User or UID"
+: "ผู้ใช้ หรือ UID"
+
+, "Group or GID"
+: "กลุ่ม หรือ GID"
+
+, "Home Template"
+: ""
+
+, "Password Scheme"
+: ""
+
+, "PLAIN-MD5"
+: ""
+
+, "MD5-CRYPT"
+: ""
+
+, "SHA1"
+: ""
+
+, "SHA256"
+: ""
+
+, "SSHA256"
+: ""
+
+, "SHA512"
+: ""
+
+, "SSHA512"
+: ""
+
+, "PLAIN"
+: ""
+
+, "Setup"
+: ""
+
+, "Application, Applications"
+: [
+  "แอพพลิเคชั่น"
+
+]
+, "Terms and Conditions"
+: ""
+
+, "Setup Checks"
+: ""
+
+, "Config Manager"
+: ""
+
+, "Authentication/Accounts"
+: ""
+
+, "Email"
+: "อีเมล"
+
+, "Application Manager"
+: "ตัวจัดการแอพพลิเคชั่น"
+
+, "I have read the license agreement and accept it"
+: ""
+
+, "License Agreement"
+: ""
+
+, "I have read the privacy agreement and accept it"
+: ""
+
+, "Privacy Agreement"
+: "ข้อตกลงเรื่องความเป็นส่วนตัว"
+
+, "Accept Terms and Conditions"
+: ""
+
+
 , "Application"
 : "แอพพลิเคชั่น"
 
