@@ -5,190 +5,31 @@ Tine.__translationData.msgs = Tine.__translationData.msgs || {};
 /********************** tine translations of Setup **********************/ 
 Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 ""
-: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
+: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"
 
-, "I have read the license agreement and accept it"
-: "Tôi đã đọc thỏa thuận về giấy phép sử dụng và chấp nhận nó."
+, "Performing Environment Checks..."
+: "Đang thực hiện kiểm tra môi trường ..."
 
-, "License Agreement"
-: "Thỏa thuận giấy phép sử dụng"
+, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
+: "Không có gì được tìm thấy {0}. Xin thay đổi điều kiện tìm kiếm của bạn, tùy chọn xem hoặc {1} bạn tìm kiếm trong đó."
 
-, "I have read the privacy agreement and accept it"
-: "Tôi đã đọc chính sách riêng tư và chấp nhận nó"
+, "Check"
+: "Kiểm tra"
 
-, "Privacy Agreement"
-: "Thỏa thuận chính sách"
+, "Result"
+: "Kết quả"
 
-, "Accept Terms and Conditions"
-: "Điều khoản sử dụng"
-
-, "Backend"
-: "Nền tảng"
-
-, "Standard IMAP"
-: "Standard IMAP"
-
-, "Standard SMTP"
-: "Standard SMTP"
-
-, "Imap"
-: "Imap"
-
-, "Hostname"
-: "Hostname"
-
-, "Username"
-: "Tên đăng nhập"
-
-, "Password"
-: "Mật khẩu"
-
-, "Port"
-: "Cổng"
-
-, "Secure Connection"
-: "Kết nối bảo mật"
-
-, "None"
-: "Không"
-
-, "TLS"
-: "TLS"
-
-, "SSL"
-: "SSL"
-
-, "Verify peer Certificate"
+, "Message"
 : ""
 
-, "Use system account"
-: "Sử dụng tài khoản hệ thống"
+, "Run setup tests"
+: "Chạy kiếm tra cài đặt"
 
-, "No"
-: "Không"
+, "Ignore setup tests"
+: "Bỏ qua kiểm tra cài đặt"
 
-, "Yes"
-: "Có"
-
-, "Append domain to login name"
-: "Ghép domain vào tên đăng nhập"
-
-, "Use email address as login name"
-: ""
-
-, "Cyrus Admin"
-: "Cyrus Admin"
-
-, "Cyrus Admin Password"
-: "Cyrus Admin Password"
-
-, "Use proxy auth"
-: ""
-
-, "Smtp"
-: "Smtp"
-
-, "Authentication"
-: "Authentication"
-
-, "Login"
-: "Đăng nhập"
-
-, "Plain"
-: "Thuần text"
-
-, "Primary Domain"
-: "Domain chính"
-
-, "Secondary Domains (comma separated)"
-: "Domain phụ (cách nhau bằng dấu phẩy)"
-
-, "Notifications service address"
-: "Địa chỉ thông báo dịch vụ"
-
-, "Notification Username"
-: "Người dùng thông báo"
-
-, "Notification Password"
-: "Mật khẩu thông báo"
-
-, "Notifications local client (hostname or IP address)"
-: "Notifications local client (hostname or IP address)"
-
-, "SIEVE"
-: "SIEVE"
-
-, "MySql Hostname"
-: "MySql Hostname"
-
-, "MySql Database"
-: "MySql Database"
-
-, "MySql User"
-: "MySql User"
-
-, "MySql Password"
-: "MySql Password"
-
-, "MySql Port"
-: "MySql Port"
-
-, "User or UID"
-: "User or UID"
-
-, "Group or GID"
-: "Group or GID"
-
-, "Home Template"
-: "Home Template"
-
-, "Password Scheme"
-: "Password Scheme"
-
-, "PLAIN-MD5"
-: "PLAIN-MD5"
-
-, "MD5-CRYPT"
-: "MD5-CRYPT"
-
-, "SHA1"
-: "SHA1"
-
-, "SHA256"
-: "SHA256"
-
-, "SSHA256"
-: "SSHA256"
-
-, "SHA512"
-: "SHA512"
-
-, "SSHA512"
-: "SSHA512"
-
-, "PLAIN"
-: "PLAIN"
-
-, "Terms and Conditions"
-: "Điều khỏa sử dụng"
-
-, "Setup Checks"
-: "Kiểm tra cài đặt"
-
-, "Config Manager"
-: "Quản lý cấu hình"
-
-, "Authentication/Accounts"
-: "Xác thực/ Tài khoản"
-
-, "Email"
-: "Email"
-
-, "Application Manager"
-: "Quản lý ứng dụng"
-
-, "Setup"
-: ""
+, "Install application"
+: "Cài đặt ứng dụng"
 
 , "Name"
 : "Tên"
@@ -211,14 +52,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Depends on"
 : "Phụ thuộc vào"
 
-, "Install application"
-: "Cài đặt ứng dụng"
-
 , "Uninstall application"
 : "Gỡ ứng dụng"
 
-, "Update application"
-: "Cập nhật ứng dụng"
+, "Update applications"
+: ""
 
 , "Go to {0} login"
 : "Tới đăng nhập {0}"
@@ -244,6 +82,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
 : "Chuyển từ SQL sang LDAP sẽ xóa mọi người dùng, nhóm, và vai trò hiện tại. Bạn có thật sự muốn chuyển chế độ lưu trữ tài khoản sang LDAP?"
 
+, "Backend"
+: "Nền tảng"
+
 , "TLS client certificate"
 : ""
 
@@ -265,6 +106,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Try to split username"
 : "Thử tách tên đăng nhập"
 
+, "Yes"
+: "Có"
+
+, "No"
+: "Không"
+
 , "Account canonical form"
 : "Form đăng nhập duy nhất"
 
@@ -280,18 +127,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Login name"
 : "Tên đăng nhập"
 
+, "Password"
+: "Mật khẩu"
+
 , "Bind requires DN"
 : "Bind requires DN"
 
 , "Start TLS"
 : ""
 
+, "SSL"
+: "SSL"
+
+, "Port"
+: "Cổng"
+
 , "Base DN"
 : "Base DN"
 
 , "Search filter"
 : "Bộ lọc tìm kiếm"
 
+, "Hostname"
+: "Hostname"
+
+, "Secure Connection"
+: "Kết nối bảo mật"
+
+, "None"
+: "Không"
+
+, "TLS"
+: "TLS"
+
+, "Append domain to login name"
+: "Ghép domain vào tên đăng nhập"
+
 , "Certificate validation"
 : ""
 
@@ -454,38 +325,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "Should not be empty"
 : "Không thể rỗng"
 
-, "Performing Environment Checks..."
-: "Đang thực hiện kiểm tra môi trường ..."
-
-, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
-: "Không có gì được tìm thấy {0}. Xin thay đổi điều kiện tìm kiếm của bạn, tùy chọn xem hoặc {1} bạn tìm kiếm trong đó."
-
-, "Check"
-: "Kiểm tra"
-
-, "Result"
-: "Kết quả"
-
-, "Error"
-: "Lỗi"
-
-, "Run setup tests"
-: "Chạy kiếm tra cài đặt"
-
-, "Ignore setup tests"
-: "Bỏ qua kiểm tra cài đặt"
-
-, "Application, Applications"
-: [
-  "one: Ứng dụng\nother: Ứng dụng"
-
-]
 , "File"
 : "File"
 
 , "Setup Authentication"
 : "Cài đặt xác thực"
 
+, "Username"
+: "Tên đăng nhập"
+
 , "Database"
 : "Cơ sở dữ liệu"
 
@@ -552,6 +400,159 @@ Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
 , "This prefix is too long. Please choose a prefix no longer than {0} chars."
 : ""
 
+, "Standard IMAP"
+: "Standard IMAP"
+
+, "Standard SMTP"
+: "Standard SMTP"
+
+, "Imap"
+: "Imap"
+
+, "Verify peer Certificate"
+: ""
+
+, "Use system account"
+: "Sử dụng tài khoản hệ thống"
+
+, "Use email address as login name"
+: ""
+
+, "Cyrus Admin"
+: "Cyrus Admin"
+
+, "Cyrus Admin Password"
+: "Cyrus Admin Password"
+
+, "Use proxy auth"
+: ""
+
+, "Smtp"
+: "Smtp"
+
+, "Authentication"
+: "Authentication"
+
+, "Login"
+: "Đăng nhập"
+
+, "Plain"
+: "Thuần text"
+
+, "Primary Domain"
+: "Domain chính"
+
+, "Secondary Domains (comma separated)"
+: "Domain phụ (cách nhau bằng dấu phẩy)"
+
+, "Notifications service address"
+: "Địa chỉ thông báo dịch vụ"
+
+, "Notification Username"
+: "Người dùng thông báo"
+
+, "Notification Password"
+: "Mật khẩu thông báo"
+
+, "Notifications local client (hostname or IP address)"
+: "Notifications local client (hostname or IP address)"
+
+, "SIEVE"
+: "SIEVE"
+
+, "MySql Hostname"
+: "MySql Hostname"
+
+, "MySql Database"
+: "MySql Database"
+
+, "MySql User"
+: "MySql User"
+
+, "MySql Password"
+: "MySql Password"
+
+, "MySql Port"
+: "MySql Port"
+
+, "User or UID"
+: "User or UID"
+
+, "Group or GID"
+: "Group or GID"
+
+, "Home Template"
+: "Home Template"
+
+, "Password Scheme"
+: "Password Scheme"
+
+, "PLAIN-MD5"
+: "PLAIN-MD5"
+
+, "MD5-CRYPT"
+: "MD5-CRYPT"
+
+, "SHA1"
+: "SHA1"
+
+, "SHA256"
+: "SHA256"
+
+, "SSHA256"
+: "SSHA256"
+
+, "SHA512"
+: "SHA512"
+
+, "SSHA512"
+: "SSHA512"
+
+, "PLAIN"
+: "PLAIN"
+
+, "Setup"
+: ""
+
+, "Application, Applications"
+: [
+  "one: Ứng dụng\nother: Ứng dụng"
+
+]
+, "Terms and Conditions"
+: "Điều khỏa sử dụng"
+
+, "Setup Checks"
+: "Kiểm tra cài đặt"
+
+, "Config Manager"
+: "Quản lý cấu hình"
+
+, "Authentication/Accounts"
+: "Xác thực/ Tài khoản"
+
+, "Email"
+: "Email"
+
+, "Application Manager"
+: "Quản lý ứng dụng"
+
+, "I have read the license agreement and accept it"
+: "Tôi đã đọc thỏa thuận về giấy phép sử dụng và chấp nhận nó."
+
+, "License Agreement"
+: "Thỏa thuận giấy phép sử dụng"
+
+, "I have read the privacy agreement and accept it"
+: "Tôi đã đọc chính sách riêng tư và chấp nhận nó"
+
+, "Privacy Agreement"
+: "Thỏa thuận chính sách"
+
+, "Accept Terms and Conditions"
+: "Điều khoản sử dụng"
+
+
 , "Application"
 : "one: Ứng dụng\nother: Ứng dụng"
 
