@@ -7,54 +7,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
 ""
 : "Project-Id-Version: Tine 2.0 - Tasks\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"
 
-, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
-: [
-  "Do you really want to delete the selected task?"
- ,"Do you really want to delete the selected tasks?"
-
-]
-, "Tags"
-: "Tags"
-
-, "Lead name"
-: "Lead name"
-
-, "Summary"
-: "Summary"
-
-, "Add a task..."
-: "Add a task..."
-
-, "Due Date"
-: "Due Date"
-
-, "Priority"
-: "Priority"
-
-, "Percent"
-: "Percent"
-
-, "Status, Status"
-: [
-  "Status"
- ,"Status"
-
-]
-, "Completed"
-: "Completed"
-
-, "Responsible"
-: "Responsible"
-
 , "Add New Task"
 : "Add New Task"
 
 , "You have to supply a due date, because an alarm ist set!"
 : "You have to supply a due date, because an alarm ist set!"
 
+, "Summary"
+: "Summary"
+
 , "Due date"
 : "Due date"
 
+, "Priority"
+: "Priority"
+
 , "Organizer"
 : "Organizer"
 
@@ -70,6 +37,42 @@ Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
 , "Percentage"
 : "Percentage"
 
+, "Status, Status"
+: [
+  "Status"
+ ,"Status"
+
+]
+, "Completed"
+: "Completed"
+
+, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
+: [
+  "Do you really want to delete the selected task?"
+ ,"Do you really want to delete the selected tasks?"
+
+]
+, "Attachments"
+: "Attachments"
+
+, "Tags"
+: "Tags"
+
+, "Lead name"
+: "Lead name"
+
+, "Add a task..."
+: "Add a task..."
+
+, "Due Date"
+: "Due Date"
+
+, "Percent"
+: "Percent"
+
+, "Responsible"
+: "Responsible"
+
 , "Task, Tasks"
 : [
   "Task"
@@ -106,8 +109,32 @@ Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
 , "New Task"
 : "New Task"
 
-, "Notification for Task "
-: "Notification for Task "
+, "All my tasks"
+: "All my tasks"
+
+, "Default Favorite"
+: "Default Favorite"
+
+, "The default favorite which is loaded on Tasks startup"
+: "The default favorite which is loaded on Tasks startup"
+
+, "Default Task List"
+: "Default Task List"
+
+, "The default task list to create new tasks in."
+: "The default task list to create new tasks in."
+
+, "Enable Standard Alarm"
+: "Enable Standard Alarm"
+
+, "New task get a standard alarm as defined below"
+: "New task get a standard alarm as defined below"
+
+, "Standard Alarm Time"
+: "Standard Alarm Time"
+
+, "Minutes before the task ends"
+: "Minutes before the task ends"
 
 , "Tasks status available"
 : "Tasks status available"
@@ -142,6 +169,39 @@ Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
 , "urgent"
 : "urgent"
 
+, "%s's personal tasks"
+: "%s's personal tasks"
+
+, "GENDER_Task"
+: "GENDER_Task"
+
+, "Due"
+: "Due"
+
+, "Class"
+: "Class"
+
+, "Description"
+: "Description"
+
+, "Geo"
+: "Geo"
+
+, "Location"
+: "Location"
+
+, "Lead"
+: "Lead"
+
+, "Telephone"
+: "Telephone"
+
+, "Email"
+: "Email"
+
+, "Notification for Task %1$s"
+: "Notification for Task %1$s"
+
 , "All tasks of my taskslists"
 : "All tasks of my taskslists"
 
@@ -166,9 +226,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
 , "Tasks without responsible"
 : "Tasks without responsible"
 
-, "%s's personal tasks"
-: "%s's personal tasks"
-
 , "manage shared task lists"
 : "manage shared task lists"
 
@@ -181,53 +238,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
 , "Create or update shared tasks favorites"
 : "Create or update shared tasks favorites"
 
-, "Due"
-: "Due"
-
-, "Description"
-: "Description"
-
-, "Lead"
-: "Lead"
-
-, "Telephone"
-: "Telephone"
-
-, "Email"
-: "Email"
-
-, "All my tasks"
-: "All my tasks"
-
-, "Default Favorite"
-: "Default Favorite"
-
-, "The default favorite which is loaded on Tasks startup"
-: "The default favorite which is loaded on Tasks startup"
-
-, "Default Task List"
-: "Default Task List"
-
-, "The default task list to create new tasks in."
-: "The default task list to create new tasks in."
-
-, "Enable Standard Alarm"
-: "Enable Standard Alarm"
-
-, "New task get a standard alarm as defined below"
-: "New task get a standard alarm as defined below"
-
-, "Minutes before the task ends"
-: "Minutes before the task ends"
-
-, "Standard Alarm Time"
-: "Standard Alarm Time"
-, "Do you really want to delete the selected task?"
-: "Do you really want to delete the selected task?"
-
 , "Status"
 : "Status"
 
+, "Do you really want to delete the selected task?"
+: "Do you really want to delete the selected task?"
+
 , "Task"
 : "Task"
 
