@@ -268,6 +268,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -277,11 +280,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : ""
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : "Facturable"
 
-, "Cleared"
-: "Comptabilitzat/Liquidat"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
+: ""
 
 , "Date"
 : "Data"
@@ -307,21 +325,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: "El compte de temps s'ha tancat"
-
 , "Timetracker"
 : "Rastrejador de temps"
 
-, "Timeaccounts to bill"
-: ""
-
-, "Timeaccounts not yet billed"
-: ""
-
-, "Timeaccounts already billed"
-: ""
-
 , "My Timesheets today"
 : ""
 
@@ -337,6 +343,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : ""
 
+, "Timeaccounts to bill"
+: ""
+
+, "Timeaccounts not yet billed"
+: ""
+
+, "Timeaccounts already billed"
+: ""
+
 , "Manage timeaccounts"
 : "Gestiona comptes de temps"
 
@@ -363,6 +378,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 
 
 
+
+
 , "Timesheet"
 : "Full de temps"
 
