@@ -278,6 +278,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -287,11 +290,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : ""
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : "Lze účtovat"
 
-, "Cleared"
-: "Zaplaceno"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
+: ""
 
 , "Date"
 : "Datum"
@@ -317,21 +335,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: "Časový fond uzavřen"
-
 , "Timetracker"
 : "Sledování času"
 
-, "Timeaccounts to bill"
-: ""
-
-, "Timeaccounts not yet billed"
-: ""
-
-, "Timeaccounts already billed"
-: ""
-
 , "My Timesheets today"
 : ""
 
@@ -347,6 +353,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : ""
 
+, "Timeaccounts to bill"
+: ""
+
+, "Timeaccounts not yet billed"
+: ""
+
+, "Timeaccounts already billed"
+: ""
+
 , "Manage timeaccounts"
 : "Spravovat časové fondy"
 
@@ -373,6 +388,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 
 
 
+
+
 , "Timesheet"
 : "Pracovní výkaz"
 
