@@ -268,6 +268,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -277,11 +280,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : ""
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : "Facturable"
 
-, "Cleared"
-: "Autorizado"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
+: ""
 
 , "Date"
 : "Fecha"
@@ -307,21 +325,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: "Cuenta de Trabajo cerrada"
-
 , "Timetracker"
 : "Rastreador de Tiempo"
 
-, "Timeaccounts to bill"
-: "Cuentas de Trabajo por Facturar"
-
-, "Timeaccounts not yet billed"
-: "Cuentas de Trabajo aún no facturadas"
-
-, "Timeaccounts already billed"
-: "Cuentas de Trabajo Facturadas"
-
 , "My Timesheets today"
 : "Mis Hojas de Asistencia hoy"
 
@@ -337,6 +343,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : "Mis Hojas de Asistencia mes pasado"
 
+, "Timeaccounts to bill"
+: "Cuentas de Trabajo por Facturar"
+
+, "Timeaccounts not yet billed"
+: "Cuentas de Trabajo aún no facturadas"
+
+, "Timeaccounts already billed"
+: "Cuentas de Trabajo Facturadas"
+
 , "Manage timeaccounts"
 : "Administrar Cuentas de Trabajo"
 
@@ -363,6 +378,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 
 
 
+
+
 , "Timesheet"
 : "Hoja de Asistencia"
 
