@@ -268,6 +268,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -277,11 +280,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : "Compte de temps (nombre - titre)"
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : "Facturable"
 
-, "Cleared"
-: "Acquitté"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
+: ""
 
 , "Date"
 : "Date"
@@ -307,21 +325,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: "Compte fermé"
-
 , "Timetracker"
 : "Planificateur"
 
-, "Timeaccounts to bill"
-: "Prendre sur ces comptes de temps"
-
-, "Timeaccounts not yet billed"
-: "Comptes de temps pleins"
-
-, "Timeaccounts already billed"
-: "Comptes de temps utilisés"
-
 , "My Timesheets today"
 : "Mon tableau d'ajourd'hui"
 
@@ -337,6 +343,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : "Mon tableau du mois dernier"
 
+, "Timeaccounts to bill"
+: "Prendre sur ces comptes de temps"
+
+, "Timeaccounts not yet billed"
+: "Comptes de temps pleins"
+
+, "Timeaccounts already billed"
+: "Comptes de temps utilisés"
+
 , "Manage timeaccounts"
 : "Gérer"
 
@@ -363,6 +378,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 
 
 
+
+
 , "Timesheet"
 : "Feuille de temps"
 
