@@ -268,6 +268,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -277,11 +280,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : "Időazonosító (Szám - Cím)"
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : "Számlázható"
 
-, "Cleared"
-: "Kiegyenlítve"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
+: ""
 
 , "Date"
 : "Dátum"
@@ -307,21 +325,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: "Időazonosító lezárt"
-
 , "Timetracker"
 : "Munkaidő-követés"
 
-, "Timeaccounts to bill"
-: "Számlázandó időazonosítók"
-
-, "Timeaccounts not yet billed"
-: "Még nem számlázott időazonosítók"
-
-, "Timeaccounts already billed"
-: "Kiszámlázott időazonosítók"
-
 , "My Timesheets today"
 : "Mai munkaidőm"
 
@@ -337,6 +343,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : "Múlt havi munkaidőm"
 
+, "Timeaccounts to bill"
+: "Számlázandó időazonosítók"
+
+, "Timeaccounts not yet billed"
+: "Még nem számlázott időazonosítók"
+
+, "Timeaccounts already billed"
+: "Kiszámlázott időazonosítók"
+
 , "Manage timeaccounts"
 : "Időazonosítók kezelése"
 
@@ -363,6 +378,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 
 
 
+
+
 , "Timesheet"
 : "Munkaidő nyílvántartás"
 
