@@ -268,6 +268,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -277,11 +280,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : "Rendiconto Ore (Numero - Titolo)"
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : "Fatturabile"
 
-, "Cleared"
-: "Approvata"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
+: ""
 
 , "Date"
 : "Data"
@@ -307,21 +325,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: "Rendiconto Ore chiuso"
-
 , "Timetracker"
 : "Indicatore del tempo"
 
-, "Timeaccounts to bill"
-: "Rendiconto ore da fatturare"
-
-, "Timeaccounts not yet billed"
-: "Rendiconto ore non ancora fatturati"
-
-, "Timeaccounts already billed"
-: "Rendiconto ore già fatturati"
-
 , "My Timesheets today"
 : "La mia schede attività di oggi"
 
@@ -337,6 +343,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : "La mia scheda attività dello scorso mese"
 
+, "Timeaccounts to bill"
+: "Rendiconto ore da fatturare"
+
+, "Timeaccounts not yet billed"
+: "Rendiconto ore non ancora fatturati"
+
+, "Timeaccounts already billed"
+: "Rendiconto ore già fatturati"
+
 , "Manage timeaccounts"
 : "Gestisci rendiconto ore"
 
@@ -363,6 +378,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 
 
 
+
+
 , "Timesheet"
 : "Tabella del tempo"
 
