@@ -278,6 +278,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -287,11 +290,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : "Konto czasu (numer - tytuł)"
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : "Do przeliczenia"
 
-, "Cleared"
-: "Przeliczone"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
+: ""
 
 , "Date"
 : "Data"
@@ -317,21 +335,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: "Konto godzin zamknięte"
-
 , "Timetracker"
 : "Zliczanie czasu"
 
-, "Timeaccounts to bill"
-: "Karty czasu pracy do przeliczenia"
-
-, "Timeaccounts not yet billed"
-: "Nieprzeliczone konta godzin"
-
-, "Timeaccounts already billed"
-: "Przeliczone konta godzin"
-
 , "My Timesheets today"
 : "Moje, dzisiejsze karty czasu pracy"
 
@@ -347,6 +353,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : "Moje karty czasu pracy z ubiegłego miesiąca"
 
+, "Timeaccounts to bill"
+: "Karty czasu pracy do przeliczenia"
+
+, "Timeaccounts not yet billed"
+: "Nieprzeliczone konta godzin"
+
+, "Timeaccounts already billed"
+: "Przeliczone konta godzin"
+
 , "Manage timeaccounts"
 : "Zarządzaj kontami godzin"
 
@@ -373,6 +388,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 
 
 
+
+
 , "Timesheet"
 : "Karta czasu pracy"
 
