@@ -268,6 +268,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -277,11 +280,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : "Contagem de Tempo (Número - Título)"
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : "Faturável"
 
-, "Cleared"
-: "Apuradas"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
+: ""
 
 , "Date"
 : "Data"
@@ -307,21 +325,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: "Contagem de Tempo fechada"
-
 , "Timetracker"
 : "Prazo"
 
-, "Timeaccounts to bill"
-: "Contagem de tempo para faturar"
-
-, "Timeaccounts not yet billed"
-: "Contagem de tempo ainda não faturada"
-
-, "Timeaccounts already billed"
-: "Contagem de tempo já faturada"
-
 , "My Timesheets today"
 : "Minhas Planilhas de tempo hoje"
 
@@ -337,6 +343,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : "Minhas Planilhas de tempo do último mes"
 
+, "Timeaccounts to bill"
+: "Contagem de tempo para faturar"
+
+, "Timeaccounts not yet billed"
+: "Contagem de tempo ainda não faturada"
+
+, "Timeaccounts already billed"
+: "Contagem de tempo já faturada"
+
 , "Manage timeaccounts"
 : "Gerenciar planilhas de tempo"
 
@@ -363,6 +378,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 
 
 
+
+
 , "Timesheet"
 : "Planilha de Tempo"
 
