@@ -263,6 +263,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -272,11 +275,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : "บัญชีเวลา (หมายเลข - ตำแหน่ง)"
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : "ที่เรียกเก็บเงินได้"
 
-, "Cleared"
-: "เคลียร์แล้ว"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
+: ""
 
 , "Date"
 : "วันที่"
@@ -302,21 +320,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: "บัญชีเวลาปิดแล้ว"
-
 , "Timetracker"
 : "ตัวติดตามเวลา"
 
-, "Timeaccounts to bill"
-: "บัญชีเวลาที่จะต้องเรียกเก็บเงิน"
-
-, "Timeaccounts not yet billed"
-: "บัญชีเวลาที่ยังไม่ได้เรียกเก็บเงิน"
-
-, "Timeaccounts already billed"
-: "บัญชีเวลาที่ได้เรียกเก็บเงินแล้ว"
-
 , "My Timesheets today"
 : "ตารางเวลาของฉัน วันนี้"
 
@@ -332,6 +338,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : "ตารางเวลาของฉัน เดือนที่แล้ว"
 
+, "Timeaccounts to bill"
+: "บัญชีเวลาที่จะต้องเรียกเก็บเงิน"
+
+, "Timeaccounts not yet billed"
+: "บัญชีเวลาที่ยังไม่ได้เรียกเก็บเงิน"
+
+, "Timeaccounts already billed"
+: "บัญชีเวลาที่ได้เรียกเก็บเงินแล้ว"
+
 , "Manage timeaccounts"
 : "จัดการบัญชีเวลา"
 
@@ -358,6 +373,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 
 
 
+
+
 , "Timesheet"
 : "ตารางเวลา"
 
