@@ -263,6 +263,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -272,11 +275,26 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : "Tài khoản thời gian (số - tiêu đề)"
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : "Có thể trả"
 
-, "Cleared"
-: "Đã xóa"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
+: ""
 
 , "Date"
 : "Ngày"
@@ -302,21 +320,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: "Tài khoản thời gian đã đóng"
-
 , "Timetracker"
 : "Bộ đếm thời gian"
 
-, "Timeaccounts to bill"
-: "Tài khoản thời gian cần thanh toán"
-
-, "Timeaccounts not yet billed"
-: "Tài khoản thời gian chưa thanh toán"
-
-, "Timeaccounts already billed"
-: "Tài khoản thời gian đã thanh toán"
-
 , "My Timesheets today"
 : "Chấm công hôm nay của tôi"
 
@@ -332,6 +338,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : "Chấm công tháng trước của tôi"
 
+, "Timeaccounts to bill"
+: "Tài khoản thời gian cần thanh toán"
+
+, "Timeaccounts not yet billed"
+: "Tài khoản thời gian chưa thanh toán"
+
+, "Timeaccounts already billed"
+: "Tài khoản thời gian đã thanh toán"
+
 , "Manage timeaccounts"
 : "Quản lý tài khoản thời gian"
 
@@ -358,6 +373,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 
 
 
+
+
 , "Timesheet"
 : "one: Thời gian"
 
