@@ -263,6 +263,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Accounting time factor"
 : ""
 
+, "Stream"
+: ""
+
 , "hour"
 : ""
 
@@ -272,10 +275,25 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Time Account (Number - Title)"
 : ""
 
+, "Project time billable"
+: ""
+
+, "Project time billable (combined)"
+: ""
+
 , "Billable"
 : ""
 
-, "Cleared"
+, "Project time cleared in"
+: ""
+
+, "Project time Invoice"
+: ""
+
+, "Project time is cleared"
+: ""
+
+, "Projecttime cleared (combined)"
 : ""
 
 , "Date"
@@ -302,21 +320,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "Workingtime cleared in"
 : ""
 
-, "Time Account closed"
-: ""
-
 , "Timetracker"
 : ""
 
-, "Timeaccounts to bill"
-: ""
-
-, "Timeaccounts not yet billed"
-: ""
-
-, "Timeaccounts already billed"
-: ""
-
 , "My Timesheets today"
 : ""
 
@@ -332,6 +338,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
 , "My Timesheets last month"
 : ""
 
+, "Timeaccounts to bill"
+: ""
+
+, "Timeaccounts not yet billed"
+: ""
+
+, "Timeaccounts already billed"
+: ""
+
 , "Manage timeaccounts"
 : ""
 
